/// <reference types="node" />
import { OAuth2Client, JWT, Compute, UserRefreshClient, BaseExternalAccountClient, GaxiosPromise, GoogleConfigurable, MethodOptions, StreamMethodOptions, GlobalOptions, GoogleAuth, BodyResponseCallback, APIRequestContext } from 'googleapis-common';
import { Readable } from 'stream';
export declare namespace aiplatform_v1 {
    export interface Options extends GlobalOptions {
        version: 'v1';
    }
    interface StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient | BaseExternalAccountClient | GoogleAuth;
        /**
         * V1 error format.
         */
        '$.xgafv'?: string;
        /**
         * OAuth access token.
         */
        access_token?: string;
        /**
         * Data format for response.
         */
        alt?: string;
        /**
         * JSONP
         */
        callback?: string;
        /**
         * Selector specifying which fields to include in a partial response.
         */
        fields?: string;
        /**
         * API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
         */
        key?: string;
        /**
         * OAuth 2.0 token for the current user.
         */
        oauth_token?: string;
        /**
         * Returns response with indentations and line breaks.
         */
        prettyPrint?: boolean;
        /**
         * Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
         */
        quotaUser?: string;
        /**
         * Legacy upload protocol for media (e.g. "media", "multipart").
         */
        uploadType?: string;
        /**
         * Upload protocol for media (e.g. "raw", "multipart").
         */
        upload_protocol?: string;
    }
    /**
     * Vertex AI API
     *
     * Train high-quality custom machine learning models with minimal machine learning expertise and effort.
     *
     * @example
     * ```js
     * const {google} = require('googleapis');
     * const aiplatform = google.aiplatform('v1');
     * ```
     */
    export class Aiplatform {
        context: APIRequestContext;
        projects: Resource$Projects;
        publishers: Resource$Publishers;
        constructor(options: GlobalOptions, google?: GoogleConfigurable);
    }
    /**
     * Message that represents an arbitrary HTTP body. It should only be used for payload formats that can't be represented as JSON, such as raw binary or an HTML page. This message can be used both in streaming and non-streaming API methods in the request as well as the response. It can be used as a top-level request field, which is convenient if one wants to extract parameters from either the URL or HTTP template into the request fields and also want access to the raw HTTP body. Example: message GetResourceRequest { // A unique request id. string request_id = 1; // The raw HTTP body is bound to this field. google.api.HttpBody http_body = 2; \} service ResourceService { rpc GetResource(GetResourceRequest) returns (google.api.HttpBody); rpc UpdateResource(google.api.HttpBody) returns (google.protobuf.Empty); \} Example with streaming methods: service CaldavService { rpc GetCalendar(stream google.api.HttpBody) returns (stream google.api.HttpBody); rpc UpdateCalendar(stream google.api.HttpBody) returns (stream google.api.HttpBody); \} Use of this type only changes how the request and response bodies are handled, all other features will continue to work unchanged.
     */
    export interface Schema$GoogleApiHttpBody {
        /**
         * The HTTP Content-Type header value specifying the content type of the body.
         */
        contentType?: string | null;
        /**
         * The HTTP request/response body as raw binary.
         */
        data?: string | null;
        /**
         * Application specific response metadata. Must be set in the first response for streaming APIs.
         */
        extensions?: Array<{
            [key: string]: any;
        }> | null;
    }
    /**
     * Parameters that configure the active learning pipeline. Active learning will label the data incrementally by several iterations. For every iteration, it will select a batch of data based on the sampling strategy.
     */
    export interface Schema$GoogleCloudAiplatformV1ActiveLearningConfig {
        /**
         * Max number of human labeled DataItems.
         */
        maxDataItemCount?: string | null;
        /**
         * Max percent of total DataItems for human labeling.
         */
        maxDataItemPercentage?: number | null;
        /**
         * Active learning data sampling config. For every active learning labeling iteration, it will select a batch of data based on the sampling strategy.
         */
        sampleConfig?: Schema$GoogleCloudAiplatformV1SampleConfig;
        /**
         * CMLE training config. For every active learning labeling iteration, system will train a machine learning model on CMLE. The trained model will be used by data sampling algorithm to select DataItems.
         */
        trainingConfig?: Schema$GoogleCloudAiplatformV1TrainingConfig;
    }
    /**
     * Request message for MetadataService.AddContextArtifactsAndExecutions.
     */
    export interface Schema$GoogleCloudAiplatformV1AddContextArtifactsAndExecutionsRequest {
        /**
         * The resource names of the Artifacts to attribute to the Context. Format: `projects/{project\}/locations/{location\}/metadataStores/{metadatastore\}/artifacts/{artifact\}`
         */
        artifacts?: string[] | null;
        /**
         * The resource names of the Executions to associate with the Context. Format: `projects/{project\}/locations/{location\}/metadataStores/{metadatastore\}/executions/{execution\}`
         */
        executions?: string[] | null;
    }
    /**
     * Response message for MetadataService.AddContextArtifactsAndExecutions.
     */
    export interface Schema$GoogleCloudAiplatformV1AddContextArtifactsAndExecutionsResponse {
    }
    /**
     * Request message for MetadataService.AddContextChildren.
     */
    export interface Schema$GoogleCloudAiplatformV1AddContextChildrenRequest {
        /**
         * The resource names of the child Contexts.
         */
        childContexts?: string[] | null;
    }
    /**
     * Response message for MetadataService.AddContextChildren.
     */
    export interface Schema$GoogleCloudAiplatformV1AddContextChildrenResponse {
    }
    /**
     * Request message for MetadataService.AddExecutionEvents.
     */
    export interface Schema$GoogleCloudAiplatformV1AddExecutionEventsRequest {
        /**
         * The Events to create and add.
         */
        events?: Schema$GoogleCloudAiplatformV1Event[];
    }
    /**
     * Response message for MetadataService.AddExecutionEvents.
     */
    export interface Schema$GoogleCloudAiplatformV1AddExecutionEventsResponse {
    }
    /**
     * Request message for VizierService.AddTrialMeasurement.
     */
    export interface Schema$GoogleCloudAiplatformV1AddTrialMeasurementRequest {
        /**
         * Required. The measurement to be added to a Trial.
         */
        measurement?: Schema$GoogleCloudAiplatformV1Measurement;
    }
    /**
     * Used to assign specific AnnotationSpec to a particular area of a DataItem or the whole part of the DataItem.
     */
    export interface Schema$GoogleCloudAiplatformV1Annotation {
        /**
         * Output only. The source of the Annotation.
         */
        annotationSource?: Schema$GoogleCloudAiplatformV1UserActionReference;
        /**
         * Output only. Timestamp when this Annotation was created.
         */
        createTime?: string | null;
        /**
         * Optional. Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens.
         */
        etag?: string | null;
        /**
         * Optional. The labels with user-defined metadata to organize your Annotations. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. No more than 64 user labels can be associated with one Annotation(System labels are excluded). See https://goo.gl/xmQnxf for more information and examples of labels. System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Following system labels exist for each Annotation: * "aiplatform.googleapis.com/annotation_set_name": optional, name of the UI's annotation set this Annotation belongs to. If not set, the Annotation is not visible in the UI. * "aiplatform.googleapis.com/payload_schema": output only, its value is the payload_schema's title.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * Output only. Resource name of the Annotation.
         */
        name?: string | null;
        /**
         * Required. The schema of the payload can be found in payload_schema.
         */
        payload?: any | null;
        /**
         * Required. Google Cloud Storage URI points to a YAML file describing payload. The schema is defined as an [OpenAPI 3.0.2 Schema Object](https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.0.2.md#schemaObject). The schema files that can be used here are found in gs://google-cloud-aiplatform/schema/dataset/annotation/, note that the chosen schema must be consistent with the parent Dataset's metadata.
         */
        payloadSchemaUri?: string | null;
        /**
         * Output only. Timestamp when this Annotation was last updated.
         */
        updateTime?: string | null;
    }
    /**
     * Identifies a concept with which DataItems may be annotated with.
     */
    export interface Schema$GoogleCloudAiplatformV1AnnotationSpec {
        /**
         * Output only. Timestamp when this AnnotationSpec was created.
         */
        createTime?: string | null;
        /**
         * Required. The user-defined name of the AnnotationSpec. The name can be up to 128 characters long and can consist of any UTF-8 characters.
         */
        displayName?: string | null;
        /**
         * Optional. Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens.
         */
        etag?: string | null;
        /**
         * Output only. Resource name of the AnnotationSpec.
         */
        name?: string | null;
        /**
         * Output only. Timestamp when AnnotationSpec was last updated.
         */
        updateTime?: string | null;
    }
    /**
     * Instance of a general artifact.
     */
    export interface Schema$GoogleCloudAiplatformV1Artifact {
        /**
         * Output only. Timestamp when this Artifact was created.
         */
        createTime?: string | null;
        /**
         * Description of the Artifact
         */
        description?: string | null;
        /**
         * User provided display name of the Artifact. May be up to 128 Unicode characters.
         */
        displayName?: string | null;
        /**
         * An eTag used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens.
         */
        etag?: string | null;
        /**
         * The labels with user-defined metadata to organize your Artifacts. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. No more than 64 user labels can be associated with one Artifact (System labels are excluded).
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * Properties of the Artifact. Top level metadata keys' heading and trailing spaces will be trimmed. The size of this field should not exceed 200KB.
         */
        metadata?: {
            [key: string]: any;
        } | null;
        /**
         * Output only. The resource name of the Artifact.
         */
        name?: string | null;
        /**
         * The title of the schema describing the metadata. Schema title and version is expected to be registered in earlier Create Schema calls. And both are used together as unique identifiers to identify schemas within the local metadata store.
         */
        schemaTitle?: string | null;
        /**
         * The version of the schema in schema_name to use. Schema title and version is expected to be registered in earlier Create Schema calls. And both are used together as unique identifiers to identify schemas within the local metadata store.
         */
        schemaVersion?: string | null;
        /**
         * The state of this Artifact. This is a property of the Artifact, and does not imply or capture any ongoing process. This property is managed by clients (such as Vertex AI Pipelines), and the system does not prescribe or check the validity of state transitions.
         */
        state?: string | null;
        /**
         * Output only. Timestamp when this Artifact was last updated.
         */
        updateTime?: string | null;
        /**
         * The uniform resource identifier of the artifact file. May be empty if there is no actual artifact file.
         */
        uri?: string | null;
    }
    /**
     * Metadata information for NotebookService.AssignNotebookRuntime.
     */
    export interface Schema$GoogleCloudAiplatformV1AssignNotebookRuntimeOperationMetadata {
        /**
         * The operation generic information.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
        /**
         * A human-readable message that shows the intermediate progress details of NotebookRuntime.
         */
        progressMessage?: string | null;
    }
    /**
     * Request message for NotebookService.AssignNotebookRuntime.
     */
    export interface Schema$GoogleCloudAiplatformV1AssignNotebookRuntimeRequest {
        /**
         * Required. Provide runtime specific information (e.g. runtime owner, notebook id) used for NotebookRuntime assignment.
         */
        notebookRuntime?: Schema$GoogleCloudAiplatformV1NotebookRuntime;
        /**
         * Optional. User specified ID for the notebook runtime.
         */
        notebookRuntimeId?: string | null;
        /**
         * Required. The resource name of the NotebookRuntimeTemplate based on which a NotebookRuntime will be assigned (reuse or create a new one).
         */
        notebookRuntimeTemplate?: string | null;
    }
    /**
     * Attribution that explains a particular prediction output.
     */
    export interface Schema$GoogleCloudAiplatformV1Attribution {
        /**
         * Output only. Error of feature_attributions caused by approximation used in the explanation method. Lower value means more precise attributions. * For Sampled Shapley attribution, increasing path_count might reduce the error. * For Integrated Gradients attribution, increasing step_count might reduce the error. * For XRAI attribution, increasing step_count might reduce the error. See [this introduction](/vertex-ai/docs/explainable-ai/overview) for more information.
         */
        approximationError?: number | null;
        /**
         * Output only. Model predicted output if the input instance is constructed from the baselines of all the features defined in ExplanationMetadata.inputs. The field name of the output is determined by the key in ExplanationMetadata.outputs. If the Model's predicted output has multiple dimensions (rank \> 1), this is the value in the output located by output_index. If there are multiple baselines, their output values are averaged.
         */
        baselineOutputValue?: number | null;
        /**
         * Output only. Attributions of each explained feature. Features are extracted from the prediction instances according to explanation metadata for inputs. The value is a struct, whose keys are the name of the feature. The values are how much the feature in the instance contributed to the predicted result. The format of the value is determined by the feature's input format: * If the feature is a scalar value, the attribution value is a floating number. * If the feature is an array of scalar values, the attribution value is an array. * If the feature is a struct, the attribution value is a struct. The keys in the attribution value struct are the same as the keys in the feature struct. The formats of the values in the attribution struct are determined by the formats of the values in the feature struct. The ExplanationMetadata.feature_attributions_schema_uri field, pointed to by the ExplanationSpec field of the Endpoint.deployed_models object, points to the schema file that describes the features and their attribution values (if it is populated).
         */
        featureAttributions?: any | null;
        /**
         * Output only. Model predicted output on the corresponding explanation instance. The field name of the output is determined by the key in ExplanationMetadata.outputs. If the Model predicted output has multiple dimensions, this is the value in the output located by output_index.
         */
        instanceOutputValue?: number | null;
        /**
         * Output only. The display name of the output identified by output_index. For example, the predicted class name by a multi-classification Model. This field is only populated iff the Model predicts display names as a separate field along with the explained output. The predicted display name must has the same shape of the explained output, and can be located using output_index.
         */
        outputDisplayName?: string | null;
        /**
         * Output only. The index that locates the explained prediction output. If the prediction output is a scalar value, output_index is not populated. If the prediction output has multiple dimensions, the length of the output_index list is the same as the number of dimensions of the output. The i-th element in output_index is the element index of the i-th dimension of the output vector. Indices start from 0.
         */
        outputIndex?: number[] | null;
        /**
         * Output only. Name of the explain output. Specified as the key in ExplanationMetadata.outputs.
         */
        outputName?: string | null;
    }
    /**
     * A description of resources that to large degree are decided by Vertex AI, and require only a modest additional configuration. Each Model supporting these resources documents its specific guidelines.
     */
    export interface Schema$GoogleCloudAiplatformV1AutomaticResources {
        /**
         * Immutable. The maximum number of replicas this DeployedModel may be deployed on when the traffic against it increases. If the requested value is too large, the deployment will error, but if deployment succeeds then the ability to scale the model to that many replicas is guaranteed (barring service outages). If traffic against the DeployedModel increases beyond what its replicas at maximum may handle, a portion of the traffic will be dropped. If this value is not provided, a no upper bound for scaling under heavy traffic will be assume, though Vertex AI may be unable to scale beyond certain replica number.
         */
        maxReplicaCount?: number | null;
        /**
         * Immutable. The minimum number of replicas this DeployedModel will be always deployed on. If traffic against it increases, it may dynamically be deployed onto more replicas up to max_replica_count, and as traffic decreases, some of these extra replicas may be freed. If the requested value is too large, the deployment will error.
         */
        minReplicaCount?: number | null;
    }
    /**
     * The metric specification that defines the target resource utilization (CPU utilization, accelerator's duty cycle, and so on) for calculating the desired replica count.
     */
    export interface Schema$GoogleCloudAiplatformV1AutoscalingMetricSpec {
        /**
         * Required. The resource metric name. Supported metrics: * For Online Prediction: * `aiplatform.googleapis.com/prediction/online/accelerator/duty_cycle` * `aiplatform.googleapis.com/prediction/online/cpu/utilization`
         */
        metricName?: string | null;
        /**
         * The target resource utilization in percentage (1% - 100%) for the given metric; once the real usage deviates from the target by a certain percentage, the machine replicas change. The default value is 60 (representing 60%) if not provided.
         */
        target?: number | null;
    }
    /**
     * The storage details for Avro input content.
     */
    export interface Schema$GoogleCloudAiplatformV1AvroSource {
        /**
         * Required. Google Cloud Storage location.
         */
        gcsSource?: Schema$GoogleCloudAiplatformV1GcsSource;
    }
    /**
     * Details of operations that perform batch create Features.
     */
    export interface Schema$GoogleCloudAiplatformV1BatchCreateFeaturesOperationMetadata {
        /**
         * Operation metadata for Feature.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
    }
    /**
     * Request message for FeaturestoreService.BatchCreateFeatures.
     */
    export interface Schema$GoogleCloudAiplatformV1BatchCreateFeaturesRequest {
        /**
         * Required. The request message specifying the Features to create. All Features must be created under the same parent EntityType. The `parent` field in each child request message can be omitted. If `parent` is set in a child request, then the value must match the `parent` value in this request message.
         */
        requests?: Schema$GoogleCloudAiplatformV1CreateFeatureRequest[];
    }
    /**
     * Response message for FeaturestoreService.BatchCreateFeatures.
     */
    export interface Schema$GoogleCloudAiplatformV1BatchCreateFeaturesResponse {
        /**
         * The Features created.
         */
        features?: Schema$GoogleCloudAiplatformV1Feature[];
    }
    /**
     * Request message for TensorboardService.BatchCreateTensorboardRuns.
     */
    export interface Schema$GoogleCloudAiplatformV1BatchCreateTensorboardRunsRequest {
        /**
         * Required. The request message specifying the TensorboardRuns to create. A maximum of 1000 TensorboardRuns can be created in a batch.
         */
        requests?: Schema$GoogleCloudAiplatformV1CreateTensorboardRunRequest[];
    }
    /**
     * Response message for TensorboardService.BatchCreateTensorboardRuns.
     */
    export interface Schema$GoogleCloudAiplatformV1BatchCreateTensorboardRunsResponse {
        /**
         * The created TensorboardRuns.
         */
        tensorboardRuns?: Schema$GoogleCloudAiplatformV1TensorboardRun[];
    }
    /**
     * Request message for TensorboardService.BatchCreateTensorboardTimeSeries.
     */
    export interface Schema$GoogleCloudAiplatformV1BatchCreateTensorboardTimeSeriesRequest {
        /**
         * Required. The request message specifying the TensorboardTimeSeries to create. A maximum of 1000 TensorboardTimeSeries can be created in a batch.
         */
        requests?: Schema$GoogleCloudAiplatformV1CreateTensorboardTimeSeriesRequest[];
    }
    /**
     * Response message for TensorboardService.BatchCreateTensorboardTimeSeries.
     */
    export interface Schema$GoogleCloudAiplatformV1BatchCreateTensorboardTimeSeriesResponse {
        /**
         * The created TensorboardTimeSeries.
         */
        tensorboardTimeSeries?: Schema$GoogleCloudAiplatformV1TensorboardTimeSeries[];
    }
    /**
     * A description of resources that are used for performing batch operations, are dedicated to a Model, and need manual configuration.
     */
    export interface Schema$GoogleCloudAiplatformV1BatchDedicatedResources {
        /**
         * Required. Immutable. The specification of a single machine.
         */
        machineSpec?: Schema$GoogleCloudAiplatformV1MachineSpec;
        /**
         * Immutable. The maximum number of machine replicas the batch operation may be scaled to. The default value is 10.
         */
        maxReplicaCount?: number | null;
        /**
         * Immutable. The number of machine replicas used at the start of the batch operation. If not set, Vertex AI decides starting number, not greater than max_replica_count
         */
        startingReplicaCount?: number | null;
    }
    /**
     * Request message for ModelService.BatchImportEvaluatedAnnotations
     */
    export interface Schema$GoogleCloudAiplatformV1BatchImportEvaluatedAnnotationsRequest {
        /**
         * Required. Evaluated annotations resource to be imported.
         */
        evaluatedAnnotations?: Schema$GoogleCloudAiplatformV1EvaluatedAnnotation[];
    }
    /**
     * Response message for ModelService.BatchImportEvaluatedAnnotations
     */
    export interface Schema$GoogleCloudAiplatformV1BatchImportEvaluatedAnnotationsResponse {
        /**
         * Output only. Number of EvaluatedAnnotations imported.
         */
        importedEvaluatedAnnotationsCount?: number | null;
    }
    /**
     * Request message for ModelService.BatchImportModelEvaluationSlices
     */
    export interface Schema$GoogleCloudAiplatformV1BatchImportModelEvaluationSlicesRequest {
        /**
         * Required. Model evaluation slice resource to be imported.
         */
        modelEvaluationSlices?: Schema$GoogleCloudAiplatformV1ModelEvaluationSlice[];
    }
    /**
     * Response message for ModelService.BatchImportModelEvaluationSlices
     */
    export interface Schema$GoogleCloudAiplatformV1BatchImportModelEvaluationSlicesResponse {
        /**
         * Output only. List of imported ModelEvaluationSlice.name.
         */
        importedModelEvaluationSlices?: string[] | null;
    }
    /**
     * Runtime operation information for MigrationService.BatchMigrateResources.
     */
    export interface Schema$GoogleCloudAiplatformV1BatchMigrateResourcesOperationMetadata {
        /**
         * The common part of the operation metadata.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
        /**
         * Partial results that reflect the latest migration operation progress.
         */
        partialResults?: Schema$GoogleCloudAiplatformV1BatchMigrateResourcesOperationMetadataPartialResult[];
    }
    /**
     * Represents a partial result in batch migration operation for one MigrateResourceRequest.
     */
    export interface Schema$GoogleCloudAiplatformV1BatchMigrateResourcesOperationMetadataPartialResult {
        /**
         * Migrated dataset resource name.
         */
        dataset?: string | null;
        /**
         * The error result of the migration request in case of failure.
         */
        error?: Schema$GoogleRpcStatus;
        /**
         * Migrated model resource name.
         */
        model?: string | null;
        /**
         * It's the same as the value in MigrateResourceRequest.migrate_resource_requests.
         */
        request?: Schema$GoogleCloudAiplatformV1MigrateResourceRequest;
    }
    /**
     * Request message for MigrationService.BatchMigrateResources.
     */
    export interface Schema$GoogleCloudAiplatformV1BatchMigrateResourcesRequest {
        /**
         * Required. The request messages specifying the resources to migrate. They must be in the same location as the destination. Up to 50 resources can be migrated in one batch.
         */
        migrateResourceRequests?: Schema$GoogleCloudAiplatformV1MigrateResourceRequest[];
    }
    /**
     * Response message for MigrationService.BatchMigrateResources.
     */
    export interface Schema$GoogleCloudAiplatformV1BatchMigrateResourcesResponse {
        /**
         * Successfully migrated resources.
         */
        migrateResourceResponses?: Schema$GoogleCloudAiplatformV1MigrateResourceResponse[];
    }
    /**
     * A job that uses a Model to produce predictions on multiple input instances. If predictions for significant portion of the instances fail, the job may finish without attempting predictions for all remaining instances.
     */
    export interface Schema$GoogleCloudAiplatformV1BatchPredictionJob {
        /**
         * Output only. Statistics on completed and failed prediction instances.
         */
        completionStats?: Schema$GoogleCloudAiplatformV1CompletionStats;
        /**
         * Output only. Time when the BatchPredictionJob was created.
         */
        createTime?: string | null;
        /**
         * The config of resources used by the Model during the batch prediction. If the Model supports DEDICATED_RESOURCES this config may be provided (and the job will use these resources), if the Model doesn't support AUTOMATIC_RESOURCES, this config must be provided.
         */
        dedicatedResources?: Schema$GoogleCloudAiplatformV1BatchDedicatedResources;
        /**
         * For custom-trained Models and AutoML Tabular Models, the container of the DeployedModel instances will send `stderr` and `stdout` streams to Cloud Logging by default. Please note that the logs incur cost, which are subject to [Cloud Logging pricing](https://cloud.google.com/logging/pricing). User can disable container logging by setting this flag to true.
         */
        disableContainerLogging?: boolean | null;
        /**
         * Required. The user-defined name of this BatchPredictionJob.
         */
        displayName?: string | null;
        /**
         * Customer-managed encryption key options for a BatchPredictionJob. If this is set, then all resources created by the BatchPredictionJob will be encrypted with the provided encryption key.
         */
        encryptionSpec?: Schema$GoogleCloudAiplatformV1EncryptionSpec;
        /**
         * Output only. Time when the BatchPredictionJob entered any of the following states: `JOB_STATE_SUCCEEDED`, `JOB_STATE_FAILED`, `JOB_STATE_CANCELLED`.
         */
        endTime?: string | null;
        /**
         * Output only. Only populated when the job's state is JOB_STATE_FAILED or JOB_STATE_CANCELLED.
         */
        error?: Schema$GoogleRpcStatus;
        /**
         * Explanation configuration for this BatchPredictionJob. Can be specified only if generate_explanation is set to `true`. This value overrides the value of Model.explanation_spec. All fields of explanation_spec are optional in the request. If a field of the explanation_spec object is not populated, the corresponding field of the Model.explanation_spec object is inherited.
         */
        explanationSpec?: Schema$GoogleCloudAiplatformV1ExplanationSpec;
        /**
         * Generate explanation with the batch prediction results. When set to `true`, the batch prediction output changes based on the `predictions_format` field of the BatchPredictionJob.output_config object: * `bigquery`: output includes a column named `explanation`. The value is a struct that conforms to the Explanation object. * `jsonl`: The JSON objects on each line include an additional entry keyed `explanation`. The value of the entry is a JSON object that conforms to the Explanation object. * `csv`: Generating explanations for CSV format is not supported. If this field is set to true, either the Model.explanation_spec or explanation_spec must be populated.
         */
        generateExplanation?: boolean | null;
        /**
         * Required. Input configuration of the instances on which predictions are performed. The schema of any single instance may be specified via the Model's PredictSchemata's instance_schema_uri.
         */
        inputConfig?: Schema$GoogleCloudAiplatformV1BatchPredictionJobInputConfig;
        /**
         * Configuration for how to convert batch prediction input instances to the prediction instances that are sent to the Model.
         */
        instanceConfig?: Schema$GoogleCloudAiplatformV1BatchPredictionJobInstanceConfig;
        /**
         * The labels with user-defined metadata to organize BatchPredictionJobs. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * Immutable. Parameters configuring the batch behavior. Currently only applicable when dedicated_resources are used (in other cases Vertex AI does the tuning itself).
         */
        manualBatchTuningParameters?: Schema$GoogleCloudAiplatformV1ManualBatchTuningParameters;
        /**
         * The name of the Model resource that produces the predictions via this job, must share the same ancestor Location. Starting this job has no impact on any existing deployments of the Model and their resources. Exactly one of model and unmanaged_container_model must be set. The model resource name may contain version id or version alias to specify the version. Example: `projects/{project\}/locations/{location\}/models/{model\}@2` or `projects/{project\}/locations/{location\}/models/{model\}@golden` if no version is specified, the default version will be deployed. The model resource could also be a publisher model. Example: `publishers/{publisher\}/models/{model\}` or `projects/{project\}/locations/{location\}/publishers/{publisher\}/models/{model\}`
         */
        model?: string | null;
        /**
         * The parameters that govern the predictions. The schema of the parameters may be specified via the Model's PredictSchemata's parameters_schema_uri.
         */
        modelParameters?: any | null;
        /**
         * Output only. The version ID of the Model that produces the predictions via this job.
         */
        modelVersionId?: string | null;
        /**
         * Output only. Resource name of the BatchPredictionJob.
         */
        name?: string | null;
        /**
         * Required. The Configuration specifying where output predictions should be written. The schema of any single prediction may be specified as a concatenation of Model's PredictSchemata's instance_schema_uri and prediction_schema_uri.
         */
        outputConfig?: Schema$GoogleCloudAiplatformV1BatchPredictionJobOutputConfig;
        /**
         * Output only. Information further describing the output of this job.
         */
        outputInfo?: Schema$GoogleCloudAiplatformV1BatchPredictionJobOutputInfo;
        /**
         * Output only. Partial failures encountered. For example, single files that can't be read. This field never exceeds 20 entries. Status details fields contain standard Google Cloud error details.
         */
        partialFailures?: Schema$GoogleRpcStatus[];
        /**
         * Output only. Information about resources that had been consumed by this job. Provided in real time at best effort basis, as well as a final value once the job completes. Note: This field currently may be not populated for batch predictions that use AutoML Models.
         */
        resourcesConsumed?: Schema$GoogleCloudAiplatformV1ResourcesConsumed;
        /**
         * The service account that the DeployedModel's container runs as. If not specified, a system generated one will be used, which has minimal permissions and the custom container, if used, may not have enough permission to access other Google Cloud resources. Users deploying the Model must have the `iam.serviceAccounts.actAs` permission on this service account.
         */
        serviceAccount?: string | null;
        /**
         * Output only. Time when the BatchPredictionJob for the first time entered the `JOB_STATE_RUNNING` state.
         */
        startTime?: string | null;
        /**
         * Output only. The detailed state of the job.
         */
        state?: string | null;
        /**
         * Contains model information necessary to perform batch prediction without requiring uploading to model registry. Exactly one of model and unmanaged_container_model must be set.
         */
        unmanagedContainerModel?: Schema$GoogleCloudAiplatformV1UnmanagedContainerModel;
        /**
         * Output only. Time when the BatchPredictionJob was most recently updated.
         */
        updateTime?: string | null;
    }
    /**
     * Configures the input to BatchPredictionJob. See Model.supported_input_storage_formats for Model's supported input formats, and how instances should be expressed via any of them.
     */
    export interface Schema$GoogleCloudAiplatformV1BatchPredictionJobInputConfig {
        /**
         * The BigQuery location of the input table. The schema of the table should be in the format described by the given context OpenAPI Schema, if one is provided. The table may contain additional columns that are not described by the schema, and they will be ignored.
         */
        bigquerySource?: Schema$GoogleCloudAiplatformV1BigQuerySource;
        /**
         * The Cloud Storage location for the input instances.
         */
        gcsSource?: Schema$GoogleCloudAiplatformV1GcsSource;
        /**
         * Required. The format in which instances are given, must be one of the Model's supported_input_storage_formats.
         */
        instancesFormat?: string | null;
    }
    /**
     * Configuration defining how to transform batch prediction input instances to the instances that the Model accepts.
     */
    export interface Schema$GoogleCloudAiplatformV1BatchPredictionJobInstanceConfig {
        /**
         * Fields that will be excluded in the prediction instance that is sent to the Model. Excluded will be attached to the batch prediction output if key_field is not specified. When excluded_fields is populated, included_fields must be empty. The input must be JSONL with objects at each line, CSV, BigQuery or TfRecord.
         */
        excludedFields?: string[] | null;
        /**
         * Fields that will be included in the prediction instance that is sent to the Model. If instance_type is `array`, the order of field names in included_fields also determines the order of the values in the array. When included_fields is populated, excluded_fields must be empty. The input must be JSONL with objects at each line, CSV, BigQuery or TfRecord.
         */
        includedFields?: string[] | null;
        /**
         * The format of the instance that the Model accepts. Vertex AI will convert compatible batch prediction input instance formats to the specified format. Supported values are: * `object`: Each input is converted to JSON object format. * For `bigquery`, each row is converted to an object. * For `jsonl`, each line of the JSONL input must be an object. * Does not apply to `csv`, `file-list`, `tf-record`, or `tf-record-gzip`. * `array`: Each input is converted to JSON array format. * For `bigquery`, each row is converted to an array. The order of columns is determined by the BigQuery column order, unless included_fields is populated. included_fields must be populated for specifying field orders. * For `jsonl`, if each line of the JSONL input is an object, included_fields must be populated for specifying field orders. * Does not apply to `csv`, `file-list`, `tf-record`, or `tf-record-gzip`. If not specified, Vertex AI converts the batch prediction input as follows: * For `bigquery` and `csv`, the behavior is the same as `array`. The order of columns is the same as defined in the file or table, unless included_fields is populated. * For `jsonl`, the prediction instance format is determined by each line of the input. * For `tf-record`/`tf-record-gzip`, each record will be converted to an object in the format of `{"b64": \}`, where `` is the Base64-encoded string of the content of the record. * For `file-list`, each file in the list will be converted to an object in the format of `{"b64": \}`, where `` is the Base64-encoded string of the content of the file.
         */
        instanceType?: string | null;
        /**
         * The name of the field that is considered as a key. The values identified by the key field is not included in the transformed instances that is sent to the Model. This is similar to specifying this name of the field in excluded_fields. In addition, the batch prediction output will not include the instances. Instead the output will only include the value of the key field, in a field named `key` in the output: * For `jsonl` output format, the output will have a `key` field instead of the `instance` field. * For `csv`/`bigquery` output format, the output will have have a `key` column instead of the instance feature columns. The input must be JSONL with objects at each line, CSV, BigQuery or TfRecord.
         */
        keyField?: string | null;
    }
    /**
     * Configures the output of BatchPredictionJob. See Model.supported_output_storage_formats for supported output formats, and how predictions are expressed via any of them.
     */
    export interface Schema$GoogleCloudAiplatformV1BatchPredictionJobOutputConfig {
        /**
         * The BigQuery project or dataset location where the output is to be written to. If project is provided, a new dataset is created with name `prediction__` where is made BigQuery-dataset-name compatible (for example, most special characters become underscores), and timestamp is in YYYY_MM_DDThh_mm_ss_sssZ "based on ISO-8601" format. In the dataset two tables will be created, `predictions`, and `errors`. If the Model has both instance and prediction schemata defined then the tables have columns as follows: The `predictions` table contains instances for which the prediction succeeded, it has columns as per a concatenation of the Model's instance and prediction schemata. The `errors` table contains rows for which the prediction has failed, it has instance columns, as per the instance schema, followed by a single "errors" column, which as values has google.rpc.Status represented as a STRUCT, and containing only `code` and `message`.
         */
        bigqueryDestination?: Schema$GoogleCloudAiplatformV1BigQueryDestination;
        /**
         * The Cloud Storage location of the directory where the output is to be written to. In the given directory a new directory is created. Its name is `prediction--`, where timestamp is in YYYY-MM-DDThh:mm:ss.sssZ ISO-8601 format. Inside of it files `predictions_0001.`, `predictions_0002.`, ..., `predictions_N.` are created where `` depends on chosen predictions_format, and N may equal 0001 and depends on the total number of successfully predicted instances. If the Model has both instance and prediction schemata defined then each such file contains predictions as per the predictions_format. If prediction for any instance failed (partially or completely), then an additional `errors_0001.`, `errors_0002.`,..., `errors_N.` files are created (N depends on total number of failed predictions). These files contain the failed instances, as per their schema, followed by an additional `error` field which as value has google.rpc.Status containing only `code` and `message` fields.
         */
        gcsDestination?: Schema$GoogleCloudAiplatformV1GcsDestination;
        /**
         * Required. The format in which Vertex AI gives the predictions, must be one of the Model's supported_output_storage_formats.
         */
        predictionsFormat?: string | null;
    }
    /**
     * Further describes this job's output. Supplements output_config.
     */
    export interface Schema$GoogleCloudAiplatformV1BatchPredictionJobOutputInfo {
        /**
         * Output only. The path of the BigQuery dataset created, in `bq://projectId.bqDatasetId` format, into which the prediction output is written.
         */
        bigqueryOutputDataset?: string | null;
        /**
         * Output only. The name of the BigQuery table created, in `predictions_` format, into which the prediction output is written. Can be used by UI to generate the BigQuery output path, for example.
         */
        bigqueryOutputTable?: string | null;
        /**
         * Output only. The full path of the Cloud Storage directory created, into which the prediction output is written.
         */
        gcsOutputDirectory?: string | null;
    }
    /**
     * Details of operations that batch reads Feature values.
     */
    export interface Schema$GoogleCloudAiplatformV1BatchReadFeatureValuesOperationMetadata {
        /**
         * Operation metadata for Featurestore batch read Features values.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
    }
    /**
     * Request message for FeaturestoreService.BatchReadFeatureValues.
     */
    export interface Schema$GoogleCloudAiplatformV1BatchReadFeatureValuesRequest {
        /**
         * Similar to csv_read_instances, but from BigQuery source.
         */
        bigqueryReadInstances?: Schema$GoogleCloudAiplatformV1BigQuerySource;
        /**
         * Each read instance consists of exactly one read timestamp and one or more entity IDs identifying entities of the corresponding EntityTypes whose Features are requested. Each output instance contains Feature values of requested entities concatenated together as of the read time. An example read instance may be `foo_entity_id, bar_entity_id, 2020-01-01T10:00:00.123Z`. An example output instance may be `foo_entity_id, bar_entity_id, 2020-01-01T10:00:00.123Z, foo_entity_feature1_value, bar_entity_feature2_value`. Timestamp in each read instance must be millisecond-aligned. `csv_read_instances` are read instances stored in a plain-text CSV file. The header should be: [ENTITY_TYPE_ID1], [ENTITY_TYPE_ID2], ..., timestamp The columns can be in any order. Values in the timestamp column must use the RFC 3339 format, e.g. `2012-07-30T10:43:17.123Z`.
         */
        csvReadInstances?: Schema$GoogleCloudAiplatformV1CsvSource;
        /**
         * Required. Specifies output location and format.
         */
        destination?: Schema$GoogleCloudAiplatformV1FeatureValueDestination;
        /**
         * Required. Specifies EntityType grouping Features to read values of and settings.
         */
        entityTypeSpecs?: Schema$GoogleCloudAiplatformV1BatchReadFeatureValuesRequestEntityTypeSpec[];
        /**
         * When not empty, the specified fields in the *_read_instances source will be joined as-is in the output, in addition to those fields from the Featurestore Entity. For BigQuery source, the type of the pass-through values will be automatically inferred. For CSV source, the pass-through values will be passed as opaque bytes.
         */
        passThroughFields?: Schema$GoogleCloudAiplatformV1BatchReadFeatureValuesRequestPassThroughField[];
        /**
         * Optional. Excludes Feature values with feature generation timestamp before this timestamp. If not set, retrieve oldest values kept in Feature Store. Timestamp, if present, must not have higher than millisecond precision.
         */
        startTime?: string | null;
    }
    /**
     * Selects Features of an EntityType to read values of and specifies read settings.
     */
    export interface Schema$GoogleCloudAiplatformV1BatchReadFeatureValuesRequestEntityTypeSpec {
        /**
         * Required. ID of the EntityType to select Features. The EntityType id is the entity_type_id specified during EntityType creation.
         */
        entityTypeId?: string | null;
        /**
         * Required. Selectors choosing which Feature values to read from the EntityType.
         */
        featureSelector?: Schema$GoogleCloudAiplatformV1FeatureSelector;
        /**
         * Per-Feature settings for the batch read.
         */
        settings?: Schema$GoogleCloudAiplatformV1DestinationFeatureSetting[];
    }
    /**
     * Describe pass-through fields in read_instance source.
     */
    export interface Schema$GoogleCloudAiplatformV1BatchReadFeatureValuesRequestPassThroughField {
        /**
         * Required. The name of the field in the CSV header or the name of the column in BigQuery table. The naming restriction is the same as Feature.name.
         */
        fieldName?: string | null;
    }
    /**
     * Response message for FeaturestoreService.BatchReadFeatureValues.
     */
    export interface Schema$GoogleCloudAiplatformV1BatchReadFeatureValuesResponse {
    }
    /**
     * Response message for TensorboardService.BatchReadTensorboardTimeSeriesData.
     */
    export interface Schema$GoogleCloudAiplatformV1BatchReadTensorboardTimeSeriesDataResponse {
        /**
         * The returned time series data.
         */
        timeSeriesData?: Schema$GoogleCloudAiplatformV1TimeSeriesData[];
    }
    /**
     * The BigQuery location for the output content.
     */
    export interface Schema$GoogleCloudAiplatformV1BigQueryDestination {
        /**
         * Required. BigQuery URI to a project or table, up to 2000 characters long. When only the project is specified, the Dataset and Table is created. When the full table reference is specified, the Dataset must exist and table must not exist. Accepted forms: * BigQuery path. For example: `bq://projectId` or `bq://projectId.bqDatasetId` or `bq://projectId.bqDatasetId.bqTableId`.
         */
        outputUri?: string | null;
    }
    /**
     * The BigQuery location for the input content.
     */
    export interface Schema$GoogleCloudAiplatformV1BigQuerySource {
        /**
         * Required. BigQuery URI to a table, up to 2000 characters long. Accepted forms: * BigQuery path. For example: `bq://projectId.bqDatasetId.bqTableId`.
         */
        inputUri?: string | null;
    }
    /**
     * Config for blur baseline. When enabled, a linear path from the maximally blurred image to the input image is created. Using a blurred baseline instead of zero (black image) is motivated by the BlurIG approach explained here: https://arxiv.org/abs/2004.03383
     */
    export interface Schema$GoogleCloudAiplatformV1BlurBaselineConfig {
        /**
         * The standard deviation of the blur kernel for the blurred baseline. The same blurring parameter is used for both the height and the width dimension. If not set, the method defaults to the zero (i.e. black for images) baseline.
         */
        maxBlurSigma?: number | null;
    }
    /**
     * A list of boolean values.
     */
    export interface Schema$GoogleCloudAiplatformV1BoolArray {
        /**
         * A list of bool values.
         */
        values?: boolean[] | null;
    }
    /**
     * Request message for JobService.CancelBatchPredictionJob.
     */
    export interface Schema$GoogleCloudAiplatformV1CancelBatchPredictionJobRequest {
    }
    /**
     * Request message for JobService.CancelCustomJob.
     */
    export interface Schema$GoogleCloudAiplatformV1CancelCustomJobRequest {
    }
    /**
     * Request message for JobService.CancelDataLabelingJob.
     */
    export interface Schema$GoogleCloudAiplatformV1CancelDataLabelingJobRequest {
    }
    /**
     * Request message for JobService.CancelHyperparameterTuningJob.
     */
    export interface Schema$GoogleCloudAiplatformV1CancelHyperparameterTuningJobRequest {
    }
    /**
     * Request message for JobService.CancelNasJob.
     */
    export interface Schema$GoogleCloudAiplatformV1CancelNasJobRequest {
    }
    /**
     * Request message for PipelineService.CancelPipelineJob.
     */
    export interface Schema$GoogleCloudAiplatformV1CancelPipelineJobRequest {
    }
    /**
     * Request message for PipelineService.CancelTrainingPipeline.
     */
    export interface Schema$GoogleCloudAiplatformV1CancelTrainingPipelineRequest {
    }
    /**
     * This message will be placed in the metadata field of a google.longrunning.Operation associated with a CheckTrialEarlyStoppingState request.
     */
    export interface Schema$GoogleCloudAiplatformV1CheckTrialEarlyStoppingStateMetatdata {
        /**
         * Operation metadata for suggesting Trials.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
        /**
         * The name of the Study that the Trial belongs to.
         */
        study?: string | null;
        /**
         * The Trial name.
         */
        trial?: string | null;
    }
    /**
     * Request message for VizierService.CheckTrialEarlyStoppingState.
     */
    export interface Schema$GoogleCloudAiplatformV1CheckTrialEarlyStoppingStateRequest {
    }
    /**
     * Response message for VizierService.CheckTrialEarlyStoppingState.
     */
    export interface Schema$GoogleCloudAiplatformV1CheckTrialEarlyStoppingStateResponse {
        /**
         * True if the Trial should stop.
         */
        shouldStop?: boolean | null;
    }
    /**
     * Request message for VizierService.CompleteTrial.
     */
    export interface Schema$GoogleCloudAiplatformV1CompleteTrialRequest {
        /**
         * Optional. If provided, it will be used as the completed Trial's final_measurement; Otherwise, the service will auto-select a previously reported measurement as the final-measurement
         */
        finalMeasurement?: Schema$GoogleCloudAiplatformV1Measurement;
        /**
         * Optional. A human readable reason why the trial was infeasible. This should only be provided if `trial_infeasible` is true.
         */
        infeasibleReason?: string | null;
        /**
         * Optional. True if the Trial cannot be run with the given Parameter, and final_measurement will be ignored.
         */
        trialInfeasible?: boolean | null;
    }
    /**
     * Success and error statistics of processing multiple entities (for example, DataItems or structured data rows) in batch.
     */
    export interface Schema$GoogleCloudAiplatformV1CompletionStats {
        /**
         * Output only. The number of entities for which any error was encountered.
         */
        failedCount?: string | null;
        /**
         * Output only. In cases when enough errors are encountered a job, pipeline, or operation may be failed as a whole. Below is the number of entities for which the processing had not been finished (either in successful or failed state). Set to -1 if the number is unknown (for example, the operation failed before the total entity number could be collected).
         */
        incompleteCount?: string | null;
        /**
         * Output only. The number of entities that had been processed successfully.
         */
        successfulCount?: string | null;
        /**
         * Output only. The number of the successful forecast points that are generated by the forecasting model. This is ONLY used by the forecasting batch prediction.
         */
        successfulForecastPointCount?: string | null;
    }
    /**
     * The Container Registry location for the container image.
     */
    export interface Schema$GoogleCloudAiplatformV1ContainerRegistryDestination {
        /**
         * Required. Container Registry URI of a container image. Only Google Container Registry and Artifact Registry are supported now. Accepted forms: * Google Container Registry path. For example: `gcr.io/projectId/imageName:tag`. * Artifact Registry path. For example: `us-central1-docker.pkg.dev/projectId/repoName/imageName:tag`. If a tag is not specified, "latest" will be used as the default tag.
         */
        outputUri?: string | null;
    }
    /**
     * The spec of a Container.
     */
    export interface Schema$GoogleCloudAiplatformV1ContainerSpec {
        /**
         * The arguments to be passed when starting the container.
         */
        args?: string[] | null;
        /**
         * The command to be invoked when the container is started. It overrides the entrypoint instruction in Dockerfile when provided.
         */
        command?: string[] | null;
        /**
         * Environment variables to be passed to the container. Maximum limit is 100.
         */
        env?: Schema$GoogleCloudAiplatformV1EnvVar[];
        /**
         * Required. The URI of a container image in the Container Registry that is to be run on each worker replica.
         */
        imageUri?: string | null;
    }
    /**
     * Instance of a general context.
     */
    export interface Schema$GoogleCloudAiplatformV1Context {
        /**
         * Output only. Timestamp when this Context was created.
         */
        createTime?: string | null;
        /**
         * Description of the Context
         */
        description?: string | null;
        /**
         * User provided display name of the Context. May be up to 128 Unicode characters.
         */
        displayName?: string | null;
        /**
         * An eTag used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens.
         */
        etag?: string | null;
        /**
         * The labels with user-defined metadata to organize your Contexts. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. No more than 64 user labels can be associated with one Context (System labels are excluded).
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * Properties of the Context. Top level metadata keys' heading and trailing spaces will be trimmed. The size of this field should not exceed 200KB.
         */
        metadata?: {
            [key: string]: any;
        } | null;
        /**
         * Immutable. The resource name of the Context.
         */
        name?: string | null;
        /**
         * Output only. A list of resource names of Contexts that are parents of this Context. A Context may have at most 10 parent_contexts.
         */
        parentContexts?: string[] | null;
        /**
         * The title of the schema describing the metadata. Schema title and version is expected to be registered in earlier Create Schema calls. And both are used together as unique identifiers to identify schemas within the local metadata store.
         */
        schemaTitle?: string | null;
        /**
         * The version of the schema in schema_name to use. Schema title and version is expected to be registered in earlier Create Schema calls. And both are used together as unique identifiers to identify schemas within the local metadata store.
         */
        schemaVersion?: string | null;
        /**
         * Output only. Timestamp when this Context was last updated.
         */
        updateTime?: string | null;
    }
    /**
     * Details of ModelService.CopyModel operation.
     */
    export interface Schema$GoogleCloudAiplatformV1CopyModelOperationMetadata {
        /**
         * The common part of the operation metadata.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
    }
    /**
     * Request message for ModelService.CopyModel.
     */
    export interface Schema$GoogleCloudAiplatformV1CopyModelRequest {
        /**
         * Customer-managed encryption key options. If this is set, then the Model copy will be encrypted with the provided encryption key.
         */
        encryptionSpec?: Schema$GoogleCloudAiplatformV1EncryptionSpec;
        /**
         * Optional. Copy source_model into a new Model with this ID. The ID will become the final component of the model resource name. This value may be up to 63 characters, and valid characters are `[a-z0-9_-]`. The first character cannot be a number or hyphen.
         */
        modelId?: string | null;
        /**
         * Optional. Specify this field to copy source_model into this existing Model as a new version. Format: `projects/{project\}/locations/{location\}/models/{model\}`
         */
        parentModel?: string | null;
        /**
         * Required. The resource name of the Model to copy. That Model must be in the same Project. Format: `projects/{project\}/locations/{location\}/models/{model\}`
         */
        sourceModel?: string | null;
    }
    /**
     * Response message of ModelService.CopyModel operation.
     */
    export interface Schema$GoogleCloudAiplatformV1CopyModelResponse {
        /**
         * The name of the copied Model resource. Format: `projects/{project\}/locations/{location\}/models/{model\}`
         */
        model?: string | null;
        /**
         * Output only. The version ID of the model that is copied.
         */
        modelVersionId?: string | null;
    }
    /**
     * Runtime operation information for DatasetService.CreateDataset.
     */
    export interface Schema$GoogleCloudAiplatformV1CreateDatasetOperationMetadata {
        /**
         * The operation generic information.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
    }
    /**
     * Runtime operation information for DatasetService.CreateDatasetVersion.
     */
    export interface Schema$GoogleCloudAiplatformV1CreateDatasetVersionOperationMetadata {
        /**
         * The common part of the operation metadata.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
    }
    /**
     * Runtime operation information for EndpointService.CreateEndpoint.
     */
    export interface Schema$GoogleCloudAiplatformV1CreateEndpointOperationMetadata {
        /**
         * The operation generic information.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
    }
    /**
     * Details of operations that perform create EntityType.
     */
    export interface Schema$GoogleCloudAiplatformV1CreateEntityTypeOperationMetadata {
        /**
         * Operation metadata for EntityType.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
    }
    /**
     * Details of operations that perform create Feature.
     */
    export interface Schema$GoogleCloudAiplatformV1CreateFeatureOperationMetadata {
        /**
         * Operation metadata for Feature.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
    }
    /**
     * Request message for FeaturestoreService.CreateFeature. Request message for FeatureRegistryService.CreateFeature.
     */
    export interface Schema$GoogleCloudAiplatformV1CreateFeatureRequest {
        /**
         * Required. The Feature to create.
         */
        feature?: Schema$GoogleCloudAiplatformV1Feature;
        /**
         * Required. The ID to use for the Feature, which will become the final component of the Feature's resource name. This value may be up to 128 characters, and valid characters are `[a-z0-9_]`. The first character cannot be a number. The value must be unique within an EntityType/FeatureGroup.
         */
        featureId?: string | null;
        parent?: string | null;
    }
    /**
     * Details of operations that perform create Featurestore.
     */
    export interface Schema$GoogleCloudAiplatformV1CreateFeaturestoreOperationMetadata {
        /**
         * Operation metadata for Featurestore.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
    }
    /**
     * Runtime operation information for IndexEndpointService.CreateIndexEndpoint.
     */
    export interface Schema$GoogleCloudAiplatformV1CreateIndexEndpointOperationMetadata {
        /**
         * The operation generic information.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
    }
    /**
     * Runtime operation information for IndexService.CreateIndex.
     */
    export interface Schema$GoogleCloudAiplatformV1CreateIndexOperationMetadata {
        /**
         * The operation generic information.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
        /**
         * The operation metadata with regard to Matching Engine Index operation.
         */
        nearestNeighborSearchOperationMetadata?: Schema$GoogleCloudAiplatformV1NearestNeighborSearchOperationMetadata;
    }
    /**
     * Details of operations that perform MetadataService.CreateMetadataStore.
     */
    export interface Schema$GoogleCloudAiplatformV1CreateMetadataStoreOperationMetadata {
        /**
         * Operation metadata for creating a MetadataStore.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
    }
    /**
     * Metadata information for NotebookService.CreateNotebookRuntimeTemplate.
     */
    export interface Schema$GoogleCloudAiplatformV1CreateNotebookRuntimeTemplateOperationMetadata {
        /**
         * The operation generic information.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
    }
    /**
     * Request message for PipelineService.CreatePipelineJob.
     */
    export interface Schema$GoogleCloudAiplatformV1CreatePipelineJobRequest {
        /**
         * Required. The resource name of the Location to create the PipelineJob in. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string | null;
        /**
         * Required. The PipelineJob to create.
         */
        pipelineJob?: Schema$GoogleCloudAiplatformV1PipelineJob;
        /**
         * The ID to use for the PipelineJob, which will become the final component of the PipelineJob name. If not provided, an ID will be automatically generated. This value should be less than 128 characters, and valid characters are `/a-z-/`.
         */
        pipelineJobId?: string | null;
    }
    /**
     * Runtime operation information for SpecialistPoolService.CreateSpecialistPool.
     */
    export interface Schema$GoogleCloudAiplatformV1CreateSpecialistPoolOperationMetadata {
        /**
         * The operation generic information.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
    }
    /**
     * Details of operations that perform create Tensorboard.
     */
    export interface Schema$GoogleCloudAiplatformV1CreateTensorboardOperationMetadata {
        /**
         * Operation metadata for Tensorboard.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
    }
    /**
     * Request message for TensorboardService.CreateTensorboardRun.
     */
    export interface Schema$GoogleCloudAiplatformV1CreateTensorboardRunRequest {
        /**
         * Required. The resource name of the TensorboardExperiment to create the TensorboardRun in. Format: `projects/{project\}/locations/{location\}/tensorboards/{tensorboard\}/experiments/{experiment\}`
         */
        parent?: string | null;
        /**
         * Required. The TensorboardRun to create.
         */
        tensorboardRun?: Schema$GoogleCloudAiplatformV1TensorboardRun;
        /**
         * Required. The ID to use for the Tensorboard run, which becomes the final component of the Tensorboard run's resource name. This value should be 1-128 characters, and valid characters are `/a-z-/`.
         */
        tensorboardRunId?: string | null;
    }
    /**
     * Request message for TensorboardService.CreateTensorboardTimeSeries.
     */
    export interface Schema$GoogleCloudAiplatformV1CreateTensorboardTimeSeriesRequest {
        /**
         * Required. The resource name of the TensorboardRun to create the TensorboardTimeSeries in. Format: `projects/{project\}/locations/{location\}/tensorboards/{tensorboard\}/experiments/{experiment\}/runs/{run\}`
         */
        parent?: string | null;
        /**
         * Required. The TensorboardTimeSeries to create.
         */
        tensorboardTimeSeries?: Schema$GoogleCloudAiplatformV1TensorboardTimeSeries;
        /**
         * Optional. The user specified unique ID to use for the TensorboardTimeSeries, which becomes the final component of the TensorboardTimeSeries's resource name. This value should match "a-z0-9{0, 127\}"
         */
        tensorboardTimeSeriesId?: string | null;
    }
    /**
     * The storage details for CSV output content.
     */
    export interface Schema$GoogleCloudAiplatformV1CsvDestination {
        /**
         * Required. Google Cloud Storage location.
         */
        gcsDestination?: Schema$GoogleCloudAiplatformV1GcsDestination;
    }
    /**
     * The storage details for CSV input content.
     */
    export interface Schema$GoogleCloudAiplatformV1CsvSource {
        /**
         * Required. Google Cloud Storage location.
         */
        gcsSource?: Schema$GoogleCloudAiplatformV1GcsSource;
    }
    /**
     * Represents a job that runs custom workloads such as a Docker container or a Python package. A CustomJob can have multiple worker pools and each worker pool can have its own machine and input spec. A CustomJob will be cleaned up once the job enters terminal state (failed or succeeded).
     */
    export interface Schema$GoogleCloudAiplatformV1CustomJob {
        /**
         * Output only. Time when the CustomJob was created.
         */
        createTime?: string | null;
        /**
         * Required. The display name of the CustomJob. The name can be up to 128 characters long and can consist of any UTF-8 characters.
         */
        displayName?: string | null;
        /**
         * Customer-managed encryption key options for a CustomJob. If this is set, then all resources created by the CustomJob will be encrypted with the provided encryption key.
         */
        encryptionSpec?: Schema$GoogleCloudAiplatformV1EncryptionSpec;
        /**
         * Output only. Time when the CustomJob entered any of the following states: `JOB_STATE_SUCCEEDED`, `JOB_STATE_FAILED`, `JOB_STATE_CANCELLED`.
         */
        endTime?: string | null;
        /**
         * Output only. Only populated when job's state is `JOB_STATE_FAILED` or `JOB_STATE_CANCELLED`.
         */
        error?: Schema$GoogleRpcStatus;
        /**
         * Required. Job spec.
         */
        jobSpec?: Schema$GoogleCloudAiplatformV1CustomJobSpec;
        /**
         * The labels with user-defined metadata to organize CustomJobs. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * Output only. Resource name of a CustomJob.
         */
        name?: string | null;
        /**
         * Output only. Time when the CustomJob for the first time entered the `JOB_STATE_RUNNING` state.
         */
        startTime?: string | null;
        /**
         * Output only. The detailed state of the job.
         */
        state?: string | null;
        /**
         * Output only. Time when the CustomJob was most recently updated.
         */
        updateTime?: string | null;
        /**
         * Output only. URIs for accessing [interactive shells](https://cloud.google.com/vertex-ai/docs/training/monitor-debug-interactive-shell) (one URI for each training node). Only available if job_spec.enable_web_access is `true`. The keys are names of each node in the training job; for example, `workerpool0-0` for the primary node, `workerpool1-0` for the first node in the second worker pool, and `workerpool1-1` for the second node in the second worker pool. The values are the URIs for each node's interactive shell.
         */
        webAccessUris?: {
            [key: string]: string;
        } | null;
    }
    /**
     * Represents the spec of a CustomJob.
     */
    export interface Schema$GoogleCloudAiplatformV1CustomJobSpec {
        /**
         * The Cloud Storage location to store the output of this CustomJob or HyperparameterTuningJob. For HyperparameterTuningJob, the baseOutputDirectory of each child CustomJob backing a Trial is set to a subdirectory of name id under its parent HyperparameterTuningJob's baseOutputDirectory. The following Vertex AI environment variables will be passed to containers or python modules when this field is set: For CustomJob: * AIP_MODEL_DIR = `/model/` * AIP_CHECKPOINT_DIR = `/checkpoints/` * AIP_TENSORBOARD_LOG_DIR = `/logs/` For CustomJob backing a Trial of HyperparameterTuningJob: * AIP_MODEL_DIR = `//model/` * AIP_CHECKPOINT_DIR = `//checkpoints/` * AIP_TENSORBOARD_LOG_DIR = `//logs/`
         */
        baseOutputDirectory?: Schema$GoogleCloudAiplatformV1GcsDestination;
        /**
         * Optional. Whether you want Vertex AI to enable access to the customized dashboard in training chief container. If set to `true`, you can access the dashboard at the URIs given by CustomJob.web_access_uris or Trial.web_access_uris (within HyperparameterTuningJob.trials).
         */
        enableDashboardAccess?: boolean | null;
        /**
         * Optional. Whether you want Vertex AI to enable [interactive shell access](https://cloud.google.com/vertex-ai/docs/training/monitor-debug-interactive-shell) to training containers. If set to `true`, you can access interactive shells at the URIs given by CustomJob.web_access_uris or Trial.web_access_uris (within HyperparameterTuningJob.trials).
         */
        enableWebAccess?: boolean | null;
        /**
         * Optional. The Experiment associated with this job. Format: `projects/{project\}/locations/{location\}/metadataStores/{metadataStores\}/contexts/{experiment-name\}`
         */
        experiment?: string | null;
        /**
         * Optional. The Experiment Run associated with this job. Format: `projects/{project\}/locations/{location\}/metadataStores/{metadataStores\}/contexts/{experiment-name\}-{experiment-run-name\}`
         */
        experimentRun?: string | null;
        /**
         * Optional. The full name of the Compute Engine [network](/compute/docs/networks-and-firewalls#networks) to which the Job should be peered. For example, `projects/12345/global/networks/myVPC`. [Format](/compute/docs/reference/rest/v1/networks/insert) is of the form `projects/{project\}/global/networks/{network\}`. Where {project\} is a project number, as in `12345`, and {network\} is a network name. To specify this field, you must have already [configured VPC Network Peering for Vertex AI](https://cloud.google.com/vertex-ai/docs/general/vpc-peering). If this field is left unspecified, the job is not peered with any network.
         */
        network?: string | null;
        /**
         * Optional. A list of names for the reserved ip ranges under the VPC network that can be used for this job. If set, we will deploy the job within the provided ip ranges. Otherwise, the job will be deployed to any ip ranges under the provided VPC network. Example: ['vertex-ai-ip-range'].
         */
        reservedIpRanges?: string[] | null;
        /**
         * Scheduling options for a CustomJob.
         */
        scheduling?: Schema$GoogleCloudAiplatformV1Scheduling;
        /**
         * Specifies the service account for workload run-as account. Users submitting jobs must have act-as permission on this run-as account. If unspecified, the [Vertex AI Custom Code Service Agent](https://cloud.google.com/vertex-ai/docs/general/access-control#service-agents) for the CustomJob's project is used.
         */
        serviceAccount?: string | null;
        /**
         * Optional. The name of a Vertex AI Tensorboard resource to which this CustomJob will upload Tensorboard logs. Format: `projects/{project\}/locations/{location\}/tensorboards/{tensorboard\}`
         */
        tensorboard?: string | null;
        /**
         * Required. The spec of the worker pools including machine type and Docker image. All worker pools except the first one are optional and can be skipped by providing an empty value.
         */
        workerPoolSpecs?: Schema$GoogleCloudAiplatformV1WorkerPoolSpec[];
    }
    /**
     * A piece of data in a Dataset. Could be an image, a video, a document or plain text.
     */
    export interface Schema$GoogleCloudAiplatformV1DataItem {
        /**
         * Output only. Timestamp when this DataItem was created.
         */
        createTime?: string | null;
        /**
         * Optional. Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens.
         */
        etag?: string | null;
        /**
         * Optional. The labels with user-defined metadata to organize your DataItems. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. No more than 64 user labels can be associated with one DataItem(System labels are excluded). See https://goo.gl/xmQnxf for more information and examples of labels. System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * Output only. The resource name of the DataItem.
         */
        name?: string | null;
        /**
         * Required. The data that the DataItem represents (for example, an image or a text snippet). The schema of the payload is stored in the parent Dataset's metadata schema's dataItemSchemaUri field.
         */
        payload?: any | null;
        /**
         * Output only. Timestamp when this DataItem was last updated.
         */
        updateTime?: string | null;
    }
    /**
     * A container for a single DataItem and Annotations on it.
     */
    export interface Schema$GoogleCloudAiplatformV1DataItemView {
        /**
         * The Annotations on the DataItem. If too many Annotations should be returned for the DataItem, this field will be truncated per annotations_limit in request. If it was, then the has_truncated_annotations will be set to true.
         */
        annotations?: Schema$GoogleCloudAiplatformV1Annotation[];
        /**
         * The DataItem.
         */
        dataItem?: Schema$GoogleCloudAiplatformV1DataItem;
        /**
         * True if and only if the Annotations field has been truncated. It happens if more Annotations for this DataItem met the request's annotation_filter than are allowed to be returned by annotations_limit. Note that if Annotations field is not being returned due to field mask, then this field will not be set to true no matter how many Annotations are there.
         */
        hasTruncatedAnnotations?: boolean | null;
    }
    /**
     * DataLabelingJob is used to trigger a human labeling job on unlabeled data from the following Dataset:
     */
    export interface Schema$GoogleCloudAiplatformV1DataLabelingJob {
        /**
         * Parameters that configure the active learning pipeline. Active learning will label the data incrementally via several iterations. For every iteration, it will select a batch of data based on the sampling strategy.
         */
        activeLearningConfig?: Schema$GoogleCloudAiplatformV1ActiveLearningConfig;
        /**
         * Labels to assign to annotations generated by this DataLabelingJob. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable.
         */
        annotationLabels?: {
            [key: string]: string;
        } | null;
        /**
         * Output only. Timestamp when this DataLabelingJob was created.
         */
        createTime?: string | null;
        /**
         * Output only. Estimated cost(in US dollars) that the DataLabelingJob has incurred to date.
         */
        currentSpend?: Schema$GoogleTypeMoney;
        /**
         * Required. Dataset resource names. Right now we only support labeling from a single Dataset. Format: `projects/{project\}/locations/{location\}/datasets/{dataset\}`
         */
        datasets?: string[] | null;
        /**
         * Required. The user-defined name of the DataLabelingJob. The name can be up to 128 characters long and can consist of any UTF-8 characters. Display name of a DataLabelingJob.
         */
        displayName?: string | null;
        /**
         * Customer-managed encryption key spec for a DataLabelingJob. If set, this DataLabelingJob will be secured by this key. Note: Annotations created in the DataLabelingJob are associated with the EncryptionSpec of the Dataset they are exported to.
         */
        encryptionSpec?: Schema$GoogleCloudAiplatformV1EncryptionSpec;
        /**
         * Output only. DataLabelingJob errors. It is only populated when job's state is `JOB_STATE_FAILED` or `JOB_STATE_CANCELLED`.
         */
        error?: Schema$GoogleRpcStatus;
        /**
         * Required. Input config parameters for the DataLabelingJob.
         */
        inputs?: any | null;
        /**
         * Required. Points to a YAML file stored on Google Cloud Storage describing the config for a specific type of DataLabelingJob. The schema files that can be used here are found in the https://storage.googleapis.com/google-cloud-aiplatform bucket in the /schema/datalabelingjob/inputs/ folder.
         */
        inputsSchemaUri?: string | null;
        /**
         * Required. The Google Cloud Storage location of the instruction pdf. This pdf is shared with labelers, and provides detailed description on how to label DataItems in Datasets.
         */
        instructionUri?: string | null;
        /**
         * Required. Number of labelers to work on each DataItem.
         */
        labelerCount?: number | null;
        /**
         * Output only. Current labeling job progress percentage scaled in interval [0, 100], indicating the percentage of DataItems that has been finished.
         */
        labelingProgress?: number | null;
        /**
         * The labels with user-defined metadata to organize your DataLabelingJobs. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Following system labels exist for each DataLabelingJob: * "aiplatform.googleapis.com/schema": output only, its value is the inputs_schema's title.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * Output only. Resource name of the DataLabelingJob.
         */
        name?: string | null;
        /**
         * The SpecialistPools' resource names associated with this job.
         */
        specialistPools?: string[] | null;
        /**
         * Output only. The detailed state of the job.
         */
        state?: string | null;
        /**
         * Output only. Timestamp when this DataLabelingJob was updated most recently.
         */
        updateTime?: string | null;
    }
    /**
     * A collection of DataItems and Annotations on them.
     */
    export interface Schema$GoogleCloudAiplatformV1Dataset {
        /**
         * Output only. Timestamp when this Dataset was created.
         */
        createTime?: string | null;
        /**
         * Output only. The number of DataItems in this Dataset. Only apply for non-structured Dataset.
         */
        dataItemCount?: string | null;
        /**
         * The description of the Dataset.
         */
        description?: string | null;
        /**
         * Required. The user-defined name of the Dataset. The name can be up to 128 characters long and can consist of any UTF-8 characters.
         */
        displayName?: string | null;
        /**
         * Customer-managed encryption key spec for a Dataset. If set, this Dataset and all sub-resources of this Dataset will be secured by this key.
         */
        encryptionSpec?: Schema$GoogleCloudAiplatformV1EncryptionSpec;
        /**
         * Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens.
         */
        etag?: string | null;
        /**
         * The labels with user-defined metadata to organize your Datasets. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. No more than 64 user labels can be associated with one Dataset (System labels are excluded). See https://goo.gl/xmQnxf for more information and examples of labels. System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Following system labels exist for each Dataset: * "aiplatform.googleapis.com/dataset_metadata_schema": output only, its value is the metadata_schema's title.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * Required. Additional information about the Dataset.
         */
        metadata?: any | null;
        /**
         * Output only. The resource name of the Artifact that was created in MetadataStore when creating the Dataset. The Artifact resource name pattern is `projects/{project\}/locations/{location\}/metadataStores/{metadata_store\}/artifacts/{artifact\}`.
         */
        metadataArtifact?: string | null;
        /**
         * Required. Points to a YAML file stored on Google Cloud Storage describing additional information about the Dataset. The schema is defined as an OpenAPI 3.0.2 Schema Object. The schema files that can be used here are found in gs://google-cloud-aiplatform/schema/dataset/metadata/.
         */
        metadataSchemaUri?: string | null;
        /**
         * Output only. The resource name of the Dataset.
         */
        name?: string | null;
        /**
         * All SavedQueries belong to the Dataset will be returned in List/Get Dataset response. The annotation_specs field will not be populated except for UI cases which will only use annotation_spec_count. In CreateDataset request, a SavedQuery is created together if this field is set, up to one SavedQuery can be set in CreateDatasetRequest. The SavedQuery should not contain any AnnotationSpec.
         */
        savedQueries?: Schema$GoogleCloudAiplatformV1SavedQuery[];
        /**
         * Output only. Timestamp when this Dataset was last updated.
         */
        updateTime?: string | null;
    }
    /**
     * Describes the dataset version.
     */
    export interface Schema$GoogleCloudAiplatformV1DatasetVersion {
        /**
         * Output only. Name of the associated BigQuery dataset.
         */
        bigQueryDatasetName?: string | null;
        /**
         * Output only. Timestamp when this DatasetVersion was created.
         */
        createTime?: string | null;
        /**
         * Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens.
         */
        etag?: string | null;
        /**
         * Output only. The resource name of the DatasetVersion.
         */
        name?: string | null;
        /**
         * Output only. Timestamp when this DatasetVersion was last updated.
         */
        updateTime?: string | null;
    }
    /**
     * A description of resources that are dedicated to a DeployedModel, and that need a higher degree of manual configuration.
     */
    export interface Schema$GoogleCloudAiplatformV1DedicatedResources {
        /**
         * Immutable. The metric specifications that overrides a resource utilization metric (CPU utilization, accelerator's duty cycle, and so on) target value (default to 60 if not set). At most one entry is allowed per metric. If machine_spec.accelerator_count is above 0, the autoscaling will be based on both CPU utilization and accelerator's duty cycle metrics and scale up when either metrics exceeds its target value while scale down if both metrics are under their target value. The default target value is 60 for both metrics. If machine_spec.accelerator_count is 0, the autoscaling will be based on CPU utilization metric only with default target value 60 if not explicitly set. For example, in the case of Online Prediction, if you want to override target CPU utilization to 80, you should set autoscaling_metric_specs.metric_name to `aiplatform.googleapis.com/prediction/online/cpu/utilization` and autoscaling_metric_specs.target to `80`.
         */
        autoscalingMetricSpecs?: Schema$GoogleCloudAiplatformV1AutoscalingMetricSpec[];
        /**
         * Required. Immutable. The specification of a single machine used by the prediction.
         */
        machineSpec?: Schema$GoogleCloudAiplatformV1MachineSpec;
        /**
         * Immutable. The maximum number of replicas this DeployedModel may be deployed on when the traffic against it increases. If the requested value is too large, the deployment will error, but if deployment succeeds then the ability to scale the model to that many replicas is guaranteed (barring service outages). If traffic against the DeployedModel increases beyond what its replicas at maximum may handle, a portion of the traffic will be dropped. If this value is not provided, will use min_replica_count as the default value. The value of this field impacts the charge against Vertex CPU and GPU quotas. Specifically, you will be charged for (max_replica_count * number of cores in the selected machine type) and (max_replica_count * number of GPUs per replica in the selected machine type).
         */
        maxReplicaCount?: number | null;
        /**
         * Required. Immutable. The minimum number of machine replicas this DeployedModel will be always deployed on. This value must be greater than or equal to 1. If traffic against the DeployedModel increases, it may dynamically be deployed onto more replicas, and as traffic decreases, some of these extra replicas may be freed.
         */
        minReplicaCount?: number | null;
    }
    /**
     * Details of operations that delete Feature values.
     */
    export interface Schema$GoogleCloudAiplatformV1DeleteFeatureValuesOperationMetadata {
        /**
         * Operation metadata for Featurestore delete Features values.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
    }
    /**
     * Request message for FeaturestoreService.DeleteFeatureValues.
     */
    export interface Schema$GoogleCloudAiplatformV1DeleteFeatureValuesRequest {
        /**
         * Select feature values to be deleted by specifying entities.
         */
        selectEntity?: Schema$GoogleCloudAiplatformV1DeleteFeatureValuesRequestSelectEntity;
        /**
         * Select feature values to be deleted by specifying time range and features.
         */
        selectTimeRangeAndFeature?: Schema$GoogleCloudAiplatformV1DeleteFeatureValuesRequestSelectTimeRangeAndFeature;
    }
    /**
     * Message to select entity. If an entity id is selected, all the feature values corresponding to the entity id will be deleted, including the entityId.
     */
    export interface Schema$GoogleCloudAiplatformV1DeleteFeatureValuesRequestSelectEntity {
        /**
         * Required. Selectors choosing feature values of which entity id to be deleted from the EntityType.
         */
        entityIdSelector?: Schema$GoogleCloudAiplatformV1EntityIdSelector;
    }
    /**
     * Message to select time range and feature. Values of the selected feature generated within an inclusive time range will be deleted. Using this option permanently deletes the feature values from the specified feature IDs within the specified time range. This might include data from the online storage. If you want to retain any deleted historical data in the online storage, you must re-ingest it.
     */
    export interface Schema$GoogleCloudAiplatformV1DeleteFeatureValuesRequestSelectTimeRangeAndFeature {
        /**
         * Required. Selectors choosing which feature values to be deleted from the EntityType.
         */
        featureSelector?: Schema$GoogleCloudAiplatformV1FeatureSelector;
        /**
         * If set, data will not be deleted from online storage. When time range is older than the data in online storage, setting this to be true will make the deletion have no impact on online serving.
         */
        skipOnlineStorageDelete?: boolean | null;
        /**
         * Required. Select feature generated within a half-inclusive time range. The time range is lower inclusive and upper exclusive.
         */
        timeRange?: Schema$GoogleTypeInterval;
    }
    /**
     * Response message for FeaturestoreService.DeleteFeatureValues.
     */
    export interface Schema$GoogleCloudAiplatformV1DeleteFeatureValuesResponse {
        /**
         * Response for request specifying the entities to delete
         */
        selectEntity?: Schema$GoogleCloudAiplatformV1DeleteFeatureValuesResponseSelectEntity;
        /**
         * Response for request specifying time range and feature
         */
        selectTimeRangeAndFeature?: Schema$GoogleCloudAiplatformV1DeleteFeatureValuesResponseSelectTimeRangeAndFeature;
    }
    /**
     * Response message if the request uses the SelectEntity option.
     */
    export interface Schema$GoogleCloudAiplatformV1DeleteFeatureValuesResponseSelectEntity {
        /**
         * The count of deleted entity rows in the offline storage. Each row corresponds to the combination of an entity ID and a timestamp. One entity ID can have multiple rows in the offline storage.
         */
        offlineStorageDeletedEntityRowCount?: string | null;
        /**
         * The count of deleted entities in the online storage. Each entity ID corresponds to one entity.
         */
        onlineStorageDeletedEntityCount?: string | null;
    }
    /**
     * Response message if the request uses the SelectTimeRangeAndFeature option.
     */
    export interface Schema$GoogleCloudAiplatformV1DeleteFeatureValuesResponseSelectTimeRangeAndFeature {
        /**
         * The count of the features or columns impacted. This is the same as the feature count in the request.
         */
        impactedFeatureCount?: string | null;
        /**
         * The count of modified entity rows in the offline storage. Each row corresponds to the combination of an entity ID and a timestamp. One entity ID can have multiple rows in the offline storage. Within each row, only the features specified in the request are deleted.
         */
        offlineStorageModifiedEntityRowCount?: string | null;
        /**
         * The count of modified entities in the online storage. Each entity ID corresponds to one entity. Within each entity, only the features specified in the request are deleted.
         */
        onlineStorageModifiedEntityCount?: string | null;
    }
    /**
     * Details of operations that perform MetadataService.DeleteMetadataStore.
     */
    export interface Schema$GoogleCloudAiplatformV1DeleteMetadataStoreOperationMetadata {
        /**
         * Operation metadata for deleting a MetadataStore.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
    }
    /**
     * Details of operations that perform deletes of any entities.
     */
    export interface Schema$GoogleCloudAiplatformV1DeleteOperationMetadata {
        /**
         * The common part of the operation metadata.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
    }
    /**
     * A deployment of an Index. IndexEndpoints contain one or more DeployedIndexes.
     */
    export interface Schema$GoogleCloudAiplatformV1DeployedIndex {
        /**
         * Optional. A description of resources that the DeployedIndex uses, which to large degree are decided by Vertex AI, and optionally allows only a modest additional configuration. If min_replica_count is not set, the default value is 2 (we don't provide SLA when min_replica_count=1). If max_replica_count is not set, the default value is min_replica_count. The max allowed replica count is 1000.
         */
        automaticResources?: Schema$GoogleCloudAiplatformV1AutomaticResources;
        /**
         * Output only. Timestamp when the DeployedIndex was created.
         */
        createTime?: string | null;
        /**
         * Optional. A description of resources that are dedicated to the DeployedIndex, and that need a higher degree of manual configuration. If min_replica_count is not set, the default value is 2 (we don't provide SLA when min_replica_count=1). If max_replica_count is not set, the default value is min_replica_count. The max allowed replica count is 1000. Available machine types for SMALL shard: e2-standard-2 and all machine types available for MEDIUM and LARGE shard. Available machine types for MEDIUM shard: e2-standard-16 and all machine types available for LARGE shard. Available machine types for LARGE shard: e2-highmem-16, n2d-standard-32. n1-standard-16 and n1-standard-32 are still available, but we recommend e2-standard-16 and e2-highmem-16 for cost efficiency.
         */
        dedicatedResources?: Schema$GoogleCloudAiplatformV1DedicatedResources;
        /**
         * Optional. If set, the authentication is enabled for the private endpoint.
         */
        deployedIndexAuthConfig?: Schema$GoogleCloudAiplatformV1DeployedIndexAuthConfig;
        /**
         * Optional. The deployment group can be no longer than 64 characters (eg: 'test', 'prod'). If not set, we will use the 'default' deployment group. Creating `deployment_groups` with `reserved_ip_ranges` is a recommended practice when the peered network has multiple peering ranges. This creates your deployments from predictable IP spaces for easier traffic administration. Also, one deployment_group (except 'default') can only be used with the same reserved_ip_ranges which means if the deployment_group has been used with reserved_ip_ranges: [a, b, c], using it with [a, b] or [d, e] is disallowed. Note: we only support up to 5 deployment groups(not including 'default').
         */
        deploymentGroup?: string | null;
        /**
         * The display name of the DeployedIndex. If not provided upon creation, the Index's display_name is used.
         */
        displayName?: string | null;
        /**
         * Optional. If true, private endpoint's access logs are sent to Cloud Logging. These logs are like standard server access logs, containing information like timestamp and latency for each MatchRequest. Note that logs may incur a cost, especially if the deployed index receives a high queries per second rate (QPS). Estimate your costs before enabling this option.
         */
        enableAccessLogging?: boolean | null;
        /**
         * Required. The user specified ID of the DeployedIndex. The ID can be up to 128 characters long and must start with a letter and only contain letters, numbers, and underscores. The ID must be unique within the project it is created in.
         */
        id?: string | null;
        /**
         * Required. The name of the Index this is the deployment of. We may refer to this Index as the DeployedIndex's "original" Index.
         */
        index?: string | null;
        /**
         * Output only. The DeployedIndex may depend on various data on its original Index. Additionally when certain changes to the original Index are being done (e.g. when what the Index contains is being changed) the DeployedIndex may be asynchronously updated in the background to reflect these changes. If this timestamp's value is at least the Index.update_time of the original Index, it means that this DeployedIndex and the original Index are in sync. If this timestamp is older, then to see which updates this DeployedIndex already contains (and which it does not), one must list the operations that are running on the original Index. Only the successfully completed Operations with update_time equal or before this sync time are contained in this DeployedIndex.
         */
        indexSyncTime?: string | null;
        /**
         * Output only. Provides paths for users to send requests directly to the deployed index services running on Cloud via private services access. This field is populated if network is configured.
         */
        privateEndpoints?: Schema$GoogleCloudAiplatformV1IndexPrivateEndpoints;
        /**
         * Optional. A list of reserved ip ranges under the VPC network that can be used for this DeployedIndex. If set, we will deploy the index within the provided ip ranges. Otherwise, the index might be deployed to any ip ranges under the provided VPC network. The value should be the name of the address (https://cloud.google.com/compute/docs/reference/rest/v1/addresses) Example: ['vertex-ai-ip-range']. For more information about subnets and network IP ranges, please see https://cloud.google.com/vpc/docs/subnets#manually_created_subnet_ip_ranges.
         */
        reservedIpRanges?: string[] | null;
    }
    /**
     * Used to set up the auth on the DeployedIndex's private endpoint.
     */
    export interface Schema$GoogleCloudAiplatformV1DeployedIndexAuthConfig {
        /**
         * Defines the authentication provider that the DeployedIndex uses.
         */
        authProvider?: Schema$GoogleCloudAiplatformV1DeployedIndexAuthConfigAuthProvider;
    }
    /**
     * Configuration for an authentication provider, including support for [JSON Web Token (JWT)](https://tools.ietf.org/html/draft-ietf-oauth-json-web-token-32).
     */
    export interface Schema$GoogleCloudAiplatformV1DeployedIndexAuthConfigAuthProvider {
        /**
         * A list of allowed JWT issuers. Each entry must be a valid Google service account, in the following format: `service-account-name@project-id.iam.gserviceaccount.com`
         */
        allowedIssuers?: string[] | null;
        /**
         * The list of JWT [audiences](https://tools.ietf.org/html/draft-ietf-oauth-json-web-token-32#section-4.1.3). that are allowed to access. A JWT containing any of these audiences will be accepted.
         */
        audiences?: string[] | null;
    }
    /**
     * Points to a DeployedIndex.
     */
    export interface Schema$GoogleCloudAiplatformV1DeployedIndexRef {
        /**
         * Immutable. The ID of the DeployedIndex in the above IndexEndpoint.
         */
        deployedIndexId?: string | null;
        /**
         * Immutable. A resource name of the IndexEndpoint.
         */
        indexEndpoint?: string | null;
    }
    /**
     * A deployment of a Model. Endpoints contain one or more DeployedModels.
     */
    export interface Schema$GoogleCloudAiplatformV1DeployedModel {
        /**
         * A description of resources that to large degree are decided by Vertex AI, and require only a modest additional configuration.
         */
        automaticResources?: Schema$GoogleCloudAiplatformV1AutomaticResources;
        /**
         * Output only. Timestamp when the DeployedModel was created.
         */
        createTime?: string | null;
        /**
         * A description of resources that are dedicated to the DeployedModel, and that need a higher degree of manual configuration.
         */
        dedicatedResources?: Schema$GoogleCloudAiplatformV1DedicatedResources;
        /**
         * For custom-trained Models and AutoML Tabular Models, the container of the DeployedModel instances will send `stderr` and `stdout` streams to Cloud Logging by default. Please note that the logs incur cost, which are subject to [Cloud Logging pricing](https://cloud.google.com/logging/pricing). User can disable container logging by setting this flag to true.
         */
        disableContainerLogging?: boolean | null;
        /**
         * The display name of the DeployedModel. If not provided upon creation, the Model's display_name is used.
         */
        displayName?: string | null;
        /**
         * If true, online prediction access logs are sent to Cloud Logging. These logs are like standard server access logs, containing information like timestamp and latency for each prediction request. Note that logs may incur a cost, especially if your project receives prediction requests at a high queries per second rate (QPS). Estimate your costs before enabling this option.
         */
        enableAccessLogging?: boolean | null;
        /**
         * Explanation configuration for this DeployedModel. When deploying a Model using EndpointService.DeployModel, this value overrides the value of Model.explanation_spec. All fields of explanation_spec are optional in the request. If a field of explanation_spec is not populated, the value of the same field of Model.explanation_spec is inherited. If the corresponding Model.explanation_spec is not populated, all fields of the explanation_spec will be used for the explanation configuration.
         */
        explanationSpec?: Schema$GoogleCloudAiplatformV1ExplanationSpec;
        /**
         * Immutable. The ID of the DeployedModel. If not provided upon deployment, Vertex AI will generate a value for this ID. This value should be 1-10 characters, and valid characters are `/[0-9]/`.
         */
        id?: string | null;
        /**
         * Required. The resource name of the Model that this is the deployment of. Note that the Model may be in a different location than the DeployedModel's Endpoint. The resource name may contain version id or version alias to specify the version. Example: `projects/{project\}/locations/{location\}/models/{model\}@2` or `projects/{project\}/locations/{location\}/models/{model\}@golden` if no version is specified, the default version will be deployed.
         */
        model?: string | null;
        /**
         * Output only. The version ID of the model that is deployed.
         */
        modelVersionId?: string | null;
        /**
         * Output only. Provide paths for users to send predict/explain/health requests directly to the deployed model services running on Cloud via private services access. This field is populated if network is configured.
         */
        privateEndpoints?: Schema$GoogleCloudAiplatformV1PrivateEndpoints;
        /**
         * The service account that the DeployedModel's container runs as. Specify the email address of the service account. If this service account is not specified, the container runs as a service account that doesn't have access to the resource project. Users deploying the Model must have the `iam.serviceAccounts.actAs` permission on this service account.
         */
        serviceAccount?: string | null;
    }
    /**
     * Points to a DeployedModel.
     */
    export interface Schema$GoogleCloudAiplatformV1DeployedModelRef {
        /**
         * Immutable. An ID of a DeployedModel in the above Endpoint.
         */
        deployedModelId?: string | null;
        /**
         * Immutable. A resource name of an Endpoint.
         */
        endpoint?: string | null;
    }
    /**
     * Runtime operation information for IndexEndpointService.DeployIndex.
     */
    export interface Schema$GoogleCloudAiplatformV1DeployIndexOperationMetadata {
        /**
         * The unique index id specified by user
         */
        deployedIndexId?: string | null;
        /**
         * The operation generic information.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
    }
    /**
     * Request message for IndexEndpointService.DeployIndex.
     */
    export interface Schema$GoogleCloudAiplatformV1DeployIndexRequest {
        /**
         * Required. The DeployedIndex to be created within the IndexEndpoint.
         */
        deployedIndex?: Schema$GoogleCloudAiplatformV1DeployedIndex;
    }
    /**
     * Response message for IndexEndpointService.DeployIndex.
     */
    export interface Schema$GoogleCloudAiplatformV1DeployIndexResponse {
        /**
         * The DeployedIndex that had been deployed in the IndexEndpoint.
         */
        deployedIndex?: Schema$GoogleCloudAiplatformV1DeployedIndex;
    }
    /**
     * Runtime operation information for EndpointService.DeployModel.
     */
    export interface Schema$GoogleCloudAiplatformV1DeployModelOperationMetadata {
        /**
         * The operation generic information.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
    }
    /**
     * Request message for EndpointService.DeployModel.
     */
    export interface Schema$GoogleCloudAiplatformV1DeployModelRequest {
        /**
         * Required. The DeployedModel to be created within the Endpoint. Note that Endpoint.traffic_split must be updated for the DeployedModel to start receiving traffic, either as part of this call, or via EndpointService.UpdateEndpoint.
         */
        deployedModel?: Schema$GoogleCloudAiplatformV1DeployedModel;
        /**
         * A map from a DeployedModel's ID to the percentage of this Endpoint's traffic that should be forwarded to that DeployedModel. If this field is non-empty, then the Endpoint's traffic_split will be overwritten with it. To refer to the ID of the just being deployed Model, a "0" should be used, and the actual ID of the new DeployedModel will be filled in its place by this method. The traffic percentage values must add up to 100. If this field is empty, then the Endpoint's traffic_split is not updated.
         */
        trafficSplit?: {
            [key: string]: number;
        } | null;
    }
    /**
     * Response message for EndpointService.DeployModel.
     */
    export interface Schema$GoogleCloudAiplatformV1DeployModelResponse {
        /**
         * The DeployedModel that had been deployed in the Endpoint.
         */
        deployedModel?: Schema$GoogleCloudAiplatformV1DeployedModel;
    }
    export interface Schema$GoogleCloudAiplatformV1DestinationFeatureSetting {
        /**
         * Specify the field name in the export destination. If not specified, Feature ID is used.
         */
        destinationField?: string | null;
        /**
         * Required. The ID of the Feature to apply the setting to.
         */
        featureId?: string | null;
    }
    /**
     * Represents the spec of disk options.
     */
    export interface Schema$GoogleCloudAiplatformV1DiskSpec {
        /**
         * Size in GB of the boot disk (default is 100GB).
         */
        bootDiskSizeGb?: number | null;
        /**
         * Type of the boot disk (default is "pd-ssd"). Valid values: "pd-ssd" (Persistent Disk Solid State Drive) or "pd-standard" (Persistent Disk Hard Disk Drive).
         */
        bootDiskType?: string | null;
    }
    /**
     * A list of double values.
     */
    export interface Schema$GoogleCloudAiplatformV1DoubleArray {
        /**
         * A list of double values.
         */
        values?: number[] | null;
    }
    /**
     * Represents a customer-managed encryption key spec that can be applied to a top-level resource.
     */
    export interface Schema$GoogleCloudAiplatformV1EncryptionSpec {
        /**
         * Required. The Cloud KMS resource identifier of the customer managed encryption key used to protect a resource. Has the form: `projects/my-project/locations/my-region/keyRings/my-kr/cryptoKeys/my-key`. The key needs to be in the same region as where the compute resource is created.
         */
        kmsKeyName?: string | null;
    }
    /**
     * Models are deployed into it, and afterwards Endpoint is called to obtain predictions and explanations.
     */
    export interface Schema$GoogleCloudAiplatformV1Endpoint {
        /**
         * Output only. Timestamp when this Endpoint was created.
         */
        createTime?: string | null;
        /**
         * Output only. The models deployed in this Endpoint. To add or remove DeployedModels use EndpointService.DeployModel and EndpointService.UndeployModel respectively.
         */
        deployedModels?: Schema$GoogleCloudAiplatformV1DeployedModel[];
        /**
         * The description of the Endpoint.
         */
        description?: string | null;
        /**
         * Required. The display name of the Endpoint. The name can be up to 128 characters long and can consist of any UTF-8 characters.
         */
        displayName?: string | null;
        /**
         * Deprecated: If true, expose the Endpoint via private service connect. Only one of the fields, network or enable_private_service_connect, can be set.
         */
        enablePrivateServiceConnect?: boolean | null;
        /**
         * Customer-managed encryption key spec for an Endpoint. If set, this Endpoint and all sub-resources of this Endpoint will be secured by this key.
         */
        encryptionSpec?: Schema$GoogleCloudAiplatformV1EncryptionSpec;
        /**
         * Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens.
         */
        etag?: string | null;
        /**
         * The labels with user-defined metadata to organize your Endpoints. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * Output only. Resource name of the Model Monitoring job associated with this Endpoint if monitoring is enabled by JobService.CreateModelDeploymentMonitoringJob. Format: `projects/{project\}/locations/{location\}/modelDeploymentMonitoringJobs/{model_deployment_monitoring_job\}`
         */
        modelDeploymentMonitoringJob?: string | null;
        /**
         * Output only. The resource name of the Endpoint.
         */
        name?: string | null;
        /**
         * Optional. The full name of the Google Compute Engine [network](https://cloud.google.com//compute/docs/networks-and-firewalls#networks) to which the Endpoint should be peered. Private services access must already be configured for the network. If left unspecified, the Endpoint is not peered with any network. Only one of the fields, network or enable_private_service_connect, can be set. [Format](https://cloud.google.com/compute/docs/reference/rest/v1/networks/insert): `projects/{project\}/global/networks/{network\}`. Where `{project\}` is a project number, as in `12345`, and `{network\}` is network name.
         */
        network?: string | null;
        /**
         * Configures the request-response logging for online prediction.
         */
        predictRequestResponseLoggingConfig?: Schema$GoogleCloudAiplatformV1PredictRequestResponseLoggingConfig;
        /**
         * A map from a DeployedModel's ID to the percentage of this Endpoint's traffic that should be forwarded to that DeployedModel. If a DeployedModel's ID is not listed in this map, then it receives no traffic. The traffic percentage values must add up to 100, or map must be empty if the Endpoint is to not accept any traffic at a moment.
         */
        trafficSplit?: {
            [key: string]: number;
        } | null;
        /**
         * Output only. Timestamp when this Endpoint was last updated.
         */
        updateTime?: string | null;
    }
    /**
     * Selector for entityId. Getting ids from the given source.
     */
    export interface Schema$GoogleCloudAiplatformV1EntityIdSelector {
        /**
         * Source of Csv
         */
        csvSource?: Schema$GoogleCloudAiplatformV1CsvSource;
        /**
         * Source column that holds entity IDs. If not provided, entity IDs are extracted from the column named entity_id.
         */
        entityIdField?: string | null;
    }
    /**
     * An entity type is a type of object in a system that needs to be modeled and have stored information about. For example, driver is an entity type, and driver0 is an instance of an entity type driver.
     */
    export interface Schema$GoogleCloudAiplatformV1EntityType {
        /**
         * Output only. Timestamp when this EntityType was created.
         */
        createTime?: string | null;
        /**
         * Optional. Description of the EntityType.
         */
        description?: string | null;
        /**
         * Optional. Used to perform a consistent read-modify-write updates. If not set, a blind "overwrite" update happens.
         */
        etag?: string | null;
        /**
         * Optional. The labels with user-defined metadata to organize your EntityTypes. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information on and examples of labels. No more than 64 user labels can be associated with one EntityType (System labels are excluded)." System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * Optional. The default monitoring configuration for all Features with value type (Feature.ValueType) BOOL, STRING, DOUBLE or INT64 under this EntityType. If this is populated with [FeaturestoreMonitoringConfig.monitoring_interval] specified, snapshot analysis monitoring is enabled. Otherwise, snapshot analysis monitoring is disabled.
         */
        monitoringConfig?: Schema$GoogleCloudAiplatformV1FeaturestoreMonitoringConfig;
        /**
         * Immutable. Name of the EntityType. Format: `projects/{project\}/locations/{location\}/featurestores/{featurestore\}/entityTypes/{entity_type\}` The last part entity_type is assigned by the client. The entity_type can be up to 64 characters long and can consist only of ASCII Latin letters A-Z and a-z and underscore(_), and ASCII digits 0-9 starting with a letter. The value will be unique given a featurestore.
         */
        name?: string | null;
        /**
         * Optional. Config for data retention policy in offline storage. TTL in days for feature values that will be stored in offline storage. The Feature Store offline storage periodically removes obsolete feature values older than `offline_storage_ttl_days` since the feature generation time. If unset (or explicitly set to 0), default to 4000 days TTL.
         */
        offlineStorageTtlDays?: number | null;
        /**
         * Output only. Timestamp when this EntityType was most recently updated.
         */
        updateTime?: string | null;
    }
    /**
     * Represents an environment variable present in a Container or Python Module.
     */
    export interface Schema$GoogleCloudAiplatformV1EnvVar {
        /**
         * Required. Name of the environment variable. Must be a valid C identifier.
         */
        name?: string | null;
        /**
         * Required. Variables that reference a $(VAR_NAME) are expanded using the previous defined environment variables in the container and any service environment variables. If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not.
         */
        value?: string | null;
    }
    /**
     * Model error analysis for each annotation.
     */
    export interface Schema$GoogleCloudAiplatformV1ErrorAnalysisAnnotation {
        /**
         * Attributed items for a given annotation, typically representing neighbors from the training sets constrained by the query type.
         */
        attributedItems?: Schema$GoogleCloudAiplatformV1ErrorAnalysisAnnotationAttributedItem[];
        /**
         * The outlier score of this annotated item. Usually defined as the min of all distances from attributed items.
         */
        outlierScore?: number | null;
        /**
         * The threshold used to determine if this annotation is an outlier or not.
         */
        outlierThreshold?: number | null;
        /**
         * The query type used for finding the attributed items.
         */
        queryType?: string | null;
    }
    /**
     * Attributed items for a given annotation, typically representing neighbors from the training sets constrained by the query type.
     */
    export interface Schema$GoogleCloudAiplatformV1ErrorAnalysisAnnotationAttributedItem {
        /**
         * The unique ID for each annotation. Used by FE to allocate the annotation in DB.
         */
        annotationResourceName?: string | null;
        /**
         * The distance of this item to the annotation.
         */
        distance?: number | null;
    }
    /**
     * True positive, false positive, or false negative. EvaluatedAnnotation is only available under ModelEvaluationSlice with slice of `annotationSpec` dimension.
     */
    export interface Schema$GoogleCloudAiplatformV1EvaluatedAnnotation {
        /**
         * Output only. The data item payload that the Model predicted this EvaluatedAnnotation on.
         */
        dataItemPayload?: any | null;
        /**
         * Annotations of model error analysis results.
         */
        errorAnalysisAnnotations?: Schema$GoogleCloudAiplatformV1ErrorAnalysisAnnotation[];
        /**
         * Output only. ID of the EvaluatedDataItemView under the same ancestor ModelEvaluation. The EvaluatedDataItemView consists of all ground truths and predictions on data_item_payload.
         */
        evaluatedDataItemViewId?: string | null;
        /**
         * Explanations of predictions. Each element of the explanations indicates the explanation for one explanation Method. The attributions list in the EvaluatedAnnotationExplanation.explanation object corresponds to the predictions list. For example, the second element in the attributions list explains the second element in the predictions list.
         */
        explanations?: Schema$GoogleCloudAiplatformV1EvaluatedAnnotationExplanation[];
        /**
         * Output only. The ground truth Annotations, i.e. the Annotations that exist in the test data the Model is evaluated on. For true positive, there is one and only one ground truth annotation, which matches the only prediction in predictions. For false positive, there are zero or more ground truth annotations that are similar to the only prediction in predictions, but not enough for a match. For false negative, there is one and only one ground truth annotation, which doesn't match any predictions created by the model. The schema of the ground truth is stored in ModelEvaluation.annotation_schema_uri
         */
        groundTruths?: any[] | null;
        /**
         * Output only. The model predicted annotations. For true positive, there is one and only one prediction, which matches the only one ground truth annotation in ground_truths. For false positive, there is one and only one prediction, which doesn't match any ground truth annotation of the corresponding data_item_view_id. For false negative, there are zero or more predictions which are similar to the only ground truth annotation in ground_truths but not enough for a match. The schema of the prediction is stored in ModelEvaluation.annotation_schema_uri
         */
        predictions?: any[] | null;
        /**
         * Output only. Type of the EvaluatedAnnotation.
         */
        type?: string | null;
    }
    /**
     * Explanation result of the prediction produced by the Model.
     */
    export interface Schema$GoogleCloudAiplatformV1EvaluatedAnnotationExplanation {
        /**
         * Explanation attribution response details.
         */
        explanation?: Schema$GoogleCloudAiplatformV1Explanation;
        /**
         * Explanation type. For AutoML Image Classification models, possible values are: * `image-integrated-gradients` * `image-xrai`
         */
        explanationType?: string | null;
    }
    /**
     * An edge describing the relationship between an Artifact and an Execution in a lineage graph.
     */
    export interface Schema$GoogleCloudAiplatformV1Event {
        /**
         * Required. The relative resource name of the Artifact in the Event.
         */
        artifact?: string | null;
        /**
         * Output only. Time the Event occurred.
         */
        eventTime?: string | null;
        /**
         * Output only. The relative resource name of the Execution in the Event.
         */
        execution?: string | null;
        /**
         * The labels with user-defined metadata to annotate Events. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. No more than 64 user labels can be associated with one Event (System labels are excluded). See https://goo.gl/xmQnxf for more information and examples of labels. System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * Required. The type of the Event.
         */
        type?: string | null;
    }
    /**
     * Example-based explainability that returns the nearest neighbors from the provided dataset.
     */
    export interface Schema$GoogleCloudAiplatformV1Examples {
        /**
         * The Cloud Storage input instances.
         */
        exampleGcsSource?: Schema$GoogleCloudAiplatformV1ExamplesExampleGcsSource;
        /**
         * The full configuration for the generated index, the semantics are the same as metadata and should match [NearestNeighborSearchConfig](https://cloud.google.com/vertex-ai/docs/explainable-ai/configuring-explanations-example-based#nearest-neighbor-search-config).
         */
        nearestNeighborSearchConfig?: any | null;
        /**
         * The number of neighbors to return when querying for examples.
         */
        neighborCount?: number | null;
        /**
         * Simplified preset configuration, which automatically sets configuration values based on the desired query speed-precision trade-off and modality.
         */
        presets?: Schema$GoogleCloudAiplatformV1Presets;
    }
    /**
     * The Cloud Storage input instances.
     */
    export interface Schema$GoogleCloudAiplatformV1ExamplesExampleGcsSource {
        /**
         * The format in which instances are given, if not specified, assume it's JSONL format. Currently only JSONL format is supported.
         */
        dataFormat?: string | null;
        /**
         * The Cloud Storage location for the input instances.
         */
        gcsSource?: Schema$GoogleCloudAiplatformV1GcsSource;
    }
    /**
     * Overrides for example-based explanations.
     */
    export interface Schema$GoogleCloudAiplatformV1ExamplesOverride {
        /**
         * The number of neighbors to return that have the same crowding tag.
         */
        crowdingCount?: number | null;
        /**
         * The format of the data being provided with each call.
         */
        dataFormat?: string | null;
        /**
         * The number of neighbors to return.
         */
        neighborCount?: number | null;
        /**
         * Restrict the resulting nearest neighbors to respect these constraints.
         */
        restrictions?: Schema$GoogleCloudAiplatformV1ExamplesRestrictionsNamespace[];
        /**
         * If true, return the embeddings instead of neighbors.
         */
        returnEmbeddings?: boolean | null;
    }
    /**
     * Restrictions namespace for example-based explanations overrides.
     */
    export interface Schema$GoogleCloudAiplatformV1ExamplesRestrictionsNamespace {
        /**
         * The list of allowed tags.
         */
        allow?: string[] | null;
        /**
         * The list of deny tags.
         */
        deny?: string[] | null;
        /**
         * The namespace name.
         */
        namespaceName?: string | null;
    }
    /**
     * Instance of a general execution.
     */
    export interface Schema$GoogleCloudAiplatformV1Execution {
        /**
         * Output only. Timestamp when this Execution was created.
         */
        createTime?: string | null;
        /**
         * Description of the Execution
         */
        description?: string | null;
        /**
         * User provided display name of the Execution. May be up to 128 Unicode characters.
         */
        displayName?: string | null;
        /**
         * An eTag used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens.
         */
        etag?: string | null;
        /**
         * The labels with user-defined metadata to organize your Executions. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. No more than 64 user labels can be associated with one Execution (System labels are excluded).
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * Properties of the Execution. Top level metadata keys' heading and trailing spaces will be trimmed. The size of this field should not exceed 200KB.
         */
        metadata?: {
            [key: string]: any;
        } | null;
        /**
         * Output only. The resource name of the Execution.
         */
        name?: string | null;
        /**
         * The title of the schema describing the metadata. Schema title and version is expected to be registered in earlier Create Schema calls. And both are used together as unique identifiers to identify schemas within the local metadata store.
         */
        schemaTitle?: string | null;
        /**
         * The version of the schema in `schema_title` to use. Schema title and version is expected to be registered in earlier Create Schema calls. And both are used together as unique identifiers to identify schemas within the local metadata store.
         */
        schemaVersion?: string | null;
        /**
         * The state of this Execution. This is a property of the Execution, and does not imply or capture any ongoing process. This property is managed by clients (such as Vertex AI Pipelines) and the system does not prescribe or check the validity of state transitions.
         */
        state?: string | null;
        /**
         * Output only. Timestamp when this Execution was last updated.
         */
        updateTime?: string | null;
    }
    /**
     * Request message for PredictionService.Explain.
     */
    export interface Schema$GoogleCloudAiplatformV1ExplainRequest {
        /**
         * If specified, this ExplainRequest will be served by the chosen DeployedModel, overriding Endpoint.traffic_split.
         */
        deployedModelId?: string | null;
        /**
         * If specified, overrides the explanation_spec of the DeployedModel. Can be used for explaining prediction results with different configurations, such as: - Explaining top-5 predictions results as opposed to top-1; - Increasing path count or step count of the attribution methods to reduce approximate errors; - Using different baselines for explaining the prediction results.
         */
        explanationSpecOverride?: Schema$GoogleCloudAiplatformV1ExplanationSpecOverride;
        /**
         * Required. The instances that are the input to the explanation call. A DeployedModel may have an upper limit on the number of instances it supports per request, and when it is exceeded the explanation call errors in case of AutoML Models, or, in case of customer created Models, the behaviour is as documented by that Model. The schema of any single instance may be specified via Endpoint's DeployedModels' Model's PredictSchemata's instance_schema_uri.
         */
        instances?: any[] | null;
        /**
         * The parameters that govern the prediction. The schema of the parameters may be specified via Endpoint's DeployedModels' Model's PredictSchemata's parameters_schema_uri.
         */
        parameters?: any | null;
    }
    /**
     * Response message for PredictionService.Explain.
     */
    export interface Schema$GoogleCloudAiplatformV1ExplainResponse {
        /**
         * ID of the Endpoint's DeployedModel that served this explanation.
         */
        deployedModelId?: string | null;
        /**
         * The explanations of the Model's PredictResponse.predictions. It has the same number of elements as instances to be explained.
         */
        explanations?: Schema$GoogleCloudAiplatformV1Explanation[];
        /**
         * The predictions that are the output of the predictions call. Same as PredictResponse.predictions.
         */
        predictions?: any[] | null;
    }
    /**
     * Explanation of a prediction (provided in PredictResponse.predictions) produced by the Model on a given instance.
     */
    export interface Schema$GoogleCloudAiplatformV1Explanation {
        /**
         * Output only. Feature attributions grouped by predicted outputs. For Models that predict only one output, such as regression Models that predict only one score, there is only one attibution that explains the predicted output. For Models that predict multiple outputs, such as multiclass Models that predict multiple classes, each element explains one specific item. Attribution.output_index can be used to identify which output this attribution is explaining. If users set ExplanationParameters.top_k, the attributions are sorted by instance_output_value in descending order. If ExplanationParameters.output_indices is specified, the attributions are stored by Attribution.output_index in the same order as they appear in the output_indices.
         */
        attributions?: Schema$GoogleCloudAiplatformV1Attribution[];
        /**
         * Output only. List of the nearest neighbors for example-based explanations. For models deployed with the examples explanations feature enabled, the attributions field is empty and instead the neighbors field is populated.
         */
        neighbors?: Schema$GoogleCloudAiplatformV1Neighbor[];
    }
    /**
     * Metadata describing the Model's input and output for explanation.
     */
    export interface Schema$GoogleCloudAiplatformV1ExplanationMetadata {
        /**
         * Points to a YAML file stored on Google Cloud Storage describing the format of the feature attributions. The schema is defined as an OpenAPI 3.0.2 [Schema Object](https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.0.2.md#schemaObject). AutoML tabular Models always have this field populated by Vertex AI. Note: The URI given on output may be different, including the URI scheme, than the one given on input. The output URI will point to a location where the user only has a read access.
         */
        featureAttributionsSchemaUri?: string | null;
        /**
         * Required. Map from feature names to feature input metadata. Keys are the name of the features. Values are the specification of the feature. An empty InputMetadata is valid. It describes a text feature which has the name specified as the key in ExplanationMetadata.inputs. The baseline of the empty feature is chosen by Vertex AI. For Vertex AI-provided Tensorflow images, the key can be any friendly name of the feature. Once specified, featureAttributions are keyed by this key (if not grouped with another feature). For custom images, the key must match with the key in instance.
         */
        inputs?: {
            [key: string]: Schema$GoogleCloudAiplatformV1ExplanationMetadataInputMetadata;
        } | null;
        /**
         * Name of the source to generate embeddings for example based explanations.
         */
        latentSpaceSource?: string | null;
        /**
         * Required. Map from output names to output metadata. For Vertex AI-provided Tensorflow images, keys can be any user defined string that consists of any UTF-8 characters. For custom images, keys are the name of the output field in the prediction to be explained. Currently only one key is allowed.
         */
        outputs?: {
            [key: string]: Schema$GoogleCloudAiplatformV1ExplanationMetadataOutputMetadata;
        } | null;
    }
    /**
     * Metadata of the input of a feature. Fields other than InputMetadata.input_baselines are applicable only for Models that are using Vertex AI-provided images for Tensorflow.
     */
    export interface Schema$GoogleCloudAiplatformV1ExplanationMetadataInputMetadata {
        /**
         * Specifies the shape of the values of the input if the input is a sparse representation. Refer to Tensorflow documentation for more details: https://www.tensorflow.org/api_docs/python/tf/sparse/SparseTensor.
         */
        denseShapeTensorName?: string | null;
        /**
         * A list of baselines for the encoded tensor. The shape of each baseline should match the shape of the encoded tensor. If a scalar is provided, Vertex AI broadcasts to the same shape as the encoded tensor.
         */
        encodedBaselines?: any[] | null;
        /**
         * Encoded tensor is a transformation of the input tensor. Must be provided if choosing Integrated Gradients attribution or XRAI attribution and the input tensor is not differentiable. An encoded tensor is generated if the input tensor is encoded by a lookup table.
         */
        encodedTensorName?: string | null;
        /**
         * Defines how the feature is encoded into the input tensor. Defaults to IDENTITY.
         */
        encoding?: string | null;
        /**
         * The domain details of the input feature value. Like min/max, original mean or standard deviation if normalized.
         */
        featureValueDomain?: Schema$GoogleCloudAiplatformV1ExplanationMetadataInputMetadataFeatureValueDomain;
        /**
         * Name of the group that the input belongs to. Features with the same group name will be treated as one feature when computing attributions. Features grouped together can have different shapes in value. If provided, there will be one single attribution generated in Attribution.feature_attributions, keyed by the group name.
         */
        groupName?: string | null;
        /**
         * A list of feature names for each index in the input tensor. Required when the input InputMetadata.encoding is BAG_OF_FEATURES, BAG_OF_FEATURES_SPARSE, INDICATOR.
         */
        indexFeatureMapping?: string[] | null;
        /**
         * Specifies the index of the values of the input tensor. Required when the input tensor is a sparse representation. Refer to Tensorflow documentation for more details: https://www.tensorflow.org/api_docs/python/tf/sparse/SparseTensor.
         */
        indicesTensorName?: string | null;
        /**
         * Baseline inputs for this feature. If no baseline is specified, Vertex AI chooses the baseline for this feature. If multiple baselines are specified, Vertex AI returns the average attributions across them in Attribution.feature_attributions. For Vertex AI-provided Tensorflow images (both 1.x and 2.x), the shape of each baseline must match the shape of the input tensor. If a scalar is provided, we broadcast to the same shape as the input tensor. For custom images, the element of the baselines must be in the same format as the feature's input in the instance[]. The schema of any single instance may be specified via Endpoint's DeployedModels' Model's PredictSchemata's instance_schema_uri.
         */
        inputBaselines?: any[] | null;
        /**
         * Name of the input tensor for this feature. Required and is only applicable to Vertex AI-provided images for Tensorflow.
         */
        inputTensorName?: string | null;
        /**
         * Modality of the feature. Valid values are: numeric, image. Defaults to numeric.
         */
        modality?: string | null;
        /**
         * Visualization configurations for image explanation.
         */
        visualization?: Schema$GoogleCloudAiplatformV1ExplanationMetadataInputMetadataVisualization;
    }
    /**
     * Domain details of the input feature value. Provides numeric information about the feature, such as its range (min, max). If the feature has been pre-processed, for example with z-scoring, then it provides information about how to recover the original feature. For example, if the input feature is an image and it has been pre-processed to obtain 0-mean and stddev = 1 values, then original_mean, and original_stddev refer to the mean and stddev of the original feature (e.g. image tensor) from which input feature (with mean = 0 and stddev = 1) was obtained.
     */
    export interface Schema$GoogleCloudAiplatformV1ExplanationMetadataInputMetadataFeatureValueDomain {
        /**
         * The maximum permissible value for this feature.
         */
        maxValue?: number | null;
        /**
         * The minimum permissible value for this feature.
         */
        minValue?: number | null;
        /**
         * If this input feature has been normalized to a mean value of 0, the original_mean specifies the mean value of the domain prior to normalization.
         */
        originalMean?: number | null;
        /**
         * If this input feature has been normalized to a standard deviation of 1.0, the original_stddev specifies the standard deviation of the domain prior to normalization.
         */
        originalStddev?: number | null;
    }
    /**
     * Visualization configurations for image explanation.
     */
    export interface Schema$GoogleCloudAiplatformV1ExplanationMetadataInputMetadataVisualization {
        /**
         * Excludes attributions below the specified percentile, from the highlighted areas. Defaults to 62.
         */
        clipPercentLowerbound?: number | null;
        /**
         * Excludes attributions above the specified percentile from the highlighted areas. Using the clip_percent_upperbound and clip_percent_lowerbound together can be useful for filtering out noise and making it easier to see areas of strong attribution. Defaults to 99.9.
         */
        clipPercentUpperbound?: number | null;
        /**
         * The color scheme used for the highlighted areas. Defaults to PINK_GREEN for Integrated Gradients attribution, which shows positive attributions in green and negative in pink. Defaults to VIRIDIS for XRAI attribution, which highlights the most influential regions in yellow and the least influential in blue.
         */
        colorMap?: string | null;
        /**
         * How the original image is displayed in the visualization. Adjusting the overlay can help increase visual clarity if the original image makes it difficult to view the visualization. Defaults to NONE.
         */
        overlayType?: string | null;
        /**
         * Whether to only highlight pixels with positive contributions, negative or both. Defaults to POSITIVE.
         */
        polarity?: string | null;
        /**
         * Type of the image visualization. Only applicable to Integrated Gradients attribution. OUTLINES shows regions of attribution, while PIXELS shows per-pixel attribution. Defaults to OUTLINES.
         */
        type?: string | null;
    }
    /**
     * Metadata of the prediction output to be explained.
     */
    export interface Schema$GoogleCloudAiplatformV1ExplanationMetadataOutputMetadata {
        /**
         * Specify a field name in the prediction to look for the display name. Use this if the prediction contains the display names for the outputs. The display names in the prediction must have the same shape of the outputs, so that it can be located by Attribution.output_index for a specific output.
         */
        displayNameMappingKey?: string | null;
        /**
         * Static mapping between the index and display name. Use this if the outputs are a deterministic n-dimensional array, e.g. a list of scores of all the classes in a pre-defined order for a multi-classification Model. It's not feasible if the outputs are non-deterministic, e.g. the Model produces top-k classes or sort the outputs by their values. The shape of the value must be an n-dimensional array of strings. The number of dimensions must match that of the outputs to be explained. The Attribution.output_display_name is populated by locating in the mapping with Attribution.output_index.
         */
        indexDisplayNameMapping?: any | null;
        /**
         * Name of the output tensor. Required and is only applicable to Vertex AI provided images for Tensorflow.
         */
        outputTensorName?: string | null;
    }
    /**
     * The ExplanationMetadata entries that can be overridden at online explanation time.
     */
    export interface Schema$GoogleCloudAiplatformV1ExplanationMetadataOverride {
        /**
         * Required. Overrides the input metadata of the features. The key is the name of the feature to be overridden. The keys specified here must exist in the input metadata to be overridden. If a feature is not specified here, the corresponding feature's input metadata is not overridden.
         */
        inputs?: {
            [key: string]: Schema$GoogleCloudAiplatformV1ExplanationMetadataOverrideInputMetadataOverride;
        } | null;
    }
    /**
     * The input metadata entries to be overridden.
     */
    export interface Schema$GoogleCloudAiplatformV1ExplanationMetadataOverrideInputMetadataOverride {
        /**
         * Baseline inputs for this feature. This overrides the `input_baseline` field of the ExplanationMetadata.InputMetadata object of the corresponding feature's input metadata. If it's not specified, the original baselines are not overridden.
         */
        inputBaselines?: any[] | null;
    }
    /**
     * Parameters to configure explaining for Model's predictions.
     */
    export interface Schema$GoogleCloudAiplatformV1ExplanationParameters {
        /**
         * Example-based explanations that returns the nearest neighbors from the provided dataset.
         */
        examples?: Schema$GoogleCloudAiplatformV1Examples;
        /**
         * An attribution method that computes Aumann-Shapley values taking advantage of the model's fully differentiable structure. Refer to this paper for more details: https://arxiv.org/abs/1703.01365
         */
        integratedGradientsAttribution?: Schema$GoogleCloudAiplatformV1IntegratedGradientsAttribution;
        /**
         * If populated, only returns attributions that have output_index contained in output_indices. It must be an ndarray of integers, with the same shape of the output it's explaining. If not populated, returns attributions for top_k indices of outputs. If neither top_k nor output_indices is populated, returns the argmax index of the outputs. Only applicable to Models that predict multiple outputs (e,g, multi-class Models that predict multiple classes).
         */
        outputIndices?: any[] | null;
        /**
         * An attribution method that approximates Shapley values for features that contribute to the label being predicted. A sampling strategy is used to approximate the value rather than considering all subsets of features. Refer to this paper for model details: https://arxiv.org/abs/1306.4265.
         */
        sampledShapleyAttribution?: Schema$GoogleCloudAiplatformV1SampledShapleyAttribution;
        /**
         * If populated, returns attributions for top K indices of outputs (defaults to 1). Only applies to Models that predicts more than one outputs (e,g, multi-class Models). When set to -1, returns explanations for all outputs.
         */
        topK?: number | null;
        /**
         * An attribution method that redistributes Integrated Gradients attribution to segmented regions, taking advantage of the model's fully differentiable structure. Refer to this paper for more details: https://arxiv.org/abs/1906.02825 XRAI currently performs better on natural images, like a picture of a house or an animal. If the images are taken in artificial environments, like a lab or manufacturing line, or from diagnostic equipment, like x-rays or quality-control cameras, use Integrated Gradients instead.
         */
        xraiAttribution?: Schema$GoogleCloudAiplatformV1XraiAttribution;
    }
    /**
     * Specification of Model explanation.
     */
    export interface Schema$GoogleCloudAiplatformV1ExplanationSpec {
        /**
         * Optional. Metadata describing the Model's input and output for explanation.
         */
        metadata?: Schema$GoogleCloudAiplatformV1ExplanationMetadata;
        /**
         * Required. Parameters that configure explaining of the Model's predictions.
         */
        parameters?: Schema$GoogleCloudAiplatformV1ExplanationParameters;
    }
    /**
     * The ExplanationSpec entries that can be overridden at online explanation time.
     */
    export interface Schema$GoogleCloudAiplatformV1ExplanationSpecOverride {
        /**
         * The example-based explanations parameter overrides.
         */
        examplesOverride?: Schema$GoogleCloudAiplatformV1ExamplesOverride;
        /**
         * The metadata to be overridden. If not specified, no metadata is overridden.
         */
        metadata?: Schema$GoogleCloudAiplatformV1ExplanationMetadataOverride;
        /**
         * The parameters to be overridden. Note that the attribution method cannot be changed. If not specified, no parameter is overridden.
         */
        parameters?: Schema$GoogleCloudAiplatformV1ExplanationParameters;
    }
    /**
     * Describes what part of the Dataset is to be exported, the destination of the export and how to export.
     */
    export interface Schema$GoogleCloudAiplatformV1ExportDataConfig {
        /**
         * An expression for filtering what part of the Dataset is to be exported. Only Annotations that match this filter will be exported. The filter syntax is the same as in ListAnnotations.
         */
        annotationsFilter?: string | null;
        /**
         * Split based on fractions defining the size of each set.
         */
        fractionSplit?: Schema$GoogleCloudAiplatformV1ExportFractionSplit;
        /**
         * The Google Cloud Storage location where the output is to be written to. In the given directory a new directory will be created with name: `export-data--` where timestamp is in YYYY-MM-DDThh:mm:ss.sssZ ISO-8601 format. All export output will be written into that directory. Inside that directory, annotations with the same schema will be grouped into sub directories which are named with the corresponding annotations' schema title. Inside these sub directories, a schema.yaml will be created to describe the output format.
         */
        gcsDestination?: Schema$GoogleCloudAiplatformV1GcsDestination;
    }
    /**
     * Runtime operation information for DatasetService.ExportData.
     */
    export interface Schema$GoogleCloudAiplatformV1ExportDataOperationMetadata {
        /**
         * A Google Cloud Storage directory which path ends with '/'. The exported data is stored in the directory.
         */
        gcsOutputDirectory?: string | null;
        /**
         * The common part of the operation metadata.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
    }
    /**
     * Request message for DatasetService.ExportData.
     */
    export interface Schema$GoogleCloudAiplatformV1ExportDataRequest {
        /**
         * Required. The desired output location.
         */
        exportConfig?: Schema$GoogleCloudAiplatformV1ExportDataConfig;
    }
    /**
     * Response message for DatasetService.ExportData.
     */
    export interface Schema$GoogleCloudAiplatformV1ExportDataResponse {
        /**
         * All of the files that are exported in this export operation.
         */
        exportedFiles?: string[] | null;
    }
    /**
     * Details of operations that exports Features values.
     */
    export interface Schema$GoogleCloudAiplatformV1ExportFeatureValuesOperationMetadata {
        /**
         * Operation metadata for Featurestore export Feature values.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
    }
    /**
     * Request message for FeaturestoreService.ExportFeatureValues.
     */
    export interface Schema$GoogleCloudAiplatformV1ExportFeatureValuesRequest {
        /**
         * Required. Specifies destination location and format.
         */
        destination?: Schema$GoogleCloudAiplatformV1FeatureValueDestination;
        /**
         * Required. Selects Features to export values of.
         */
        featureSelector?: Schema$GoogleCloudAiplatformV1FeatureSelector;
        /**
         * Exports all historical values of all entities of the EntityType within a time range
         */
        fullExport?: Schema$GoogleCloudAiplatformV1ExportFeatureValuesRequestFullExport;
        /**
         * Per-Feature export settings.
         */
        settings?: Schema$GoogleCloudAiplatformV1DestinationFeatureSetting[];
        /**
         * Exports the latest Feature values of all entities of the EntityType within a time range.
         */
        snapshotExport?: Schema$GoogleCloudAiplatformV1ExportFeatureValuesRequestSnapshotExport;
    }
    /**
     * Describes exporting all historical Feature values of all entities of the EntityType between [start_time, end_time].
     */
    export interface Schema$GoogleCloudAiplatformV1ExportFeatureValuesRequestFullExport {
        /**
         * Exports Feature values as of this timestamp. If not set, retrieve values as of now. Timestamp, if present, must not have higher than millisecond precision.
         */
        endTime?: string | null;
        /**
         * Excludes Feature values with feature generation timestamp before this timestamp. If not set, retrieve oldest values kept in Feature Store. Timestamp, if present, must not have higher than millisecond precision.
         */
        startTime?: string | null;
    }
    /**
     * Describes exporting the latest Feature values of all entities of the EntityType between [start_time, snapshot_time].
     */
    export interface Schema$GoogleCloudAiplatformV1ExportFeatureValuesRequestSnapshotExport {
        /**
         * Exports Feature values as of this timestamp. If not set, retrieve values as of now. Timestamp, if present, must not have higher than millisecond precision.
         */
        snapshotTime?: string | null;
        /**
         * Excludes Feature values with feature generation timestamp before this timestamp. If not set, retrieve oldest values kept in Feature Store. Timestamp, if present, must not have higher than millisecond precision.
         */
        startTime?: string | null;
    }
    /**
     * Response message for FeaturestoreService.ExportFeatureValues.
     */
    export interface Schema$GoogleCloudAiplatformV1ExportFeatureValuesResponse {
    }
    /**
     * Assigns the input data to training, validation, and test sets as per the given fractions. Any of `training_fraction`, `validation_fraction` and `test_fraction` may optionally be provided, they must sum to up to 1. If the provided ones sum to less than 1, the remainder is assigned to sets as decided by Vertex AI. If none of the fractions are set, by default roughly 80% of data is used for training, 10% for validation, and 10% for test.
     */
    export interface Schema$GoogleCloudAiplatformV1ExportFractionSplit {
        /**
         * The fraction of the input data that is to be used to evaluate the Model.
         */
        testFraction?: number | null;
        /**
         * The fraction of the input data that is to be used to train the Model.
         */
        trainingFraction?: number | null;
        /**
         * The fraction of the input data that is to be used to validate the Model.
         */
        validationFraction?: number | null;
    }
    /**
     * Details of ModelService.ExportModel operation.
     */
    export interface Schema$GoogleCloudAiplatformV1ExportModelOperationMetadata {
        /**
         * The common part of the operation metadata.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
        /**
         * Output only. Information further describing the output of this Model export.
         */
        outputInfo?: Schema$GoogleCloudAiplatformV1ExportModelOperationMetadataOutputInfo;
    }
    /**
     * Further describes the output of the ExportModel. Supplements ExportModelRequest.OutputConfig.
     */
    export interface Schema$GoogleCloudAiplatformV1ExportModelOperationMetadataOutputInfo {
        /**
         * Output only. If the Model artifact is being exported to Google Cloud Storage this is the full path of the directory created, into which the Model files are being written to.
         */
        artifactOutputUri?: string | null;
        /**
         * Output only. If the Model image is being exported to Google Container Registry or Artifact Registry this is the full path of the image created.
         */
        imageOutputUri?: string | null;
    }
    /**
     * Request message for ModelService.ExportModel.
     */
    export interface Schema$GoogleCloudAiplatformV1ExportModelRequest {
        /**
         * Required. The desired output location and configuration.
         */
        outputConfig?: Schema$GoogleCloudAiplatformV1ExportModelRequestOutputConfig;
    }
    /**
     * Output configuration for the Model export.
     */
    export interface Schema$GoogleCloudAiplatformV1ExportModelRequestOutputConfig {
        /**
         * The Cloud Storage location where the Model artifact is to be written to. Under the directory given as the destination a new one with name "`model-export--`", where timestamp is in YYYY-MM-DDThh:mm:ss.sssZ ISO-8601 format, will be created. Inside, the Model and any of its supporting files will be written. This field should only be set when the `exportableContent` field of the [Model.supported_export_formats] object contains `ARTIFACT`.
         */
        artifactDestination?: Schema$GoogleCloudAiplatformV1GcsDestination;
        /**
         * The ID of the format in which the Model must be exported. Each Model lists the export formats it supports. If no value is provided here, then the first from the list of the Model's supported formats is used by default.
         */
        exportFormatId?: string | null;
        /**
         * The Google Container Registry or Artifact Registry uri where the Model container image will be copied to. This field should only be set when the `exportableContent` field of the [Model.supported_export_formats] object contains `IMAGE`.
         */
        imageDestination?: Schema$GoogleCloudAiplatformV1ContainerRegistryDestination;
    }
    /**
     * Response message of ModelService.ExportModel operation.
     */
    export interface Schema$GoogleCloudAiplatformV1ExportModelResponse {
    }
    /**
     * Request message for TensorboardService.ExportTensorboardTimeSeriesData.
     */
    export interface Schema$GoogleCloudAiplatformV1ExportTensorboardTimeSeriesDataRequest {
        /**
         * Exports the TensorboardTimeSeries' data that match the filter expression.
         */
        filter?: string | null;
        /**
         * Field to use to sort the TensorboardTimeSeries' data. By default, TensorboardTimeSeries' data is returned in a pseudo random order.
         */
        orderBy?: string | null;
        /**
         * The maximum number of data points to return per page. The default page_size is 1000. Values must be between 1 and 10000. Values above 10000 are coerced to 10000.
         */
        pageSize?: number | null;
        /**
         * A page token, received from a previous ExportTensorboardTimeSeriesData call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to ExportTensorboardTimeSeriesData must match the call that provided the page token.
         */
        pageToken?: string | null;
    }
    /**
     * Response message for TensorboardService.ExportTensorboardTimeSeriesData.
     */
    export interface Schema$GoogleCloudAiplatformV1ExportTensorboardTimeSeriesDataResponse {
        /**
         * A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.
         */
        nextPageToken?: string | null;
        /**
         * The returned time series data points.
         */
        timeSeriesDataPoints?: Schema$GoogleCloudAiplatformV1TimeSeriesDataPoint[];
    }
    /**
     * Feature Metadata information that describes an attribute of an entity type. For example, apple is an entity type, and color is a feature that describes apple.
     */
    export interface Schema$GoogleCloudAiplatformV1Feature {
        /**
         * Output only. Timestamp when this EntityType was created.
         */
        createTime?: string | null;
        /**
         * Description of the Feature.
         */
        description?: string | null;
        /**
         * Optional. If not set, use the monitoring_config defined for the EntityType this Feature belongs to. Only Features with type (Feature.ValueType) BOOL, STRING, DOUBLE or INT64 can enable monitoring. If set to true, all types of data monitoring are disabled despite the config on EntityType.
         */
        disableMonitoring?: boolean | null;
        /**
         * Used to perform a consistent read-modify-write updates. If not set, a blind "overwrite" update happens.
         */
        etag?: string | null;
        /**
         * Optional. The labels with user-defined metadata to organize your Features. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information on and examples of labels. No more than 64 user labels can be associated with one Feature (System labels are excluded)." System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * Output only. The list of historical stats and anomalies with specified objectives.
         */
        monitoringStatsAnomalies?: Schema$GoogleCloudAiplatformV1FeatureMonitoringStatsAnomaly[];
        /**
         * Immutable. Name of the Feature. Format: `projects/{project\}/locations/{location\}/featurestores/{featurestore\}/entityTypes/{entity_type\}/features/{feature\}` The last part feature is assigned by the client. The feature can be up to 64 characters long and can consist only of ASCII Latin letters A-Z and a-z, underscore(_), and ASCII digits 0-9 starting with a letter. The value will be unique given an entity type.
         */
        name?: string | null;
        /**
         * Output only. Timestamp when this EntityType was most recently updated.
         */
        updateTime?: string | null;
        /**
         * Immutable. Type of Feature value.
         */
        valueType?: string | null;
    }
    /**
     * A list of historical SnapshotAnalysis or ImportFeaturesAnalysis stats requested by user, sorted by FeatureStatsAnomaly.start_time descending.
     */
    export interface Schema$GoogleCloudAiplatformV1FeatureMonitoringStatsAnomaly {
        /**
         * Output only. The stats and anomalies generated at specific timestamp.
         */
        featureStatsAnomaly?: Schema$GoogleCloudAiplatformV1FeatureStatsAnomaly;
        /**
         * Output only. The objective for each stats.
         */
        objective?: string | null;
    }
    /**
     * Noise sigma by features. Noise sigma represents the standard deviation of the gaussian kernel that will be used to add noise to interpolated inputs prior to computing gradients.
     */
    export interface Schema$GoogleCloudAiplatformV1FeatureNoiseSigma {
        /**
         * Noise sigma per feature. No noise is added to features that are not set.
         */
        noiseSigma?: Schema$GoogleCloudAiplatformV1FeatureNoiseSigmaNoiseSigmaForFeature[];
    }
    /**
     * Noise sigma for a single feature.
     */
    export interface Schema$GoogleCloudAiplatformV1FeatureNoiseSigmaNoiseSigmaForFeature {
        /**
         * The name of the input feature for which noise sigma is provided. The features are defined in explanation metadata inputs.
         */
        name?: string | null;
        /**
         * This represents the standard deviation of the Gaussian kernel that will be used to add noise to the feature prior to computing gradients. Similar to noise_sigma but represents the noise added to the current feature. Defaults to 0.1.
         */
        sigma?: number | null;
    }
    /**
     * Selector for Features of an EntityType.
     */
    export interface Schema$GoogleCloudAiplatformV1FeatureSelector {
        /**
         * Required. Matches Features based on ID.
         */
        idMatcher?: Schema$GoogleCloudAiplatformV1IdMatcher;
    }
    /**
     * Stats and Anomaly generated at specific timestamp for specific Feature. The start_time and end_time are used to define the time range of the dataset that current stats belongs to, e.g. prediction traffic is bucketed into prediction datasets by time window. If the Dataset is not defined by time window, start_time = end_time. Timestamp of the stats and anomalies always refers to end_time. Raw stats and anomalies are stored in stats_uri or anomaly_uri in the tensorflow defined protos. Field data_stats contains almost identical information with the raw stats in Vertex AI defined proto, for UI to display.
     */
    export interface Schema$GoogleCloudAiplatformV1FeatureStatsAnomaly {
        /**
         * This is the threshold used when detecting anomalies. The threshold can be changed by user, so this one might be different from ThresholdConfig.value.
         */
        anomalyDetectionThreshold?: number | null;
        /**
         * Path of the anomaly file for current feature values in Cloud Storage bucket. Format: gs:////anomalies. Example: gs://monitoring_bucket/feature_name/anomalies. Stats are stored as binary format with Protobuf message Anoamlies are stored as binary format with Protobuf message [tensorflow.metadata.v0.AnomalyInfo] (https://github.com/tensorflow/metadata/blob/master/tensorflow_metadata/proto/v0/anomalies.proto).
         */
        anomalyUri?: string | null;
        /**
         * Deviation from the current stats to baseline stats. 1. For categorical feature, the distribution distance is calculated by L-inifinity norm. 2. For numerical feature, the distribution distance is calculated by Jensen–Shannon divergence.
         */
        distributionDeviation?: number | null;
        /**
         * The end timestamp of window where stats were generated. For objectives where time window doesn't make sense (e.g. Featurestore Snapshot Monitoring), end_time indicates the timestamp of the data used to generate stats (e.g. timestamp we take snapshots for feature values).
         */
        endTime?: string | null;
        /**
         * Feature importance score, only populated when cross-feature monitoring is enabled. For now only used to represent feature attribution score within range [0, 1] for ModelDeploymentMonitoringObjectiveType.FEATURE_ATTRIBUTION_SKEW and ModelDeploymentMonitoringObjectiveType.FEATURE_ATTRIBUTION_DRIFT.
         */
        score?: number | null;
        /**
         * The start timestamp of window where stats were generated. For objectives where time window doesn't make sense (e.g. Featurestore Snapshot Monitoring), start_time is only used to indicate the monitoring intervals, so it always equals to (end_time - monitoring_interval).
         */
        startTime?: string | null;
        /**
         * Path of the stats file for current feature values in Cloud Storage bucket. Format: gs:////stats. Example: gs://monitoring_bucket/feature_name/stats. Stats are stored as binary format with Protobuf message [tensorflow.metadata.v0.FeatureNameStatistics](https://github.com/tensorflow/metadata/blob/master/tensorflow_metadata/proto/v0/statistics.proto).
         */
        statsUri?: string | null;
    }
    /**
     * Vertex AI Feature Store provides a centralized repository for organizing, storing, and serving ML features. The Featurestore is a top-level container for your features and their values.
     */
    export interface Schema$GoogleCloudAiplatformV1Featurestore {
        /**
         * Output only. Timestamp when this Featurestore was created.
         */
        createTime?: string | null;
        /**
         * Optional. Customer-managed encryption key spec for data storage. If set, both of the online and offline data storage will be secured by this key.
         */
        encryptionSpec?: Schema$GoogleCloudAiplatformV1EncryptionSpec;
        /**
         * Optional. Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens.
         */
        etag?: string | null;
        /**
         * Optional. The labels with user-defined metadata to organize your Featurestore. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information on and examples of labels. No more than 64 user labels can be associated with one Featurestore(System labels are excluded)." System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * Output only. Name of the Featurestore. Format: `projects/{project\}/locations/{location\}/featurestores/{featurestore\}`
         */
        name?: string | null;
        /**
         * Optional. Config for online storage resources. The field should not co-exist with the field of `OnlineStoreReplicationConfig`. If both of it and OnlineStoreReplicationConfig are unset, the feature store will not have an online store and cannot be used for online serving.
         */
        onlineServingConfig?: Schema$GoogleCloudAiplatformV1FeaturestoreOnlineServingConfig;
        /**
         * Optional. TTL in days for feature values that will be stored in online serving storage. The Feature Store online storage periodically removes obsolete feature values older than `online_storage_ttl_days` since the feature generation time. Note that `online_storage_ttl_days` should be less than or equal to `offline_storage_ttl_days` for each EntityType under a featurestore. If not set, default to 4000 days
         */
        onlineStorageTtlDays?: number | null;
        /**
         * Output only. State of the featurestore.
         */
        state?: string | null;
        /**
         * Output only. Timestamp when this Featurestore was last updated.
         */
        updateTime?: string | null;
    }
    /**
     * Configuration of how features in Featurestore are monitored.
     */
    export interface Schema$GoogleCloudAiplatformV1FeaturestoreMonitoringConfig {
        /**
         * Threshold for categorical features of anomaly detection. This is shared by all types of Featurestore Monitoring for categorical features (i.e. Features with type (Feature.ValueType) BOOL or STRING).
         */
        categoricalThresholdConfig?: Schema$GoogleCloudAiplatformV1FeaturestoreMonitoringConfigThresholdConfig;
        /**
         * The config for ImportFeatures Analysis Based Feature Monitoring.
         */
        importFeaturesAnalysis?: Schema$GoogleCloudAiplatformV1FeaturestoreMonitoringConfigImportFeaturesAnalysis;
        /**
         * Threshold for numerical features of anomaly detection. This is shared by all objectives of Featurestore Monitoring for numerical features (i.e. Features with type (Feature.ValueType) DOUBLE or INT64).
         */
        numericalThresholdConfig?: Schema$GoogleCloudAiplatformV1FeaturestoreMonitoringConfigThresholdConfig;
        /**
         * The config for Snapshot Analysis Based Feature Monitoring.
         */
        snapshotAnalysis?: Schema$GoogleCloudAiplatformV1FeaturestoreMonitoringConfigSnapshotAnalysis;
    }
    /**
     * Configuration of the Featurestore's ImportFeature Analysis Based Monitoring. This type of analysis generates statistics for values of each Feature imported by every ImportFeatureValues operation.
     */
    export interface Schema$GoogleCloudAiplatformV1FeaturestoreMonitoringConfigImportFeaturesAnalysis {
        /**
         * The baseline used to do anomaly detection for the statistics generated by import features analysis.
         */
        anomalyDetectionBaseline?: string | null;
        /**
         * Whether to enable / disable / inherite default hebavior for import features analysis.
         */
        state?: string | null;
    }
    /**
     * Configuration of the Featurestore's Snapshot Analysis Based Monitoring. This type of analysis generates statistics for each Feature based on a snapshot of the latest feature value of each entities every monitoring_interval.
     */
    export interface Schema$GoogleCloudAiplatformV1FeaturestoreMonitoringConfigSnapshotAnalysis {
        /**
         * The monitoring schedule for snapshot analysis. For EntityType-level config: unset / disabled = true indicates disabled by default for Features under it; otherwise by default enable snapshot analysis monitoring with monitoring_interval for Features under it. Feature-level config: disabled = true indicates disabled regardless of the EntityType-level config; unset monitoring_interval indicates going with EntityType-level config; otherwise run snapshot analysis monitoring with monitoring_interval regardless of the EntityType-level config. Explicitly Disable the snapshot analysis based monitoring.
         */
        disabled?: boolean | null;
        /**
         * Configuration of the snapshot analysis based monitoring pipeline running interval. The value indicates number of days.
         */
        monitoringIntervalDays?: number | null;
        /**
         * Customized export features time window for snapshot analysis. Unit is one day. Default value is 3 weeks. Minimum value is 1 day. Maximum value is 4000 days.
         */
        stalenessDays?: number | null;
    }
    /**
     * The config for Featurestore Monitoring threshold.
     */
    export interface Schema$GoogleCloudAiplatformV1FeaturestoreMonitoringConfigThresholdConfig {
        /**
         * Specify a threshold value that can trigger the alert. 1. For categorical feature, the distribution distance is calculated by L-inifinity norm. 2. For numerical feature, the distribution distance is calculated by Jensen–Shannon divergence. Each feature must have a non-zero threshold if they need to be monitored. Otherwise no alert will be triggered for that feature.
         */
        value?: number | null;
    }
    /**
     * OnlineServingConfig specifies the details for provisioning online serving resources.
     */
    export interface Schema$GoogleCloudAiplatformV1FeaturestoreOnlineServingConfig {
        /**
         * The number of nodes for the online store. The number of nodes doesn't scale automatically, but you can manually update the number of nodes. If set to 0, the featurestore will not have an online store and cannot be used for online serving.
         */
        fixedNodeCount?: number | null;
        /**
         * Online serving scaling configuration. Only one of `fixed_node_count` and `scaling` can be set. Setting one will reset the other.
         */
        scaling?: Schema$GoogleCloudAiplatformV1FeaturestoreOnlineServingConfigScaling;
    }
    /**
     * Online serving scaling configuration. If min_node_count and max_node_count are set to the same value, the cluster will be configured with the fixed number of node (no auto-scaling).
     */
    export interface Schema$GoogleCloudAiplatformV1FeaturestoreOnlineServingConfigScaling {
        /**
         * Optional. The cpu utilization that the Autoscaler should be trying to achieve. This number is on a scale from 0 (no utilization) to 100 (total utilization), and is limited between 10 and 80. When a cluster's CPU utilization exceeds the target that you have set, Bigtable immediately adds nodes to the cluster. When CPU utilization is substantially lower than the target, Bigtable removes nodes. If not set or set to 0, default to 50.
         */
        cpuUtilizationTarget?: number | null;
        /**
         * The maximum number of nodes to scale up to. Must be greater than min_node_count, and less than or equal to 10 times of 'min_node_count'.
         */
        maxNodeCount?: number | null;
        /**
         * Required. The minimum number of nodes to scale down to. Must be greater than or equal to 1.
         */
        minNodeCount?: number | null;
    }
    /**
     * Value for a feature.
     */
    export interface Schema$GoogleCloudAiplatformV1FeatureValue {
        /**
         * A list of bool type feature value.
         */
        boolArrayValue?: Schema$GoogleCloudAiplatformV1BoolArray;
        /**
         * Bool type feature value.
         */
        boolValue?: boolean | null;
        /**
         * Bytes feature value.
         */
        bytesValue?: string | null;
        /**
         * A list of double type feature value.
         */
        doubleArrayValue?: Schema$GoogleCloudAiplatformV1DoubleArray;
        /**
         * Double type feature value.
         */
        doubleValue?: number | null;
        /**
         * A list of int64 type feature value.
         */
        int64ArrayValue?: Schema$GoogleCloudAiplatformV1Int64Array;
        /**
         * Int64 feature value.
         */
        int64Value?: string | null;
        /**
         * Metadata of feature value.
         */
        metadata?: Schema$GoogleCloudAiplatformV1FeatureValueMetadata;
        /**
         * A list of string type feature value.
         */
        stringArrayValue?: Schema$GoogleCloudAiplatformV1StringArray;
        /**
         * String feature value.
         */
        stringValue?: string | null;
    }
    /**
     * A destination location for Feature values and format.
     */
    export interface Schema$GoogleCloudAiplatformV1FeatureValueDestination {
        /**
         * Output in BigQuery format. BigQueryDestination.output_uri in FeatureValueDestination.bigquery_destination must refer to a table.
         */
        bigqueryDestination?: Schema$GoogleCloudAiplatformV1BigQueryDestination;
        /**
         * Output in CSV format. Array Feature value types are not allowed in CSV format.
         */
        csvDestination?: Schema$GoogleCloudAiplatformV1CsvDestination;
        /**
         * Output in TFRecord format. Below are the mapping from Feature value type in Featurestore to Feature value type in TFRecord: Value type in Featurestore | Value type in TFRecord DOUBLE, DOUBLE_ARRAY | FLOAT_LIST INT64, INT64_ARRAY | INT64_LIST STRING, STRING_ARRAY, BYTES | BYTES_LIST true -\> byte_string("true"), false -\> byte_string("false") BOOL, BOOL_ARRAY (true, false) | BYTES_LIST
         */
        tfrecordDestination?: Schema$GoogleCloudAiplatformV1TFRecordDestination;
    }
    /**
     * Container for list of values.
     */
    export interface Schema$GoogleCloudAiplatformV1FeatureValueList {
        /**
         * A list of feature values. All of them should be the same data type.
         */
        values?: Schema$GoogleCloudAiplatformV1FeatureValue[];
    }
    /**
     * Metadata of feature value.
     */
    export interface Schema$GoogleCloudAiplatformV1FeatureValueMetadata {
        /**
         * Feature generation timestamp. Typically, it is provided by user at feature ingestion time. If not, feature store will use the system timestamp when the data is ingested into feature store. For streaming ingestion, the time, aligned by days, must be no older than five years (1825 days) and no later than one year (366 days) in the future.
         */
        generateTime?: string | null;
    }
    /**
     * Assigns input data to training, validation, and test sets based on the given filters, data pieces not matched by any filter are ignored. Currently only supported for Datasets containing DataItems. If any of the filters in this message are to match nothing, then they can be set as '-' (the minus sign). Supported only for unstructured Datasets.
     */
    export interface Schema$GoogleCloudAiplatformV1FilterSplit {
        /**
         * Required. A filter on DataItems of the Dataset. DataItems that match this filter are used to test the Model. A filter with same syntax as the one used in DatasetService.ListDataItems may be used. If a single DataItem is matched by more than one of the FilterSplit filters, then it is assigned to the first set that applies to it in the training, validation, test order.
         */
        testFilter?: string | null;
        /**
         * Required. A filter on DataItems of the Dataset. DataItems that match this filter are used to train the Model. A filter with same syntax as the one used in DatasetService.ListDataItems may be used. If a single DataItem is matched by more than one of the FilterSplit filters, then it is assigned to the first set that applies to it in the training, validation, test order.
         */
        trainingFilter?: string | null;
        /**
         * Required. A filter on DataItems of the Dataset. DataItems that match this filter are used to validate the Model. A filter with same syntax as the one used in DatasetService.ListDataItems may be used. If a single DataItem is matched by more than one of the FilterSplit filters, then it is assigned to the first set that applies to it in the training, validation, test order.
         */
        validationFilter?: string | null;
    }
    /**
     * The request message for MatchService.FindNeighbors.
     */
    export interface Schema$GoogleCloudAiplatformV1FindNeighborsRequest {
        /**
         * The ID of the DeployedIndex that will serve the request. This request is sent to a specific IndexEndpoint, as per the IndexEndpoint.network. That IndexEndpoint also has IndexEndpoint.deployed_indexes, and each such index has a DeployedIndex.id field. The value of the field below must equal one of the DeployedIndex.id fields of the IndexEndpoint that is being called for this request.
         */
        deployedIndexId?: string | null;
        /**
         * The list of queries.
         */
        queries?: Schema$GoogleCloudAiplatformV1FindNeighborsRequestQuery[];
        /**
         * If set to true, the full datapoints (including all vector values and restricts) of the nearest neighbors are returned. Note that returning full datapoint will significantly increase the latency and cost of the query.
         */
        returnFullDatapoint?: boolean | null;
    }
    /**
     * A query to find a number of the nearest neighbors (most similar vectors) of a vector.
     */
    export interface Schema$GoogleCloudAiplatformV1FindNeighborsRequestQuery {
        /**
         * The number of neighbors to find via approximate search before exact reordering is performed. If not set, the default value from scam config is used; if set, this value must be \> 0.
         */
        approximateNeighborCount?: number | null;
        /**
         * Required. The datapoint/vector whose nearest neighbors should be searched for.
         */
        datapoint?: Schema$GoogleCloudAiplatformV1IndexDatapoint;
        /**
         * The fraction of the number of leaves to search, set at query time allows user to tune search performance. This value increase result in both search accuracy and latency increase. The value should be between 0.0 and 1.0. If not set or set to 0.0, query uses the default value specified in NearestNeighborSearchConfig.TreeAHConfig.fraction_leaf_nodes_to_search.
         */
        fractionLeafNodesToSearchOverride?: number | null;
        /**
         * The number of nearest neighbors to be retrieved from database for each query. If not set, will use the default from the service configuration (https://cloud.google.com/vertex-ai/docs/matching-engine/configuring-indexes#nearest-neighbor-search-config).
         */
        neighborCount?: number | null;
        /**
         * Crowding is a constraint on a neighbor list produced by nearest neighbor search requiring that no more than some value k' of the k neighbors returned have the same value of crowding_attribute. It's used for improving result diversity. This field is the maximum number of matches with the same crowding tag.
         */
        perCrowdingAttributeNeighborCount?: number | null;
    }
    /**
     * The response message for MatchService.FindNeighbors.
     */
    export interface Schema$GoogleCloudAiplatformV1FindNeighborsResponse {
        /**
         * The nearest neighbors of the query datapoints.
         */
        nearestNeighbors?: Schema$GoogleCloudAiplatformV1FindNeighborsResponseNearestNeighbors[];
    }
    /**
     * Nearest neighbors for one query.
     */
    export interface Schema$GoogleCloudAiplatformV1FindNeighborsResponseNearestNeighbors {
        /**
         * The ID of the query datapoint.
         */
        id?: string | null;
        /**
         * All its neighbors.
         */
        neighbors?: Schema$GoogleCloudAiplatformV1FindNeighborsResponseNeighbor[];
    }
    /**
     * A neighbor of the query vector.
     */
    export interface Schema$GoogleCloudAiplatformV1FindNeighborsResponseNeighbor {
        /**
         * The datapoint of the neighbor. Note that full datapoints are returned only when "return_full_datapoint" is set to true. Otherwise, only the "datapoint_id" and "crowding_tag" fields are populated.
         */
        datapoint?: Schema$GoogleCloudAiplatformV1IndexDatapoint;
        /**
         * The distance between the neighbor and the query vector.
         */
        distance?: number | null;
    }
    /**
     * Assigns the input data to training, validation, and test sets as per the given fractions. Any of `training_fraction`, `validation_fraction` and `test_fraction` may optionally be provided, they must sum to up to 1. If the provided ones sum to less than 1, the remainder is assigned to sets as decided by Vertex AI. If none of the fractions are set, by default roughly 80% of data is used for training, 10% for validation, and 10% for test.
     */
    export interface Schema$GoogleCloudAiplatformV1FractionSplit {
        /**
         * The fraction of the input data that is to be used to evaluate the Model.
         */
        testFraction?: number | null;
        /**
         * The fraction of the input data that is to be used to train the Model.
         */
        trainingFraction?: number | null;
        /**
         * The fraction of the input data that is to be used to validate the Model.
         */
        validationFraction?: number | null;
    }
    /**
     * The Google Cloud Storage location where the output is to be written to.
     */
    export interface Schema$GoogleCloudAiplatformV1GcsDestination {
        /**
         * Required. Google Cloud Storage URI to output directory. If the uri doesn't end with '/', a '/' will be automatically appended. The directory is created if it doesn't exist.
         */
        outputUriPrefix?: string | null;
    }
    /**
     * The Google Cloud Storage location for the input content.
     */
    export interface Schema$GoogleCloudAiplatformV1GcsSource {
        /**
         * Required. Google Cloud Storage URI(-s) to the input file(s). May contain wildcards. For more information on wildcards, see https://cloud.google.com/storage/docs/gsutil/addlhelp/WildcardNames.
         */
        uris?: string[] | null;
    }
    /**
     * Generic Metadata shared by all operations.
     */
    export interface Schema$GoogleCloudAiplatformV1GenericOperationMetadata {
        /**
         * Output only. Time when the operation was created.
         */
        createTime?: string | null;
        /**
         * Output only. Partial failures encountered. E.g. single files that couldn't be read. This field should never exceed 20 entries. Status details field will contain standard Google Cloud error details.
         */
        partialFailures?: Schema$GoogleRpcStatus[];
        /**
         * Output only. Time when the operation was updated for the last time. If the operation has finished (successfully or not), this is the finish time.
         */
        updateTime?: string | null;
    }
    /**
     * Represents a HyperparameterTuningJob. A HyperparameterTuningJob has a Study specification and multiple CustomJobs with identical CustomJob specification.
     */
    export interface Schema$GoogleCloudAiplatformV1HyperparameterTuningJob {
        /**
         * Output only. Time when the HyperparameterTuningJob was created.
         */
        createTime?: string | null;
        /**
         * Required. The display name of the HyperparameterTuningJob. The name can be up to 128 characters long and can consist of any UTF-8 characters.
         */
        displayName?: string | null;
        /**
         * Customer-managed encryption key options for a HyperparameterTuningJob. If this is set, then all resources created by the HyperparameterTuningJob will be encrypted with the provided encryption key.
         */
        encryptionSpec?: Schema$GoogleCloudAiplatformV1EncryptionSpec;
        /**
         * Output only. Time when the HyperparameterTuningJob entered any of the following states: `JOB_STATE_SUCCEEDED`, `JOB_STATE_FAILED`, `JOB_STATE_CANCELLED`.
         */
        endTime?: string | null;
        /**
         * Output only. Only populated when job's state is JOB_STATE_FAILED or JOB_STATE_CANCELLED.
         */
        error?: Schema$GoogleRpcStatus;
        /**
         * The labels with user-defined metadata to organize HyperparameterTuningJobs. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * The number of failed Trials that need to be seen before failing the HyperparameterTuningJob. If set to 0, Vertex AI decides how many Trials must fail before the whole job fails.
         */
        maxFailedTrialCount?: number | null;
        /**
         * Required. The desired total number of Trials.
         */
        maxTrialCount?: number | null;
        /**
         * Output only. Resource name of the HyperparameterTuningJob.
         */
        name?: string | null;
        /**
         * Required. The desired number of Trials to run in parallel.
         */
        parallelTrialCount?: number | null;
        /**
         * Output only. Time when the HyperparameterTuningJob for the first time entered the `JOB_STATE_RUNNING` state.
         */
        startTime?: string | null;
        /**
         * Output only. The detailed state of the job.
         */
        state?: string | null;
        /**
         * Required. Study configuration of the HyperparameterTuningJob.
         */
        studySpec?: Schema$GoogleCloudAiplatformV1StudySpec;
        /**
         * Required. The spec of a trial job. The same spec applies to the CustomJobs created in all the trials.
         */
        trialJobSpec?: Schema$GoogleCloudAiplatformV1CustomJobSpec;
        /**
         * Output only. Trials of the HyperparameterTuningJob.
         */
        trials?: Schema$GoogleCloudAiplatformV1Trial[];
        /**
         * Output only. Time when the HyperparameterTuningJob was most recently updated.
         */
        updateTime?: string | null;
    }
    /**
     * Matcher for Features of an EntityType by Feature ID.
     */
    export interface Schema$GoogleCloudAiplatformV1IdMatcher {
        /**
         * Required. The following are accepted as `ids`: * A single-element list containing only `*`, which selects all Features in the target EntityType, or * A list containing only Feature IDs, which selects only Features with those IDs in the target EntityType.
         */
        ids?: string[] | null;
    }
    /**
     * Describes the location from where we import data into a Dataset, together with the labels that will be applied to the DataItems and the Annotations.
     */
    export interface Schema$GoogleCloudAiplatformV1ImportDataConfig {
        /**
         * Labels that will be applied to newly imported Annotations. If two Annotations are identical, one of them will be deduped. Two Annotations are considered identical if their payload, payload_schema_uri and all of their labels are the same. These labels will be overridden by Annotation labels specified inside index file referenced by import_schema_uri, e.g. jsonl file.
         */
        annotationLabels?: {
            [key: string]: string;
        } | null;
        /**
         * Labels that will be applied to newly imported DataItems. If an identical DataItem as one being imported already exists in the Dataset, then these labels will be appended to these of the already existing one, and if labels with identical key is imported before, the old label value will be overwritten. If two DataItems are identical in the same import data operation, the labels will be combined and if key collision happens in this case, one of the values will be picked randomly. Two DataItems are considered identical if their content bytes are identical (e.g. image bytes or pdf bytes). These labels will be overridden by Annotation labels specified inside index file referenced by import_schema_uri, e.g. jsonl file.
         */
        dataItemLabels?: {
            [key: string]: string;
        } | null;
        /**
         * The Google Cloud Storage location for the input content.
         */
        gcsSource?: Schema$GoogleCloudAiplatformV1GcsSource;
        /**
         * Required. Points to a YAML file stored on Google Cloud Storage describing the import format. Validation will be done against the schema. The schema is defined as an [OpenAPI 3.0.2 Schema Object](https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.0.2.md#schemaObject).
         */
        importSchemaUri?: string | null;
    }
    /**
     * Runtime operation information for DatasetService.ImportData.
     */
    export interface Schema$GoogleCloudAiplatformV1ImportDataOperationMetadata {
        /**
         * The common part of the operation metadata.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
    }
    /**
     * Request message for DatasetService.ImportData.
     */
    export interface Schema$GoogleCloudAiplatformV1ImportDataRequest {
        /**
         * Required. The desired input locations. The contents of all input locations will be imported in one batch.
         */
        importConfigs?: Schema$GoogleCloudAiplatformV1ImportDataConfig[];
    }
    /**
     * Response message for DatasetService.ImportData.
     */
    export interface Schema$GoogleCloudAiplatformV1ImportDataResponse {
    }
    /**
     * Details of operations that perform import Feature values.
     */
    export interface Schema$GoogleCloudAiplatformV1ImportFeatureValuesOperationMetadata {
        /**
         * List of ImportFeatureValues operations running under a single EntityType that are blocking this operation.
         */
        blockingOperationIds?: string[] | null;
        /**
         * Operation metadata for Featurestore import Feature values.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
        /**
         * Number of entities that have been imported by the operation.
         */
        importedEntityCount?: string | null;
        /**
         * Number of Feature values that have been imported by the operation.
         */
        importedFeatureValueCount?: string | null;
        /**
         * The number of rows in input source that weren't imported due to either * Not having any featureValues. * Having a null entityId. * Having a null timestamp. * Not being parsable (applicable for CSV sources).
         */
        invalidRowCount?: string | null;
        /**
         * The source URI from where Feature values are imported.
         */
        sourceUris?: string[] | null;
        /**
         * The number rows that weren't ingested due to having timestamps outside the retention boundary.
         */
        timestampOutsideRetentionRowsCount?: string | null;
    }
    /**
     * Request message for FeaturestoreService.ImportFeatureValues.
     */
    export interface Schema$GoogleCloudAiplatformV1ImportFeatureValuesRequest {
        avroSource?: Schema$GoogleCloudAiplatformV1AvroSource;
        bigquerySource?: Schema$GoogleCloudAiplatformV1BigQuerySource;
        csvSource?: Schema$GoogleCloudAiplatformV1CsvSource;
        /**
         * If true, API doesn't start ingestion analysis pipeline.
         */
        disableIngestionAnalysis?: boolean | null;
        /**
         * If set, data will not be imported for online serving. This is typically used for backfilling, where Feature generation timestamps are not in the timestamp range needed for online serving.
         */
        disableOnlineServing?: boolean | null;
        /**
         * Source column that holds entity IDs. If not provided, entity IDs are extracted from the column named entity_id.
         */
        entityIdField?: string | null;
        /**
         * Required. Specifications defining which Feature values to import from the entity. The request fails if no feature_specs are provided, and having multiple feature_specs for one Feature is not allowed.
         */
        featureSpecs?: Schema$GoogleCloudAiplatformV1ImportFeatureValuesRequestFeatureSpec[];
        /**
         * Single Feature timestamp for all entities being imported. The timestamp must not have higher than millisecond precision.
         */
        featureTime?: string | null;
        /**
         * Source column that holds the Feature timestamp for all Feature values in each entity.
         */
        featureTimeField?: string | null;
        /**
         * Specifies the number of workers that are used to write data to the Featurestore. Consider the online serving capacity that you require to achieve the desired import throughput without interfering with online serving. The value must be positive, and less than or equal to 100. If not set, defaults to using 1 worker. The low count ensures minimal impact on online serving performance.
         */
        workerCount?: number | null;
    }
    /**
     * Defines the Feature value(s) to import.
     */
    export interface Schema$GoogleCloudAiplatformV1ImportFeatureValuesRequestFeatureSpec {
        /**
         * Required. ID of the Feature to import values of. This Feature must exist in the target EntityType, or the request will fail.
         */
        id?: string | null;
        /**
         * Source column to get the Feature values from. If not set, uses the column with the same name as the Feature ID.
         */
        sourceField?: string | null;
    }
    /**
     * Response message for FeaturestoreService.ImportFeatureValues.
     */
    export interface Schema$GoogleCloudAiplatformV1ImportFeatureValuesResponse {
        /**
         * Number of entities that have been imported by the operation.
         */
        importedEntityCount?: string | null;
        /**
         * Number of Feature values that have been imported by the operation.
         */
        importedFeatureValueCount?: string | null;
        /**
         * The number of rows in input source that weren't imported due to either * Not having any featureValues. * Having a null entityId. * Having a null timestamp. * Not being parsable (applicable for CSV sources).
         */
        invalidRowCount?: string | null;
        /**
         * The number rows that weren't ingested due to having feature timestamps outside the retention boundary.
         */
        timestampOutsideRetentionRowsCount?: string | null;
    }
    /**
     * Request message for ModelService.ImportModelEvaluation
     */
    export interface Schema$GoogleCloudAiplatformV1ImportModelEvaluationRequest {
        /**
         * Required. Model evaluation resource to be imported.
         */
        modelEvaluation?: Schema$GoogleCloudAiplatformV1ModelEvaluation;
    }
    /**
     * A representation of a collection of database items organized in a way that allows for approximate nearest neighbor (a.k.a ANN) algorithms search.
     */
    export interface Schema$GoogleCloudAiplatformV1Index {
        /**
         * Output only. Timestamp when this Index was created.
         */
        createTime?: string | null;
        /**
         * Output only. The pointers to DeployedIndexes created from this Index. An Index can be only deleted if all its DeployedIndexes had been undeployed first.
         */
        deployedIndexes?: Schema$GoogleCloudAiplatformV1DeployedIndexRef[];
        /**
         * The description of the Index.
         */
        description?: string | null;
        /**
         * Required. The display name of the Index. The name can be up to 128 characters long and can consist of any UTF-8 characters.
         */
        displayName?: string | null;
        /**
         * Immutable. Customer-managed encryption key spec for an Index. If set, this Index and all sub-resources of this Index will be secured by this key.
         */
        encryptionSpec?: Schema$GoogleCloudAiplatformV1EncryptionSpec;
        /**
         * Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens.
         */
        etag?: string | null;
        /**
         * Output only. Stats of the index resource.
         */
        indexStats?: Schema$GoogleCloudAiplatformV1IndexStats;
        /**
         * Immutable. The update method to use with this Index. If not set, BATCH_UPDATE will be used by default.
         */
        indexUpdateMethod?: string | null;
        /**
         * The labels with user-defined metadata to organize your Indexes. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * An additional information about the Index; the schema of the metadata can be found in metadata_schema.
         */
        metadata?: any | null;
        /**
         * Immutable. Points to a YAML file stored on Google Cloud Storage describing additional information about the Index, that is specific to it. Unset if the Index does not have any additional information. The schema is defined as an OpenAPI 3.0.2 [Schema Object](https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.0.2.md#schemaObject). Note: The URI given on output will be immutable and probably different, including the URI scheme, than the one given on input. The output URI will point to a location where the user only has a read access.
         */
        metadataSchemaUri?: string | null;
        /**
         * Output only. The resource name of the Index.
         */
        name?: string | null;
        /**
         * Output only. Timestamp when this Index was most recently updated. This also includes any update to the contents of the Index. Note that Operations working on this Index may have their Operations.metadata.generic_metadata.update_time a little after the value of this timestamp, yet that does not mean their results are not already reflected in the Index. Result of any successfully completed Operation on the Index is reflected in it.
         */
        updateTime?: string | null;
    }
    /**
     * A datapoint of Index.
     */
    export interface Schema$GoogleCloudAiplatformV1IndexDatapoint {
        /**
         * Optional. CrowdingTag of the datapoint, the number of neighbors to return in each crowding can be configured during query.
         */
        crowdingTag?: Schema$GoogleCloudAiplatformV1IndexDatapointCrowdingTag;
        /**
         * Required. Unique identifier of the datapoint.
         */
        datapointId?: string | null;
        /**
         * Required. Feature embedding vector. An array of numbers with the length of [NearestNeighborSearchConfig.dimensions].
         */
        featureVector?: number[] | null;
        /**
         * Optional. List of Restrict of the datapoint, used to perform "restricted searches" where boolean rule are used to filter the subset of the database eligible for matching. This uses categorical tokens. See: https://cloud.google.com/vertex-ai/docs/matching-engine/filtering
         */
        restricts?: Schema$GoogleCloudAiplatformV1IndexDatapointRestriction[];
    }
    /**
     * Crowding tag is a constraint on a neighbor list produced by nearest neighbor search requiring that no more than some value k' of the k neighbors returned have the same value of crowding_attribute.
     */
    export interface Schema$GoogleCloudAiplatformV1IndexDatapointCrowdingTag {
        /**
         * The attribute value used for crowding. The maximum number of neighbors to return per crowding attribute value (per_crowding_attribute_num_neighbors) is configured per-query. This field is ignored if per_crowding_attribute_num_neighbors is larger than the total number of neighbors to return for a given query.
         */
        crowdingAttribute?: string | null;
    }
    /**
     * Restriction of a datapoint which describe its attributes(tokens) from each of several attribute categories(namespaces).
     */
    export interface Schema$GoogleCloudAiplatformV1IndexDatapointRestriction {
        /**
         * The attributes to allow in this namespace. e.g.: 'red'
         */
        allowList?: string[] | null;
        /**
         * The attributes to deny in this namespace. e.g.: 'blue'
         */
        denyList?: string[] | null;
        /**
         * The namespace of this restriction. e.g.: color.
         */
        namespace?: string | null;
    }
    /**
     * Indexes are deployed into it. An IndexEndpoint can have multiple DeployedIndexes.
     */
    export interface Schema$GoogleCloudAiplatformV1IndexEndpoint {
        /**
         * Output only. Timestamp when this IndexEndpoint was created.
         */
        createTime?: string | null;
        /**
         * Output only. The indexes deployed in this endpoint.
         */
        deployedIndexes?: Schema$GoogleCloudAiplatformV1DeployedIndex[];
        /**
         * The description of the IndexEndpoint.
         */
        description?: string | null;
        /**
         * Required. The display name of the IndexEndpoint. The name can be up to 128 characters long and can consist of any UTF-8 characters.
         */
        displayName?: string | null;
        /**
         * Optional. Deprecated: If true, expose the IndexEndpoint via private service connect. Only one of the fields, network or enable_private_service_connect, can be set.
         */
        enablePrivateServiceConnect?: boolean | null;
        /**
         * Immutable. Customer-managed encryption key spec for an IndexEndpoint. If set, this IndexEndpoint and all sub-resources of this IndexEndpoint will be secured by this key.
         */
        encryptionSpec?: Schema$GoogleCloudAiplatformV1EncryptionSpec;
        /**
         * Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens.
         */
        etag?: string | null;
        /**
         * The labels with user-defined metadata to organize your IndexEndpoints. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * Output only. The resource name of the IndexEndpoint.
         */
        name?: string | null;
        /**
         * Optional. The full name of the Google Compute Engine [network](https://cloud.google.com/compute/docs/networks-and-firewalls#networks) to which the IndexEndpoint should be peered. Private services access must already be configured for the network. If left unspecified, the Endpoint is not peered with any network. network and private_service_connect_config are mutually exclusive. [Format](https://cloud.google.com/compute/docs/reference/rest/v1/networks/insert): `projects/{project\}/global/networks/{network\}`. Where {project\} is a project number, as in '12345', and {network\} is network name.
         */
        network?: string | null;
        /**
         * Optional. Configuration for private service connect. network and private_service_connect_config are mutually exclusive.
         */
        privateServiceConnectConfig?: Schema$GoogleCloudAiplatformV1PrivateServiceConnectConfig;
        /**
         * Output only. If public_endpoint_enabled is true, this field will be populated with the domain name to use for this index endpoint.
         */
        publicEndpointDomainName?: string | null;
        /**
         * Optional. If true, the deployed index will be accessible through public endpoint.
         */
        publicEndpointEnabled?: boolean | null;
        /**
         * Output only. Timestamp when this IndexEndpoint was last updated. This timestamp is not updated when the endpoint's DeployedIndexes are updated, e.g. due to updates of the original Indexes they are the deployments of.
         */
        updateTime?: string | null;
    }
    /**
     * IndexPrivateEndpoints proto is used to provide paths for users to send requests via private endpoints (e.g. private service access, private service connect). To send request via private service access, use match_grpc_address. To send request via private service connect, use service_attachment.
     */
    export interface Schema$GoogleCloudAiplatformV1IndexPrivateEndpoints {
        /**
         * Output only. The ip address used to send match gRPC requests.
         */
        matchGrpcAddress?: string | null;
        /**
         * Output only. The name of the service attachment resource. Populated if private service connect is enabled.
         */
        serviceAttachment?: string | null;
    }
    /**
     * Stats of the Index.
     */
    export interface Schema$GoogleCloudAiplatformV1IndexStats {
        /**
         * Output only. The number of shards in the Index.
         */
        shardsCount?: number | null;
        /**
         * Output only. The number of vectors in the Index.
         */
        vectorsCount?: string | null;
    }
    /**
     * Specifies Vertex AI owned input data to be used for training, and possibly evaluating, the Model.
     */
    export interface Schema$GoogleCloudAiplatformV1InputDataConfig {
        /**
         * Applicable only to custom training with Datasets that have DataItems and Annotations. Cloud Storage URI that points to a YAML file describing the annotation schema. The schema is defined as an OpenAPI 3.0.2 [Schema Object](https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.0.2.md#schemaObject). The schema files that can be used here are found in gs://google-cloud-aiplatform/schema/dataset/annotation/ , note that the chosen schema must be consistent with metadata of the Dataset specified by dataset_id. Only Annotations that both match this schema and belong to DataItems not ignored by the split method are used in respectively training, validation or test role, depending on the role of the DataItem they are on. When used in conjunction with annotations_filter, the Annotations used for training are filtered by both annotations_filter and annotation_schema_uri.
         */
        annotationSchemaUri?: string | null;
        /**
         * Applicable only to Datasets that have DataItems and Annotations. A filter on Annotations of the Dataset. Only Annotations that both match this filter and belong to DataItems not ignored by the split method are used in respectively training, validation or test role, depending on the role of the DataItem they are on (for the auto-assigned that role is decided by Vertex AI). A filter with same syntax as the one used in ListAnnotations may be used, but note here it filters across all Annotations of the Dataset, and not just within a single DataItem.
         */
        annotationsFilter?: string | null;
        /**
         * Only applicable to custom training with tabular Dataset with BigQuery source. The BigQuery project location where the training data is to be written to. In the given project a new dataset is created with name `dataset___` where timestamp is in YYYY_MM_DDThh_mm_ss_sssZ format. All training input data is written into that dataset. In the dataset three tables are created, `training`, `validation` and `test`. * AIP_DATA_FORMAT = "bigquery". * AIP_TRAINING_DATA_URI = "bigquery_destination.dataset___.training" * AIP_VALIDATION_DATA_URI = "bigquery_destination.dataset___.validation" * AIP_TEST_DATA_URI = "bigquery_destination.dataset___.test"
         */
        bigqueryDestination?: Schema$GoogleCloudAiplatformV1BigQueryDestination;
        /**
         * Required. The ID of the Dataset in the same Project and Location which data will be used to train the Model. The Dataset must use schema compatible with Model being trained, and what is compatible should be described in the used TrainingPipeline's training_task_definition. For tabular Datasets, all their data is exported to training, to pick and choose from.
         */
        datasetId?: string | null;
        /**
         * Split based on the provided filters for each set.
         */
        filterSplit?: Schema$GoogleCloudAiplatformV1FilterSplit;
        /**
         * Split based on fractions defining the size of each set.
         */
        fractionSplit?: Schema$GoogleCloudAiplatformV1FractionSplit;
        /**
         * The Cloud Storage location where the training data is to be written to. In the given directory a new directory is created with name: `dataset---` where timestamp is in YYYY-MM-DDThh:mm:ss.sssZ ISO-8601 format. All training input data is written into that directory. The Vertex AI environment variables representing Cloud Storage data URIs are represented in the Cloud Storage wildcard format to support sharded data. e.g.: "gs://.../training-*.jsonl" * AIP_DATA_FORMAT = "jsonl" for non-tabular data, "csv" for tabular data * AIP_TRAINING_DATA_URI = "gcs_destination/dataset---/training-*.${AIP_DATA_FORMAT\}" * AIP_VALIDATION_DATA_URI = "gcs_destination/dataset---/validation-*.${AIP_DATA_FORMAT\}" * AIP_TEST_DATA_URI = "gcs_destination/dataset---/test-*.${AIP_DATA_FORMAT\}"
         */
        gcsDestination?: Schema$GoogleCloudAiplatformV1GcsDestination;
        /**
         * Whether to persist the ML use assignment to data item system labels.
         */
        persistMlUseAssignment?: boolean | null;
        /**
         * Supported only for tabular Datasets. Split based on a predefined key.
         */
        predefinedSplit?: Schema$GoogleCloudAiplatformV1PredefinedSplit;
        /**
         * Only applicable to Datasets that have SavedQueries. The ID of a SavedQuery (annotation set) under the Dataset specified by dataset_id used for filtering Annotations for training. Only Annotations that are associated with this SavedQuery are used in respectively training. When used in conjunction with annotations_filter, the Annotations used for training are filtered by both saved_query_id and annotations_filter. Only one of saved_query_id and annotation_schema_uri should be specified as both of them represent the same thing: problem type.
         */
        savedQueryId?: string | null;
        /**
         * Supported only for tabular Datasets. Split based on the distribution of the specified column.
         */
        stratifiedSplit?: Schema$GoogleCloudAiplatformV1StratifiedSplit;
        /**
         * Supported only for tabular Datasets. Split based on the timestamp of the input data pieces.
         */
        timestampSplit?: Schema$GoogleCloudAiplatformV1TimestampSplit;
    }
    /**
     * A list of int64 values.
     */
    export interface Schema$GoogleCloudAiplatformV1Int64Array {
        /**
         * A list of int64 values.
         */
        values?: string[] | null;
    }
    /**
     * An attribution method that computes the Aumann-Shapley value taking advantage of the model's fully differentiable structure. Refer to this paper for more details: https://arxiv.org/abs/1703.01365
     */
    export interface Schema$GoogleCloudAiplatformV1IntegratedGradientsAttribution {
        /**
         * Config for IG with blur baseline. When enabled, a linear path from the maximally blurred image to the input image is created. Using a blurred baseline instead of zero (black image) is motivated by the BlurIG approach explained here: https://arxiv.org/abs/2004.03383
         */
        blurBaselineConfig?: Schema$GoogleCloudAiplatformV1BlurBaselineConfig;
        /**
         * Config for SmoothGrad approximation of gradients. When enabled, the gradients are approximated by averaging the gradients from noisy samples in the vicinity of the inputs. Adding noise can help improve the computed gradients. Refer to this paper for more details: https://arxiv.org/pdf/1706.03825.pdf
         */
        smoothGradConfig?: Schema$GoogleCloudAiplatformV1SmoothGradConfig;
        /**
         * Required. The number of steps for approximating the path integral. A good value to start is 50 and gradually increase until the sum to diff property is within the desired error range. Valid range of its value is [1, 100], inclusively.
         */
        stepCount?: number | null;
    }
    /**
     * Contains information about the Large Model.
     */
    export interface Schema$GoogleCloudAiplatformV1LargeModelReference {
        /**
         * Required. The unique name of the large Foundation or pre-built model. Like "chat-bison", "text-bison". Or model name with version ID, like "chat-bison@001", "text-bison@005", etc.
         */
        name?: string | null;
    }
    /**
     * A subgraph of the overall lineage graph. Event edges connect Artifact and Execution nodes.
     */
    export interface Schema$GoogleCloudAiplatformV1LineageSubgraph {
        /**
         * The Artifact nodes in the subgraph.
         */
        artifacts?: Schema$GoogleCloudAiplatformV1Artifact[];
        /**
         * The Event edges between Artifacts and Executions in the subgraph.
         */
        events?: Schema$GoogleCloudAiplatformV1Event[];
        /**
         * The Execution nodes in the subgraph.
         */
        executions?: Schema$GoogleCloudAiplatformV1Execution[];
    }
    /**
     * Response message for DatasetService.ListAnnotations.
     */
    export interface Schema$GoogleCloudAiplatformV1ListAnnotationsResponse {
        /**
         * A list of Annotations that matches the specified filter in the request.
         */
        annotations?: Schema$GoogleCloudAiplatformV1Annotation[];
        /**
         * The standard List next-page token.
         */
        nextPageToken?: string | null;
    }
    /**
     * Response message for MetadataService.ListArtifacts.
     */
    export interface Schema$GoogleCloudAiplatformV1ListArtifactsResponse {
        /**
         * The Artifacts retrieved from the MetadataStore.
         */
        artifacts?: Schema$GoogleCloudAiplatformV1Artifact[];
        /**
         * A token, which can be sent as ListArtifactsRequest.page_token to retrieve the next page. If this field is not populated, there are no subsequent pages.
         */
        nextPageToken?: string | null;
    }
    /**
     * Response message for JobService.ListBatchPredictionJobs
     */
    export interface Schema$GoogleCloudAiplatformV1ListBatchPredictionJobsResponse {
        /**
         * List of BatchPredictionJobs in the requested page.
         */
        batchPredictionJobs?: Schema$GoogleCloudAiplatformV1BatchPredictionJob[];
        /**
         * A token to retrieve the next page of results. Pass to ListBatchPredictionJobsRequest.page_token to obtain that page.
         */
        nextPageToken?: string | null;
    }
    /**
     * Response message for MetadataService.ListContexts.
     */
    export interface Schema$GoogleCloudAiplatformV1ListContextsResponse {
        /**
         * The Contexts retrieved from the MetadataStore.
         */
        contexts?: Schema$GoogleCloudAiplatformV1Context[];
        /**
         * A token, which can be sent as ListContextsRequest.page_token to retrieve the next page. If this field is not populated, there are no subsequent pages.
         */
        nextPageToken?: string | null;
    }
    /**
     * Response message for JobService.ListCustomJobs
     */
    export interface Schema$GoogleCloudAiplatformV1ListCustomJobsResponse {
        /**
         * List of CustomJobs in the requested page.
         */
        customJobs?: Schema$GoogleCloudAiplatformV1CustomJob[];
        /**
         * A token to retrieve the next page of results. Pass to ListCustomJobsRequest.page_token to obtain that page.
         */
        nextPageToken?: string | null;
    }
    /**
     * Response message for DatasetService.ListDataItems.
     */
    export interface Schema$GoogleCloudAiplatformV1ListDataItemsResponse {
        /**
         * A list of DataItems that matches the specified filter in the request.
         */
        dataItems?: Schema$GoogleCloudAiplatformV1DataItem[];
        /**
         * The standard List next-page token.
         */
        nextPageToken?: string | null;
    }
    /**
     * Response message for JobService.ListDataLabelingJobs.
     */
    export interface Schema$GoogleCloudAiplatformV1ListDataLabelingJobsResponse {
        /**
         * A list of DataLabelingJobs that matches the specified filter in the request.
         */
        dataLabelingJobs?: Schema$GoogleCloudAiplatformV1DataLabelingJob[];
        /**
         * The standard List next-page token.
         */
        nextPageToken?: string | null;
    }
    /**
     * Response message for DatasetService.ListDatasets.
     */
    export interface Schema$GoogleCloudAiplatformV1ListDatasetsResponse {
        /**
         * A list of Datasets that matches the specified filter in the request.
         */
        datasets?: Schema$GoogleCloudAiplatformV1Dataset[];
        /**
         * The standard List next-page token.
         */
        nextPageToken?: string | null;
    }
    /**
     * Response message for DatasetService.ListDatasetVersions.
     */
    export interface Schema$GoogleCloudAiplatformV1ListDatasetVersionsResponse {
        /**
         * A list of DatasetVersions that matches the specified filter in the request.
         */
        datasetVersions?: Schema$GoogleCloudAiplatformV1DatasetVersion[];
        /**
         * The standard List next-page token.
         */
        nextPageToken?: string | null;
    }
    /**
     * Response message for EndpointService.ListEndpoints.
     */
    export interface Schema$GoogleCloudAiplatformV1ListEndpointsResponse {
        /**
         * List of Endpoints in the requested page.
         */
        endpoints?: Schema$GoogleCloudAiplatformV1Endpoint[];
        /**
         * A token to retrieve the next page of results. Pass to ListEndpointsRequest.page_token to obtain that page.
         */
        nextPageToken?: string | null;
    }
    /**
     * Response message for FeaturestoreService.ListEntityTypes.
     */
    export interface Schema$GoogleCloudAiplatformV1ListEntityTypesResponse {
        /**
         * The EntityTypes matching the request.
         */
        entityTypes?: Schema$GoogleCloudAiplatformV1EntityType[];
        /**
         * A token, which can be sent as ListEntityTypesRequest.page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.
         */
        nextPageToken?: string | null;
    }
    /**
     * Response message for MetadataService.ListExecutions.
     */
    export interface Schema$GoogleCloudAiplatformV1ListExecutionsResponse {
        /**
         * The Executions retrieved from the MetadataStore.
         */
        executions?: Schema$GoogleCloudAiplatformV1Execution[];
        /**
         * A token, which can be sent as ListExecutionsRequest.page_token to retrieve the next page. If this field is not populated, there are no subsequent pages.
         */
        nextPageToken?: string | null;
    }
    /**
     * Response message for FeaturestoreService.ListFeatures. Response message for FeatureRegistryService.ListFeatures.
     */
    export interface Schema$GoogleCloudAiplatformV1ListFeaturesResponse {
        /**
         * The Features matching the request.
         */
        features?: Schema$GoogleCloudAiplatformV1Feature[];
        /**
         * A token, which can be sent as ListFeaturesRequest.page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.
         */
        nextPageToken?: string | null;
    }
    /**
     * Response message for FeaturestoreService.ListFeaturestores.
     */
    export interface Schema$GoogleCloudAiplatformV1ListFeaturestoresResponse {
        /**
         * The Featurestores matching the request.
         */
        featurestores?: Schema$GoogleCloudAiplatformV1Featurestore[];
        /**
         * A token, which can be sent as ListFeaturestoresRequest.page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.
         */
        nextPageToken?: string | null;
    }
    /**
     * Response message for JobService.ListHyperparameterTuningJobs
     */
    export interface Schema$GoogleCloudAiplatformV1ListHyperparameterTuningJobsResponse {
        /**
         * List of HyperparameterTuningJobs in the requested page. HyperparameterTuningJob.trials of the jobs will be not be returned.
         */
        hyperparameterTuningJobs?: Schema$GoogleCloudAiplatformV1HyperparameterTuningJob[];
        /**
         * A token to retrieve the next page of results. Pass to ListHyperparameterTuningJobsRequest.page_token to obtain that page.
         */
        nextPageToken?: string | null;
    }
    /**
     * Response message for IndexEndpointService.ListIndexEndpoints.
     */
    export interface Schema$GoogleCloudAiplatformV1ListIndexEndpointsResponse {
        /**
         * List of IndexEndpoints in the requested page.
         */
        indexEndpoints?: Schema$GoogleCloudAiplatformV1IndexEndpoint[];
        /**
         * A token to retrieve next page of results. Pass to ListIndexEndpointsRequest.page_token to obtain that page.
         */
        nextPageToken?: string | null;
    }
    /**
     * Response message for IndexService.ListIndexes.
     */
    export interface Schema$GoogleCloudAiplatformV1ListIndexesResponse {
        /**
         * List of indexes in the requested page.
         */
        indexes?: Schema$GoogleCloudAiplatformV1Index[];
        /**
         * A token to retrieve next page of results. Pass to ListIndexesRequest.page_token to obtain that page.
         */
        nextPageToken?: string | null;
    }
    /**
     * Response message for MetadataService.ListMetadataSchemas.
     */
    export interface Schema$GoogleCloudAiplatformV1ListMetadataSchemasResponse {
        /**
         * The MetadataSchemas found for the MetadataStore.
         */
        metadataSchemas?: Schema$GoogleCloudAiplatformV1MetadataSchema[];
        /**
         * A token, which can be sent as ListMetadataSchemasRequest.page_token to retrieve the next page. If this field is not populated, there are no subsequent pages.
         */
        nextPageToken?: string | null;
    }
    /**
     * Response message for MetadataService.ListMetadataStores.
     */
    export interface Schema$GoogleCloudAiplatformV1ListMetadataStoresResponse {
        /**
         * The MetadataStores found for the Location.
         */
        metadataStores?: Schema$GoogleCloudAiplatformV1MetadataStore[];
        /**
         * A token, which can be sent as ListMetadataStoresRequest.page_token to retrieve the next page. If this field is not populated, there are no subsequent pages.
         */
        nextPageToken?: string | null;
    }
    /**
     * Response message for JobService.ListModelDeploymentMonitoringJobs.
     */
    export interface Schema$GoogleCloudAiplatformV1ListModelDeploymentMonitoringJobsResponse {
        /**
         * A list of ModelDeploymentMonitoringJobs that matches the specified filter in the request.
         */
        modelDeploymentMonitoringJobs?: Schema$GoogleCloudAiplatformV1ModelDeploymentMonitoringJob[];
        /**
         * The standard List next-page token.
         */
        nextPageToken?: string | null;
    }
    /**
     * Response message for ModelService.ListModelEvaluationSlices.
     */
    export interface Schema$GoogleCloudAiplatformV1ListModelEvaluationSlicesResponse {
        /**
         * List of ModelEvaluations in the requested page.
         */
        modelEvaluationSlices?: Schema$GoogleCloudAiplatformV1ModelEvaluationSlice[];
        /**
         * A token to retrieve next page of results. Pass to ListModelEvaluationSlicesRequest.page_token to obtain that page.
         */
        nextPageToken?: string | null;
    }
    /**
     * Response message for ModelService.ListModelEvaluations.
     */
    export interface Schema$GoogleCloudAiplatformV1ListModelEvaluationsResponse {
        /**
         * List of ModelEvaluations in the requested page.
         */
        modelEvaluations?: Schema$GoogleCloudAiplatformV1ModelEvaluation[];
        /**
         * A token to retrieve next page of results. Pass to ListModelEvaluationsRequest.page_token to obtain that page.
         */
        nextPageToken?: string | null;
    }
    /**
     * Response message for ModelService.ListModels
     */
    export interface Schema$GoogleCloudAiplatformV1ListModelsResponse {
        /**
         * List of Models in the requested page.
         */
        models?: Schema$GoogleCloudAiplatformV1Model[];
        /**
         * A token to retrieve next page of results. Pass to ListModelsRequest.page_token to obtain that page.
         */
        nextPageToken?: string | null;
    }
    /**
     * Response message for ModelService.ListModelVersions
     */
    export interface Schema$GoogleCloudAiplatformV1ListModelVersionsResponse {
        /**
         * List of Model versions in the requested page. In the returned Model name field, version ID instead of regvision tag will be included.
         */
        models?: Schema$GoogleCloudAiplatformV1Model[];
        /**
         * A token to retrieve the next page of results. Pass to ListModelVersionsRequest.page_token to obtain that page.
         */
        nextPageToken?: string | null;
    }
    /**
     * Response message for JobService.ListNasJobs
     */
    export interface Schema$GoogleCloudAiplatformV1ListNasJobsResponse {
        /**
         * List of NasJobs in the requested page. NasJob.nas_job_output of the jobs will not be returned.
         */
        nasJobs?: Schema$GoogleCloudAiplatformV1NasJob[];
        /**
         * A token to retrieve the next page of results. Pass to ListNasJobsRequest.page_token to obtain that page.
         */
        nextPageToken?: string | null;
    }
    /**
     * Response message for JobService.ListNasTrialDetails
     */
    export interface Schema$GoogleCloudAiplatformV1ListNasTrialDetailsResponse {
        /**
         * List of top NasTrials in the requested page.
         */
        nasTrialDetails?: Schema$GoogleCloudAiplatformV1NasTrialDetail[];
        /**
         * A token to retrieve the next page of results. Pass to ListNasTrialDetailsRequest.page_token to obtain that page.
         */
        nextPageToken?: string | null;
    }
    /**
     * Response message for NotebookService.ListNotebookRuntimes.
     */
    export interface Schema$GoogleCloudAiplatformV1ListNotebookRuntimesResponse {
        /**
         * A token to retrieve next page of results. Pass to ListNotebookRuntimesRequest.page_token to obtain that page.
         */
        nextPageToken?: string | null;
        /**
         * List of NotebookRuntimes in the requested page.
         */
        notebookRuntimes?: Schema$GoogleCloudAiplatformV1NotebookRuntime[];
    }
    /**
     * Response message for NotebookService.ListNotebookRuntimeTemplates.
     */
    export interface Schema$GoogleCloudAiplatformV1ListNotebookRuntimeTemplatesResponse {
        /**
         * A token to retrieve next page of results. Pass to ListNotebookRuntimeTemplatesRequest.page_token to obtain that page.
         */
        nextPageToken?: string | null;
        /**
         * List of NotebookRuntimeTemplates in the requested page.
         */
        notebookRuntimeTemplates?: Schema$GoogleCloudAiplatformV1NotebookRuntimeTemplate[];
    }
    /**
     * Request message for VizierService.ListOptimalTrials.
     */
    export interface Schema$GoogleCloudAiplatformV1ListOptimalTrialsRequest {
    }
    /**
     * Response message for VizierService.ListOptimalTrials.
     */
    export interface Schema$GoogleCloudAiplatformV1ListOptimalTrialsResponse {
        /**
         * The pareto-optimal Trials for multiple objective Study or the optimal trial for single objective Study. The definition of pareto-optimal can be checked in wiki page. https://en.wikipedia.org/wiki/Pareto_efficiency
         */
        optimalTrials?: Schema$GoogleCloudAiplatformV1Trial[];
    }
    /**
     * Response message for PipelineService.ListPipelineJobs
     */
    export interface Schema$GoogleCloudAiplatformV1ListPipelineJobsResponse {
        /**
         * A token to retrieve the next page of results. Pass to ListPipelineJobsRequest.page_token to obtain that page.
         */
        nextPageToken?: string | null;
        /**
         * List of PipelineJobs in the requested page.
         */
        pipelineJobs?: Schema$GoogleCloudAiplatformV1PipelineJob[];
    }
    /**
     * Response message for DatasetService.ListSavedQueries.
     */
    export interface Schema$GoogleCloudAiplatformV1ListSavedQueriesResponse {
        /**
         * The standard List next-page token.
         */
        nextPageToken?: string | null;
        /**
         * A list of SavedQueries that match the specified filter in the request.
         */
        savedQueries?: Schema$GoogleCloudAiplatformV1SavedQuery[];
    }
    /**
     * Response message for ScheduleService.ListSchedules
     */
    export interface Schema$GoogleCloudAiplatformV1ListSchedulesResponse {
        /**
         * A token to retrieve the next page of results. Pass to ListSchedulesRequest.page_token to obtain that page.
         */
        nextPageToken?: string | null;
        /**
         * List of Schedules in the requested page.
         */
        schedules?: Schema$GoogleCloudAiplatformV1Schedule[];
    }
    /**
     * Response message for SpecialistPoolService.ListSpecialistPools.
     */
    export interface Schema$GoogleCloudAiplatformV1ListSpecialistPoolsResponse {
        /**
         * The standard List next-page token.
         */
        nextPageToken?: string | null;
        /**
         * A list of SpecialistPools that matches the specified filter in the request.
         */
        specialistPools?: Schema$GoogleCloudAiplatformV1SpecialistPool[];
    }
    /**
     * Response message for VizierService.ListStudies.
     */
    export interface Schema$GoogleCloudAiplatformV1ListStudiesResponse {
        /**
         * Passes this token as the `page_token` field of the request for a subsequent call. If this field is omitted, there are no subsequent pages.
         */
        nextPageToken?: string | null;
        /**
         * The studies associated with the project.
         */
        studies?: Schema$GoogleCloudAiplatformV1Study[];
    }
    /**
     * Response message for TensorboardService.ListTensorboardExperiments.
     */
    export interface Schema$GoogleCloudAiplatformV1ListTensorboardExperimentsResponse {
        /**
         * A token, which can be sent as ListTensorboardExperimentsRequest.page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.
         */
        nextPageToken?: string | null;
        /**
         * The TensorboardExperiments mathching the request.
         */
        tensorboardExperiments?: Schema$GoogleCloudAiplatformV1TensorboardExperiment[];
    }
    /**
     * Response message for TensorboardService.ListTensorboardRuns.
     */
    export interface Schema$GoogleCloudAiplatformV1ListTensorboardRunsResponse {
        /**
         * A token, which can be sent as ListTensorboardRunsRequest.page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.
         */
        nextPageToken?: string | null;
        /**
         * The TensorboardRuns mathching the request.
         */
        tensorboardRuns?: Schema$GoogleCloudAiplatformV1TensorboardRun[];
    }
    /**
     * Response message for TensorboardService.ListTensorboards.
     */
    export interface Schema$GoogleCloudAiplatformV1ListTensorboardsResponse {
        /**
         * A token, which can be sent as ListTensorboardsRequest.page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.
         */
        nextPageToken?: string | null;
        /**
         * The Tensorboards mathching the request.
         */
        tensorboards?: Schema$GoogleCloudAiplatformV1Tensorboard[];
    }
    /**
     * Response message for TensorboardService.ListTensorboardTimeSeries.
     */
    export interface Schema$GoogleCloudAiplatformV1ListTensorboardTimeSeriesResponse {
        /**
         * A token, which can be sent as ListTensorboardTimeSeriesRequest.page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.
         */
        nextPageToken?: string | null;
        /**
         * The TensorboardTimeSeries mathching the request.
         */
        tensorboardTimeSeries?: Schema$GoogleCloudAiplatformV1TensorboardTimeSeries[];
    }
    /**
     * Response message for PipelineService.ListTrainingPipelines
     */
    export interface Schema$GoogleCloudAiplatformV1ListTrainingPipelinesResponse {
        /**
         * A token to retrieve the next page of results. Pass to ListTrainingPipelinesRequest.page_token to obtain that page.
         */
        nextPageToken?: string | null;
        /**
         * List of TrainingPipelines in the requested page.
         */
        trainingPipelines?: Schema$GoogleCloudAiplatformV1TrainingPipeline[];
    }
    /**
     * Response message for VizierService.ListTrials.
     */
    export interface Schema$GoogleCloudAiplatformV1ListTrialsResponse {
        /**
         * Pass this token as the `page_token` field of the request for a subsequent call. If this field is omitted, there are no subsequent pages.
         */
        nextPageToken?: string | null;
        /**
         * The Trials associated with the Study.
         */
        trials?: Schema$GoogleCloudAiplatformV1Trial[];
    }
    /**
     * Request message for VizierService.LookupStudy.
     */
    export interface Schema$GoogleCloudAiplatformV1LookupStudyRequest {
        /**
         * Required. The user-defined display name of the Study
         */
        displayName?: string | null;
    }
    /**
     * Specification of a single machine.
     */
    export interface Schema$GoogleCloudAiplatformV1MachineSpec {
        /**
         * The number of accelerators to attach to the machine.
         */
        acceleratorCount?: number | null;
        /**
         * Immutable. The type of accelerator(s) that may be attached to the machine as per accelerator_count.
         */
        acceleratorType?: string | null;
        /**
         * Immutable. The type of the machine. See the [list of machine types supported for prediction](https://cloud.google.com/vertex-ai/docs/predictions/configure-compute#machine-types) See the [list of machine types supported for custom training](https://cloud.google.com/vertex-ai/docs/training/configure-compute#machine-types). For DeployedModel this field is optional, and the default value is `n1-standard-2`. For BatchPredictionJob or as part of WorkerPoolSpec this field is required.
         */
        machineType?: string | null;
        /**
         * Immutable. The topology of the TPUs. Corresponds to the TPU topologies available from GKE. (Example: tpu_topology: "2x2x1").
         */
        tpuTopology?: string | null;
    }
    /**
     * Manual batch tuning parameters.
     */
    export interface Schema$GoogleCloudAiplatformV1ManualBatchTuningParameters {
        /**
         * Immutable. The number of the records (e.g. instances) of the operation given in each batch to a machine replica. Machine type, and size of a single record should be considered when setting this parameter, higher value speeds up the batch operation's execution, but too high value will result in a whole batch not fitting in a machine's memory, and the whole operation will fail. The default value is 64.
         */
        batchSize?: number | null;
    }
    /**
     * A message representing a Measurement of a Trial. A Measurement contains the Metrics got by executing a Trial using suggested hyperparameter values.
     */
    export interface Schema$GoogleCloudAiplatformV1Measurement {
        /**
         * Output only. Time that the Trial has been running at the point of this Measurement.
         */
        elapsedDuration?: string | null;
        /**
         * Output only. A list of metrics got by evaluating the objective functions using suggested Parameter values.
         */
        metrics?: Schema$GoogleCloudAiplatformV1MeasurementMetric[];
        /**
         * Output only. The number of steps the machine learning model has been trained for. Must be non-negative.
         */
        stepCount?: string | null;
    }
    /**
     * A message representing a metric in the measurement.
     */
    export interface Schema$GoogleCloudAiplatformV1MeasurementMetric {
        /**
         * Output only. The ID of the Metric. The Metric should be defined in StudySpec's Metrics.
         */
        metricId?: string | null;
        /**
         * Output only. The value for this metric.
         */
        value?: number | null;
    }
    /**
     * Request message for ModelService.MergeVersionAliases.
     */
    export interface Schema$GoogleCloudAiplatformV1MergeVersionAliasesRequest {
        /**
         * Required. The set of version aliases to merge. The alias should be at most 128 characters, and match `a-z{0,126\}[a-z-0-9]`. Add the `-` prefix to an alias means removing that alias from the version. `-` is NOT counted in the 128 characters. Example: `-golden` means removing the `golden` alias from the version. There is NO ordering in aliases, which means 1) The aliases returned from GetModel API might not have the exactly same order from this MergeVersionAliases API. 2) Adding and deleting the same alias in the request is not recommended, and the 2 operations will be cancelled out.
         */
        versionAliases?: string[] | null;
    }
    /**
     * Instance of a general MetadataSchema.
     */
    export interface Schema$GoogleCloudAiplatformV1MetadataSchema {
        /**
         * Output only. Timestamp when this MetadataSchema was created.
         */
        createTime?: string | null;
        /**
         * Description of the Metadata Schema
         */
        description?: string | null;
        /**
         * Output only. The resource name of the MetadataSchema.
         */
        name?: string | null;
        /**
         * Required. The raw YAML string representation of the MetadataSchema. The combination of [MetadataSchema.version] and the schema name given by `title` in [MetadataSchema.schema] must be unique within a MetadataStore. The schema is defined as an OpenAPI 3.0.2 [MetadataSchema Object](https://github.com/OAI/OpenAPI-Specification/blob/master/versions/3.0.2.md#schemaObject)
         */
        schema?: string | null;
        /**
         * The type of the MetadataSchema. This is a property that identifies which metadata types will use the MetadataSchema.
         */
        schemaType?: string | null;
        /**
         * The version of the MetadataSchema. The version's format must match the following regular expression: `^[0-9]+.+.+$`, which would allow to order/compare different versions. Example: 1.0.0, 1.0.1, etc.
         */
        schemaVersion?: string | null;
    }
    /**
     * Instance of a metadata store. Contains a set of metadata that can be queried.
     */
    export interface Schema$GoogleCloudAiplatformV1MetadataStore {
        /**
         * Output only. Timestamp when this MetadataStore was created.
         */
        createTime?: string | null;
        /**
         * Description of the MetadataStore.
         */
        description?: string | null;
        /**
         * Customer-managed encryption key spec for a Metadata Store. If set, this Metadata Store and all sub-resources of this Metadata Store are secured using this key.
         */
        encryptionSpec?: Schema$GoogleCloudAiplatformV1EncryptionSpec;
        /**
         * Output only. The resource name of the MetadataStore instance.
         */
        name?: string | null;
        /**
         * Output only. State information of the MetadataStore.
         */
        state?: Schema$GoogleCloudAiplatformV1MetadataStoreMetadataStoreState;
        /**
         * Output only. Timestamp when this MetadataStore was last updated.
         */
        updateTime?: string | null;
    }
    /**
     * Represents state information for a MetadataStore.
     */
    export interface Schema$GoogleCloudAiplatformV1MetadataStoreMetadataStoreState {
        /**
         * The disk utilization of the MetadataStore in bytes.
         */
        diskUtilizationBytes?: string | null;
    }
    /**
     * Represents one resource that exists in automl.googleapis.com, datalabeling.googleapis.com or ml.googleapis.com.
     */
    export interface Schema$GoogleCloudAiplatformV1MigratableResource {
        /**
         * Output only. Represents one Dataset in automl.googleapis.com.
         */
        automlDataset?: Schema$GoogleCloudAiplatformV1MigratableResourceAutomlDataset;
        /**
         * Output only. Represents one Model in automl.googleapis.com.
         */
        automlModel?: Schema$GoogleCloudAiplatformV1MigratableResourceAutomlModel;
        /**
         * Output only. Represents one Dataset in datalabeling.googleapis.com.
         */
        dataLabelingDataset?: Schema$GoogleCloudAiplatformV1MigratableResourceDataLabelingDataset;
        /**
         * Output only. Timestamp when the last migration attempt on this MigratableResource started. Will not be set if there's no migration attempt on this MigratableResource.
         */
        lastMigrateTime?: string | null;
        /**
         * Output only. Timestamp when this MigratableResource was last updated.
         */
        lastUpdateTime?: string | null;
        /**
         * Output only. Represents one Version in ml.googleapis.com.
         */
        mlEngineModelVersion?: Schema$GoogleCloudAiplatformV1MigratableResourceMlEngineModelVersion;
    }
    /**
     * Represents one Dataset in automl.googleapis.com.
     */
    export interface Schema$GoogleCloudAiplatformV1MigratableResourceAutomlDataset {
        /**
         * Full resource name of automl Dataset. Format: `projects/{project\}/locations/{location\}/datasets/{dataset\}`.
         */
        dataset?: string | null;
        /**
         * The Dataset's display name in automl.googleapis.com.
         */
        datasetDisplayName?: string | null;
    }
    /**
     * Represents one Model in automl.googleapis.com.
     */
    export interface Schema$GoogleCloudAiplatformV1MigratableResourceAutomlModel {
        /**
         * Full resource name of automl Model. Format: `projects/{project\}/locations/{location\}/models/{model\}`.
         */
        model?: string | null;
        /**
         * The Model's display name in automl.googleapis.com.
         */
        modelDisplayName?: string | null;
    }
    /**
     * Represents one Dataset in datalabeling.googleapis.com.
     */
    export interface Schema$GoogleCloudAiplatformV1MigratableResourceDataLabelingDataset {
        /**
         * The migratable AnnotatedDataset in datalabeling.googleapis.com belongs to the data labeling Dataset.
         */
        dataLabelingAnnotatedDatasets?: Schema$GoogleCloudAiplatformV1MigratableResourceDataLabelingDatasetDataLabelingAnnotatedDataset[];
        /**
         * Full resource name of data labeling Dataset. Format: `projects/{project\}/datasets/{dataset\}`.
         */
        dataset?: string | null;
        /**
         * The Dataset's display name in datalabeling.googleapis.com.
         */
        datasetDisplayName?: string | null;
    }
    /**
     * Represents one AnnotatedDataset in datalabeling.googleapis.com.
     */
    export interface Schema$GoogleCloudAiplatformV1MigratableResourceDataLabelingDatasetDataLabelingAnnotatedDataset {
        /**
         * Full resource name of data labeling AnnotatedDataset. Format: `projects/{project\}/datasets/{dataset\}/annotatedDatasets/{annotated_dataset\}`.
         */
        annotatedDataset?: string | null;
        /**
         * The AnnotatedDataset's display name in datalabeling.googleapis.com.
         */
        annotatedDatasetDisplayName?: string | null;
    }
    /**
     * Represents one model Version in ml.googleapis.com.
     */
    export interface Schema$GoogleCloudAiplatformV1MigratableResourceMlEngineModelVersion {
        /**
         * The ml.googleapis.com endpoint that this model Version currently lives in. Example values: * ml.googleapis.com * us-centrall-ml.googleapis.com * europe-west4-ml.googleapis.com * asia-east1-ml.googleapis.com
         */
        endpoint?: string | null;
        /**
         * Full resource name of ml engine model Version. Format: `projects/{project\}/models/{model\}/versions/{version\}`.
         */
        version?: string | null;
    }
    /**
     * Config of migrating one resource from automl.googleapis.com, datalabeling.googleapis.com and ml.googleapis.com to Vertex AI.
     */
    export interface Schema$GoogleCloudAiplatformV1MigrateResourceRequest {
        /**
         * Config for migrating Dataset in automl.googleapis.com to Vertex AI's Dataset.
         */
        migrateAutomlDatasetConfig?: Schema$GoogleCloudAiplatformV1MigrateResourceRequestMigrateAutomlDatasetConfig;
        /**
         * Config for migrating Model in automl.googleapis.com to Vertex AI's Model.
         */
        migrateAutomlModelConfig?: Schema$GoogleCloudAiplatformV1MigrateResourceRequestMigrateAutomlModelConfig;
        /**
         * Config for migrating Dataset in datalabeling.googleapis.com to Vertex AI's Dataset.
         */
        migrateDataLabelingDatasetConfig?: Schema$GoogleCloudAiplatformV1MigrateResourceRequestMigrateDataLabelingDatasetConfig;
        /**
         * Config for migrating Version in ml.googleapis.com to Vertex AI's Model.
         */
        migrateMlEngineModelVersionConfig?: Schema$GoogleCloudAiplatformV1MigrateResourceRequestMigrateMlEngineModelVersionConfig;
    }
    /**
     * Config for migrating Dataset in automl.googleapis.com to Vertex AI's Dataset.
     */
    export interface Schema$GoogleCloudAiplatformV1MigrateResourceRequestMigrateAutomlDatasetConfig {
        /**
         * Required. Full resource name of automl Dataset. Format: `projects/{project\}/locations/{location\}/datasets/{dataset\}`.
         */
        dataset?: string | null;
        /**
         * Required. Display name of the Dataset in Vertex AI. System will pick a display name if unspecified.
         */
        datasetDisplayName?: string | null;
    }
    /**
     * Config for migrating Model in automl.googleapis.com to Vertex AI's Model.
     */
    export interface Schema$GoogleCloudAiplatformV1MigrateResourceRequestMigrateAutomlModelConfig {
        /**
         * Required. Full resource name of automl Model. Format: `projects/{project\}/locations/{location\}/models/{model\}`.
         */
        model?: string | null;
        /**
         * Optional. Display name of the model in Vertex AI. System will pick a display name if unspecified.
         */
        modelDisplayName?: string | null;
    }
    /**
     * Config for migrating Dataset in datalabeling.googleapis.com to Vertex AI's Dataset.
     */
    export interface Schema$GoogleCloudAiplatformV1MigrateResourceRequestMigrateDataLabelingDatasetConfig {
        /**
         * Required. Full resource name of data labeling Dataset. Format: `projects/{project\}/datasets/{dataset\}`.
         */
        dataset?: string | null;
        /**
         * Optional. Display name of the Dataset in Vertex AI. System will pick a display name if unspecified.
         */
        datasetDisplayName?: string | null;
        /**
         * Optional. Configs for migrating AnnotatedDataset in datalabeling.googleapis.com to Vertex AI's SavedQuery. The specified AnnotatedDatasets have to belong to the datalabeling Dataset.
         */
        migrateDataLabelingAnnotatedDatasetConfigs?: Schema$GoogleCloudAiplatformV1MigrateResourceRequestMigrateDataLabelingDatasetConfigMigrateDataLabelingAnnotatedDatasetConfig[];
    }
    /**
     * Config for migrating AnnotatedDataset in datalabeling.googleapis.com to Vertex AI's SavedQuery.
     */
    export interface Schema$GoogleCloudAiplatformV1MigrateResourceRequestMigrateDataLabelingDatasetConfigMigrateDataLabelingAnnotatedDatasetConfig {
        /**
         * Required. Full resource name of data labeling AnnotatedDataset. Format: `projects/{project\}/datasets/{dataset\}/annotatedDatasets/{annotated_dataset\}`.
         */
        annotatedDataset?: string | null;
    }
    /**
     * Config for migrating version in ml.googleapis.com to Vertex AI's Model.
     */
    export interface Schema$GoogleCloudAiplatformV1MigrateResourceRequestMigrateMlEngineModelVersionConfig {
        /**
         * Required. The ml.googleapis.com endpoint that this model version should be migrated from. Example values: * ml.googleapis.com * us-centrall-ml.googleapis.com * europe-west4-ml.googleapis.com * asia-east1-ml.googleapis.com
         */
        endpoint?: string | null;
        /**
         * Required. Display name of the model in Vertex AI. System will pick a display name if unspecified.
         */
        modelDisplayName?: string | null;
        /**
         * Required. Full resource name of ml engine model version. Format: `projects/{project\}/models/{model\}/versions/{version\}`.
         */
        modelVersion?: string | null;
    }
    /**
     * Describes a successfully migrated resource.
     */
    export interface Schema$GoogleCloudAiplatformV1MigrateResourceResponse {
        /**
         * Migrated Dataset's resource name.
         */
        dataset?: string | null;
        /**
         * Before migration, the identifier in ml.googleapis.com, automl.googleapis.com or datalabeling.googleapis.com.
         */
        migratableResource?: Schema$GoogleCloudAiplatformV1MigratableResource;
        /**
         * Migrated Model's resource name.
         */
        model?: string | null;
    }
    /**
     * A trained machine learning Model.
     */
    export interface Schema$GoogleCloudAiplatformV1Model {
        /**
         * Immutable. The path to the directory containing the Model artifact and any of its supporting files. Not present for AutoML Models or Large Models.
         */
        artifactUri?: string | null;
        /**
         * Input only. The specification of the container that is to be used when deploying this Model. The specification is ingested upon ModelService.UploadModel, and all binaries it contains are copied and stored internally by Vertex AI. Not present for AutoML Models or Large Models.
         */
        containerSpec?: Schema$GoogleCloudAiplatformV1ModelContainerSpec;
        /**
         * Output only. Timestamp when this Model was uploaded into Vertex AI.
         */
        createTime?: string | null;
        /**
         * Output only. The pointers to DeployedModels created from this Model. Note that Model could have been deployed to Endpoints in different Locations.
         */
        deployedModels?: Schema$GoogleCloudAiplatformV1DeployedModelRef[];
        /**
         * The description of the Model.
         */
        description?: string | null;
        /**
         * Required. The display name of the Model. The name can be up to 128 characters long and can consist of any UTF-8 characters.
         */
        displayName?: string | null;
        /**
         * Customer-managed encryption key spec for a Model. If set, this Model and all sub-resources of this Model will be secured by this key.
         */
        encryptionSpec?: Schema$GoogleCloudAiplatformV1EncryptionSpec;
        /**
         * Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens.
         */
        etag?: string | null;
        /**
         * The default explanation specification for this Model. The Model can be used for requesting explanation after being deployed if it is populated. The Model can be used for batch explanation if it is populated. All fields of the explanation_spec can be overridden by explanation_spec of DeployModelRequest.deployed_model, or explanation_spec of BatchPredictionJob. If the default explanation specification is not set for this Model, this Model can still be used for requesting explanation by setting explanation_spec of DeployModelRequest.deployed_model and for batch explanation by setting explanation_spec of BatchPredictionJob.
         */
        explanationSpec?: Schema$GoogleCloudAiplatformV1ExplanationSpec;
        /**
         * The labels with user-defined metadata to organize your Models. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * Immutable. An additional information about the Model; the schema of the metadata can be found in metadata_schema. Unset if the Model does not have any additional information.
         */
        metadata?: any | null;
        /**
         * Output only. The resource name of the Artifact that was created in MetadataStore when creating the Model. The Artifact resource name pattern is `projects/{project\}/locations/{location\}/metadataStores/{metadata_store\}/artifacts/{artifact\}`.
         */
        metadataArtifact?: string | null;
        /**
         * Immutable. Points to a YAML file stored on Google Cloud Storage describing additional information about the Model, that is specific to it. Unset if the Model does not have any additional information. The schema is defined as an OpenAPI 3.0.2 [Schema Object](https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.0.2.md#schemaObject). AutoML Models always have this field populated by Vertex AI, if no additional metadata is needed, this field is set to an empty string. Note: The URI given on output will be immutable and probably different, including the URI scheme, than the one given on input. The output URI will point to a location where the user only has a read access.
         */
        metadataSchemaUri?: string | null;
        /**
         * Output only. Source of a model. It can either be automl training pipeline, custom training pipeline, BigQuery ML, or existing Vertex AI Model.
         */
        modelSourceInfo?: Schema$GoogleCloudAiplatformV1ModelSourceInfo;
        /**
         * The resource name of the Model.
         */
        name?: string | null;
        /**
         * Output only. If this Model is a copy of another Model, this contains info about the original.
         */
        originalModelInfo?: Schema$GoogleCloudAiplatformV1ModelOriginalModelInfo;
        /**
         * Optional. This field is populated if the model is produced by a pipeline job.
         */
        pipelineJob?: string | null;
        /**
         * The schemata that describe formats of the Model's predictions and explanations as given and returned via PredictionService.Predict and PredictionService.Explain.
         */
        predictSchemata?: Schema$GoogleCloudAiplatformV1PredictSchemata;
        /**
         * Output only. When this Model is deployed, its prediction resources are described by the `prediction_resources` field of the Endpoint.deployed_models object. Because not all Models support all resource configuration types, the configuration types this Model supports are listed here. If no configuration types are listed, the Model cannot be deployed to an Endpoint and does not support online predictions (PredictionService.Predict or PredictionService.Explain). Such a Model can serve predictions by using a BatchPredictionJob, if it has at least one entry each in supported_input_storage_formats and supported_output_storage_formats.
         */
        supportedDeploymentResourcesTypes?: string[] | null;
        /**
         * Output only. The formats in which this Model may be exported. If empty, this Model is not available for export.
         */
        supportedExportFormats?: Schema$GoogleCloudAiplatformV1ModelExportFormat[];
        /**
         * Output only. The formats this Model supports in BatchPredictionJob.input_config. If PredictSchemata.instance_schema_uri exists, the instances should be given as per that schema. The possible formats are: * `jsonl` The JSON Lines format, where each instance is a single line. Uses GcsSource. * `csv` The CSV format, where each instance is a single comma-separated line. The first line in the file is the header, containing comma-separated field names. Uses GcsSource. * `tf-record` The TFRecord format, where each instance is a single record in tfrecord syntax. Uses GcsSource. * `tf-record-gzip` Similar to `tf-record`, but the file is gzipped. Uses GcsSource. * `bigquery` Each instance is a single row in BigQuery. Uses BigQuerySource. * `file-list` Each line of the file is the location of an instance to process, uses `gcs_source` field of the InputConfig object. If this Model doesn't support any of these formats it means it cannot be used with a BatchPredictionJob. However, if it has supported_deployment_resources_types, it could serve online predictions by using PredictionService.Predict or PredictionService.Explain.
         */
        supportedInputStorageFormats?: string[] | null;
        /**
         * Output only. The formats this Model supports in BatchPredictionJob.output_config. If both PredictSchemata.instance_schema_uri and PredictSchemata.prediction_schema_uri exist, the predictions are returned together with their instances. In other words, the prediction has the original instance data first, followed by the actual prediction content (as per the schema). The possible formats are: * `jsonl` The JSON Lines format, where each prediction is a single line. Uses GcsDestination. * `csv` The CSV format, where each prediction is a single comma-separated line. The first line in the file is the header, containing comma-separated field names. Uses GcsDestination. * `bigquery` Each prediction is a single row in a BigQuery table, uses BigQueryDestination . If this Model doesn't support any of these formats it means it cannot be used with a BatchPredictionJob. However, if it has supported_deployment_resources_types, it could serve online predictions by using PredictionService.Predict or PredictionService.Explain.
         */
        supportedOutputStorageFormats?: string[] | null;
        /**
         * Output only. The resource name of the TrainingPipeline that uploaded this Model, if any.
         */
        trainingPipeline?: string | null;
        /**
         * Output only. Timestamp when this Model was most recently updated.
         */
        updateTime?: string | null;
        /**
         * User provided version aliases so that a model version can be referenced via alias (i.e. `projects/{project\}/locations/{location\}/models/{model_id\}@{version_alias\}` instead of auto-generated version id (i.e. `projects/{project\}/locations/{location\}/models/{model_id\}@{version_id\})`. The format is a-z{0,126\}[a-z0-9] to distinguish from version_id. A default version alias will be created for the first version of the model, and there must be exactly one default version alias for a model.
         */
        versionAliases?: string[] | null;
        /**
         * Output only. Timestamp when this version was created.
         */
        versionCreateTime?: string | null;
        /**
         * The description of this version.
         */
        versionDescription?: string | null;
        /**
         * Output only. Immutable. The version ID of the model. A new version is committed when a new model version is uploaded or trained under an existing model id. It is an auto-incrementing decimal number in string representation.
         */
        versionId?: string | null;
        /**
         * Output only. Timestamp when this version was most recently updated.
         */
        versionUpdateTime?: string | null;
    }
    /**
     * Specification of a container for serving predictions. Some fields in this message correspond to fields in the [Kubernetes Container v1 core specification](https://kubernetes.io/docs/reference/generated/kubernetes-api/v1.23/#container-v1-core).
     */
    export interface Schema$GoogleCloudAiplatformV1ModelContainerSpec {
        /**
         * Immutable. Specifies arguments for the command that runs when the container starts. This overrides the container's [`CMD`](https://docs.docker.com/engine/reference/builder/#cmd). Specify this field as an array of executable and arguments, similar to a Docker `CMD`'s "default parameters" form. If you don't specify this field but do specify the command field, then the command from the `command` field runs without any additional arguments. See the [Kubernetes documentation about how the `command` and `args` fields interact with a container's `ENTRYPOINT` and `CMD`](https://kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/#notes). If you don't specify this field and don't specify the `command` field, then the container's [`ENTRYPOINT`](https://docs.docker.com/engine/reference/builder/#cmd) and `CMD` determine what runs based on their default behavior. See the Docker documentation about [how `CMD` and `ENTRYPOINT` interact](https://docs.docker.com/engine/reference/builder/#understand-how-cmd-and-entrypoint-interact). In this field, you can reference [environment variables set by Vertex AI](https://cloud.google.com/vertex-ai/docs/predictions/custom-container-requirements#aip-variables) and environment variables set in the env field. You cannot reference environment variables set in the Docker image. In order for environment variables to be expanded, reference them by using the following syntax: $( VARIABLE_NAME) Note that this differs from Bash variable expansion, which does not use parentheses. If a variable cannot be resolved, the reference in the input string is used unchanged. To avoid variable expansion, you can escape this syntax with `$$`; for example: $$(VARIABLE_NAME) This field corresponds to the `args` field of the Kubernetes Containers [v1 core API](https://kubernetes.io/docs/reference/generated/kubernetes-api/v1.23/#container-v1-core).
         */
        args?: string[] | null;
        /**
         * Immutable. Specifies the command that runs when the container starts. This overrides the container's [ENTRYPOINT](https://docs.docker.com/engine/reference/builder/#entrypoint). Specify this field as an array of executable and arguments, similar to a Docker `ENTRYPOINT`'s "exec" form, not its "shell" form. If you do not specify this field, then the container's `ENTRYPOINT` runs, in conjunction with the args field or the container's [`CMD`](https://docs.docker.com/engine/reference/builder/#cmd), if either exists. If this field is not specified and the container does not have an `ENTRYPOINT`, then refer to the Docker documentation about [how `CMD` and `ENTRYPOINT` interact](https://docs.docker.com/engine/reference/builder/#understand-how-cmd-and-entrypoint-interact). If you specify this field, then you can also specify the `args` field to provide additional arguments for this command. However, if you specify this field, then the container's `CMD` is ignored. See the [Kubernetes documentation about how the `command` and `args` fields interact with a container's `ENTRYPOINT` and `CMD`](https://kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/#notes). In this field, you can reference [environment variables set by Vertex AI](https://cloud.google.com/vertex-ai/docs/predictions/custom-container-requirements#aip-variables) and environment variables set in the env field. You cannot reference environment variables set in the Docker image. In order for environment variables to be expanded, reference them by using the following syntax: $( VARIABLE_NAME) Note that this differs from Bash variable expansion, which does not use parentheses. If a variable cannot be resolved, the reference in the input string is used unchanged. To avoid variable expansion, you can escape this syntax with `$$`; for example: $$(VARIABLE_NAME) This field corresponds to the `command` field of the Kubernetes Containers [v1 core API](https://kubernetes.io/docs/reference/generated/kubernetes-api/v1.23/#container-v1-core).
         */
        command?: string[] | null;
        /**
         * Immutable. List of environment variables to set in the container. After the container starts running, code running in the container can read these environment variables. Additionally, the command and args fields can reference these variables. Later entries in this list can also reference earlier entries. For example, the following example sets the variable `VAR_2` to have the value `foo bar`: ```json [ { "name": "VAR_1", "value": "foo" \}, { "name": "VAR_2", "value": "$(VAR_1) bar" \} ] ``` If you switch the order of the variables in the example, then the expansion does not occur. This field corresponds to the `env` field of the Kubernetes Containers [v1 core API](https://kubernetes.io/docs/reference/generated/kubernetes-api/v1.23/#container-v1-core).
         */
        env?: Schema$GoogleCloudAiplatformV1EnvVar[];
        /**
         * Immutable. HTTP path on the container to send health checks to. Vertex AI intermittently sends GET requests to this path on the container's IP address and port to check that the container is healthy. Read more about [health checks](https://cloud.google.com/vertex-ai/docs/predictions/custom-container-requirements#health). For example, if you set this field to `/bar`, then Vertex AI intermittently sends a GET request to the `/bar` path on the port of your container specified by the first value of this `ModelContainerSpec`'s ports field. If you don't specify this field, it defaults to the following value when you deploy this Model to an Endpoint: /v1/endpoints/ENDPOINT/deployedModels/ DEPLOYED_MODEL:predict The placeholders in this value are replaced as follows: * ENDPOINT: The last segment (following `endpoints/`)of the Endpoint.name][] field of the Endpoint where this Model has been deployed. (Vertex AI makes this value available to your container code as the [`AIP_ENDPOINT_ID` environment variable](https://cloud.google.com/vertex-ai/docs/predictions/custom-container-requirements#aip-variables).) * DEPLOYED_MODEL: DeployedModel.id of the `DeployedModel`. (Vertex AI makes this value available to your container code as the [`AIP_DEPLOYED_MODEL_ID` environment variable](https://cloud.google.com/vertex-ai/docs/predictions/custom-container-requirements#aip-variables).)
         */
        healthRoute?: string | null;
        /**
         * Required. Immutable. URI of the Docker image to be used as the custom container for serving predictions. This URI must identify an image in Artifact Registry or Container Registry. Learn more about the [container publishing requirements](https://cloud.google.com/vertex-ai/docs/predictions/custom-container-requirements#publishing), including permissions requirements for the Vertex AI Service Agent. The container image is ingested upon ModelService.UploadModel, stored internally, and this original path is afterwards not used. To learn about the requirements for the Docker image itself, see [Custom container requirements](https://cloud.google.com/vertex-ai/docs/predictions/custom-container-requirements#). You can use the URI to one of Vertex AI's [pre-built container images for prediction](https://cloud.google.com/vertex-ai/docs/predictions/pre-built-containers) in this field.
         */
        imageUri?: string | null;
        /**
         * Immutable. List of ports to expose from the container. Vertex AI sends any prediction requests that it receives to the first port on this list. Vertex AI also sends [liveness and health checks](https://cloud.google.com/vertex-ai/docs/predictions/custom-container-requirements#liveness) to this port. If you do not specify this field, it defaults to following value: ```json [ { "containerPort": 8080 \} ] ``` Vertex AI does not use ports other than the first one listed. This field corresponds to the `ports` field of the Kubernetes Containers [v1 core API](https://kubernetes.io/docs/reference/generated/kubernetes-api/v1.23/#container-v1-core).
         */
        ports?: Schema$GoogleCloudAiplatformV1Port[];
        /**
         * Immutable. HTTP path on the container to send prediction requests to. Vertex AI forwards requests sent using projects.locations.endpoints.predict to this path on the container's IP address and port. Vertex AI then returns the container's response in the API response. For example, if you set this field to `/foo`, then when Vertex AI receives a prediction request, it forwards the request body in a POST request to the `/foo` path on the port of your container specified by the first value of this `ModelContainerSpec`'s ports field. If you don't specify this field, it defaults to the following value when you deploy this Model to an Endpoint: /v1/endpoints/ENDPOINT/deployedModels/DEPLOYED_MODEL:predict The placeholders in this value are replaced as follows: * ENDPOINT: The last segment (following `endpoints/`)of the Endpoint.name][] field of the Endpoint where this Model has been deployed. (Vertex AI makes this value available to your container code as the [`AIP_ENDPOINT_ID` environment variable](https://cloud.google.com/vertex-ai/docs/predictions/custom-container-requirements#aip-variables).) * DEPLOYED_MODEL: DeployedModel.id of the `DeployedModel`. (Vertex AI makes this value available to your container code as the [`AIP_DEPLOYED_MODEL_ID` environment variable](https://cloud.google.com/vertex-ai/docs/predictions/custom-container-requirements#aip-variables).)
         */
        predictRoute?: string | null;
    }
    /**
     * ModelDeploymentMonitoringBigQueryTable specifies the BigQuery table name as well as some information of the logs stored in this table.
     */
    export interface Schema$GoogleCloudAiplatformV1ModelDeploymentMonitoringBigQueryTable {
        /**
         * The created BigQuery table to store logs. Customer could do their own query & analysis. Format: `bq://.model_deployment_monitoring_._`
         */
        bigqueryTablePath?: string | null;
        /**
         * The source of log.
         */
        logSource?: string | null;
        /**
         * The type of log.
         */
        logType?: string | null;
    }
    /**
     * Represents a job that runs periodically to monitor the deployed models in an endpoint. It will analyze the logged training & prediction data to detect any abnormal behaviors.
     */
    export interface Schema$GoogleCloudAiplatformV1ModelDeploymentMonitoringJob {
        /**
         * YAML schema file uri describing the format of a single instance that you want Tensorflow Data Validation (TFDV) to analyze. If this field is empty, all the feature data types are inferred from predict_instance_schema_uri, meaning that TFDV will use the data in the exact format(data type) as prediction request/response. If there are any data type differences between predict instance and TFDV instance, this field can be used to override the schema. For models trained with Vertex AI, this field must be set as all the fields in predict instance formatted as string.
         */
        analysisInstanceSchemaUri?: string | null;
        /**
         * Output only. The created bigquery tables for the job under customer project. Customer could do their own query & analysis. There could be 4 log tables in maximum: 1. Training data logging predict request/response 2. Serving data logging predict request/response
         */
        bigqueryTables?: Schema$GoogleCloudAiplatformV1ModelDeploymentMonitoringBigQueryTable[];
        /**
         * Output only. Timestamp when this ModelDeploymentMonitoringJob was created.
         */
        createTime?: string | null;
        /**
         * Required. The user-defined name of the ModelDeploymentMonitoringJob. The name can be up to 128 characters long and can consist of any UTF-8 characters. Display name of a ModelDeploymentMonitoringJob.
         */
        displayName?: string | null;
        /**
         * If true, the scheduled monitoring pipeline logs are sent to Google Cloud Logging, including pipeline status and anomalies detected. Please note the logs incur cost, which are subject to [Cloud Logging pricing](https://cloud.google.com/logging#pricing).
         */
        enableMonitoringPipelineLogs?: boolean | null;
        /**
         * Customer-managed encryption key spec for a ModelDeploymentMonitoringJob. If set, this ModelDeploymentMonitoringJob and all sub-resources of this ModelDeploymentMonitoringJob will be secured by this key.
         */
        encryptionSpec?: Schema$GoogleCloudAiplatformV1EncryptionSpec;
        /**
         * Required. Endpoint resource name. Format: `projects/{project\}/locations/{location\}/endpoints/{endpoint\}`
         */
        endpoint?: string | null;
        /**
         * Output only. Only populated when the job's state is `JOB_STATE_FAILED` or `JOB_STATE_CANCELLED`.
         */
        error?: Schema$GoogleRpcStatus;
        /**
         * The labels with user-defined metadata to organize your ModelDeploymentMonitoringJob. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * Output only. Latest triggered monitoring pipeline metadata.
         */
        latestMonitoringPipelineMetadata?: Schema$GoogleCloudAiplatformV1ModelDeploymentMonitoringJobLatestMonitoringPipelineMetadata;
        /**
         * Required. Sample Strategy for logging.
         */
        loggingSamplingStrategy?: Schema$GoogleCloudAiplatformV1SamplingStrategy;
        /**
         * The TTL of BigQuery tables in user projects which stores logs. A day is the basic unit of the TTL and we take the ceil of TTL/86400(a day). e.g. { second: 3600\} indicates ttl = 1 day.
         */
        logTtl?: string | null;
        /**
         * Required. The config for monitoring objectives. This is a per DeployedModel config. Each DeployedModel needs to be configured separately.
         */
        modelDeploymentMonitoringObjectiveConfigs?: Schema$GoogleCloudAiplatformV1ModelDeploymentMonitoringObjectiveConfig[];
        /**
         * Required. Schedule config for running the monitoring job.
         */
        modelDeploymentMonitoringScheduleConfig?: Schema$GoogleCloudAiplatformV1ModelDeploymentMonitoringScheduleConfig;
        /**
         * Alert config for model monitoring.
         */
        modelMonitoringAlertConfig?: Schema$GoogleCloudAiplatformV1ModelMonitoringAlertConfig;
        /**
         * Output only. Resource name of a ModelDeploymentMonitoringJob.
         */
        name?: string | null;
        /**
         * Output only. Timestamp when this monitoring pipeline will be scheduled to run for the next round.
         */
        nextScheduleTime?: string | null;
        /**
         * YAML schema file uri describing the format of a single instance, which are given to format this Endpoint's prediction (and explanation). If not set, we will generate predict schema from collected predict requests.
         */
        predictInstanceSchemaUri?: string | null;
        /**
         * Sample Predict instance, same format as PredictRequest.instances, this can be set as a replacement of ModelDeploymentMonitoringJob.predict_instance_schema_uri. If not set, we will generate predict schema from collected predict requests.
         */
        samplePredictInstance?: any | null;
        /**
         * Output only. Schedule state when the monitoring job is in Running state.
         */
        scheduleState?: string | null;
        /**
         * Output only. The detailed state of the monitoring job. When the job is still creating, the state will be 'PENDING'. Once the job is successfully created, the state will be 'RUNNING'. Pause the job, the state will be 'PAUSED'. Resume the job, the state will return to 'RUNNING'.
         */
        state?: string | null;
        /**
         * Stats anomalies base folder path.
         */
        statsAnomaliesBaseDirectory?: Schema$GoogleCloudAiplatformV1GcsDestination;
        /**
         * Output only. Timestamp when this ModelDeploymentMonitoringJob was updated most recently.
         */
        updateTime?: string | null;
    }
    /**
     * All metadata of most recent monitoring pipelines.
     */
    export interface Schema$GoogleCloudAiplatformV1ModelDeploymentMonitoringJobLatestMonitoringPipelineMetadata {
        /**
         * The time that most recent monitoring pipelines that is related to this run.
         */
        runTime?: string | null;
        /**
         * The status of the most recent monitoring pipeline.
         */
        status?: Schema$GoogleRpcStatus;
    }
    /**
     * ModelDeploymentMonitoringObjectiveConfig contains the pair of deployed_model_id to ModelMonitoringObjectiveConfig.
     */
    export interface Schema$GoogleCloudAiplatformV1ModelDeploymentMonitoringObjectiveConfig {
        /**
         * The DeployedModel ID of the objective config.
         */
        deployedModelId?: string | null;
        /**
         * The objective config of for the modelmonitoring job of this deployed model.
         */
        objectiveConfig?: Schema$GoogleCloudAiplatformV1ModelMonitoringObjectiveConfig;
    }
    /**
     * The config for scheduling monitoring job.
     */
    export interface Schema$GoogleCloudAiplatformV1ModelDeploymentMonitoringScheduleConfig {
        /**
         * Required. The model monitoring job scheduling interval. It will be rounded up to next full hour. This defines how often the monitoring jobs are triggered.
         */
        monitorInterval?: string | null;
        /**
         * The time window of the prediction data being included in each prediction dataset. This window specifies how long the data should be collected from historical model results for each run. If not set, ModelDeploymentMonitoringScheduleConfig.monitor_interval will be used. e.g. If currently the cutoff time is 2022-01-08 14:30:00 and the monitor_window is set to be 3600, then data from 2022-01-08 13:30:00 to 2022-01-08 14:30:00 will be retrieved and aggregated to calculate the monitoring statistics.
         */
        monitorWindow?: string | null;
    }
    /**
     * A collection of metrics calculated by comparing Model's predictions on all of the test data against annotations from the test data.
     */
    export interface Schema$GoogleCloudAiplatformV1ModelEvaluation {
        /**
         * Points to a YAML file stored on Google Cloud Storage describing EvaluatedDataItemView.predictions, EvaluatedDataItemView.ground_truths, EvaluatedAnnotation.predictions, and EvaluatedAnnotation.ground_truths. The schema is defined as an OpenAPI 3.0.2 [Schema Object](https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.0.2.md#schemaObject). This field is not populated if there are neither EvaluatedDataItemViews nor EvaluatedAnnotations under this ModelEvaluation.
         */
        annotationSchemaUri?: string | null;
        /**
         * Output only. Timestamp when this ModelEvaluation was created.
         */
        createTime?: string | null;
        /**
         * Points to a YAML file stored on Google Cloud Storage describing EvaluatedDataItemView.data_item_payload and EvaluatedAnnotation.data_item_payload. The schema is defined as an OpenAPI 3.0.2 [Schema Object](https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.0.2.md#schemaObject). This field is not populated if there are neither EvaluatedDataItemViews nor EvaluatedAnnotations under this ModelEvaluation.
         */
        dataItemSchemaUri?: string | null;
        /**
         * The display name of the ModelEvaluation.
         */
        displayName?: string | null;
        /**
         * Describes the values of ExplanationSpec that are used for explaining the predicted values on the evaluated data.
         */
        explanationSpecs?: Schema$GoogleCloudAiplatformV1ModelEvaluationModelEvaluationExplanationSpec[];
        /**
         * The metadata of the ModelEvaluation. For the ModelEvaluation uploaded from Managed Pipeline, metadata contains a structured value with keys of "pipeline_job_id", "evaluation_dataset_type", "evaluation_dataset_path".
         */
        metadata?: any | null;
        /**
         * Evaluation metrics of the Model. The schema of the metrics is stored in metrics_schema_uri
         */
        metrics?: any | null;
        /**
         * Points to a YAML file stored on Google Cloud Storage describing the metrics of this ModelEvaluation. The schema is defined as an OpenAPI 3.0.2 [Schema Object](https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.0.2.md#schemaObject).
         */
        metricsSchemaUri?: string | null;
        /**
         * Aggregated explanation metrics for the Model's prediction output over the data this ModelEvaluation uses. This field is populated only if the Model is evaluated with explanations, and only for AutoML tabular Models.
         */
        modelExplanation?: Schema$GoogleCloudAiplatformV1ModelExplanation;
        /**
         * Output only. The resource name of the ModelEvaluation.
         */
        name?: string | null;
        /**
         * All possible dimensions of ModelEvaluationSlices. The dimensions can be used as the filter of the ModelService.ListModelEvaluationSlices request, in the form of `slice.dimension = `.
         */
        sliceDimensions?: string[] | null;
    }
    export interface Schema$GoogleCloudAiplatformV1ModelEvaluationModelEvaluationExplanationSpec {
        /**
         * Explanation spec details.
         */
        explanationSpec?: Schema$GoogleCloudAiplatformV1ExplanationSpec;
        /**
         * Explanation type. For AutoML Image Classification models, possible values are: * `image-integrated-gradients` * `image-xrai`
         */
        explanationType?: string | null;
    }
    /**
     * A collection of metrics calculated by comparing Model's predictions on a slice of the test data against ground truth annotations.
     */
    export interface Schema$GoogleCloudAiplatformV1ModelEvaluationSlice {
        /**
         * Output only. Timestamp when this ModelEvaluationSlice was created.
         */
        createTime?: string | null;
        /**
         * Output only. Sliced evaluation metrics of the Model. The schema of the metrics is stored in metrics_schema_uri
         */
        metrics?: any | null;
        /**
         * Output only. Points to a YAML file stored on Google Cloud Storage describing the metrics of this ModelEvaluationSlice. The schema is defined as an OpenAPI 3.0.2 [Schema Object](https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.0.2.md#schemaObject).
         */
        metricsSchemaUri?: string | null;
        /**
         * Output only. Aggregated explanation metrics for the Model's prediction output over the data this ModelEvaluation uses. This field is populated only if the Model is evaluated with explanations, and only for tabular Models.
         */
        modelExplanation?: Schema$GoogleCloudAiplatformV1ModelExplanation;
        /**
         * Output only. The resource name of the ModelEvaluationSlice.
         */
        name?: string | null;
        /**
         * Output only. The slice of the test data that is used to evaluate the Model.
         */
        slice?: Schema$GoogleCloudAiplatformV1ModelEvaluationSliceSlice;
    }
    /**
     * Definition of a slice.
     */
    export interface Schema$GoogleCloudAiplatformV1ModelEvaluationSliceSlice {
        /**
         * Output only. The dimension of the slice. Well-known dimensions are: * `annotationSpec`: This slice is on the test data that has either ground truth or prediction with AnnotationSpec.display_name equals to value. * `slice`: This slice is a user customized slice defined by its SliceSpec.
         */
        dimension?: string | null;
        /**
         * Output only. Specification for how the data was sliced.
         */
        sliceSpec?: Schema$GoogleCloudAiplatformV1ModelEvaluationSliceSliceSliceSpec;
        /**
         * Output only. The value of the dimension in this slice.
         */
        value?: string | null;
    }
    /**
     * Specification for how the data should be sliced.
     */
    export interface Schema$GoogleCloudAiplatformV1ModelEvaluationSliceSliceSliceSpec {
        /**
         * Mapping configuration for this SliceSpec. The key is the name of the feature. By default, the key will be prefixed by "instance" as a dictionary prefix for Vertex Batch Predictions output format.
         */
        configs?: {
            [key: string]: Schema$GoogleCloudAiplatformV1ModelEvaluationSliceSliceSliceSpecSliceConfig;
        } | null;
    }
    /**
     * A range of values for slice(s). `low` is inclusive, `high` is exclusive.
     */
    export interface Schema$GoogleCloudAiplatformV1ModelEvaluationSliceSliceSliceSpecRange {
        /**
         * Exclusive high value for the range.
         */
        high?: number | null;
        /**
         * Inclusive low value for the range.
         */
        low?: number | null;
    }
    /**
     * Specification message containing the config for this SliceSpec. When `kind` is selected as `value` and/or `range`, only a single slice will be computed. When `all_values` is present, a separate slice will be computed for each possible label/value for the corresponding key in `config`. Examples, with feature zip_code with values 12345, 23334, 88888 and feature country with values "US", "Canada", "Mexico" in the dataset: Example 1: { "zip_code": { "value": { "float_value": 12345.0 \} \} \} A single slice for any data with zip_code 12345 in the dataset. Example 2: { "zip_code": { "range": { "low": 12345, "high": 20000 \} \} \} A single slice containing data where the zip_codes between 12345 and 20000 For this example, data with the zip_code of 12345 will be in this slice. Example 3: { "zip_code": { "range": { "low": 10000, "high": 20000 \} \}, "country": { "value": { "string_value": "US" \} \} \} A single slice containing data where the zip_codes between 10000 and 20000 has the country "US". For this example, data with the zip_code of 12345 and country "US" will be in this slice. Example 4: { "country": {"all_values": { "value": true \} \} \} Three slices are computed, one for each unique country in the dataset. Example 5: { "country": { "all_values": { "value": true \} \}, "zip_code": { "value": { "float_value": 12345.0 \} \} \} Three slices are computed, one for each unique country in the dataset where the zip_code is also 12345. For this example, data with zip_code 12345 and country "US" will be in one slice, zip_code 12345 and country "Canada" in another slice, and zip_code 12345 and country "Mexico" in another slice, totaling 3 slices.
     */
    export interface Schema$GoogleCloudAiplatformV1ModelEvaluationSliceSliceSliceSpecSliceConfig {
        /**
         * If all_values is set to true, then all possible labels of the keyed feature will have another slice computed. Example: `{"all_values":{"value":true\}\}`
         */
        allValues?: boolean | null;
        /**
         * A range of values for a numerical feature. Example: `{"range":{"low":10000.0,"high":50000.0\}\}` will capture 12345 and 23334 in the slice.
         */
        range?: Schema$GoogleCloudAiplatformV1ModelEvaluationSliceSliceSliceSpecRange;
        /**
         * A unique specific value for a given feature. Example: `{ "value": { "string_value": "12345" \} \}`
         */
        value?: Schema$GoogleCloudAiplatformV1ModelEvaluationSliceSliceSliceSpecValue;
    }
    /**
     * Single value that supports strings and floats.
     */
    export interface Schema$GoogleCloudAiplatformV1ModelEvaluationSliceSliceSliceSpecValue {
        /**
         * Float type.
         */
        floatValue?: number | null;
        /**
         * String type.
         */
        stringValue?: string | null;
    }
    /**
     * Aggregated explanation metrics for a Model over a set of instances.
     */
    export interface Schema$GoogleCloudAiplatformV1ModelExplanation {
        /**
         * Output only. Aggregated attributions explaining the Model's prediction outputs over the set of instances. The attributions are grouped by outputs. For Models that predict only one output, such as regression Models that predict only one score, there is only one attibution that explains the predicted output. For Models that predict multiple outputs, such as multiclass Models that predict multiple classes, each element explains one specific item. Attribution.output_index can be used to identify which output this attribution is explaining. The baselineOutputValue, instanceOutputValue and featureAttributions fields are averaged over the test data. NOTE: Currently AutoML tabular classification Models produce only one attribution, which averages attributions over all the classes it predicts. Attribution.approximation_error is not populated.
         */
        meanAttributions?: Schema$GoogleCloudAiplatformV1Attribution[];
    }
    /**
     * Represents export format supported by the Model. All formats export to Google Cloud Storage.
     */
    export interface Schema$GoogleCloudAiplatformV1ModelExportFormat {
        /**
         * Output only. The content of this Model that may be exported.
         */
        exportableContents?: string[] | null;
        /**
         * Output only. The ID of the export format. The possible format IDs are: * `tflite` Used for Android mobile devices. * `edgetpu-tflite` Used for [Edge TPU](https://cloud.google.com/edge-tpu/) devices. * `tf-saved-model` A tensorflow model in SavedModel format. * `tf-js` A [TensorFlow.js](https://www.tensorflow.org/js) model that can be used in the browser and in Node.js using JavaScript. * `core-ml` Used for iOS mobile devices. * `custom-trained` A Model that was uploaded or trained by custom code.
         */
        id?: string | null;
    }
    export interface Schema$GoogleCloudAiplatformV1ModelMonitoringAlertConfig {
        /**
         * Email alert config.
         */
        emailAlertConfig?: Schema$GoogleCloudAiplatformV1ModelMonitoringAlertConfigEmailAlertConfig;
        /**
         * Dump the anomalies to Cloud Logging. The anomalies will be put to json payload encoded from proto google.cloud.aiplatform.logging.ModelMonitoringAnomaliesLogEntry. This can be further sinked to Pub/Sub or any other services supported by Cloud Logging.
         */
        enableLogging?: boolean | null;
        /**
         * Resource names of the NotificationChannels to send alert. Must be of the format `projects//notificationChannels/`
         */
        notificationChannels?: string[] | null;
    }
    /**
     * The config for email alert.
     */
    export interface Schema$GoogleCloudAiplatformV1ModelMonitoringAlertConfigEmailAlertConfig {
        /**
         * The email addresses to send the alert.
         */
        userEmails?: string[] | null;
    }
    /**
     * The objective configuration for model monitoring, including the information needed to detect anomalies for one particular model.
     */
    export interface Schema$GoogleCloudAiplatformV1ModelMonitoringObjectiveConfig {
        /**
         * The config for integrating with Vertex Explainable AI.
         */
        explanationConfig?: Schema$GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigExplanationConfig;
        /**
         * The config for drift of prediction data.
         */
        predictionDriftDetectionConfig?: Schema$GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigPredictionDriftDetectionConfig;
        /**
         * Training dataset for models. This field has to be set only if TrainingPredictionSkewDetectionConfig is specified.
         */
        trainingDataset?: Schema$GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingDataset;
        /**
         * The config for skew between training data and prediction data.
         */
        trainingPredictionSkewDetectionConfig?: Schema$GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingPredictionSkewDetectionConfig;
    }
    /**
     * The config for integrating with Vertex Explainable AI. Only applicable if the Model has explanation_spec populated.
     */
    export interface Schema$GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigExplanationConfig {
        /**
         * If want to analyze the Vertex Explainable AI feature attribute scores or not. If set to true, Vertex AI will log the feature attributions from explain response and do the skew/drift detection for them.
         */
        enableFeatureAttributes?: boolean | null;
        /**
         * Predictions generated by the BatchPredictionJob using baseline dataset.
         */
        explanationBaseline?: Schema$GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigExplanationConfigExplanationBaseline;
    }
    /**
     * Output from BatchPredictionJob for Model Monitoring baseline dataset, which can be used to generate baseline attribution scores.
     */
    export interface Schema$GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigExplanationConfigExplanationBaseline {
        /**
         * BigQuery location for BatchExplain output.
         */
        bigquery?: Schema$GoogleCloudAiplatformV1BigQueryDestination;
        /**
         * Cloud Storage location for BatchExplain output.
         */
        gcs?: Schema$GoogleCloudAiplatformV1GcsDestination;
        /**
         * The storage format of the predictions generated BatchPrediction job.
         */
        predictionFormat?: string | null;
    }
    /**
     * The config for Prediction data drift detection.
     */
    export interface Schema$GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigPredictionDriftDetectionConfig {
        /**
         * Key is the feature name and value is the threshold. The threshold here is against attribution score distance between different time windows.
         */
        attributionScoreDriftThresholds?: {
            [key: string]: Schema$GoogleCloudAiplatformV1ThresholdConfig;
        } | null;
        /**
         * Drift anomaly detection threshold used by all features. When the per-feature thresholds are not set, this field can be used to specify a threshold for all features.
         */
        defaultDriftThreshold?: Schema$GoogleCloudAiplatformV1ThresholdConfig;
        /**
         * Key is the feature name and value is the threshold. If a feature needs to be monitored for drift, a value threshold must be configured for that feature. The threshold here is against feature distribution distance between different time windws.
         */
        driftThresholds?: {
            [key: string]: Schema$GoogleCloudAiplatformV1ThresholdConfig;
        } | null;
    }
    /**
     * Training Dataset information.
     */
    export interface Schema$GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingDataset {
        /**
         * The BigQuery table of the unmanaged Dataset used to train this Model.
         */
        bigquerySource?: Schema$GoogleCloudAiplatformV1BigQuerySource;
        /**
         * Data format of the dataset, only applicable if the input is from Google Cloud Storage. The possible formats are: "tf-record" The source file is a TFRecord file. "csv" The source file is a CSV file. "jsonl" The source file is a JSONL file.
         */
        dataFormat?: string | null;
        /**
         * The resource name of the Dataset used to train this Model.
         */
        dataset?: string | null;
        /**
         * The Google Cloud Storage uri of the unmanaged Dataset used to train this Model.
         */
        gcsSource?: Schema$GoogleCloudAiplatformV1GcsSource;
        /**
         * Strategy to sample data from Training Dataset. If not set, we process the whole dataset.
         */
        loggingSamplingStrategy?: Schema$GoogleCloudAiplatformV1SamplingStrategy;
        /**
         * The target field name the model is to predict. This field will be excluded when doing Predict and (or) Explain for the training data.
         */
        targetField?: string | null;
    }
    /**
     * The config for Training & Prediction data skew detection. It specifies the training dataset sources and the skew detection parameters.
     */
    export interface Schema$GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingPredictionSkewDetectionConfig {
        /**
         * Key is the feature name and value is the threshold. The threshold here is against attribution score distance between the training and prediction feature.
         */
        attributionScoreSkewThresholds?: {
            [key: string]: Schema$GoogleCloudAiplatformV1ThresholdConfig;
        } | null;
        /**
         * Skew anomaly detection threshold used by all features. When the per-feature thresholds are not set, this field can be used to specify a threshold for all features.
         */
        defaultSkewThreshold?: Schema$GoogleCloudAiplatformV1ThresholdConfig;
        /**
         * Key is the feature name and value is the threshold. If a feature needs to be monitored for skew, a value threshold must be configured for that feature. The threshold here is against feature distribution distance between the training and prediction feature.
         */
        skewThresholds?: {
            [key: string]: Schema$GoogleCloudAiplatformV1ThresholdConfig;
        } | null;
    }
    /**
     * Statistics and anomalies generated by Model Monitoring.
     */
    export interface Schema$GoogleCloudAiplatformV1ModelMonitoringStatsAnomalies {
        /**
         * Number of anomalies within all stats.
         */
        anomalyCount?: number | null;
        /**
         * Deployed Model ID.
         */
        deployedModelId?: string | null;
        /**
         * A list of historical Stats and Anomalies generated for all Features.
         */
        featureStats?: Schema$GoogleCloudAiplatformV1ModelMonitoringStatsAnomaliesFeatureHistoricStatsAnomalies[];
        /**
         * Model Monitoring Objective those stats and anomalies belonging to.
         */
        objective?: string | null;
    }
    /**
     * Historical Stats (and Anomalies) for a specific Feature.
     */
    export interface Schema$GoogleCloudAiplatformV1ModelMonitoringStatsAnomaliesFeatureHistoricStatsAnomalies {
        /**
         * Display Name of the Feature.
         */
        featureDisplayName?: string | null;
        /**
         * A list of historical stats generated by different time window's Prediction Dataset.
         */
        predictionStats?: Schema$GoogleCloudAiplatformV1FeatureStatsAnomaly[];
        /**
         * Threshold for anomaly detection.
         */
        threshold?: Schema$GoogleCloudAiplatformV1ThresholdConfig;
        /**
         * Stats calculated for the Training Dataset.
         */
        trainingStats?: Schema$GoogleCloudAiplatformV1FeatureStatsAnomaly;
    }
    /**
     * Contains information about the original Model if this Model is a copy.
     */
    export interface Schema$GoogleCloudAiplatformV1ModelOriginalModelInfo {
        /**
         * Output only. The resource name of the Model this Model is a copy of, including the revision. Format: `projects/{project\}/locations/{location\}/models/{model_id\}@{version_id\}`
         */
        model?: string | null;
    }
    /**
     * Detail description of the source information of the model.
     */
    export interface Schema$GoogleCloudAiplatformV1ModelSourceInfo {
        /**
         * If this Model is copy of another Model. If true then source_type pertains to the original.
         */
        copy?: boolean | null;
        /**
         * Type of the model source.
         */
        sourceType?: string | null;
    }
    /**
     * Runtime operation information for IndexEndpointService.MutateDeployedIndex.
     */
    export interface Schema$GoogleCloudAiplatformV1MutateDeployedIndexOperationMetadata {
        /**
         * The unique index id specified by user
         */
        deployedIndexId?: string | null;
        /**
         * The operation generic information.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
    }
    /**
     * Response message for IndexEndpointService.MutateDeployedIndex.
     */
    export interface Schema$GoogleCloudAiplatformV1MutateDeployedIndexResponse {
        /**
         * The DeployedIndex that had been updated in the IndexEndpoint.
         */
        deployedIndex?: Schema$GoogleCloudAiplatformV1DeployedIndex;
    }
    /**
     * Runtime operation information for EndpointService.MutateDeployedModel.
     */
    export interface Schema$GoogleCloudAiplatformV1MutateDeployedModelOperationMetadata {
        /**
         * The operation generic information.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
    }
    /**
     * Request message for EndpointService.MutateDeployedModel.
     */
    export interface Schema$GoogleCloudAiplatformV1MutateDeployedModelRequest {
        /**
         * Required. The DeployedModel to be mutated within the Endpoint. Only the following fields can be mutated: * `min_replica_count` in either DedicatedResources or AutomaticResources * `max_replica_count` in either DedicatedResources or AutomaticResources * autoscaling_metric_specs * `disable_container_logging` (v1 only) * `enable_container_logging` (v1beta1 only)
         */
        deployedModel?: Schema$GoogleCloudAiplatformV1DeployedModel;
        /**
         * Required. The update mask applies to the resource. See google.protobuf.FieldMask.
         */
        updateMask?: string | null;
    }
    /**
     * Response message for EndpointService.MutateDeployedModel.
     */
    export interface Schema$GoogleCloudAiplatformV1MutateDeployedModelResponse {
        /**
         * The DeployedModel that's being mutated.
         */
        deployedModel?: Schema$GoogleCloudAiplatformV1DeployedModel;
    }
    /**
     * Represents a Neural Architecture Search (NAS) job.
     */
    export interface Schema$GoogleCloudAiplatformV1NasJob {
        /**
         * Output only. Time when the NasJob was created.
         */
        createTime?: string | null;
        /**
         * Required. The display name of the NasJob. The name can be up to 128 characters long and can consist of any UTF-8 characters.
         */
        displayName?: string | null;
        /**
         * Optional. Enable a separation of Custom model training and restricted image training for tenant project.
         */
        enableRestrictedImageTraining?: boolean | null;
        /**
         * Customer-managed encryption key options for a NasJob. If this is set, then all resources created by the NasJob will be encrypted with the provided encryption key.
         */
        encryptionSpec?: Schema$GoogleCloudAiplatformV1EncryptionSpec;
        /**
         * Output only. Time when the NasJob entered any of the following states: `JOB_STATE_SUCCEEDED`, `JOB_STATE_FAILED`, `JOB_STATE_CANCELLED`.
         */
        endTime?: string | null;
        /**
         * Output only. Only populated when job's state is JOB_STATE_FAILED or JOB_STATE_CANCELLED.
         */
        error?: Schema$GoogleRpcStatus;
        /**
         * The labels with user-defined metadata to organize NasJobs. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * Output only. Resource name of the NasJob.
         */
        name?: string | null;
        /**
         * Output only. Output of the NasJob.
         */
        nasJobOutput?: Schema$GoogleCloudAiplatformV1NasJobOutput;
        /**
         * Required. The specification of a NasJob.
         */
        nasJobSpec?: Schema$GoogleCloudAiplatformV1NasJobSpec;
        /**
         * Output only. Time when the NasJob for the first time entered the `JOB_STATE_RUNNING` state.
         */
        startTime?: string | null;
        /**
         * Output only. The detailed state of the job.
         */
        state?: string | null;
        /**
         * Output only. Time when the NasJob was most recently updated.
         */
        updateTime?: string | null;
    }
    /**
     * Represents a uCAIP NasJob output.
     */
    export interface Schema$GoogleCloudAiplatformV1NasJobOutput {
        /**
         * Output only. The output of this multi-trial Neural Architecture Search (NAS) job.
         */
        multiTrialJobOutput?: Schema$GoogleCloudAiplatformV1NasJobOutputMultiTrialJobOutput;
    }
    /**
     * The output of a multi-trial Neural Architecture Search (NAS) jobs.
     */
    export interface Schema$GoogleCloudAiplatformV1NasJobOutputMultiTrialJobOutput {
        /**
         * Output only. List of NasTrials that were started as part of search stage.
         */
        searchTrials?: Schema$GoogleCloudAiplatformV1NasTrial[];
        /**
         * Output only. List of NasTrials that were started as part of train stage.
         */
        trainTrials?: Schema$GoogleCloudAiplatformV1NasTrial[];
    }
    /**
     * Represents the spec of a NasJob.
     */
    export interface Schema$GoogleCloudAiplatformV1NasJobSpec {
        /**
         * The spec of multi-trial algorithms.
         */
        multiTrialAlgorithmSpec?: Schema$GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpec;
        /**
         * The ID of the existing NasJob in the same Project and Location which will be used to resume search. search_space_spec and nas_algorithm_spec are obtained from previous NasJob hence should not provide them again for this NasJob.
         */
        resumeNasJobId?: string | null;
        /**
         * It defines the search space for Neural Architecture Search (NAS).
         */
        searchSpaceSpec?: string | null;
    }
    /**
     * The spec of multi-trial Neural Architecture Search (NAS).
     */
    export interface Schema$GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpec {
        /**
         * Metric specs for the NAS job. Validation for this field is done at `multi_trial_algorithm_spec` field.
         */
        metric?: Schema$GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecMetricSpec;
        /**
         * The multi-trial Neural Architecture Search (NAS) algorithm type. Defaults to `REINFORCEMENT_LEARNING`.
         */
        multiTrialAlgorithm?: string | null;
        /**
         * Required. Spec for search trials.
         */
        searchTrialSpec?: Schema$GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec;
        /**
         * Spec for train trials. Top N [TrainTrialSpec.max_parallel_trial_count] search trials will be trained for every M [TrainTrialSpec.frequency] trials searched.
         */
        trainTrialSpec?: Schema$GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecTrainTrialSpec;
    }
    /**
     * Represents a metric to optimize.
     */
    export interface Schema$GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecMetricSpec {
        /**
         * Required. The optimization goal of the metric.
         */
        goal?: string | null;
        /**
         * Required. The ID of the metric. Must not contain whitespaces.
         */
        metricId?: string | null;
    }
    /**
     * Represent spec for search trials.
     */
    export interface Schema$GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec {
        /**
         * The number of failed trials that need to be seen before failing the NasJob. If set to 0, Vertex AI decides how many trials must fail before the whole job fails.
         */
        maxFailedTrialCount?: number | null;
        /**
         * Required. The maximum number of trials to run in parallel.
         */
        maxParallelTrialCount?: number | null;
        /**
         * Required. The maximum number of Neural Architecture Search (NAS) trials to run.
         */
        maxTrialCount?: number | null;
        /**
         * Required. The spec of a search trial job. The same spec applies to all search trials.
         */
        searchTrialJobSpec?: Schema$GoogleCloudAiplatformV1CustomJobSpec;
    }
    /**
     * Represent spec for train trials.
     */
    export interface Schema$GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecTrainTrialSpec {
        /**
         * Required. Frequency of search trials to start train stage. Top N [TrainTrialSpec.max_parallel_trial_count] search trials will be trained for every M [TrainTrialSpec.frequency] trials searched.
         */
        frequency?: number | null;
        /**
         * Required. The maximum number of trials to run in parallel.
         */
        maxParallelTrialCount?: number | null;
        /**
         * Required. The spec of a train trial job. The same spec applies to all train trials.
         */
        trainTrialJobSpec?: Schema$GoogleCloudAiplatformV1CustomJobSpec;
    }
    /**
     * Represents a uCAIP NasJob trial.
     */
    export interface Schema$GoogleCloudAiplatformV1NasTrial {
        /**
         * Output only. Time when the NasTrial's status changed to `SUCCEEDED` or `INFEASIBLE`.
         */
        endTime?: string | null;
        /**
         * Output only. The final measurement containing the objective value.
         */
        finalMeasurement?: Schema$GoogleCloudAiplatformV1Measurement;
        /**
         * Output only. The identifier of the NasTrial assigned by the service.
         */
        id?: string | null;
        /**
         * Output only. Time when the NasTrial was started.
         */
        startTime?: string | null;
        /**
         * Output only. The detailed state of the NasTrial.
         */
        state?: string | null;
    }
    /**
     * Represents a NasTrial details along with its parameters. If there is a corresponding train NasTrial, the train NasTrial is also returned.
     */
    export interface Schema$GoogleCloudAiplatformV1NasTrialDetail {
        /**
         * Output only. Resource name of the NasTrialDetail.
         */
        name?: string | null;
        /**
         * The parameters for the NasJob NasTrial.
         */
        parameters?: string | null;
        /**
         * The requested search NasTrial.
         */
        searchTrial?: Schema$GoogleCloudAiplatformV1NasTrial;
        /**
         * The train NasTrial corresponding to search_trial. Only populated if search_trial is used for training.
         */
        trainTrial?: Schema$GoogleCloudAiplatformV1NasTrial;
    }
    /**
     * Runtime operation metadata with regard to Matching Engine Index.
     */
    export interface Schema$GoogleCloudAiplatformV1NearestNeighborSearchOperationMetadata {
        /**
         * The validation stats of the content (per file) to be inserted or updated on the Matching Engine Index resource. Populated if contentsDeltaUri is provided as part of Index.metadata. Please note that, currently for those files that are broken or has unsupported file format, we will not have the stats for those files.
         */
        contentValidationStats?: Schema$GoogleCloudAiplatformV1NearestNeighborSearchOperationMetadataContentValidationStats[];
        /**
         * The ingested data size in bytes.
         */
        dataBytesCount?: string | null;
    }
    export interface Schema$GoogleCloudAiplatformV1NearestNeighborSearchOperationMetadataContentValidationStats {
        /**
         * Number of records in this file we skipped due to validate errors.
         */
        invalidRecordCount?: string | null;
        /**
         * The detail information of the partial failures encountered for those invalid records that couldn't be parsed. Up to 50 partial errors will be reported.
         */
        partialErrors?: Schema$GoogleCloudAiplatformV1NearestNeighborSearchOperationMetadataRecordError[];
        /**
         * Cloud Storage URI pointing to the original file in user's bucket.
         */
        sourceGcsUri?: string | null;
        /**
         * Number of records in this file that were successfully processed.
         */
        validRecordCount?: string | null;
    }
    export interface Schema$GoogleCloudAiplatformV1NearestNeighborSearchOperationMetadataRecordError {
        /**
         * Empty if the embedding id is failed to parse.
         */
        embeddingId?: string | null;
        /**
         * A human-readable message that is shown to the user to help them fix the error. Note that this message may change from time to time, your code should check against error_type as the source of truth.
         */
        errorMessage?: string | null;
        /**
         * The error type of this record.
         */
        errorType?: string | null;
        /**
         * The original content of this record.
         */
        rawRecord?: string | null;
        /**
         * Cloud Storage URI pointing to the original file in user's bucket.
         */
        sourceGcsUri?: string | null;
    }
    /**
     * Neighbors for example-based explanations.
     */
    export interface Schema$GoogleCloudAiplatformV1Neighbor {
        /**
         * Output only. The neighbor distance.
         */
        neighborDistance?: number | null;
        /**
         * Output only. The neighbor id.
         */
        neighborId?: string | null;
    }
    /**
     * Network spec.
     */
    export interface Schema$GoogleCloudAiplatformV1NetworkSpec {
        /**
         * Whether to enable public internet access. Default false.
         */
        enableInternetAccess?: boolean | null;
        /**
         * The full name of the Google Compute Engine [network](https://cloud.google.com//compute/docs/networks-and-firewalls#networks)
         */
        network?: string | null;
        /**
         * The name of the subnet that this instance is in. Format: `projects/{project_id_or_number\}/regions/{region\}/subnetworks/{subnetwork_id\}`
         */
        subnetwork?: string | null;
    }
    /**
     * Represents a mount configuration for Network File System (NFS) to mount.
     */
    export interface Schema$GoogleCloudAiplatformV1NfsMount {
        /**
         * Required. Destination mount path. The NFS will be mounted for the user under /mnt/nfs/
         */
        mountPoint?: string | null;
        /**
         * Required. Source path exported from NFS server. Has to start with '/', and combined with the ip address, it indicates the source mount path in the form of `server:path`
         */
        path?: string | null;
        /**
         * Required. IP address of the NFS server.
         */
        server?: string | null;
    }
    /**
     * The euc configuration of NotebookRuntimeTemplate.
     */
    export interface Schema$GoogleCloudAiplatformV1NotebookEucConfig {
        /**
         * Output only. Whether ActAs check is bypassed for service account attached to the VM. If false, we need ActAs check for the default Compute Engine Service account. When a Runtime is created, a VM is allocated using Default Compute Engine Service Account. Any user requesting to use this Runtime requires Service Account User (ActAs) permission over this SA. If true, Runtime owner is using EUC and does not require the above permission as VM no longer use default Compute Engine SA, but a P4SA.
         */
        bypassActasCheck?: boolean | null;
        /**
         * Input only. Whether EUC is disabled in this NotebookRuntimeTemplate. In proto3, the default value of a boolean is false. In this way, by default EUC will be enabled for NotebookRuntimeTemplate.
         */
        eucDisabled?: boolean | null;
    }
    /**
     * The idle shutdown configuration of NotebookRuntimeTemplate, which contains the idle_timeout as required field.
     */
    export interface Schema$GoogleCloudAiplatformV1NotebookIdleShutdownConfig {
        /**
         * Whether Idle Shutdown is disabled in this NotebookRuntimeTemplate.
         */
        idleShutdownDisabled?: boolean | null;
        /**
         * Required. Duration is accurate to the second. In Notebook, Idle Timeout is accurate to minute so the range of idle_timeout (second) is: 10 * 60 ~ 1440 * 60.
         */
        idleTimeout?: string | null;
    }
    /**
     * A runtime is a virtual machine allocated to a particular user for a particular Notebook file on temporary basis with lifetime limited to 24 hours.
     */
    export interface Schema$GoogleCloudAiplatformV1NotebookRuntime {
        /**
         * Output only. Timestamp when this NotebookRuntime was created.
         */
        createTime?: string | null;
        /**
         * The description of the NotebookRuntime.
         */
        description?: string | null;
        /**
         * Required. The display name of the NotebookRuntime. The name can be up to 128 characters long and can consist of any UTF-8 characters.
         */
        displayName?: string | null;
        /**
         * Output only. Timestamp when this NotebookRuntime will be expired: 1. System Predefined NotebookRuntime: 24 hours after creation. After expiration, system predifined runtime will be deleted. 2. User created NotebookRuntime: 6 months after last upgrade. After expiration, user created runtime will be stopped and allowed for upgrade.
         */
        expirationTime?: string | null;
        /**
         * Output only. The health state of the NotebookRuntime.
         */
        healthState?: string | null;
        /**
         * The labels with user-defined metadata to organize your NotebookRuntime. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. No more than 64 user labels can be associated with one NotebookRuntime (System labels are excluded). See https://goo.gl/xmQnxf for more information and examples of labels. System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Following system labels exist for NotebookRuntime: * "aiplatform.googleapis.com/notebook_runtime_gce_instance_id": output only, its value is the Compute Engine instance id. * "aiplatform.googleapis.com/colab_enterprise_entry_service": its value is either "bigquery" or "vertex"; if absent, it should be "vertex". This is to describe the entry service, either BigQuery or Vertex.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * Output only. The resource name of the NotebookRuntime.
         */
        name?: string | null;
        /**
         * Output only. The pointer to NotebookRuntimeTemplate this NotebookRuntime is created from.
         */
        notebookRuntimeTemplateRef?: Schema$GoogleCloudAiplatformV1NotebookRuntimeTemplateRef;
        /**
         * Output only. The type of the notebook runtime.
         */
        notebookRuntimeType?: string | null;
        /**
         * Output only. The proxy endpoint used to access the NotebookRuntime.
         */
        proxyUri?: string | null;
        /**
         * Output only. The runtime (instance) state of the NotebookRuntime.
         */
        runtimeState?: string | null;
        /**
         * Required. The user email of the NotebookRuntime.
         */
        runtimeUser?: string | null;
        /**
         * Output only. The service account that the NotebookRuntime workload runs as.
         */
        serviceAccount?: string | null;
        /**
         * Output only. Timestamp when this NotebookRuntime was most recently updated.
         */
        updateTime?: string | null;
        /**
         * Output only. The VM os image version of NotebookRuntime.
         */
        version?: string | null;
    }
    /**
     * A template that specifies runtime configurations such as machine type, runtime version, network configurations, etc. Multiple runtimes can be created from a runtime template.
     */
    export interface Schema$GoogleCloudAiplatformV1NotebookRuntimeTemplate {
        /**
         * Output only. Timestamp when this NotebookRuntimeTemplate was created.
         */
        createTime?: string | null;
        /**
         * Optional. The specification of persistent disk attached to the runtime as data disk storage.
         */
        dataPersistentDiskSpec?: Schema$GoogleCloudAiplatformV1PersistentDiskSpec;
        /**
         * The description of the NotebookRuntimeTemplate.
         */
        description?: string | null;
        /**
         * Required. The display name of the NotebookRuntimeTemplate. The name can be up to 128 characters long and can consist of any UTF-8 characters.
         */
        displayName?: string | null;
        /**
         * Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens.
         */
        etag?: string | null;
        /**
         * EUC configuration of the NotebookRuntimeTemplate.
         */
        eucConfig?: Schema$GoogleCloudAiplatformV1NotebookEucConfig;
        /**
         * The idle shutdown configuration of NotebookRuntimeTemplate. This config will only be set when idle shutdown is enabled.
         */
        idleShutdownConfig?: Schema$GoogleCloudAiplatformV1NotebookIdleShutdownConfig;
        /**
         * Output only. The default template to use if not specified.
         */
        isDefault?: boolean | null;
        /**
         * The labels with user-defined metadata to organize the NotebookRuntimeTemplates. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * Optional. Immutable. The specification of a single machine for the template.
         */
        machineSpec?: Schema$GoogleCloudAiplatformV1MachineSpec;
        /**
         * Output only. The resource name of the NotebookRuntimeTemplate.
         */
        name?: string | null;
        /**
         * Optional. Network spec.
         */
        networkSpec?: Schema$GoogleCloudAiplatformV1NetworkSpec;
        /**
         * Optional. Immutable. The type of the notebook runtime template.
         */
        notebookRuntimeType?: string | null;
        /**
         * The service account that the runtime workload runs as. You can use any service account within the same project, but you must have the service account user permission to use the instance. If not specified, the [Compute Engine default service account](https://cloud.google.com/compute/docs/access/service-accounts#default_service_account) is used.
         */
        serviceAccount?: string | null;
        /**
         * Output only. Timestamp when this NotebookRuntimeTemplate was most recently updated.
         */
        updateTime?: string | null;
    }
    /**
     * Points to a NotebookRuntimeTemplateRef.
     */
    export interface Schema$GoogleCloudAiplatformV1NotebookRuntimeTemplateRef {
        /**
         * Immutable. A resource name of the NotebookRuntimeTemplate.
         */
        notebookRuntimeTemplate?: string | null;
    }
    /**
     * Request message for JobService.PauseModelDeploymentMonitoringJob.
     */
    export interface Schema$GoogleCloudAiplatformV1PauseModelDeploymentMonitoringJobRequest {
    }
    /**
     * Request message for ScheduleService.PauseSchedule.
     */
    export interface Schema$GoogleCloudAiplatformV1PauseScheduleRequest {
    }
    /**
     * Represents the spec of persistent disk options.
     */
    export interface Schema$GoogleCloudAiplatformV1PersistentDiskSpec {
        /**
         * Size in GB of the disk (default is 100GB).
         */
        diskSizeGb?: string | null;
        /**
         * Type of the disk (default is "pd-standard"). Valid values: "pd-ssd" (Persistent Disk Solid State Drive) "pd-standard" (Persistent Disk Hard Disk Drive) "pd-balanced" (Balanced Persistent Disk) "pd-extreme" (Extreme Persistent Disk)
         */
        diskType?: string | null;
    }
    /**
     * An instance of a machine learning PipelineJob.
     */
    export interface Schema$GoogleCloudAiplatformV1PipelineJob {
        /**
         * Output only. Pipeline creation time.
         */
        createTime?: string | null;
        /**
         * The display name of the Pipeline. The name can be up to 128 characters long and can consist of any UTF-8 characters.
         */
        displayName?: string | null;
        /**
         * Customer-managed encryption key spec for a pipelineJob. If set, this PipelineJob and all of its sub-resources will be secured by this key.
         */
        encryptionSpec?: Schema$GoogleCloudAiplatformV1EncryptionSpec;
        /**
         * Output only. Pipeline end time.
         */
        endTime?: string | null;
        /**
         * Output only. The error that occurred during pipeline execution. Only populated when the pipeline's state is FAILED or CANCELLED.
         */
        error?: Schema$GoogleRpcStatus;
        /**
         * Output only. The details of pipeline run. Not available in the list view.
         */
        jobDetail?: Schema$GoogleCloudAiplatformV1PipelineJobDetail;
        /**
         * The labels with user-defined metadata to organize PipelineJob. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Note there is some reserved label key for Vertex AI Pipelines. - `vertex-ai-pipelines-run-billing-id`, user set value will get overrided.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * Output only. The resource name of the PipelineJob.
         */
        name?: string | null;
        /**
         * The full name of the Compute Engine [network](/compute/docs/networks-and-firewalls#networks) to which the Pipeline Job's workload should be peered. For example, `projects/12345/global/networks/myVPC`. [Format](/compute/docs/reference/rest/v1/networks/insert) is of the form `projects/{project\}/global/networks/{network\}`. Where {project\} is a project number, as in `12345`, and {network\} is a network name. Private services access must already be configured for the network. Pipeline job will apply the network configuration to the Google Cloud resources being launched, if applied, such as Vertex AI Training or Dataflow job. If left unspecified, the workload is not peered with any network.
         */
        network?: string | null;
        /**
         * The spec of the pipeline.
         */
        pipelineSpec?: {
            [key: string]: any;
        } | null;
        /**
         * A list of names for the reserved ip ranges under the VPC network that can be used for this Pipeline Job's workload. If set, we will deploy the Pipeline Job's workload within the provided ip ranges. Otherwise, the job will be deployed to any ip ranges under the provided VPC network. Example: ['vertex-ai-ip-range'].
         */
        reservedIpRanges?: string[] | null;
        /**
         * Runtime config of the pipeline.
         */
        runtimeConfig?: Schema$GoogleCloudAiplatformV1PipelineJobRuntimeConfig;
        /**
         * Output only. The schedule resource name. Only returned if the Pipeline is created by Schedule API.
         */
        scheduleName?: string | null;
        /**
         * The service account that the pipeline workload runs as. If not specified, the Compute Engine default service account in the project will be used. See https://cloud.google.com/compute/docs/access/service-accounts#default_service_account Users starting the pipeline must have the `iam.serviceAccounts.actAs` permission on this service account.
         */
        serviceAccount?: string | null;
        /**
         * Output only. Pipeline start time.
         */
        startTime?: string | null;
        /**
         * Output only. The detailed state of the job.
         */
        state?: string | null;
        /**
         * Output only. Pipeline template metadata. Will fill up fields if PipelineJob.template_uri is from supported template registry.
         */
        templateMetadata?: Schema$GoogleCloudAiplatformV1PipelineTemplateMetadata;
        /**
         * A template uri from where the PipelineJob.pipeline_spec, if empty, will be downloaded. Currently, only uri from Vertex Template Registry & Gallery is supported. Reference to https://cloud.google.com/vertex-ai/docs/pipelines/create-pipeline-template.
         */
        templateUri?: string | null;
        /**
         * Output only. Timestamp when this PipelineJob was most recently updated.
         */
        updateTime?: string | null;
    }
    /**
     * The runtime detail of PipelineJob.
     */
    export interface Schema$GoogleCloudAiplatformV1PipelineJobDetail {
        /**
         * Output only. The context of the pipeline.
         */
        pipelineContext?: Schema$GoogleCloudAiplatformV1Context;
        /**
         * Output only. The context of the current pipeline run.
         */
        pipelineRunContext?: Schema$GoogleCloudAiplatformV1Context;
        /**
         * Output only. The runtime details of the tasks under the pipeline.
         */
        taskDetails?: Schema$GoogleCloudAiplatformV1PipelineTaskDetail[];
    }
    /**
     * The runtime config of a PipelineJob.
     */
    export interface Schema$GoogleCloudAiplatformV1PipelineJobRuntimeConfig {
        /**
         * Represents the failure policy of a pipeline. Currently, the default of a pipeline is that the pipeline will continue to run until no more tasks can be executed, also known as PIPELINE_FAILURE_POLICY_FAIL_SLOW. However, if a pipeline is set to PIPELINE_FAILURE_POLICY_FAIL_FAST, it will stop scheduling any new tasks when a task has failed. Any scheduled tasks will continue to completion.
         */
        failurePolicy?: string | null;
        /**
         * Required. A path in a Cloud Storage bucket, which will be treated as the root output directory of the pipeline. It is used by the system to generate the paths of output artifacts. The artifact paths are generated with a sub-path pattern `{job_id\}/{task_id\}/{output_key\}` under the specified output directory. The service account specified in this pipeline must have the `storage.objects.get` and `storage.objects.create` permissions for this bucket.
         */
        gcsOutputDirectory?: string | null;
        /**
         * The runtime artifacts of the PipelineJob. The key will be the input artifact name and the value would be one of the InputArtifact.
         */
        inputArtifacts?: {
            [key: string]: Schema$GoogleCloudAiplatformV1PipelineJobRuntimeConfigInputArtifact;
        } | null;
        /**
         * Deprecated. Use RuntimeConfig.parameter_values instead. The runtime parameters of the PipelineJob. The parameters will be passed into PipelineJob.pipeline_spec to replace the placeholders at runtime. This field is used by pipelines built using `PipelineJob.pipeline_spec.schema_version` 2.0.0 or lower, such as pipelines built using Kubeflow Pipelines SDK 1.8 or lower.
         */
        parameters?: {
            [key: string]: Schema$GoogleCloudAiplatformV1Value;
        } | null;
        /**
         * The runtime parameters of the PipelineJob. The parameters will be passed into PipelineJob.pipeline_spec to replace the placeholders at runtime. This field is used by pipelines built using `PipelineJob.pipeline_spec.schema_version` 2.1.0, such as pipelines built using Kubeflow Pipelines SDK 1.9 or higher and the v2 DSL.
         */
        parameterValues?: {
            [key: string]: any;
        } | null;
    }
    /**
     * The type of an input artifact.
     */
    export interface Schema$GoogleCloudAiplatformV1PipelineJobRuntimeConfigInputArtifact {
        /**
         * Artifact resource id from MLMD. Which is the last portion of an artifact resource name: `projects/{project\}/locations/{location\}/metadataStores/default/artifacts/{artifact_id\}`. The artifact must stay within the same project, location and default metadatastore as the pipeline.
         */
        artifactId?: string | null;
    }
    /**
     * The runtime detail of a task execution.
     */
    export interface Schema$GoogleCloudAiplatformV1PipelineTaskDetail {
        /**
         * Output only. Task create time.
         */
        createTime?: string | null;
        /**
         * Output only. Task end time.
         */
        endTime?: string | null;
        /**
         * Output only. The error that occurred during task execution. Only populated when the task's state is FAILED or CANCELLED.
         */
        error?: Schema$GoogleRpcStatus;
        /**
         * Output only. The execution metadata of the task.
         */
        execution?: Schema$GoogleCloudAiplatformV1Execution;
        /**
         * Output only. The detailed execution info.
         */
        executorDetail?: Schema$GoogleCloudAiplatformV1PipelineTaskExecutorDetail;
        /**
         * Output only. The runtime input artifacts of the task.
         */
        inputs?: {
            [key: string]: Schema$GoogleCloudAiplatformV1PipelineTaskDetailArtifactList;
        } | null;
        /**
         * Output only. The runtime output artifacts of the task.
         */
        outputs?: {
            [key: string]: Schema$GoogleCloudAiplatformV1PipelineTaskDetailArtifactList;
        } | null;
        /**
         * Output only. The id of the parent task if the task is within a component scope. Empty if the task is at the root level.
         */
        parentTaskId?: string | null;
        /**
         * Output only. A list of task status. This field keeps a record of task status evolving over time.
         */
        pipelineTaskStatus?: Schema$GoogleCloudAiplatformV1PipelineTaskDetailPipelineTaskStatus[];
        /**
         * Output only. Task start time.
         */
        startTime?: string | null;
        /**
         * Output only. State of the task.
         */
        state?: string | null;
        /**
         * Output only. The system generated ID of the task.
         */
        taskId?: string | null;
        /**
         * Output only. The user specified name of the task that is defined in pipeline_spec.
         */
        taskName?: string | null;
    }
    /**
     * A list of artifact metadata.
     */
    export interface Schema$GoogleCloudAiplatformV1PipelineTaskDetailArtifactList {
        /**
         * Output only. A list of artifact metadata.
         */
        artifacts?: Schema$GoogleCloudAiplatformV1Artifact[];
    }
    /**
     * A single record of the task status.
     */
    export interface Schema$GoogleCloudAiplatformV1PipelineTaskDetailPipelineTaskStatus {
        /**
         * Output only. The error that occurred during the state. May be set when the state is any of the non-final state (PENDING/RUNNING/CANCELLING) or FAILED state. If the state is FAILED, the error here is final and not going to be retried. If the state is a non-final state, the error indicates a system-error being retried.
         */
        error?: Schema$GoogleRpcStatus;
        /**
         * Output only. The state of the task.
         */
        state?: string | null;
        /**
         * Output only. Update time of this status.
         */
        updateTime?: string | null;
    }
    /**
     * The runtime detail of a pipeline executor.
     */
    export interface Schema$GoogleCloudAiplatformV1PipelineTaskExecutorDetail {
        /**
         * Output only. The detailed info for a container executor.
         */
        containerDetail?: Schema$GoogleCloudAiplatformV1PipelineTaskExecutorDetailContainerDetail;
        /**
         * Output only. The detailed info for a custom job executor.
         */
        customJobDetail?: Schema$GoogleCloudAiplatformV1PipelineTaskExecutorDetailCustomJobDetail;
    }
    /**
     * The detail of a container execution. It contains the job names of the lifecycle of a container execution.
     */
    export interface Schema$GoogleCloudAiplatformV1PipelineTaskExecutorDetailContainerDetail {
        /**
         * Output only. The names of the previously failed CustomJob for the main container executions. The list includes the all attempts in chronological order.
         */
        failedMainJobs?: string[] | null;
        /**
         * Output only. The names of the previously failed CustomJob for the pre-caching-check container executions. This job will be available if the PipelineJob.pipeline_spec specifies the `pre_caching_check` hook in the lifecycle events. The list includes the all attempts in chronological order.
         */
        failedPreCachingCheckJobs?: string[] | null;
        /**
         * Output only. The name of the CustomJob for the main container execution.
         */
        mainJob?: string | null;
        /**
         * Output only. The name of the CustomJob for the pre-caching-check container execution. This job will be available if the PipelineJob.pipeline_spec specifies the `pre_caching_check` hook in the lifecycle events.
         */
        preCachingCheckJob?: string | null;
    }
    /**
     * The detailed info for a custom job executor.
     */
    export interface Schema$GoogleCloudAiplatformV1PipelineTaskExecutorDetailCustomJobDetail {
        /**
         * Output only. The names of the previously failed CustomJob. The list includes the all attempts in chronological order.
         */
        failedJobs?: string[] | null;
        /**
         * Output only. The name of the CustomJob.
         */
        job?: string | null;
    }
    /**
     * Pipeline template metadata if PipelineJob.template_uri is from supported template registry. Currently, the only supported registry is Artifact Registry.
     */
    export interface Schema$GoogleCloudAiplatformV1PipelineTemplateMetadata {
        /**
         * The version_name in artifact registry. Will always be presented in output if the PipelineJob.template_uri is from supported template registry. Format is "sha256:abcdef123456...".
         */
        version?: string | null;
    }
    /**
     * Represents a network port in a container.
     */
    export interface Schema$GoogleCloudAiplatformV1Port {
        /**
         * The number of the port to expose on the pod's IP address. Must be a valid port number, between 1 and 65535 inclusive.
         */
        containerPort?: number | null;
    }
    /**
     * Assigns input data to training, validation, and test sets based on the value of a provided key. Supported only for tabular Datasets.
     */
    export interface Schema$GoogleCloudAiplatformV1PredefinedSplit {
        /**
         * Required. The key is a name of one of the Dataset's data columns. The value of the key (either the label's value or value in the column) must be one of {`training`, `validation`, `test`\}, and it defines to which set the given piece of data is assigned. If for a piece of data the key is not present or has an invalid value, that piece is ignored by the pipeline.
         */
        key?: string | null;
    }
    /**
     * Request message for PredictionService.Predict.
     */
    export interface Schema$GoogleCloudAiplatformV1PredictRequest {
        /**
         * Required. The instances that are the input to the prediction call. A DeployedModel may have an upper limit on the number of instances it supports per request, and when it is exceeded the prediction call errors in case of AutoML Models, or, in case of customer created Models, the behaviour is as documented by that Model. The schema of any single instance may be specified via Endpoint's DeployedModels' Model's PredictSchemata's instance_schema_uri.
         */
        instances?: any[] | null;
        /**
         * The parameters that govern the prediction. The schema of the parameters may be specified via Endpoint's DeployedModels' Model's PredictSchemata's parameters_schema_uri.
         */
        parameters?: any | null;
    }
    /**
     * Configuration for logging request-response to a BigQuery table.
     */
    export interface Schema$GoogleCloudAiplatformV1PredictRequestResponseLoggingConfig {
        /**
         * BigQuery table for logging. If only given a project, a new dataset will be created with name `logging__` where will be made BigQuery-dataset-name compatible (e.g. most special characters will become underscores). If no table name is given, a new table will be created with name `request_response_logging`
         */
        bigqueryDestination?: Schema$GoogleCloudAiplatformV1BigQueryDestination;
        /**
         * If logging is enabled or not.
         */
        enabled?: boolean | null;
        /**
         * Percentage of requests to be logged, expressed as a fraction in range(0,1].
         */
        samplingRate?: number | null;
    }
    /**
     * Response message for PredictionService.Predict.
     */
    export interface Schema$GoogleCloudAiplatformV1PredictResponse {
        /**
         * ID of the Endpoint's DeployedModel that served this prediction.
         */
        deployedModelId?: string | null;
        /**
         * Output only. Request-level metadata returned by the model. The metadata type will be dependent upon the model implementation.
         */
        metadata?: any | null;
        /**
         * Output only. The resource name of the Model which is deployed as the DeployedModel that this prediction hits.
         */
        model?: string | null;
        /**
         * Output only. The display name of the Model which is deployed as the DeployedModel that this prediction hits.
         */
        modelDisplayName?: string | null;
        /**
         * Output only. The version ID of the Model which is deployed as the DeployedModel that this prediction hits.
         */
        modelVersionId?: string | null;
        /**
         * The predictions that are the output of the predictions call. The schema of any single prediction may be specified via Endpoint's DeployedModels' Model's PredictSchemata's prediction_schema_uri.
         */
        predictions?: any[] | null;
    }
    /**
     * Contains the schemata used in Model's predictions and explanations via PredictionService.Predict, PredictionService.Explain and BatchPredictionJob.
     */
    export interface Schema$GoogleCloudAiplatformV1PredictSchemata {
        /**
         * Immutable. Points to a YAML file stored on Google Cloud Storage describing the format of a single instance, which are used in PredictRequest.instances, ExplainRequest.instances and BatchPredictionJob.input_config. The schema is defined as an OpenAPI 3.0.2 [Schema Object](https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.0.2.md#schemaObject). AutoML Models always have this field populated by Vertex AI. Note: The URI given on output will be immutable and probably different, including the URI scheme, than the one given on input. The output URI will point to a location where the user only has a read access.
         */
        instanceSchemaUri?: string | null;
        /**
         * Immutable. Points to a YAML file stored on Google Cloud Storage describing the parameters of prediction and explanation via PredictRequest.parameters, ExplainRequest.parameters and BatchPredictionJob.model_parameters. The schema is defined as an OpenAPI 3.0.2 [Schema Object](https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.0.2.md#schemaObject). AutoML Models always have this field populated by Vertex AI, if no parameters are supported, then it is set to an empty string. Note: The URI given on output will be immutable and probably different, including the URI scheme, than the one given on input. The output URI will point to a location where the user only has a read access.
         */
        parametersSchemaUri?: string | null;
        /**
         * Immutable. Points to a YAML file stored on Google Cloud Storage describing the format of a single prediction produced by this Model, which are returned via PredictResponse.predictions, ExplainResponse.explanations, and BatchPredictionJob.output_config. The schema is defined as an OpenAPI 3.0.2 [Schema Object](https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.0.2.md#schemaObject). AutoML Models always have this field populated by Vertex AI. Note: The URI given on output will be immutable and probably different, including the URI scheme, than the one given on input. The output URI will point to a location where the user only has a read access.
         */
        predictionSchemaUri?: string | null;
    }
    /**
     * Preset configuration for example-based explanations
     */
    export interface Schema$GoogleCloudAiplatformV1Presets {
        /**
         * The modality of the uploaded model, which automatically configures the distance measurement and feature normalization for the underlying example index and queries. If your model does not precisely fit one of these types, it is okay to choose the closest type.
         */
        modality?: string | null;
        /**
         * Preset option controlling parameters for speed-precision trade-off when querying for examples. If omitted, defaults to `PRECISE`.
         */
        query?: string | null;
    }
    /**
     * PrivateEndpoints proto is used to provide paths for users to send requests privately. To send request via private service access, use predict_http_uri, explain_http_uri or health_http_uri. To send request via private service connect, use service_attachment.
     */
    export interface Schema$GoogleCloudAiplatformV1PrivateEndpoints {
        /**
         * Output only. Http(s) path to send explain requests.
         */
        explainHttpUri?: string | null;
        /**
         * Output only. Http(s) path to send health check requests.
         */
        healthHttpUri?: string | null;
        /**
         * Output only. Http(s) path to send prediction requests.
         */
        predictHttpUri?: string | null;
        /**
         * Output only. The name of the service attachment resource. Populated if private service connect is enabled.
         */
        serviceAttachment?: string | null;
    }
    /**
     * Represents configuration for private service connect.
     */
    export interface Schema$GoogleCloudAiplatformV1PrivateServiceConnectConfig {
        /**
         * Required. If true, expose the IndexEndpoint via private service connect.
         */
        enablePrivateServiceConnect?: boolean | null;
        /**
         * A list of Projects from which the forwarding rule will target the service attachment.
         */
        projectAllowlist?: string[] | null;
    }
    /**
     * A Model Garden Publisher Model.
     */
    export interface Schema$GoogleCloudAiplatformV1PublisherModel {
        /**
         * Optional. Additional information about the model's Frameworks.
         */
        frameworks?: string[] | null;
        /**
         * Optional. Indicates the launch stage of the model.
         */
        launchStage?: string | null;
        /**
         * Output only. The resource name of the PublisherModel.
         */
        name?: string | null;
        /**
         * Required. Indicates the open source category of the publisher model.
         */
        openSourceCategory?: string | null;
        /**
         * Optional. The schemata that describes formats of the PublisherModel's predictions and explanations as given and returned via PredictionService.Predict.
         */
        predictSchemata?: Schema$GoogleCloudAiplatformV1PredictSchemata;
        /**
         * Optional. Output only. Immutable. Used to indicate this model has a publisher model and provide the template of the publisher model resource name.
         */
        publisherModelTemplate?: string | null;
        /**
         * Optional. Supported call-to-action options.
         */
        supportedActions?: Schema$GoogleCloudAiplatformV1PublisherModelCallToAction;
        /**
         * Output only. Immutable. The version ID of the PublisherModel. A new version is committed when a new model version is uploaded under an existing model id. It is an auto-incrementing decimal number in string representation.
         */
        versionId?: string | null;
    }
    /**
     * Actions could take on this Publisher Model.
     */
    export interface Schema$GoogleCloudAiplatformV1PublisherModelCallToAction {
        /**
         * Optional. Create application using the PublisherModel.
         */
        createApplication?: Schema$GoogleCloudAiplatformV1PublisherModelCallToActionRegionalResourceReferences;
        /**
         * Optional. Deploy the PublisherModel to Vertex Endpoint.
         */
        deploy?: Schema$GoogleCloudAiplatformV1PublisherModelCallToActionDeploy;
        /**
         * Optional. Open evaluation pipeline of the PublisherModel.
         */
        openEvaluationPipeline?: Schema$GoogleCloudAiplatformV1PublisherModelCallToActionRegionalResourceReferences;
        /**
         * Optional. Open fine-tuning pipeline of the PublisherModel.
         */
        openFineTuningPipeline?: Schema$GoogleCloudAiplatformV1PublisherModelCallToActionRegionalResourceReferences;
        /**
         * Optional. Open in Generation AI Studio.
         */
        openGenerationAiStudio?: Schema$GoogleCloudAiplatformV1PublisherModelCallToActionRegionalResourceReferences;
        /**
         * Optional. Open Genie / Playground.
         */
        openGenie?: Schema$GoogleCloudAiplatformV1PublisherModelCallToActionRegionalResourceReferences;
        /**
         * Optional. Open notebook of the PublisherModel.
         */
        openNotebook?: Schema$GoogleCloudAiplatformV1PublisherModelCallToActionRegionalResourceReferences;
        /**
         * Optional. Open prompt-tuning pipeline of the PublisherModel.
         */
        openPromptTuningPipeline?: Schema$GoogleCloudAiplatformV1PublisherModelCallToActionRegionalResourceReferences;
        /**
         * Optional. Request for access.
         */
        requestAccess?: Schema$GoogleCloudAiplatformV1PublisherModelCallToActionRegionalResourceReferences;
        /**
         * Optional. To view Rest API docs.
         */
        viewRestApi?: Schema$GoogleCloudAiplatformV1PublisherModelCallToActionViewRestApi;
    }
    /**
     * Model metadata that is needed for UploadModel or DeployModel/CreateEndpoint requests.
     */
    export interface Schema$GoogleCloudAiplatformV1PublisherModelCallToActionDeploy {
        /**
         * Optional. The path to the directory containing the Model artifact and any of its supporting files.
         */
        artifactUri?: string | null;
        /**
         * A description of resources that to large degree are decided by Vertex AI, and require only a modest additional configuration.
         */
        automaticResources?: Schema$GoogleCloudAiplatformV1AutomaticResources;
        /**
         * Optional. The specification of the container that is to be used when deploying this Model in Vertex AI. Not present for Large Models.
         */
        containerSpec?: Schema$GoogleCloudAiplatformV1ModelContainerSpec;
        /**
         * A description of resources that are dedicated to the DeployedModel, and that need a higher degree of manual configuration.
         */
        dedicatedResources?: Schema$GoogleCloudAiplatformV1DedicatedResources;
        /**
         * Optional. Large model reference. When this is set, model_artifact_spec is not needed.
         */
        largeModelReference?: Schema$GoogleCloudAiplatformV1LargeModelReference;
        /**
         * Optional. Default model display name.
         */
        modelDisplayName?: string | null;
        /**
         * The resource name of the shared DeploymentResourcePool to deploy on. Format: `projects/{project\}/locations/{location\}/deploymentResourcePools/{deployment_resource_pool\}`
         */
        sharedResources?: string | null;
        /**
         * Required. The title of the regional resource reference.
         */
        title?: string | null;
    }
    /**
     * The regional resource name or the URI. Key is region, e.g., us-central1, europe-west2, global, etc..
     */
    export interface Schema$GoogleCloudAiplatformV1PublisherModelCallToActionRegionalResourceReferences {
        /**
         * Required.
         */
        references?: {
            [key: string]: Schema$GoogleCloudAiplatformV1PublisherModelResourceReference;
        } | null;
        /**
         * Required. The title of the regional resource reference.
         */
        title?: string | null;
    }
    /**
     * Rest API docs.
     */
    export interface Schema$GoogleCloudAiplatformV1PublisherModelCallToActionViewRestApi {
        /**
         * Required.
         */
        documentations?: Schema$GoogleCloudAiplatformV1PublisherModelDocumentation[];
        /**
         * Required. The title of the view rest API.
         */
        title?: string | null;
    }
    /**
     * A named piece of documentation.
     */
    export interface Schema$GoogleCloudAiplatformV1PublisherModelDocumentation {
        /**
         * Required. Content of this piece of document (in Markdown format).
         */
        content?: string | null;
        /**
         * Required. E.g., OVERVIEW, USE CASES, DOCUMENTATION, SDK & SAMPLES, JAVA, NODE.JS, etc..
         */
        title?: string | null;
    }
    /**
     * Reference to a resource.
     */
    export interface Schema$GoogleCloudAiplatformV1PublisherModelResourceReference {
        /**
         * The resource name of the Google Cloud resource.
         */
        resourceName?: string | null;
        /**
         * The URI of the resource.
         */
        uri?: string | null;
    }
    /**
     * Details of operations that perform MetadataService.PurgeArtifacts.
     */
    export interface Schema$GoogleCloudAiplatformV1PurgeArtifactsMetadata {
        /**
         * Operation metadata for purging Artifacts.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
    }
    /**
     * Request message for MetadataService.PurgeArtifacts.
     */
    export interface Schema$GoogleCloudAiplatformV1PurgeArtifactsRequest {
        /**
         * Required. A required filter matching the Artifacts to be purged. E.g., `update_time <= 2020-11-19T11:30:00-04:00`.
         */
        filter?: string | null;
        /**
         * Optional. Flag to indicate to actually perform the purge. If `force` is set to false, the method will return a sample of Artifact names that would be deleted.
         */
        force?: boolean | null;
    }
    /**
     * Response message for MetadataService.PurgeArtifacts.
     */
    export interface Schema$GoogleCloudAiplatformV1PurgeArtifactsResponse {
        /**
         * The number of Artifacts that this request deleted (or, if `force` is false, the number of Artifacts that will be deleted). This can be an estimate.
         */
        purgeCount?: string | null;
        /**
         * A sample of the Artifact names that will be deleted. Only populated if `force` is set to false. The maximum number of samples is 100 (it is possible to return fewer).
         */
        purgeSample?: string[] | null;
    }
    /**
     * Details of operations that perform MetadataService.PurgeContexts.
     */
    export interface Schema$GoogleCloudAiplatformV1PurgeContextsMetadata {
        /**
         * Operation metadata for purging Contexts.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
    }
    /**
     * Request message for MetadataService.PurgeContexts.
     */
    export interface Schema$GoogleCloudAiplatformV1PurgeContextsRequest {
        /**
         * Required. A required filter matching the Contexts to be purged. E.g., `update_time <= 2020-11-19T11:30:00-04:00`.
         */
        filter?: string | null;
        /**
         * Optional. Flag to indicate to actually perform the purge. If `force` is set to false, the method will return a sample of Context names that would be deleted.
         */
        force?: boolean | null;
    }
    /**
     * Response message for MetadataService.PurgeContexts.
     */
    export interface Schema$GoogleCloudAiplatformV1PurgeContextsResponse {
        /**
         * The number of Contexts that this request deleted (or, if `force` is false, the number of Contexts that will be deleted). This can be an estimate.
         */
        purgeCount?: string | null;
        /**
         * A sample of the Context names that will be deleted. Only populated if `force` is set to false. The maximum number of samples is 100 (it is possible to return fewer).
         */
        purgeSample?: string[] | null;
    }
    /**
     * Details of operations that perform MetadataService.PurgeExecutions.
     */
    export interface Schema$GoogleCloudAiplatformV1PurgeExecutionsMetadata {
        /**
         * Operation metadata for purging Executions.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
    }
    /**
     * Request message for MetadataService.PurgeExecutions.
     */
    export interface Schema$GoogleCloudAiplatformV1PurgeExecutionsRequest {
        /**
         * Required. A required filter matching the Executions to be purged. E.g., `update_time <= 2020-11-19T11:30:00-04:00`.
         */
        filter?: string | null;
        /**
         * Optional. Flag to indicate to actually perform the purge. If `force` is set to false, the method will return a sample of Execution names that would be deleted.
         */
        force?: boolean | null;
    }
    /**
     * Response message for MetadataService.PurgeExecutions.
     */
    export interface Schema$GoogleCloudAiplatformV1PurgeExecutionsResponse {
        /**
         * The number of Executions that this request deleted (or, if `force` is false, the number of Executions that will be deleted). This can be an estimate.
         */
        purgeCount?: string | null;
        /**
         * A sample of the Execution names that will be deleted. Only populated if `force` is set to false. The maximum number of samples is 100 (it is possible to return fewer).
         */
        purgeSample?: string[] | null;
    }
    /**
     * The spec of a Python packaged code.
     */
    export interface Schema$GoogleCloudAiplatformV1PythonPackageSpec {
        /**
         * Command line arguments to be passed to the Python task.
         */
        args?: string[] | null;
        /**
         * Environment variables to be passed to the python module. Maximum limit is 100.
         */
        env?: Schema$GoogleCloudAiplatformV1EnvVar[];
        /**
         * Required. The URI of a container image in Artifact Registry that will run the provided Python package. Vertex AI provides a wide range of executor images with pre-installed packages to meet users' various use cases. See the list of [pre-built containers for training](https://cloud.google.com/vertex-ai/docs/training/pre-built-containers). You must use an image from this list.
         */
        executorImageUri?: string | null;
        /**
         * Required. The Google Cloud Storage location of the Python package files which are the training program and its dependent packages. The maximum number of package URIs is 100.
         */
        packageUris?: string[] | null;
        /**
         * Required. The Python module name to run after installing the packages.
         */
        pythonModule?: string | null;
    }
    /**
     * Request message for PredictionService.RawPredict.
     */
    export interface Schema$GoogleCloudAiplatformV1RawPredictRequest {
        /**
         * The prediction input. Supports HTTP headers and arbitrary data payload. A DeployedModel may have an upper limit on the number of instances it supports per request. When this limit it is exceeded for an AutoML model, the RawPredict method returns an error. When this limit is exceeded for a custom-trained model, the behavior varies depending on the model. You can specify the schema for each instance in the predict_schemata.instance_schema_uri field when you create a Model. This schema applies when you deploy the `Model` as a `DeployedModel` to an Endpoint and use the `RawPredict` method.
         */
        httpBody?: Schema$GoogleApiHttpBody;
    }
    /**
     * Request message for FeaturestoreOnlineServingService.ReadFeatureValues.
     */
    export interface Schema$GoogleCloudAiplatformV1ReadFeatureValuesRequest {
        /**
         * Required. ID for a specific entity. For example, for a machine learning model predicting user clicks on a website, an entity ID could be `user_123`.
         */
        entityId?: string | null;
        /**
         * Required. Selector choosing Features of the target EntityType.
         */
        featureSelector?: Schema$GoogleCloudAiplatformV1FeatureSelector;
    }
    /**
     * Response message for FeaturestoreOnlineServingService.ReadFeatureValues.
     */
    export interface Schema$GoogleCloudAiplatformV1ReadFeatureValuesResponse {
        /**
         * Entity view with Feature values. This may be the entity in the Featurestore if values for all Features were requested, or a projection of the entity in the Featurestore if values for only some Features were requested.
         */
        entityView?: Schema$GoogleCloudAiplatformV1ReadFeatureValuesResponseEntityView;
        /**
         * Response header.
         */
        header?: Schema$GoogleCloudAiplatformV1ReadFeatureValuesResponseHeader;
    }
    /**
     * Entity view with Feature values.
     */
    export interface Schema$GoogleCloudAiplatformV1ReadFeatureValuesResponseEntityView {
        /**
         * Each piece of data holds the k requested values for one requested Feature. If no values for the requested Feature exist, the corresponding cell will be empty. This has the same size and is in the same order as the features from the header ReadFeatureValuesResponse.header.
         */
        data?: Schema$GoogleCloudAiplatformV1ReadFeatureValuesResponseEntityViewData[];
        /**
         * ID of the requested entity.
         */
        entityId?: string | null;
    }
    /**
     * Container to hold value(s), successive in time, for one Feature from the request.
     */
    export interface Schema$GoogleCloudAiplatformV1ReadFeatureValuesResponseEntityViewData {
        /**
         * Feature value if a single value is requested.
         */
        value?: Schema$GoogleCloudAiplatformV1FeatureValue;
        /**
         * Feature values list if values, successive in time, are requested. If the requested number of values is greater than the number of existing Feature values, nonexistent values are omitted instead of being returned as empty.
         */
        values?: Schema$GoogleCloudAiplatformV1FeatureValueList;
    }
    /**
     * Metadata for requested Features.
     */
    export interface Schema$GoogleCloudAiplatformV1ReadFeatureValuesResponseFeatureDescriptor {
        /**
         * Feature ID.
         */
        id?: string | null;
    }
    /**
     * Response header with metadata for the requested ReadFeatureValuesRequest.entity_type and Features.
     */
    export interface Schema$GoogleCloudAiplatformV1ReadFeatureValuesResponseHeader {
        /**
         * The resource name of the EntityType from the ReadFeatureValuesRequest. Value format: `projects/{project\}/locations/{location\}/featurestores/{featurestore\}/entityTypes/{entityType\}`.
         */
        entityType?: string | null;
        /**
         * List of Feature metadata corresponding to each piece of ReadFeatureValuesResponse.EntityView.data.
         */
        featureDescriptors?: Schema$GoogleCloudAiplatformV1ReadFeatureValuesResponseFeatureDescriptor[];
    }
    /**
     * The request message for MatchService.ReadIndexDatapoints.
     */
    export interface Schema$GoogleCloudAiplatformV1ReadIndexDatapointsRequest {
        /**
         * The ID of the DeployedIndex that will serve the request.
         */
        deployedIndexId?: string | null;
        /**
         * IDs of the datapoints to be searched for.
         */
        ids?: string[] | null;
    }
    /**
     * The response message for MatchService.ReadIndexDatapoints.
     */
    export interface Schema$GoogleCloudAiplatformV1ReadIndexDatapointsResponse {
        /**
         * The result list of datapoints.
         */
        datapoints?: Schema$GoogleCloudAiplatformV1IndexDatapoint[];
    }
    /**
     * Response message for TensorboardService.ReadTensorboardBlobData.
     */
    export interface Schema$GoogleCloudAiplatformV1ReadTensorboardBlobDataResponse {
        /**
         * Blob messages containing blob bytes.
         */
        blobs?: Schema$GoogleCloudAiplatformV1TensorboardBlob[];
    }
    /**
     * Response message for TensorboardService.ReadTensorboardSize.
     */
    export interface Schema$GoogleCloudAiplatformV1ReadTensorboardSizeResponse {
        /**
         * Payload storage size for the TensorBoard
         */
        storageSizeByte?: string | null;
    }
    /**
     * Response message for TensorboardService.ReadTensorboardTimeSeriesData.
     */
    export interface Schema$GoogleCloudAiplatformV1ReadTensorboardTimeSeriesDataResponse {
        /**
         * The returned time series data.
         */
        timeSeriesData?: Schema$GoogleCloudAiplatformV1TimeSeriesData;
    }
    /**
     * Response message for TensorboardService.ReadTensorboardUsage.
     */
    export interface Schema$GoogleCloudAiplatformV1ReadTensorboardUsageResponse {
        /**
         * Maps year-month (YYYYMM) string to per month usage data.
         */
        monthlyUsageData?: {
            [key: string]: Schema$GoogleCloudAiplatformV1ReadTensorboardUsageResponsePerMonthUsageData;
        } | null;
    }
    /**
     * Per month usage data
     */
    export interface Schema$GoogleCloudAiplatformV1ReadTensorboardUsageResponsePerMonthUsageData {
        /**
         * Usage data for each user in the given month.
         */
        userUsageData?: Schema$GoogleCloudAiplatformV1ReadTensorboardUsageResponsePerUserUsageData[];
    }
    /**
     * Per user usage data.
     */
    export interface Schema$GoogleCloudAiplatformV1ReadTensorboardUsageResponsePerUserUsageData {
        /**
         * User's username
         */
        username?: string | null;
        /**
         * Number of times the user has read data within the Tensorboard.
         */
        viewCount?: string | null;
    }
    /**
     * Request message for MetadataService.DeleteContextChildrenRequest.
     */
    export interface Schema$GoogleCloudAiplatformV1RemoveContextChildrenRequest {
        /**
         * The resource names of the child Contexts.
         */
        childContexts?: string[] | null;
    }
    /**
     * Response message for MetadataService.RemoveContextChildren.
     */
    export interface Schema$GoogleCloudAiplatformV1RemoveContextChildrenResponse {
    }
    /**
     * Request message for IndexService.RemoveDatapoints
     */
    export interface Schema$GoogleCloudAiplatformV1RemoveDatapointsRequest {
        /**
         * A list of datapoint ids to be deleted.
         */
        datapointIds?: string[] | null;
    }
    /**
     * Response message for IndexService.RemoveDatapoints
     */
    export interface Schema$GoogleCloudAiplatformV1RemoveDatapointsResponse {
    }
    /**
     * Statistics information about resource consumption.
     */
    export interface Schema$GoogleCloudAiplatformV1ResourcesConsumed {
        /**
         * Output only. The number of replica hours used. Note that many replicas may run in parallel, and additionally any given work may be queued for some time. Therefore this value is not strictly related to wall time.
         */
        replicaHours?: number | null;
    }
    /**
     * Runtime operation information for DatasetService.RestoreDatasetVersion.
     */
    export interface Schema$GoogleCloudAiplatformV1RestoreDatasetVersionOperationMetadata {
        /**
         * The common part of the operation metadata.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
    }
    /**
     * Request message for JobService.ResumeModelDeploymentMonitoringJob.
     */
    export interface Schema$GoogleCloudAiplatformV1ResumeModelDeploymentMonitoringJobRequest {
    }
    /**
     * Request message for ScheduleService.ResumeSchedule.
     */
    export interface Schema$GoogleCloudAiplatformV1ResumeScheduleRequest {
        /**
         * Optional. Whether to backfill missed runs when the schedule is resumed from PAUSED state. If set to true, all missed runs will be scheduled. New runs will be scheduled after the backfill is complete. This will also update Schedule.catch_up field. Default to false.
         */
        catchUp?: boolean | null;
    }
    /**
     * Active learning data sampling config. For every active learning labeling iteration, it will select a batch of data based on the sampling strategy.
     */
    export interface Schema$GoogleCloudAiplatformV1SampleConfig {
        /**
         * The percentage of data needed to be labeled in each following batch (except the first batch).
         */
        followingBatchSamplePercentage?: number | null;
        /**
         * The percentage of data needed to be labeled in the first batch.
         */
        initialBatchSamplePercentage?: number | null;
        /**
         * Field to choose sampling strategy. Sampling strategy will decide which data should be selected for human labeling in every batch.
         */
        sampleStrategy?: string | null;
    }
    /**
     * An attribution method that approximates Shapley values for features that contribute to the label being predicted. A sampling strategy is used to approximate the value rather than considering all subsets of features.
     */
    export interface Schema$GoogleCloudAiplatformV1SampledShapleyAttribution {
        /**
         * Required. The number of feature permutations to consider when approximating the Shapley values. Valid range of its value is [1, 50], inclusively.
         */
        pathCount?: number | null;
    }
    /**
     * Sampling Strategy for logging, can be for both training and prediction dataset.
     */
    export interface Schema$GoogleCloudAiplatformV1SamplingStrategy {
        /**
         * Random sample config. Will support more sampling strategies later.
         */
        randomSampleConfig?: Schema$GoogleCloudAiplatformV1SamplingStrategyRandomSampleConfig;
    }
    /**
     * Requests are randomly selected.
     */
    export interface Schema$GoogleCloudAiplatformV1SamplingStrategyRandomSampleConfig {
        /**
         * Sample rate (0, 1]
         */
        sampleRate?: number | null;
    }
    /**
     * A SavedQuery is a view of the dataset. It references a subset of annotations by problem type and filters.
     */
    export interface Schema$GoogleCloudAiplatformV1SavedQuery {
        /**
         * Output only. Filters on the Annotations in the dataset.
         */
        annotationFilter?: string | null;
        /**
         * Output only. Number of AnnotationSpecs in the context of the SavedQuery.
         */
        annotationSpecCount?: number | null;
        /**
         * Output only. Timestamp when this SavedQuery was created.
         */
        createTime?: string | null;
        /**
         * Required. The user-defined name of the SavedQuery. The name can be up to 128 characters long and can consist of any UTF-8 characters.
         */
        displayName?: string | null;
        /**
         * Used to perform a consistent read-modify-write update. If not set, a blind "overwrite" update happens.
         */
        etag?: string | null;
        /**
         * Some additional information about the SavedQuery.
         */
        metadata?: any | null;
        /**
         * Output only. Resource name of the SavedQuery.
         */
        name?: string | null;
        /**
         * Required. Problem type of the SavedQuery. Allowed values: * IMAGE_CLASSIFICATION_SINGLE_LABEL * IMAGE_CLASSIFICATION_MULTI_LABEL * IMAGE_BOUNDING_POLY * IMAGE_BOUNDING_BOX * TEXT_CLASSIFICATION_SINGLE_LABEL * TEXT_CLASSIFICATION_MULTI_LABEL * TEXT_EXTRACTION * TEXT_SENTIMENT * VIDEO_CLASSIFICATION * VIDEO_OBJECT_TRACKING
         */
        problemType?: string | null;
        /**
         * Output only. If the Annotations belonging to the SavedQuery can be used for AutoML training.
         */
        supportAutomlTraining?: boolean | null;
        /**
         * Output only. Timestamp when SavedQuery was last updated.
         */
        updateTime?: string | null;
    }
    /**
     * One point viewable on a scalar metric plot.
     */
    export interface Schema$GoogleCloudAiplatformV1Scalar {
        /**
         * Value of the point at this step / timestamp.
         */
        value?: number | null;
    }
    /**
     * An instance of a Schedule periodically schedules runs to make API calls based on user specified time specification and API request type.
     */
    export interface Schema$GoogleCloudAiplatformV1Schedule {
        /**
         * Optional. Whether new scheduled runs can be queued when max_concurrent_runs limit is reached. If set to true, new runs will be queued instead of skipped. Default to false.
         */
        allowQueueing?: boolean | null;
        /**
         * Output only. Whether to backfill missed runs when the schedule is resumed from PAUSED state. If set to true, all missed runs will be scheduled. New runs will be scheduled after the backfill is complete. Default to false.
         */
        catchUp?: boolean | null;
        /**
         * Request for PipelineService.CreatePipelineJob. CreatePipelineJobRequest.parent field is required (format: projects/{project\}/locations/{location\}).
         */
        createPipelineJobRequest?: Schema$GoogleCloudAiplatformV1CreatePipelineJobRequest;
        /**
         * Output only. Timestamp when this Schedule was created.
         */
        createTime?: string | null;
        /**
         * Cron schedule (https://en.wikipedia.org/wiki/Cron) to launch scheduled runs. To explicitly set a timezone to the cron tab, apply a prefix in the cron tab: "CRON_TZ=${IANA_TIME_ZONE\}" or "TZ=${IANA_TIME_ZONE\}". The ${IANA_TIME_ZONE\} may only be a valid string from IANA time zone database. For example, "CRON_TZ=America/New_York 1 * * * *", or "TZ=America/New_York 1 * * * *".
         */
        cron?: string | null;
        /**
         * Required. User provided name of the Schedule. The name can be up to 128 characters long and can consist of any UTF-8 characters.
         */
        displayName?: string | null;
        /**
         * Optional. Timestamp after which no new runs can be scheduled. If specified, The schedule will be completed when either end_time is reached or when scheduled_run_count \>= max_run_count. If not specified, new runs will keep getting scheduled until this Schedule is paused or deleted. Already scheduled runs will be allowed to complete. Unset if not specified.
         */
        endTime?: string | null;
        /**
         * Output only. Timestamp when this Schedule was last paused. Unset if never paused.
         */
        lastPauseTime?: string | null;
        /**
         * Output only. Timestamp when this Schedule was last resumed. Unset if never resumed from pause.
         */
        lastResumeTime?: string | null;
        /**
         * Output only. Response of the last scheduled run. This is the response for starting the scheduled requests and not the execution of the operations/jobs created by the requests (if applicable). Unset if no run has been scheduled yet.
         */
        lastScheduledRunResponse?: Schema$GoogleCloudAiplatformV1ScheduleRunResponse;
        /**
         * Required. Maximum number of runs that can be started concurrently for this Schedule. This is the limit for starting the scheduled requests and not the execution of the operations/jobs created by the requests (if applicable).
         */
        maxConcurrentRunCount?: string | null;
        /**
         * Optional. Maximum run count of the schedule. If specified, The schedule will be completed when either started_run_count \>= max_run_count or when end_time is reached. If not specified, new runs will keep getting scheduled until this Schedule is paused or deleted. Already scheduled runs will be allowed to complete. Unset if not specified.
         */
        maxRunCount?: string | null;
        /**
         * Immutable. The resource name of the Schedule.
         */
        name?: string | null;
        /**
         * Output only. Timestamp when this Schedule should schedule the next run. Having a next_run_time in the past means the runs are being started behind schedule.
         */
        nextRunTime?: string | null;
        /**
         * Output only. The number of runs started by this schedule.
         */
        startedRunCount?: string | null;
        /**
         * Optional. Timestamp after which the first run can be scheduled. Default to Schedule create time if not specified.
         */
        startTime?: string | null;
        /**
         * Output only. The state of this Schedule.
         */
        state?: string | null;
        /**
         * Output only. Timestamp when this Schedule was updated.
         */
        updateTime?: string | null;
    }
    /**
     * Status of a scheduled run.
     */
    export interface Schema$GoogleCloudAiplatformV1ScheduleRunResponse {
        /**
         * The response of the scheduled run.
         */
        runResponse?: string | null;
        /**
         * The scheduled run time based on the user-specified schedule.
         */
        scheduledRunTime?: string | null;
    }
    /**
     * All parameters related to queuing and scheduling of custom jobs.
     */
    export interface Schema$GoogleCloudAiplatformV1Scheduling {
        /**
         * Optional. Indicates if the job should retry for internal errors after the job starts running. If true, overrides `Scheduling.restart_job_on_worker_restart` to false.
         */
        disableRetries?: boolean | null;
        /**
         * Restarts the entire CustomJob if a worker gets restarted. This feature can be used by distributed training jobs that are not resilient to workers leaving and joining a job.
         */
        restartJobOnWorkerRestart?: boolean | null;
        /**
         * The maximum job running time. The default is 7 days.
         */
        timeout?: string | null;
    }
    /**
     * An entry of mapping between color and AnnotationSpec. The mapping is used in segmentation mask.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaAnnotationSpecColor {
        /**
         * The color of the AnnotationSpec in a segmentation mask.
         */
        color?: Schema$GoogleTypeColor;
        /**
         * The display name of the AnnotationSpec represented by the color in the segmentation mask.
         */
        displayName?: string | null;
        /**
         * The ID of the AnnotationSpec represented by the color in the segmentation mask.
         */
        id?: string | null;
    }
    /**
     * Annotation details specific to image object detection.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaImageBoundingBoxAnnotation {
        /**
         * The resource Id of the AnnotationSpec that this Annotation pertains to.
         */
        annotationSpecId?: string | null;
        /**
         * The display name of the AnnotationSpec that this Annotation pertains to.
         */
        displayName?: string | null;
        /**
         * The rightmost coordinate of the bounding box.
         */
        xMax?: number | null;
        /**
         * The leftmost coordinate of the bounding box.
         */
        xMin?: number | null;
        /**
         * The bottommost coordinate of the bounding box.
         */
        yMax?: number | null;
        /**
         * The topmost coordinate of the bounding box.
         */
        yMin?: number | null;
    }
    /**
     * Annotation details specific to image classification.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaImageClassificationAnnotation {
        /**
         * The resource Id of the AnnotationSpec that this Annotation pertains to.
         */
        annotationSpecId?: string | null;
        /**
         * The display name of the AnnotationSpec that this Annotation pertains to.
         */
        displayName?: string | null;
    }
    /**
     * Payload of Image DataItem.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaImageDataItem {
        /**
         * Required. Google Cloud Storage URI points to the original image in user's bucket. The image is up to 30MB in size.
         */
        gcsUri?: string | null;
        /**
         * Output only. The mime type of the content of the image. Only the images in below listed mime types are supported. - image/jpeg - image/gif - image/png - image/webp - image/bmp - image/tiff - image/vnd.microsoft.icon
         */
        mimeType?: string | null;
    }
    /**
     * The metadata of Datasets that contain Image DataItems.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaImageDatasetMetadata {
        /**
         * Points to a YAML file stored on Google Cloud Storage describing payload of the Image DataItems that belong to this Dataset.
         */
        dataItemSchemaUri?: string | null;
        /**
         * Google Cloud Storage Bucket name that contains the blob data of this Dataset.
         */
        gcsBucket?: string | null;
    }
    /**
     * Annotation details specific to image segmentation.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaImageSegmentationAnnotation {
        /**
         * Mask based segmentation annotation. Only one mask annotation can exist for one image.
         */
        maskAnnotation?: Schema$GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationMaskAnnotation;
        /**
         * Polygon annotation.
         */
        polygonAnnotation?: Schema$GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationPolygonAnnotation;
        /**
         * Polyline annotation.
         */
        polylineAnnotation?: Schema$GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationPolylineAnnotation;
    }
    /**
     * The mask based segmentation annotation.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationMaskAnnotation {
        /**
         * The mapping between color and AnnotationSpec for this Annotation.
         */
        annotationSpecColors?: Schema$GoogleCloudAiplatformV1SchemaAnnotationSpecColor[];
        /**
         * Google Cloud Storage URI that points to the mask image. The image must be in PNG format. It must have the same size as the DataItem's image. Each pixel in the image mask represents the AnnotationSpec which the pixel in the image DataItem belong to. Each color is mapped to one AnnotationSpec based on annotation_spec_colors.
         */
        maskGcsUri?: string | null;
    }
    /**
     * Represents a polygon in image.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationPolygonAnnotation {
        /**
         * The resource Id of the AnnotationSpec that this Annotation pertains to.
         */
        annotationSpecId?: string | null;
        /**
         * The display name of the AnnotationSpec that this Annotation pertains to.
         */
        displayName?: string | null;
        /**
         * The vertexes are connected one by one and the last vertex is connected to the first one to represent a polygon.
         */
        vertexes?: Schema$GoogleCloudAiplatformV1SchemaVertex[];
    }
    /**
     * Represents a polyline in image.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationPolylineAnnotation {
        /**
         * The resource Id of the AnnotationSpec that this Annotation pertains to.
         */
        annotationSpecId?: string | null;
        /**
         * The display name of the AnnotationSpec that this Annotation pertains to.
         */
        displayName?: string | null;
        /**
         * The vertexes are connected one by one and the last vertex in not connected to the first one.
         */
        vertexes?: Schema$GoogleCloudAiplatformV1SchemaVertex[];
    }
    /**
     * Bounding box matching model metrics for a single intersection-over-union threshold and multiple label match confidence thresholds.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetrics {
        /**
         * Metrics for each label-match confidence_threshold from 0.05,0.10,...,0.95,0.96,0.97,0.98,0.99. Precision-recall curve is derived from them.
         */
        confidenceMetrics?: Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetricsConfidenceMetrics[];
        /**
         * The intersection-over-union threshold value used to compute this metrics entry.
         */
        iouThreshold?: number | null;
        /**
         * The mean average precision, most often close to `auPrc`.
         */
        meanAveragePrecision?: number | null;
    }
    /**
     * Metrics for a single confidence threshold.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetricsConfidenceMetrics {
        /**
         * The confidence threshold value used to compute the metrics.
         */
        confidenceThreshold?: number | null;
        /**
         * The harmonic mean of recall and precision.
         */
        f1Score?: number | null;
        /**
         * Precision under the given confidence threshold.
         */
        precision?: number | null;
        /**
         * Recall under the given confidence threshold.
         */
        recall?: number | null;
    }
    /**
     * Metrics for classification evaluation results.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsClassificationEvaluationMetrics {
        /**
         * The Area Under Precision-Recall Curve metric. Micro-averaged for the overall evaluation.
         */
        auPrc?: number | null;
        /**
         * The Area Under Receiver Operating Characteristic curve metric. Micro-averaged for the overall evaluation.
         */
        auRoc?: number | null;
        /**
         * Metrics for each `confidenceThreshold` in 0.00,0.05,0.10,...,0.95,0.96,0.97,0.98,0.99 and `positionThreshold` = INT32_MAX_VALUE. ROC and precision-recall curves, and other aggregated metrics are derived from them. The confidence metrics entries may also be supplied for additional values of `positionThreshold`, but from these no aggregated metrics are computed.
         */
        confidenceMetrics?: Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsClassificationEvaluationMetricsConfidenceMetrics[];
        /**
         * Confusion matrix of the evaluation.
         */
        confusionMatrix?: Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsConfusionMatrix;
        /**
         * The Log Loss metric.
         */
        logLoss?: number | null;
    }
    export interface Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsClassificationEvaluationMetricsConfidenceMetrics {
        /**
         * Metrics are computed with an assumption that the Model never returns predictions with score lower than this value.
         */
        confidenceThreshold?: number | null;
        /**
         * Confusion matrix of the evaluation for this confidence_threshold.
         */
        confusionMatrix?: Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsConfusionMatrix;
        /**
         * The harmonic mean of recall and precision. For summary metrics, it computes the micro-averaged F1 score.
         */
        f1Score?: number | null;
        /**
         * The harmonic mean of recallAt1 and precisionAt1.
         */
        f1ScoreAt1?: number | null;
        /**
         * Macro-averaged F1 Score.
         */
        f1ScoreMacro?: number | null;
        /**
         * Micro-averaged F1 Score.
         */
        f1ScoreMicro?: number | null;
        /**
         * The number of ground truth labels that are not matched by a Model created label.
         */
        falseNegativeCount?: string | null;
        /**
         * The number of Model created labels that do not match a ground truth label.
         */
        falsePositiveCount?: string | null;
        /**
         * False Positive Rate for the given confidence threshold.
         */
        falsePositiveRate?: number | null;
        /**
         * The False Positive Rate when only considering the label that has the highest prediction score and not below the confidence threshold for each DataItem.
         */
        falsePositiveRateAt1?: number | null;
        /**
         * Metrics are computed with an assumption that the Model always returns at most this many predictions (ordered by their score, descendingly), but they all still need to meet the `confidenceThreshold`.
         */
        maxPredictions?: number | null;
        /**
         * Precision for the given confidence threshold.
         */
        precision?: number | null;
        /**
         * The precision when only considering the label that has the highest prediction score and not below the confidence threshold for each DataItem.
         */
        precisionAt1?: number | null;
        /**
         * Recall (True Positive Rate) for the given confidence threshold.
         */
        recall?: number | null;
        /**
         * The Recall (True Positive Rate) when only considering the label that has the highest prediction score and not below the confidence threshold for each DataItem.
         */
        recallAt1?: number | null;
        /**
         * The number of labels that were not created by the Model, but if they would, they would not match a ground truth label.
         */
        trueNegativeCount?: string | null;
        /**
         * The number of Model created labels that match a ground truth label.
         */
        truePositiveCount?: string | null;
    }
    export interface Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsConfusionMatrix {
        /**
         * AnnotationSpecs used in the confusion matrix. For AutoML Text Extraction, a special negative AnnotationSpec with empty `id` and `displayName` of "NULL" will be added as the last element.
         */
        annotationSpecs?: Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsConfusionMatrixAnnotationSpecRef[];
        /**
         * Rows in the confusion matrix. The number of rows is equal to the size of `annotationSpecs`. `rowsi` is the number of DataItems that have ground truth of the `annotationSpecs[i]` and are predicted as `annotationSpecs[j]` by the Model being evaluated. For Text Extraction, when `annotationSpecs[i]` is the last element in `annotationSpecs`, i.e. the special negative AnnotationSpec, `rowsi` is the number of predicted entities of `annoatationSpec[j]` that are not labeled as any of the ground truth AnnotationSpec. When annotationSpecs[j] is the special negative AnnotationSpec, `rowsi` is the number of entities have ground truth of `annotationSpec[i]` that are not predicted as an entity by the Model. The value of the last cell, i.e. `rowi` where i == j and `annotationSpec[i]` is the special negative AnnotationSpec, is always 0.
         */
        rows?: any[][] | null;
    }
    export interface Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsConfusionMatrixAnnotationSpecRef {
        /**
         * Display name of the AnnotationSpec.
         */
        displayName?: string | null;
        /**
         * ID of the AnnotationSpec.
         */
        id?: string | null;
    }
    /**
     * Metrics for forecasting evaluation results.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsForecastingEvaluationMetrics {
        /**
         * Mean Absolute Error (MAE).
         */
        meanAbsoluteError?: number | null;
        /**
         * Mean absolute percentage error. Infinity when there are zeros in the ground truth.
         */
        meanAbsolutePercentageError?: number | null;
        /**
         * The quantile metrics entries for each quantile.
         */
        quantileMetrics?: Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsForecastingEvaluationMetricsQuantileMetricsEntry[];
        /**
         * Root Mean Squared Error (RMSE).
         */
        rootMeanSquaredError?: number | null;
        /**
         * Root mean squared log error. Undefined when there are negative ground truth values or predictions.
         */
        rootMeanSquaredLogError?: number | null;
        /**
         * Root Mean Square Percentage Error. Square root of MSPE. Undefined/imaginary when MSPE is negative.
         */
        rootMeanSquaredPercentageError?: number | null;
        /**
         * Coefficient of determination as Pearson correlation coefficient. Undefined when ground truth or predictions are constant or near constant.
         */
        rSquared?: number | null;
        /**
         * Weighted Absolute Percentage Error. Does not use weights, this is just what the metric is called. Undefined if actual values sum to zero. Will be very large if actual values sum to a very small number.
         */
        weightedAbsolutePercentageError?: number | null;
    }
    /**
     * Entry for the Quantiles loss type optimization objective.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsForecastingEvaluationMetricsQuantileMetricsEntry {
        /**
         * This is a custom metric that calculates the percentage of true values that were less than the predicted value for that quantile. Only populated when optimization_objective is minimize-quantile-loss and each entry corresponds to an entry in quantiles The percent value can be used to compare with the quantile value, which is the target value.
         */
        observedQuantile?: number | null;
        /**
         * The quantile for this entry.
         */
        quantile?: number | null;
        /**
         * The scaled pinball loss of this quantile.
         */
        scaledPinballLoss?: number | null;
    }
    export interface Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsGeneralTextGenerationEvaluationMetrics {
        /**
         * BLEU (bilingual evaluation understudy) scores based on sacrebleu implementation.
         */
        bleu?: number | null;
        /**
         * ROUGE-L (Longest Common Subsequence) scoring at summary level.
         */
        rougeLSum?: number | null;
    }
    /**
     * Metrics for image object detection evaluation results.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsImageObjectDetectionEvaluationMetrics {
        /**
         * The single metric for bounding boxes evaluation: the `meanAveragePrecision` averaged over all `boundingBoxMetricsEntries`.
         */
        boundingBoxMeanAveragePrecision?: number | null;
        /**
         * The bounding boxes match metrics for each intersection-over-union threshold 0.05,0.10,...,0.95,0.96,0.97,0.98,0.99 and each label confidence threshold 0.05,0.10,...,0.95,0.96,0.97,0.98,0.99 pair.
         */
        boundingBoxMetrics?: Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetrics[];
        /**
         * The total number of bounding boxes (i.e. summed over all images) the ground truth used to create this evaluation had.
         */
        evaluatedBoundingBoxCount?: number | null;
    }
    /**
     * Metrics for image segmentation evaluation results.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsImageSegmentationEvaluationMetrics {
        /**
         * Metrics for each confidenceThreshold in 0.00,0.05,0.10,...,0.95,0.96,0.97,0.98,0.99 Precision-recall curve can be derived from it.
         */
        confidenceMetricsEntries?: Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsImageSegmentationEvaluationMetricsConfidenceMetricsEntry[];
    }
    export interface Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsImageSegmentationEvaluationMetricsConfidenceMetricsEntry {
        /**
         * Metrics are computed with an assumption that the model never returns predictions with score lower than this value.
         */
        confidenceThreshold?: number | null;
        /**
         * Confusion matrix for the given confidence threshold.
         */
        confusionMatrix?: Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsConfusionMatrix;
        /**
         * DSC or the F1 score, The harmonic mean of recall and precision.
         */
        diceScoreCoefficient?: number | null;
        /**
         * The intersection-over-union score. The measure of overlap of the annotation's category mask with ground truth category mask on the DataItem.
         */
        iouScore?: number | null;
        /**
         * Precision for the given confidence threshold.
         */
        precision?: number | null;
        /**
         * Recall (True Positive Rate) for the given confidence threshold.
         */
        recall?: number | null;
    }
    export interface Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsQuestionAnsweringEvaluationMetrics {
        /**
         * The rate at which the input predicted strings exactly match their references.
         */
        exactMatch?: number | null;
    }
    /**
     * Metrics for regression evaluation results.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsRegressionEvaluationMetrics {
        /**
         * Mean Absolute Error (MAE).
         */
        meanAbsoluteError?: number | null;
        /**
         * Mean absolute percentage error. Infinity when there are zeros in the ground truth.
         */
        meanAbsolutePercentageError?: number | null;
        /**
         * Root Mean Squared Error (RMSE).
         */
        rootMeanSquaredError?: number | null;
        /**
         * Root mean squared log error. Undefined when there are negative ground truth values or predictions.
         */
        rootMeanSquaredLogError?: number | null;
        /**
         * Coefficient of determination as Pearson correlation coefficient. Undefined when ground truth or predictions are constant or near constant.
         */
        rSquared?: number | null;
    }
    export interface Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsSummarizationEvaluationMetrics {
        /**
         * ROUGE-L (Longest Common Subsequence) scoring at summary level.
         */
        rougeLSum?: number | null;
    }
    /**
     * Metrics for text extraction evaluation results.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsTextExtractionEvaluationMetrics {
        /**
         * Metrics that have confidence thresholds. Precision-recall curve can be derived from them.
         */
        confidenceMetrics?: Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsTextExtractionEvaluationMetricsConfidenceMetrics[];
        /**
         * Confusion matrix of the evaluation. Only set for Models where number of AnnotationSpecs is no more than 10. Only set for ModelEvaluations, not for ModelEvaluationSlices.
         */
        confusionMatrix?: Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsConfusionMatrix;
    }
    export interface Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsTextExtractionEvaluationMetricsConfidenceMetrics {
        /**
         * Metrics are computed with an assumption that the Model never returns predictions with score lower than this value.
         */
        confidenceThreshold?: number | null;
        /**
         * The harmonic mean of recall and precision.
         */
        f1Score?: number | null;
        /**
         * Precision for the given confidence threshold.
         */
        precision?: number | null;
        /**
         * Recall (True Positive Rate) for the given confidence threshold.
         */
        recall?: number | null;
    }
    /**
     * Model evaluation metrics for text sentiment problems.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsTextSentimentEvaluationMetrics {
        /**
         * Confusion matrix of the evaluation. Only set for ModelEvaluations, not for ModelEvaluationSlices.
         */
        confusionMatrix?: Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsConfusionMatrix;
        /**
         * The harmonic mean of recall and precision.
         */
        f1Score?: number | null;
        /**
         * Linear weighted kappa. Only set for ModelEvaluations, not for ModelEvaluationSlices.
         */
        linearKappa?: number | null;
        /**
         * Mean absolute error. Only set for ModelEvaluations, not for ModelEvaluationSlices.
         */
        meanAbsoluteError?: number | null;
        /**
         * Mean squared error. Only set for ModelEvaluations, not for ModelEvaluationSlices.
         */
        meanSquaredError?: number | null;
        /**
         * Precision.
         */
        precision?: number | null;
        /**
         * Quadratic weighted kappa. Only set for ModelEvaluations, not for ModelEvaluationSlices.
         */
        quadraticKappa?: number | null;
        /**
         * Recall.
         */
        recall?: number | null;
    }
    /**
     * UNIMPLEMENTED. Track matching model metrics for a single track match threshold and multiple label match confidence thresholds.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsTrackMetrics {
        /**
         * Metrics for each label-match `confidenceThreshold` from 0.05,0.10,...,0.95,0.96,0.97,0.98,0.99. Precision-recall curve is derived from them.
         */
        confidenceMetrics?: Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsTrackMetricsConfidenceMetrics[];
        /**
         * The intersection-over-union threshold value between bounding boxes across frames used to compute this metric entry.
         */
        iouThreshold?: number | null;
        /**
         * The mean bounding box iou over all confidence thresholds.
         */
        meanBoundingBoxIou?: number | null;
        /**
         * The mean mismatch rate over all confidence thresholds.
         */
        meanMismatchRate?: number | null;
        /**
         * The mean average precision over all confidence thresholds.
         */
        meanTrackingAveragePrecision?: number | null;
    }
    /**
     * Metrics for a single confidence threshold.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsTrackMetricsConfidenceMetrics {
        /**
         * Bounding box intersection-over-union precision. Measures how well the bounding boxes overlap between each other (e.g. complete overlap or just barely above iou_threshold).
         */
        boundingBoxIou?: number | null;
        /**
         * The confidence threshold value used to compute the metrics.
         */
        confidenceThreshold?: number | null;
        /**
         * Mismatch rate, which measures the tracking consistency, i.e. correctness of instance ID continuity.
         */
        mismatchRate?: number | null;
        /**
         * Tracking precision.
         */
        trackingPrecision?: number | null;
        /**
         * Tracking recall.
         */
        trackingRecall?: number | null;
    }
    /**
     * The Evaluation metrics given a specific precision_window_length.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoActionMetrics {
        /**
         * Metrics for each label-match confidence_threshold from 0.05,0.10,...,0.95,0.96,0.97,0.98,0.99.
         */
        confidenceMetrics?: Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoActionMetricsConfidenceMetrics[];
        /**
         * The mean average precision.
         */
        meanAveragePrecision?: number | null;
        /**
         * This VideoActionMetrics is calculated based on this prediction window length. If the predicted action's timestamp is inside the time window whose center is the ground truth action's timestamp with this specific length, the prediction result is treated as a true positive.
         */
        precisionWindowLength?: string | null;
    }
    /**
     * Metrics for a single confidence threshold.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoActionMetricsConfidenceMetrics {
        /**
         * Output only. The confidence threshold value used to compute the metrics.
         */
        confidenceThreshold?: number | null;
        /**
         * Output only. The harmonic mean of recall and precision.
         */
        f1Score?: number | null;
        /**
         * Output only. Precision for the given confidence threshold.
         */
        precision?: number | null;
        /**
         * Output only. Recall for the given confidence threshold.
         */
        recall?: number | null;
    }
    /**
     * Model evaluation metrics for video action recognition.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoActionRecognitionMetrics {
        /**
         * The number of ground truth actions used to create this evaluation.
         */
        evaluatedActionCount?: number | null;
        /**
         * The metric entries for precision window lengths: 1s,2s,3s.
         */
        videoActionMetrics?: Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoActionMetrics[];
    }
    /**
     * Model evaluation metrics for video object tracking problems. Evaluates prediction quality of both labeled bounding boxes and labeled tracks (i.e. series of bounding boxes sharing same label and instance ID).
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoObjectTrackingMetrics {
        /**
         * The single metric for bounding boxes evaluation: the `meanAveragePrecision` averaged over all `boundingBoxMetrics`.
         */
        boundingBoxMeanAveragePrecision?: number | null;
        /**
         * The bounding boxes match metrics for each intersection-over-union threshold 0.05,0.10,...,0.95,0.96,0.97,0.98,0.99 and each label confidence threshold 0.05,0.10,...,0.95,0.96,0.97,0.98,0.99 pair.
         */
        boundingBoxMetrics?: Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetrics[];
        /**
         * UNIMPLEMENTED. The total number of bounding boxes (i.e. summed over all frames) the ground truth used to create this evaluation had.
         */
        evaluatedBoundingBoxCount?: number | null;
        /**
         * UNIMPLEMENTED. The number of video frames used to create this evaluation.
         */
        evaluatedFrameCount?: number | null;
        /**
         * UNIMPLEMENTED. The total number of tracks (i.e. as seen across all frames) the ground truth used to create this evaluation had.
         */
        evaluatedTrackCount?: number | null;
        /**
         * UNIMPLEMENTED. The single metric for tracks accuracy evaluation: the `meanAveragePrecision` averaged over all `trackMetrics`.
         */
        trackMeanAveragePrecision?: number | null;
        /**
         * UNIMPLEMENTED. The single metric for tracks bounding box iou evaluation: the `meanBoundingBoxIou` averaged over all `trackMetrics`.
         */
        trackMeanBoundingBoxIou?: number | null;
        /**
         * UNIMPLEMENTED. The single metric for tracking consistency evaluation: the `meanMismatchRate` averaged over all `trackMetrics`.
         */
        trackMeanMismatchRate?: number | null;
        /**
         * UNIMPLEMENTED. The tracks match metrics for each intersection-over-union threshold 0.05,0.10,...,0.95,0.96,0.97,0.98,0.99 and each label confidence threshold 0.05,0.10,...,0.95,0.96,0.97,0.98,0.99 pair.
         */
        trackMetrics?: Schema$GoogleCloudAiplatformV1SchemaModelevaluationMetricsTrackMetrics[];
    }
    /**
     * Prediction input format for Image Classification.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaPredictInstanceImageClassificationPredictionInstance {
        /**
         * The image bytes or Cloud Storage URI to make the prediction on.
         */
        content?: string | null;
        /**
         * The MIME type of the content of the image. Only the images in below listed MIME types are supported. - image/jpeg - image/gif - image/png - image/webp - image/bmp - image/tiff - image/vnd.microsoft.icon
         */
        mimeType?: string | null;
    }
    /**
     * Prediction input format for Image Object Detection.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaPredictInstanceImageObjectDetectionPredictionInstance {
        /**
         * The image bytes or Cloud Storage URI to make the prediction on.
         */
        content?: string | null;
        /**
         * The MIME type of the content of the image. Only the images in below listed MIME types are supported. - image/jpeg - image/gif - image/png - image/webp - image/bmp - image/tiff - image/vnd.microsoft.icon
         */
        mimeType?: string | null;
    }
    /**
     * Prediction input format for Image Segmentation.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaPredictInstanceImageSegmentationPredictionInstance {
        /**
         * The image bytes to make the predictions on.
         */
        content?: string | null;
        /**
         * The MIME type of the content of the image. Only the images in below listed MIME types are supported. - image/jpeg - image/png
         */
        mimeType?: string | null;
    }
    /**
     * Prediction input format for Text Classification.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaPredictInstanceTextClassificationPredictionInstance {
        /**
         * The text snippet to make the predictions on.
         */
        content?: string | null;
        /**
         * The MIME type of the text snippet. The supported MIME types are listed below. - text/plain
         */
        mimeType?: string | null;
    }
    /**
     * Prediction input format for Text Extraction.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaPredictInstanceTextExtractionPredictionInstance {
        /**
         * The text snippet to make the predictions on.
         */
        content?: string | null;
        /**
         * This field is only used for batch prediction. If a key is provided, the batch prediction result will by mapped to this key. If omitted, then the batch prediction result will contain the entire input instance. Vertex AI will not check if keys in the request are duplicates, so it is up to the caller to ensure the keys are unique.
         */
        key?: string | null;
        /**
         * The MIME type of the text snippet. The supported MIME types are listed below. - text/plain
         */
        mimeType?: string | null;
    }
    /**
     * Prediction input format for Text Sentiment.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaPredictInstanceTextSentimentPredictionInstance {
        /**
         * The text snippet to make the predictions on.
         */
        content?: string | null;
        /**
         * The MIME type of the text snippet. The supported MIME types are listed below. - text/plain
         */
        mimeType?: string | null;
    }
    /**
     * Prediction input format for Video Action Recognition.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaPredictInstanceVideoActionRecognitionPredictionInstance {
        /**
         * The Google Cloud Storage location of the video on which to perform the prediction.
         */
        content?: string | null;
        /**
         * The MIME type of the content of the video. Only the following are supported: video/mp4 video/avi video/quicktime
         */
        mimeType?: string | null;
        /**
         * The end, exclusive, of the video's time segment on which to perform the prediction. Expressed as a number of seconds as measured from the start of the video, with "s" appended at the end. Fractions are allowed, up to a microsecond precision, and "inf" or "Infinity" is allowed, which means the end of the video.
         */
        timeSegmentEnd?: string | null;
        /**
         * The beginning, inclusive, of the video's time segment on which to perform the prediction. Expressed as a number of seconds as measured from the start of the video, with "s" appended at the end. Fractions are allowed, up to a microsecond precision.
         */
        timeSegmentStart?: string | null;
    }
    /**
     * Prediction input format for Video Classification.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaPredictInstanceVideoClassificationPredictionInstance {
        /**
         * The Google Cloud Storage location of the video on which to perform the prediction.
         */
        content?: string | null;
        /**
         * The MIME type of the content of the video. Only the following are supported: video/mp4 video/avi video/quicktime
         */
        mimeType?: string | null;
        /**
         * The end, exclusive, of the video's time segment on which to perform the prediction. Expressed as a number of seconds as measured from the start of the video, with "s" appended at the end. Fractions are allowed, up to a microsecond precision, and "inf" or "Infinity" is allowed, which means the end of the video.
         */
        timeSegmentEnd?: string | null;
        /**
         * The beginning, inclusive, of the video's time segment on which to perform the prediction. Expressed as a number of seconds as measured from the start of the video, with "s" appended at the end. Fractions are allowed, up to a microsecond precision.
         */
        timeSegmentStart?: string | null;
    }
    /**
     * Prediction input format for Video Object Tracking.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaPredictInstanceVideoObjectTrackingPredictionInstance {
        /**
         * The Google Cloud Storage location of the video on which to perform the prediction.
         */
        content?: string | null;
        /**
         * The MIME type of the content of the video. Only the following are supported: video/mp4 video/avi video/quicktime
         */
        mimeType?: string | null;
        /**
         * The end, exclusive, of the video's time segment on which to perform the prediction. Expressed as a number of seconds as measured from the start of the video, with "s" appended at the end. Fractions are allowed, up to a microsecond precision, and "inf" or "Infinity" is allowed, which means the end of the video.
         */
        timeSegmentEnd?: string | null;
        /**
         * The beginning, inclusive, of the video's time segment on which to perform the prediction. Expressed as a number of seconds as measured from the start of the video, with "s" appended at the end. Fractions are allowed, up to a microsecond precision.
         */
        timeSegmentStart?: string | null;
    }
    /**
     * Represents a line of JSONL in the batch prediction output file.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaPredictionResult {
        /**
         * The error result. Do not set prediction if this is set.
         */
        error?: Schema$GoogleCloudAiplatformV1SchemaPredictionResultError;
        /**
         * User's input instance. Struct is used here instead of Any so that JsonFormat does not append an extra "@type" field when we convert the proto to JSON.
         */
        instance?: {
            [key: string]: any;
        } | null;
        /**
         * Optional user-provided key from the input instance.
         */
        key?: string | null;
        /**
         * The prediction result. Value is used here instead of Any so that JsonFormat does not append an extra "@type" field when we convert the proto to JSON and so we can represent array of objects. Do not set error if this is set.
         */
        prediction?: any | null;
    }
    export interface Schema$GoogleCloudAiplatformV1SchemaPredictionResultError {
        /**
         * Error message with additional details.
         */
        message?: string | null;
        /**
         * Error status. This will be serialized into the enum name e.g. "NOT_FOUND".
         */
        status?: string | null;
    }
    /**
     * The configuration for grounding checking.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaPredictParamsGroundingConfig {
        /**
         * The sources for the grounding checking.
         */
        sources?: Schema$GoogleCloudAiplatformV1SchemaPredictParamsGroundingConfigSourceEntry[];
    }
    /**
     * Single source entry for the grounding checking.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaPredictParamsGroundingConfigSourceEntry {
        /**
         * The uri of the Enterprise Search data source.
         */
        enterpriseDatastore?: string | null;
        /**
         * The type of the grounding checking source.
         */
        type?: string | null;
    }
    /**
     * Prediction model parameters for Image Classification.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaPredictParamsImageClassificationPredictionParams {
        /**
         * The Model only returns predictions with at least this confidence score. Default value is 0.0
         */
        confidenceThreshold?: number | null;
        /**
         * The Model only returns up to that many top, by confidence score, predictions per instance. If this number is very high, the Model may return fewer predictions. Default value is 10.
         */
        maxPredictions?: number | null;
    }
    /**
     * Prediction model parameters for Image Object Detection.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaPredictParamsImageObjectDetectionPredictionParams {
        /**
         * The Model only returns predictions with at least this confidence score. Default value is 0.0
         */
        confidenceThreshold?: number | null;
        /**
         * The Model only returns up to that many top, by confidence score, predictions per instance. Note that number of returned predictions is also limited by metadata's predictionsLimit. Default value is 10.
         */
        maxPredictions?: number | null;
    }
    /**
     * Prediction model parameters for Image Segmentation.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaPredictParamsImageSegmentationPredictionParams {
        /**
         * When the model predicts category of pixels of the image, it will only provide predictions for pixels that it is at least this much confident about. All other pixels will be classified as background. Default value is 0.5.
         */
        confidenceThreshold?: number | null;
    }
    /**
     * Prediction model parameters for Video Action Recognition.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaPredictParamsVideoActionRecognitionPredictionParams {
        /**
         * The Model only returns predictions with at least this confidence score. Default value is 0.0
         */
        confidenceThreshold?: number | null;
        /**
         * The model only returns up to that many top, by confidence score, predictions per frame of the video. If this number is very high, the Model may return fewer predictions per frame. Default value is 50.
         */
        maxPredictions?: number | null;
    }
    /**
     * Prediction model parameters for Video Classification.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaPredictParamsVideoClassificationPredictionParams {
        /**
         * The Model only returns predictions with at least this confidence score. Default value is 0.0
         */
        confidenceThreshold?: number | null;
        /**
         * The Model only returns up to that many top, by confidence score, predictions per instance. If this number is very high, the Model may return fewer predictions. Default value is 10,000.
         */
        maxPredictions?: number | null;
        /**
         * Set to true to request classification for a video at one-second intervals. Vertex AI returns labels and their confidence scores for each second of the entire time segment of the video that user specified in the input WARNING: Model evaluation is not done for this classification type, the quality of it depends on the training data, but there are no metrics provided to describe that quality. Default value is false
         */
        oneSecIntervalClassification?: boolean | null;
        /**
         * Set to true to request segment-level classification. Vertex AI returns labels and their confidence scores for the entire time segment of the video that user specified in the input instance. Default value is true
         */
        segmentClassification?: boolean | null;
        /**
         * Set to true to request shot-level classification. Vertex AI determines the boundaries for each camera shot in the entire time segment of the video that user specified in the input instance. Vertex AI then returns labels and their confidence scores for each detected shot, along with the start and end time of the shot. WARNING: Model evaluation is not done for this classification type, the quality of it depends on the training data, but there are no metrics provided to describe that quality. Default value is false
         */
        shotClassification?: boolean | null;
    }
    /**
     * Prediction model parameters for Video Object Tracking.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaPredictParamsVideoObjectTrackingPredictionParams {
        /**
         * The Model only returns predictions with at least this confidence score. Default value is 0.0
         */
        confidenceThreshold?: number | null;
        /**
         * The model only returns up to that many top, by confidence score, predictions per frame of the video. If this number is very high, the Model may return fewer predictions per frame. Default value is 50.
         */
        maxPredictions?: number | null;
        /**
         * Only bounding boxes with shortest edge at least that long as a relative value of video frame size are returned. Default value is 0.0.
         */
        minBoundingBoxSize?: number | null;
    }
    /**
     * Prediction output format for Image and Text Classification.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaPredictPredictionClassificationPredictionResult {
        /**
         * The Model's confidences in correctness of the predicted IDs, higher value means higher confidence. Order matches the Ids.
         */
        confidences?: number[] | null;
        /**
         * The display names of the AnnotationSpecs that had been identified, order matches the IDs.
         */
        displayNames?: string[] | null;
        /**
         * The resource IDs of the AnnotationSpecs that had been identified.
         */
        ids?: string[] | null;
    }
    /**
     * Prediction output format for Image Object Detection.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaPredictPredictionImageObjectDetectionPredictionResult {
        /**
         * Bounding boxes, i.e. the rectangles over the image, that pinpoint the found AnnotationSpecs. Given in order that matches the IDs. Each bounding box is an array of 4 numbers `xMin`, `xMax`, `yMin`, and `yMax`, which represent the extremal coordinates of the box. They are relative to the image size, and the point 0,0 is in the top left of the image.
         */
        bboxes?: any[][] | null;
        /**
         * The Model's confidences in correctness of the predicted IDs, higher value means higher confidence. Order matches the Ids.
         */
        confidences?: number[] | null;
        /**
         * The display names of the AnnotationSpecs that had been identified, order matches the IDs.
         */
        displayNames?: string[] | null;
        /**
         * The resource IDs of the AnnotationSpecs that had been identified, ordered by the confidence score descendingly.
         */
        ids?: string[] | null;
    }
    /**
     * Prediction output format for Image Segmentation.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaPredictPredictionImageSegmentationPredictionResult {
        /**
         * A PNG image where each pixel in the mask represents the category in which the pixel in the original image was predicted to belong to. The size of this image will be the same as the original image. The mapping between the AnntoationSpec and the color can be found in model's metadata. The model will choose the most likely category and if none of the categories reach the confidence threshold, the pixel will be marked as background.
         */
        categoryMask?: string | null;
        /**
         * A one channel image which is encoded as an 8bit lossless PNG. The size of the image will be the same as the original image. For a specific pixel, darker color means less confidence in correctness of the cateogry in the categoryMask for the corresponding pixel. Black means no confidence and white means complete confidence.
         */
        confidenceMask?: string | null;
    }
    /**
     * Prediction output format for Tabular Classification.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaPredictPredictionTabularClassificationPredictionResult {
        /**
         * The name of the classes being classified, contains all possible values of the target column.
         */
        classes?: string[] | null;
        /**
         * The model's confidence in each class being correct, higher value means higher confidence. The N-th score corresponds to the N-th class in classes.
         */
        scores?: number[] | null;
    }
    /**
     * Prediction output format for Tabular Regression.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaPredictPredictionTabularRegressionPredictionResult {
        /**
         * The lower bound of the prediction interval.
         */
        lowerBound?: number | null;
        /**
         * Quantile predictions, in 1-1 correspondence with quantile_values.
         */
        quantilePredictions?: number[] | null;
        /**
         * Quantile values.
         */
        quantileValues?: number[] | null;
        /**
         * The upper bound of the prediction interval.
         */
        upperBound?: number | null;
        /**
         * The regression value.
         */
        value?: number | null;
    }
    /**
     * Prediction output format for Text Extraction.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaPredictPredictionTextExtractionPredictionResult {
        /**
         * The Model's confidences in correctness of the predicted IDs, higher value means higher confidence. Order matches the Ids.
         */
        confidences?: number[] | null;
        /**
         * The display names of the AnnotationSpecs that had been identified, order matches the IDs.
         */
        displayNames?: string[] | null;
        /**
         * The resource IDs of the AnnotationSpecs that had been identified, ordered by the confidence score descendingly.
         */
        ids?: string[] | null;
        /**
         * The end offsets, inclusive, of the text segment in which the AnnotationSpec has been identified. Expressed as a zero-based number of characters as measured from the start of the text snippet.
         */
        textSegmentEndOffsets?: string[] | null;
        /**
         * The start offsets, inclusive, of the text segment in which the AnnotationSpec has been identified. Expressed as a zero-based number of characters as measured from the start of the text snippet.
         */
        textSegmentStartOffsets?: string[] | null;
    }
    /**
     * Prediction output format for Text Sentiment
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaPredictPredictionTextSentimentPredictionResult {
        /**
         * The integer sentiment labels between 0 (inclusive) and sentimentMax label (inclusive), while 0 maps to the least positive sentiment and sentimentMax maps to the most positive one. The higher the score is, the more positive the sentiment in the text snippet is. Note: sentimentMax is an integer value between 1 (inclusive) and 10 (inclusive).
         */
        sentiment?: number | null;
    }
    export interface Schema$GoogleCloudAiplatformV1SchemaPredictPredictionTftFeatureImportance {
        attributeColumns?: string[] | null;
        attributeWeights?: number[] | null;
        contextColumns?: string[] | null;
        /**
         * TFT feature importance values. Each pair for {context/horizon/attribute\} should have the same shape since the weight corresponds to the column names.
         */
        contextWeights?: number[] | null;
        horizonColumns?: string[] | null;
        horizonWeights?: number[] | null;
    }
    /**
     * Prediction output format for Time Series Forecasting.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaPredictPredictionTimeSeriesForecastingPredictionResult {
        /**
         * Quantile predictions, in 1-1 correspondence with quantile_values.
         */
        quantilePredictions?: number[] | null;
        /**
         * Quantile values.
         */
        quantileValues?: number[] | null;
        /**
         * Only use these if TFt is enabled.
         */
        tftFeatureImportance?: Schema$GoogleCloudAiplatformV1SchemaPredictPredictionTftFeatureImportance;
        /**
         * The regression value.
         */
        value?: number | null;
    }
    /**
     * Prediction output format for Video Action Recognition.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaPredictPredictionVideoActionRecognitionPredictionResult {
        /**
         * The Model's confidence in correction of this prediction, higher value means higher confidence.
         */
        confidence?: number | null;
        /**
         * The display name of the AnnotationSpec that had been identified.
         */
        displayName?: string | null;
        /**
         * The resource ID of the AnnotationSpec that had been identified.
         */
        id?: string | null;
        /**
         * The end, exclusive, of the video's time segment in which the AnnotationSpec has been identified. Expressed as a number of seconds as measured from the start of the video, with fractions up to a microsecond precision, and with "s" appended at the end.
         */
        timeSegmentEnd?: string | null;
        /**
         * The beginning, inclusive, of the video's time segment in which the AnnotationSpec has been identified. Expressed as a number of seconds as measured from the start of the video, with fractions up to a microsecond precision, and with "s" appended at the end.
         */
        timeSegmentStart?: string | null;
    }
    /**
     * Prediction output format for Video Classification.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaPredictPredictionVideoClassificationPredictionResult {
        /**
         * The Model's confidence in correction of this prediction, higher value means higher confidence.
         */
        confidence?: number | null;
        /**
         * The display name of the AnnotationSpec that had been identified.
         */
        displayName?: string | null;
        /**
         * The resource ID of the AnnotationSpec that had been identified.
         */
        id?: string | null;
        /**
         * The end, exclusive, of the video's time segment in which the AnnotationSpec has been identified. Expressed as a number of seconds as measured from the start of the video, with fractions up to a microsecond precision, and with "s" appended at the end. Note that for 'segment-classification' prediction type, this equals the original 'timeSegmentEnd' from the input instance, for other types it is the end of a shot or a 1 second interval respectively.
         */
        timeSegmentEnd?: string | null;
        /**
         * The beginning, inclusive, of the video's time segment in which the AnnotationSpec has been identified. Expressed as a number of seconds as measured from the start of the video, with fractions up to a microsecond precision, and with "s" appended at the end. Note that for 'segment-classification' prediction type, this equals the original 'timeSegmentStart' from the input instance, for other types it is the start of a shot or a 1 second interval respectively.
         */
        timeSegmentStart?: string | null;
        /**
         * The type of the prediction. The requested types can be configured via parameters. This will be one of - segment-classification - shot-classification - one-sec-interval-classification
         */
        type?: string | null;
    }
    /**
     * Prediction output format for Video Object Tracking.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResult {
        /**
         * The Model's confidence in correction of this prediction, higher value means higher confidence.
         */
        confidence?: number | null;
        /**
         * The display name of the AnnotationSpec that had been identified.
         */
        displayName?: string | null;
        /**
         * All of the frames of the video in which a single object instance has been detected. The bounding boxes in the frames identify the same object.
         */
        frames?: Schema$GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResultFrame[];
        /**
         * The resource ID of the AnnotationSpec that had been identified.
         */
        id?: string | null;
        /**
         * The end, inclusive, of the video's time segment in which the object instance has been detected. Expressed as a number of seconds as measured from the start of the video, with fractions up to a microsecond precision, and with "s" appended at the end.
         */
        timeSegmentEnd?: string | null;
        /**
         * The beginning, inclusive, of the video's time segment in which the object instance has been detected. Expressed as a number of seconds as measured from the start of the video, with fractions up to a microsecond precision, and with "s" appended at the end.
         */
        timeSegmentStart?: string | null;
    }
    /**
     * The fields `xMin`, `xMax`, `yMin`, and `yMax` refer to a bounding box, i.e. the rectangle over the video frame pinpointing the found AnnotationSpec. The coordinates are relative to the frame size, and the point 0,0 is in the top left of the frame.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResultFrame {
        /**
         * A time (frame) of a video in which the object has been detected. Expressed as a number of seconds as measured from the start of the video, with fractions up to a microsecond precision, and with "s" appended at the end.
         */
        timeOffset?: string | null;
        /**
         * The rightmost coordinate of the bounding box.
         */
        xMax?: number | null;
        /**
         * The leftmost coordinate of the bounding box.
         */
        xMin?: number | null;
        /**
         * The bottommost coordinate of the bounding box.
         */
        yMax?: number | null;
        /**
         * The topmost coordinate of the bounding box.
         */
        yMin?: number | null;
    }
    /**
     * The metadata of Datasets that contain tables data.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTablesDatasetMetadata {
        inputConfig?: Schema$GoogleCloudAiplatformV1SchemaTablesDatasetMetadataInputConfig;
    }
    export interface Schema$GoogleCloudAiplatformV1SchemaTablesDatasetMetadataBigQuerySource {
        /**
         * The URI of a BigQuery table. e.g. bq://projectId.bqDatasetId.bqTableId
         */
        uri?: string | null;
    }
    export interface Schema$GoogleCloudAiplatformV1SchemaTablesDatasetMetadataGcsSource {
        /**
         * Cloud Storage URI of one or more files. Only CSV files are supported. The first line of the CSV file is used as the header. If there are multiple files, the header is the first line of the lexicographically first file, the other files must either contain the exact same header or omit the header.
         */
        uri?: string[] | null;
    }
    /**
     * The tables Dataset's data source. The Dataset doesn't store the data directly, but only pointer(s) to its data.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTablesDatasetMetadataInputConfig {
        bigquerySource?: Schema$GoogleCloudAiplatformV1SchemaTablesDatasetMetadataBigQuerySource;
        gcsSource?: Schema$GoogleCloudAiplatformV1SchemaTablesDatasetMetadataGcsSource;
    }
    /**
     * Annotation details specific to text classification.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTextClassificationAnnotation {
        /**
         * The resource Id of the AnnotationSpec that this Annotation pertains to.
         */
        annotationSpecId?: string | null;
        /**
         * The display name of the AnnotationSpec that this Annotation pertains to.
         */
        displayName?: string | null;
    }
    /**
     * Payload of Text DataItem.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTextDataItem {
        /**
         * Output only. Google Cloud Storage URI points to the original text in user's bucket. The text file is up to 10MB in size.
         */
        gcsUri?: string | null;
    }
    /**
     * The metadata of Datasets that contain Text DataItems.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTextDatasetMetadata {
        /**
         * Points to a YAML file stored on Google Cloud Storage describing payload of the Text DataItems that belong to this Dataset.
         */
        dataItemSchemaUri?: string | null;
        /**
         * Google Cloud Storage Bucket name that contains the blob data of this Dataset.
         */
        gcsBucket?: string | null;
    }
    /**
     * Annotation details specific to text extraction.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTextExtractionAnnotation {
        /**
         * The resource Id of the AnnotationSpec that this Annotation pertains to.
         */
        annotationSpecId?: string | null;
        /**
         * The display name of the AnnotationSpec that this Annotation pertains to.
         */
        displayName?: string | null;
        /**
         * The segment of the text content.
         */
        textSegment?: Schema$GoogleCloudAiplatformV1SchemaTextSegment;
    }
    /**
     * The metadata of Datasets that contain Text Prompt data.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTextPromptDatasetMetadata {
        /**
         * Number of candidates.
         */
        candidateCount?: string | null;
        /**
         * The Google Cloud Storage URI that stores the prompt data.
         */
        gcsUri?: string | null;
        /**
         * Grounding checking configuration.
         */
        groundingConfig?: Schema$GoogleCloudAiplatformV1SchemaPredictParamsGroundingConfig;
        /**
         * Value of the maximum number of tokens generated set when the dataset was saved.
         */
        maxOutputTokens?: string | null;
        /**
         * Type of the prompt dataset.
         */
        promptType?: string | null;
        /**
         * Customized stop sequences.
         */
        stopSequences?: string[] | null;
        /**
         * Temperature value used for sampling set when the dataset was saved. This value is used to tune the degree of randomness.
         */
        temperature?: number | null;
        /**
         * The content of the prompt dataset.
         */
        text?: string | null;
        /**
         * Top K value set when the dataset was saved. This value determines how many candidates with highest probability from the vocab would be selected for each decoding step.
         */
        topK?: string | null;
        /**
         * Top P value set when the dataset was saved. Given topK tokens for decoding, top candidates will be selected until the sum of their probabilities is topP.
         */
        topP?: number | null;
    }
    /**
     * The text segment inside of DataItem.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTextSegment {
        /**
         * The text content in the segment for output only.
         */
        content?: string | null;
        /**
         * Zero-based character index of the first character past the end of the text segment (counting character from the beginning of the text). The character at the end_offset is NOT included in the text segment.
         */
        endOffset?: string | null;
        /**
         * Zero-based character index of the first character of the text segment (counting characters from the beginning of the text).
         */
        startOffset?: string | null;
    }
    /**
     * Annotation details specific to text sentiment.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTextSentimentAnnotation {
        /**
         * The resource Id of the AnnotationSpec that this Annotation pertains to.
         */
        annotationSpecId?: string | null;
        /**
         * The display name of the AnnotationSpec that this Annotation pertains to.
         */
        displayName?: string | null;
        /**
         * The sentiment score for text.
         */
        sentiment?: number | null;
        /**
         * The sentiment max score for text.
         */
        sentimentMax?: number | null;
    }
    /**
     * The metadata of SavedQuery contains TextSentiment Annotations.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTextSentimentSavedQueryMetadata {
        /**
         * The maximum sentiment of sentiment Anntoation in this SavedQuery.
         */
        sentimentMax?: number | null;
    }
    /**
     * A time period inside of a DataItem that has a time dimension (e.g. video).
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTimeSegment {
        /**
         * End of the time segment (exclusive), represented as the duration since the start of the DataItem.
         */
        endTimeOffset?: string | null;
        /**
         * Start of the time segment (inclusive), represented as the duration since the start of the DataItem.
         */
        startTimeOffset?: string | null;
    }
    /**
     * The metadata of Datasets that contain time series data.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTimeSeriesDatasetMetadata {
        inputConfig?: Schema$GoogleCloudAiplatformV1SchemaTimeSeriesDatasetMetadataInputConfig;
        /**
         * The column name of the time column that identifies time order in the time series.
         */
        timeColumn?: string | null;
        /**
         * The column name of the time series identifier column that identifies the time series.
         */
        timeSeriesIdentifierColumn?: string | null;
    }
    export interface Schema$GoogleCloudAiplatformV1SchemaTimeSeriesDatasetMetadataBigQuerySource {
        /**
         * The URI of a BigQuery table.
         */
        uri?: string | null;
    }
    export interface Schema$GoogleCloudAiplatformV1SchemaTimeSeriesDatasetMetadataGcsSource {
        /**
         * Cloud Storage URI of one or more files. Only CSV files are supported. The first line of the CSV file is used as the header. If there are multiple files, the header is the first line of the lexicographically first file, the other files must either contain the exact same header or omit the header.
         */
        uri?: string[] | null;
    }
    /**
     * The time series Dataset's data source. The Dataset doesn't store the data directly, but only pointer(s) to its data.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTimeSeriesDatasetMetadataInputConfig {
        bigquerySource?: Schema$GoogleCloudAiplatformV1SchemaTimeSeriesDatasetMetadataBigQuerySource;
        gcsSource?: Schema$GoogleCloudAiplatformV1SchemaTimeSeriesDatasetMetadataGcsSource;
    }
    /**
     * A TrainingJob that trains and uploads an AutoML Forecasting Model.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecasting {
        /**
         * The input parameters of this TrainingJob.
         */
        inputs?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputs;
        /**
         * The metadata information.
         */
        metadata?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingMetadata;
    }
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputs {
        /**
         * Additional experiment flags for the time series forcasting training.
         */
        additionalExperiments?: string[] | null;
        /**
         * Names of columns that are available and provided when a forecast is requested. These columns contain information for the given entity (identified by the time_series_identifier_column column) that is known at forecast. For example, predicted weather for a specific day.
         */
        availableAtForecastColumns?: string[] | null;
        /**
         * The amount of time into the past training and prediction data is used for model training and prediction respectively. Expressed in number of units defined by the `data_granularity` field.
         */
        contextWindow?: string | null;
        /**
         * Expected difference in time granularity between rows in the data.
         */
        dataGranularity?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsGranularity;
        /**
         * If probabilistic inference is enabled, the model will fit a distribution that captures the uncertainty of a prediction. At inference time, the predictive distribution is used to make a point prediction that minimizes the optimization objective. For example, the mean of a predictive distribution is the point prediction that minimizes RMSE loss. If quantiles are specified, then the quantiles of the distribution are also returned. The optimization objective cannot be minimize-quantile-loss.
         */
        enableProbabilisticInference?: boolean | null;
        /**
         * Configuration for exporting test set predictions to a BigQuery table. If this configuration is absent, then the export is not performed.
         */
        exportEvaluatedDataItemsConfig?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionExportEvaluatedDataItemsConfig;
        /**
         * The amount of time into the future for which forecasted values for the target are returned. Expressed in number of units defined by the `data_granularity` field.
         */
        forecastHorizon?: string | null;
        /**
         * Configuration that defines the hierarchical relationship of time series and parameters for hierarchical forecasting strategies.
         */
        hierarchyConfig?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHierarchyConfig;
        /**
         * The geographical region based on which the holiday effect is applied in modeling by adding holiday categorical array feature that include all holidays matching the date. This option only allowed when data_granularity is day. By default, holiday effect modeling is disabled. To turn it on, specify the holiday region using this option.
         */
        holidayRegions?: string[] | null;
        /**
         * Objective function the model is optimizing towards. The training process creates a model that optimizes the value of the objective function over the validation set. The supported optimization objectives: * "minimize-rmse" (default) - Minimize root-mean-squared error (RMSE). * "minimize-mae" - Minimize mean-absolute error (MAE). * "minimize-rmsle" - Minimize root-mean-squared log error (RMSLE). * "minimize-rmspe" - Minimize root-mean-squared percentage error (RMSPE). * "minimize-wape-mae" - Minimize the combination of weighted absolute percentage error (WAPE) and mean-absolute-error (MAE). * "minimize-quantile-loss" - Minimize the quantile loss at the quantiles defined in `quantiles`. * "minimize-mape" - Minimize the mean absolute percentage error.
         */
        optimizationObjective?: string | null;
        /**
         * Quantiles to use for minimize-quantile-loss `optimization_objective`, or for probabilistic inference. Up to 5 quantiles are allowed of values between 0 and 1, exclusive. Required if the value of optimization_objective is minimize-quantile-loss. Represents the percent quantiles to use for that objective. Quantiles must be unique.
         */
        quantiles?: number[] | null;
        /**
         * The name of the column that the Model is to predict values for. This column must be unavailable at forecast.
         */
        targetColumn?: string | null;
        /**
         * The name of the column that identifies time order in the time series. This column must be available at forecast.
         */
        timeColumn?: string | null;
        /**
         * Column names that should be used as attribute columns. The value of these columns does not vary as a function of time. For example, store ID or item color.
         */
        timeSeriesAttributeColumns?: string[] | null;
        /**
         * The name of the column that identifies the time series.
         */
        timeSeriesIdentifierColumn?: string | null;
        /**
         * Required. The train budget of creating this model, expressed in milli node hours i.e. 1,000 value in this field means 1 node hour. The training cost of the model will not exceed this budget. The final cost will be attempted to be close to the budget, though may end up being (even) noticeably smaller - at the backend's discretion. This especially may happen when further model training ceases to provide any improvements. If the budget is set to a value known to be insufficient to train a model for the given dataset, the training won't be attempted and will error. The train budget must be between 1,000 and 72,000 milli node hours, inclusive.
         */
        trainBudgetMilliNodeHours?: string | null;
        /**
         * Each transformation will apply transform function to given input column. And the result will be used for training. When creating transformation for BigQuery Struct column, the column should be flattened using "." as the delimiter.
         */
        transformations?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformation[];
        /**
         * Names of columns that are unavailable when a forecast is requested. This column contains information for the given entity (identified by the time_series_identifier_column) that is unknown before the forecast For example, actual weather on a given day.
         */
        unavailableAtForecastColumns?: string[] | null;
        /**
         * Validation options for the data validation component. The available options are: * "fail-pipeline" - default, will validate against the validation and fail the pipeline if it fails. * "ignore-validation" - ignore the results of the validation and continue
         */
        validationOptions?: string | null;
        /**
         * Column name that should be used as the weight column. Higher values in this column give more importance to the row during model training. The column must have numeric values between 0 and 10000 inclusively; 0 means the row is ignored for training. If weight column field is not set, then all rows are assumed to have equal weight of 1.
         */
        weightColumn?: string | null;
        /**
         * Config containing strategy for generating sliding windows.
         */
        windowConfig?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionWindowConfig;
    }
    /**
     * A duration of time expressed in time granularity units.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsGranularity {
        /**
         * The number of granularity_units between data points in the training data. If `granularity_unit` is `minute`, can be 1, 5, 10, 15, or 30. For all other values of `granularity_unit`, must be 1.
         */
        quantity?: string | null;
        /**
         * The time granularity unit of this time period. The supported units are: * "minute" * "hour" * "day" * "week" * "month" * "year"
         */
        unit?: string | null;
    }
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformation {
        auto?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationAutoTransformation;
        categorical?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationCategoricalTransformation;
        numeric?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationNumericTransformation;
        text?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationTextTransformation;
        timestamp?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationTimestampTransformation;
    }
    /**
     * Training pipeline will infer the proper transformation based on the statistic of dataset.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationAutoTransformation {
        columnName?: string | null;
    }
    /**
     * Training pipeline will perform following transformation functions. * The categorical string as is--no change to case, punctuation, spelling, tense, and so on. * Convert the category name to a dictionary lookup index and generate an embedding for each index. * Categories that appear less than 5 times in the training dataset are treated as the "unknown" category. The "unknown" category gets its own special lookup index and resulting embedding.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationCategoricalTransformation {
        columnName?: string | null;
    }
    /**
     * Training pipeline will perform following transformation functions. * The value converted to float32. * The z_score of the value. * log(value+1) when the value is greater than or equal to 0. Otherwise, this transformation is not applied and the value is considered a missing value. * z_score of log(value+1) when the value is greater than or equal to 0. Otherwise, this transformation is not applied and the value is considered a missing value. * A boolean value that indicates whether the value is valid.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationNumericTransformation {
        columnName?: string | null;
    }
    /**
     * Training pipeline will perform following transformation functions. * The text as is--no change to case, punctuation, spelling, tense, and so on. * Convert the category name to a dictionary lookup index and generate an embedding for each index.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationTextTransformation {
        columnName?: string | null;
    }
    /**
     * Training pipeline will perform following transformation functions. * Apply the transformation functions for Numerical columns. * Determine the year, month, day,and weekday. Treat each value from the timestamp as a Categorical column. * Invalid numerical values (for example, values that fall outside of a typical timestamp range, or are extreme values) receive no special treatment and are not removed.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationTimestampTransformation {
        columnName?: string | null;
        /**
         * The format in which that time field is expressed. The time_format must either be one of: * `unix-seconds` * `unix-milliseconds` * `unix-microseconds` * `unix-nanoseconds` (for respectively number of seconds, milliseconds, microseconds and nanoseconds since start of the Unix epoch); or be written in `strftime` syntax. If time_format is not set, then the default format is RFC 3339 `date-time` format, where `time-offset` = `"Z"` (e.g. 1985-04-12T23:20:50.52Z)
         */
        timeFormat?: string | null;
    }
    /**
     * Model metadata specific to AutoML Forecasting.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingMetadata {
        /**
         * BigQuery destination uri for exported evaluated examples.
         */
        evaluatedDataItemsBigqueryUri?: string | null;
        /**
         * Output only. The actual training cost of the model, expressed in milli node hours, i.e. 1,000 value in this field means 1 node hour. Guaranteed to not exceed the train budget.
         */
        trainCostMilliNodeHours?: string | null;
    }
    /**
     * A TrainingJob that trains and uploads an AutoML Image Classification Model.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageClassification {
        /**
         * The input parameters of this TrainingJob.
         */
        inputs?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageClassificationInputs;
        /**
         * The metadata information.
         */
        metadata?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageClassificationMetadata;
    }
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageClassificationInputs {
        /**
         * The ID of the `base` model. If it is specified, the new model will be trained based on the `base` model. Otherwise, the new model will be trained from scratch. The `base` model must be in the same Project and Location as the new Model to train, and have the same modelType.
         */
        baseModelId?: string | null;
        /**
         * The training budget of creating this model, expressed in milli node hours i.e. 1,000 value in this field means 1 node hour. The actual metadata.costMilliNodeHours will be equal or less than this value. If further model training ceases to provide any improvements, it will stop without using the full budget and the metadata.successfulStopReason will be `model-converged`. Note, node_hour = actual_hour * number_of_nodes_involved. For modelType `cloud`(default), the budget must be between 8,000 and 800,000 milli node hours, inclusive. The default value is 192,000 which represents one day in wall time, considering 8 nodes are used. For model types `mobile-tf-low-latency-1`, `mobile-tf-versatile-1`, `mobile-tf-high-accuracy-1`, the training budget must be between 1,000 and 100,000 milli node hours, inclusive. The default value is 24,000 which represents one day in wall time on a single node that is used.
         */
        budgetMilliNodeHours?: string | null;
        /**
         * Use the entire training budget. This disables the early stopping feature. When false the early stopping feature is enabled, which means that AutoML Image Classification might stop training before the entire training budget has been used.
         */
        disableEarlyStopping?: boolean | null;
        modelType?: string | null;
        /**
         * If false, a single-label (multi-class) Model will be trained (i.e. assuming that for each image just up to one annotation may be applicable). If true, a multi-label Model will be trained (i.e. assuming that for each image multiple annotations may be applicable).
         */
        multiLabel?: boolean | null;
        /**
         * Trainer type for Vision TrainRequest.
         */
        tunableParameter?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutomlImageTrainingTunableParameter;
        /**
         * The ID of `base` model for upTraining. If it is specified, the new model will be upTrained based on the `base` model for upTraining. Otherwise, the new model will be trained from scratch. The `base` model for upTraining must be in the same Project and Location as the new Model to train, and have the same modelType.
         */
        uptrainBaseModelId?: string | null;
    }
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageClassificationMetadata {
        /**
         * The actual training cost of creating this model, expressed in milli node hours, i.e. 1,000 value in this field means 1 node hour. Guaranteed to not exceed inputs.budgetMilliNodeHours.
         */
        costMilliNodeHours?: string | null;
        /**
         * For successful job completions, this is the reason why the job has finished.
         */
        successfulStopReason?: string | null;
    }
    /**
     * A TrainingJob that trains and uploads an AutoML Image Object Detection Model.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageObjectDetection {
        /**
         * The input parameters of this TrainingJob.
         */
        inputs?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageObjectDetectionInputs;
        /**
         * The metadata information
         */
        metadata?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageObjectDetectionMetadata;
    }
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageObjectDetectionInputs {
        /**
         * The training budget of creating this model, expressed in milli node hours i.e. 1,000 value in this field means 1 node hour. The actual metadata.costMilliNodeHours will be equal or less than this value. If further model training ceases to provide any improvements, it will stop without using the full budget and the metadata.successfulStopReason will be `model-converged`. Note, node_hour = actual_hour * number_of_nodes_involved. For modelType `cloud`(default), the budget must be between 20,000 and 900,000 milli node hours, inclusive. The default value is 216,000 which represents one day in wall time, considering 9 nodes are used. For model types `mobile-tf-low-latency-1`, `mobile-tf-versatile-1`, `mobile-tf-high-accuracy-1` the training budget must be between 1,000 and 100,000 milli node hours, inclusive. The default value is 24,000 which represents one day in wall time on a single node that is used.
         */
        budgetMilliNodeHours?: string | null;
        /**
         * Use the entire training budget. This disables the early stopping feature. When false the early stopping feature is enabled, which means that AutoML Image Object Detection might stop training before the entire training budget has been used.
         */
        disableEarlyStopping?: boolean | null;
        modelType?: string | null;
        /**
         * Trainer type for Vision TrainRequest.
         */
        tunableParameter?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutomlImageTrainingTunableParameter;
        /**
         * The ID of `base` model for upTraining. If it is specified, the new model will be upTrained based on the `base` model for upTraining. Otherwise, the new model will be trained from scratch. The `base` model for upTraining must be in the same Project and Location as the new Model to train, and have the same modelType.
         */
        uptrainBaseModelId?: string | null;
    }
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageObjectDetectionMetadata {
        /**
         * The actual training cost of creating this model, expressed in milli node hours, i.e. 1,000 value in this field means 1 node hour. Guaranteed to not exceed inputs.budgetMilliNodeHours.
         */
        costMilliNodeHours?: string | null;
        /**
         * For successful job completions, this is the reason why the job has finished.
         */
        successfulStopReason?: string | null;
    }
    /**
     * A TrainingJob that trains and uploads an AutoML Image Segmentation Model.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageSegmentation {
        /**
         * The input parameters of this TrainingJob.
         */
        inputs?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageSegmentationInputs;
        /**
         * The metadata information.
         */
        metadata?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageSegmentationMetadata;
    }
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageSegmentationInputs {
        /**
         * The ID of the `base` model. If it is specified, the new model will be trained based on the `base` model. Otherwise, the new model will be trained from scratch. The `base` model must be in the same Project and Location as the new Model to train, and have the same modelType.
         */
        baseModelId?: string | null;
        /**
         * The training budget of creating this model, expressed in milli node hours i.e. 1,000 value in this field means 1 node hour. The actual metadata.costMilliNodeHours will be equal or less than this value. If further model training ceases to provide any improvements, it will stop without using the full budget and the metadata.successfulStopReason will be `model-converged`. Note, node_hour = actual_hour * number_of_nodes_involved. Or actual_wall_clock_hours = train_budget_milli_node_hours / (number_of_nodes_involved * 1000) For modelType `cloud-high-accuracy-1`(default), the budget must be between 20,000 and 2,000,000 milli node hours, inclusive. The default value is 192,000 which represents one day in wall time (1000 milli * 24 hours * 8 nodes).
         */
        budgetMilliNodeHours?: string | null;
        modelType?: string | null;
    }
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageSegmentationMetadata {
        /**
         * The actual training cost of creating this model, expressed in milli node hours, i.e. 1,000 value in this field means 1 node hour. Guaranteed to not exceed inputs.budgetMilliNodeHours.
         */
        costMilliNodeHours?: string | null;
        /**
         * For successful job completions, this is the reason why the job has finished.
         */
        successfulStopReason?: string | null;
    }
    /**
     * A wrapper class which contains the tunable parameters in an AutoML Image training job.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutomlImageTrainingTunableParameter {
        /**
         * Optional. An unique name of pretrained model checkpoint provided in model garden, it will be mapped to a GCS location internally.
         */
        checkpointName?: string | null;
        /**
         * Customizable dataset settings, used in the `model_garden_trainer`.
         */
        datasetConfig?: {
            [key: string]: string;
        } | null;
        /**
         * Optioinal. StudySpec of hyperparameter tuning job. Required for `model_garden_trainer`.
         */
        studySpec?: Schema$GoogleCloudAiplatformV1StudySpec;
        /**
         * Customizable trainer settings, used in the `model_garden_trainer`.
         */
        trainerConfig?: {
            [key: string]: string;
        } | null;
        trainerType?: string | null;
    }
    /**
     * A TrainingJob that trains and uploads an AutoML Tables Model.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTables {
        /**
         * The input parameters of this TrainingJob.
         */
        inputs?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputs;
        /**
         * The metadata information.
         */
        metadata?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesMetadata;
    }
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputs {
        /**
         * Additional experiment flags for the Tables training pipeline.
         */
        additionalExperiments?: string[] | null;
        /**
         * Use the entire training budget. This disables the early stopping feature. By default, the early stopping feature is enabled, which means that AutoML Tables might stop training before the entire training budget has been used.
         */
        disableEarlyStopping?: boolean | null;
        /**
         * Configuration for exporting test set predictions to a BigQuery table. If this configuration is absent, then the export is not performed.
         */
        exportEvaluatedDataItemsConfig?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionExportEvaluatedDataItemsConfig;
        /**
         * Objective function the model is optimizing towards. The training process creates a model that maximizes/minimizes the value of the objective function over the validation set. The supported optimization objectives depend on the prediction type. If the field is not set, a default objective function is used. classification (binary): "maximize-au-roc" (default) - Maximize the area under the receiver operating characteristic (ROC) curve. "minimize-log-loss" - Minimize log loss. "maximize-au-prc" - Maximize the area under the precision-recall curve. "maximize-precision-at-recall" - Maximize precision for a specified recall value. "maximize-recall-at-precision" - Maximize recall for a specified precision value. classification (multi-class): "minimize-log-loss" (default) - Minimize log loss. regression: "minimize-rmse" (default) - Minimize root-mean-squared error (RMSE). "minimize-mae" - Minimize mean-absolute error (MAE). "minimize-rmsle" - Minimize root-mean-squared log error (RMSLE).
         */
        optimizationObjective?: string | null;
        /**
         * Required when optimization_objective is "maximize-recall-at-precision". Must be between 0 and 1, inclusive.
         */
        optimizationObjectivePrecisionValue?: number | null;
        /**
         * Required when optimization_objective is "maximize-precision-at-recall". Must be between 0 and 1, inclusive.
         */
        optimizationObjectiveRecallValue?: number | null;
        /**
         * The type of prediction the Model is to produce. "classification" - Predict one out of multiple target values is picked for each row. "regression" - Predict a value based on its relation to other values. This type is available only to columns that contain semantically numeric values, i.e. integers or floating point number, even if stored as e.g. strings.
         */
        predictionType?: string | null;
        /**
         * The column name of the target column that the model is to predict.
         */
        targetColumn?: string | null;
        /**
         * Required. The train budget of creating this model, expressed in milli node hours i.e. 1,000 value in this field means 1 node hour. The training cost of the model will not exceed this budget. The final cost will be attempted to be close to the budget, though may end up being (even) noticeably smaller - at the backend's discretion. This especially may happen when further model training ceases to provide any improvements. If the budget is set to a value known to be insufficient to train a model for the given dataset, the training won't be attempted and will error. The train budget must be between 1,000 and 72,000 milli node hours, inclusive.
         */
        trainBudgetMilliNodeHours?: string | null;
        /**
         * Each transformation will apply transform function to given input column. And the result will be used for training. When creating transformation for BigQuery Struct column, the column should be flattened using "." as the delimiter.
         */
        transformations?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformation[];
        /**
         * Column name that should be used as the weight column. Higher values in this column give more importance to the row during model training. The column must have numeric values between 0 and 10000 inclusively; 0 means the row is ignored for training. If weight column field is not set, then all rows are assumed to have equal weight of 1.
         */
        weightColumnName?: string | null;
    }
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformation {
        auto?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationAutoTransformation;
        categorical?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationCategoricalTransformation;
        numeric?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationNumericTransformation;
        repeatedCategorical?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationCategoricalArrayTransformation;
        repeatedNumeric?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationNumericArrayTransformation;
        repeatedText?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationTextArrayTransformation;
        text?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationTextTransformation;
        timestamp?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationTimestampTransformation;
    }
    /**
     * Training pipeline will infer the proper transformation based on the statistic of dataset.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationAutoTransformation {
        columnName?: string | null;
    }
    /**
     * Treats the column as categorical array and performs following transformation functions. * For each element in the array, convert the category name to a dictionary lookup index and generate an embedding for each index. Combine the embedding of all elements into a single embedding using the mean. * Empty arrays treated as an embedding of zeroes.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationCategoricalArrayTransformation {
        columnName?: string | null;
    }
    /**
     * Training pipeline will perform following transformation functions. * The categorical string as is--no change to case, punctuation, spelling, tense, and so on. * Convert the category name to a dictionary lookup index and generate an embedding for each index. * Categories that appear less than 5 times in the training dataset are treated as the "unknown" category. The "unknown" category gets its own special lookup index and resulting embedding.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationCategoricalTransformation {
        columnName?: string | null;
    }
    /**
     * Treats the column as numerical array and performs following transformation functions. * All transformations for Numerical types applied to the average of the all elements. * The average of empty arrays is treated as zero.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationNumericArrayTransformation {
        columnName?: string | null;
        /**
         * If invalid values is allowed, the training pipeline will create a boolean feature that indicated whether the value is valid. Otherwise, the training pipeline will discard the input row from trainining data.
         */
        invalidValuesAllowed?: boolean | null;
    }
    /**
     * Training pipeline will perform following transformation functions. * The value converted to float32. * The z_score of the value. * log(value+1) when the value is greater than or equal to 0. Otherwise, this transformation is not applied and the value is considered a missing value. * z_score of log(value+1) when the value is greater than or equal to 0. Otherwise, this transformation is not applied and the value is considered a missing value. * A boolean value that indicates whether the value is valid.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationNumericTransformation {
        columnName?: string | null;
        /**
         * If invalid values is allowed, the training pipeline will create a boolean feature that indicated whether the value is valid. Otherwise, the training pipeline will discard the input row from trainining data.
         */
        invalidValuesAllowed?: boolean | null;
    }
    /**
     * Treats the column as text array and performs following transformation functions. * Concatenate all text values in the array into a single text value using a space (" ") as a delimiter, and then treat the result as a single text value. Apply the transformations for Text columns. * Empty arrays treated as an empty text.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationTextArrayTransformation {
        columnName?: string | null;
    }
    /**
     * Training pipeline will perform following transformation functions. * The text as is--no change to case, punctuation, spelling, tense, and so on. * Tokenize text to words. Convert each words to a dictionary lookup index and generate an embedding for each index. Combine the embedding of all elements into a single embedding using the mean. * Tokenization is based on unicode script boundaries. * Missing values get their own lookup index and resulting embedding. * Stop-words receive no special treatment and are not removed.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationTextTransformation {
        columnName?: string | null;
    }
    /**
     * Training pipeline will perform following transformation functions. * Apply the transformation functions for Numerical columns. * Determine the year, month, day,and weekday. Treat each value from the * timestamp as a Categorical column. * Invalid numerical values (for example, values that fall outside of a typical timestamp range, or are extreme values) receive no special treatment and are not removed.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationTimestampTransformation {
        columnName?: string | null;
        /**
         * If invalid values is allowed, the training pipeline will create a boolean feature that indicated whether the value is valid. Otherwise, the training pipeline will discard the input row from trainining data.
         */
        invalidValuesAllowed?: boolean | null;
        /**
         * The format in which that time field is expressed. The time_format must either be one of: * `unix-seconds` * `unix-milliseconds` * `unix-microseconds` * `unix-nanoseconds` (for respectively number of seconds, milliseconds, microseconds and nanoseconds since start of the Unix epoch); or be written in `strftime` syntax. If time_format is not set, then the default format is RFC 3339 `date-time` format, where `time-offset` = `"Z"` (e.g. 1985-04-12T23:20:50.52Z)
         */
        timeFormat?: string | null;
    }
    /**
     * Model metadata specific to AutoML Tables.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesMetadata {
        /**
         * BigQuery destination uri for exported evaluated examples.
         */
        evaluatedDataItemsBigqueryUri?: string | null;
        /**
         * Output only. The actual training cost of the model, expressed in milli node hours, i.e. 1,000 value in this field means 1 node hour. Guaranteed to not exceed the train budget.
         */
        trainCostMilliNodeHours?: string | null;
    }
    /**
     * A TrainingJob that trains and uploads an AutoML Text Classification Model.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTextClassification {
        /**
         * The input parameters of this TrainingJob.
         */
        inputs?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTextClassificationInputs;
    }
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTextClassificationInputs {
        multiLabel?: boolean | null;
    }
    /**
     * A TrainingJob that trains and uploads an AutoML Text Extraction Model.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTextExtraction {
        /**
         * The input parameters of this TrainingJob.
         */
        inputs?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTextExtractionInputs;
    }
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTextExtractionInputs {
    }
    /**
     * A TrainingJob that trains and uploads an AutoML Text Sentiment Model.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTextSentiment {
        /**
         * The input parameters of this TrainingJob.
         */
        inputs?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTextSentimentInputs;
    }
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTextSentimentInputs {
        /**
         * A sentiment is expressed as an integer ordinal, where higher value means a more positive sentiment. The range of sentiments that will be used is between 0 and sentimentMax (inclusive on both ends), and all the values in the range must be represented in the dataset before a model can be created. Only the Annotations with this sentimentMax will be used for training. sentimentMax value must be between 1 and 10 (inclusive).
         */
        sentimentMax?: number | null;
    }
    /**
     * A TrainingJob that trains and uploads an AutoML Video Action Recognition Model.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlVideoActionRecognition {
        /**
         * The input parameters of this TrainingJob.
         */
        inputs?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlVideoActionRecognitionInputs;
    }
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlVideoActionRecognitionInputs {
        modelType?: string | null;
    }
    /**
     * A TrainingJob that trains and uploads an AutoML Video Classification Model.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlVideoClassification {
        /**
         * The input parameters of this TrainingJob.
         */
        inputs?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlVideoClassificationInputs;
    }
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlVideoClassificationInputs {
        modelType?: string | null;
    }
    /**
     * A TrainingJob that trains and uploads an AutoML Video ObjectTracking Model.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlVideoObjectTracking {
        /**
         * The input parameters of this TrainingJob.
         */
        inputs?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlVideoObjectTrackingInputs;
    }
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlVideoObjectTrackingInputs {
        modelType?: string | null;
    }
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionCustomJobMetadata {
        /**
         * The resource name of the CustomJob that has been created to carry out this custom task.
         */
        backingCustomJob?: string | null;
    }
    /**
     * A TrainingJob that trains a custom code Model.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionCustomTask {
        /**
         * The input parameters of this CustomTask.
         */
        inputs?: Schema$GoogleCloudAiplatformV1CustomJobSpec;
        /**
         * The metadata information.
         */
        metadata?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionCustomJobMetadata;
    }
    /**
     * Configuration for exporting test set predictions to a BigQuery table.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionExportEvaluatedDataItemsConfig {
        /**
         * URI of desired destination BigQuery table. Expected format: `bq://{project_id\}:{dataset_id\}:{table\}` If not specified, then results are exported to the following auto-created BigQuery table: `{project_id\}:export_evaluated_examples_{model_name\}_{yyyy_MM_dd'T'HH_mm_ss_SSS'Z'\}.evaluated_examples`
         */
        destinationBigqueryUri?: string | null;
        /**
         * If true and an export destination is specified, then the contents of the destination are overwritten. Otherwise, if the export destination already exists, then the export operation fails.
         */
        overrideExistingTable?: boolean | null;
    }
    /**
     * Configuration that defines the hierarchical relationship of time series and parameters for hierarchical forecasting strategies.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHierarchyConfig {
        /**
         * A list of time series attribute column names that define the time series hierarchy. Only one level of hierarchy is supported, ex. 'region' for a hierarchy of stores or 'department' for a hierarchy of products. If multiple columns are specified, time series will be grouped by their combined values, ex. ('blue', 'large') for 'color' and 'size', up to 5 columns are accepted. If no group columns are specified, all time series are considered to be part of the same group.
         */
        groupColumns?: string[] | null;
        /**
         * The weight of the loss for predictions aggregated over both the horizon and time series in the same hierarchy group.
         */
        groupTemporalTotalWeight?: number | null;
        /**
         * The weight of the loss for predictions aggregated over time series in the same group.
         */
        groupTotalWeight?: number | null;
        /**
         * The weight of the loss for predictions aggregated over the horizon for a single time series.
         */
        temporalTotalWeight?: number | null;
    }
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningJobMetadata {
        /**
         * The resource name of the HyperparameterTuningJob that has been created to carry out this HyperparameterTuning task.
         */
        backingHyperparameterTuningJob?: string | null;
        /**
         * The resource name of the CustomJob that has been created to run the best Trial of this HyperparameterTuning task.
         */
        bestTrialBackingCustomJob?: string | null;
    }
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningJobSpec {
        /**
         * The number of failed Trials that need to be seen before failing the HyperparameterTuningJob. If set to 0, Vertex AI decides how many Trials must fail before the whole job fails.
         */
        maxFailedTrialCount?: number | null;
        /**
         * The desired total number of Trials.
         */
        maxTrialCount?: number | null;
        /**
         * The desired number of Trials to run in parallel.
         */
        parallelTrialCount?: number | null;
        /**
         * Study configuration of the HyperparameterTuningJob.
         */
        studySpec?: Schema$GoogleCloudAiplatformV1StudySpec;
        /**
         * The spec of a trial job. The same spec applies to the CustomJobs created in all the trials.
         */
        trialJobSpec?: Schema$GoogleCloudAiplatformV1CustomJobSpec;
    }
    /**
     * A TrainingJob that tunes Hypererparameters of a custom code Model.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningTask {
        /**
         * The input parameters of this HyperparameterTuningTask.
         */
        inputs?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningJobSpec;
        /**
         * The metadata information.
         */
        metadata?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningJobMetadata;
    }
    /**
     * A TrainingJob that trains and uploads an AutoML Forecasting Model.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecasting {
        /**
         * The input parameters of this TrainingJob.
         */
        inputs?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputs;
        /**
         * The metadata information.
         */
        metadata?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingMetadata;
    }
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputs {
        /**
         * Additional experiment flags for the time series forcasting training.
         */
        additionalExperiments?: string[] | null;
        /**
         * Names of columns that are available and provided when a forecast is requested. These columns contain information for the given entity (identified by the time_series_identifier_column column) that is known at forecast. For example, predicted weather for a specific day.
         */
        availableAtForecastColumns?: string[] | null;
        /**
         * The amount of time into the past training and prediction data is used for model training and prediction respectively. Expressed in number of units defined by the `data_granularity` field.
         */
        contextWindow?: string | null;
        /**
         * Expected difference in time granularity between rows in the data.
         */
        dataGranularity?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsGranularity;
        /**
         * Configuration for exporting test set predictions to a BigQuery table. If this configuration is absent, then the export is not performed.
         */
        exportEvaluatedDataItemsConfig?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionExportEvaluatedDataItemsConfig;
        /**
         * The amount of time into the future for which forecasted values for the target are returned. Expressed in number of units defined by the `data_granularity` field.
         */
        forecastHorizon?: string | null;
        /**
         * Configuration that defines the hierarchical relationship of time series and parameters for hierarchical forecasting strategies.
         */
        hierarchyConfig?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHierarchyConfig;
        /**
         * The geographical region based on which the holiday effect is applied in modeling by adding holiday categorical array feature that include all holidays matching the date. This option only allowed when data_granularity is day. By default, holiday effect modeling is disabled. To turn it on, specify the holiday region using this option.
         */
        holidayRegions?: string[] | null;
        /**
         * Objective function the model is optimizing towards. The training process creates a model that optimizes the value of the objective function over the validation set. The supported optimization objectives: * "minimize-rmse" (default) - Minimize root-mean-squared error (RMSE). * "minimize-mae" - Minimize mean-absolute error (MAE). * "minimize-rmsle" - Minimize root-mean-squared log error (RMSLE). * "minimize-rmspe" - Minimize root-mean-squared percentage error (RMSPE). * "minimize-wape-mae" - Minimize the combination of weighted absolute percentage error (WAPE) and mean-absolute-error (MAE). * "minimize-quantile-loss" - Minimize the quantile loss at the quantiles defined in `quantiles`. * "minimize-mape" - Minimize the mean absolute percentage error.
         */
        optimizationObjective?: string | null;
        /**
         * Quantiles to use for minimize-quantile-loss `optimization_objective`. Up to 5 quantiles are allowed of values between 0 and 1, exclusive. Required if the value of optimization_objective is minimize-quantile-loss. Represents the percent quantiles to use for that objective. Quantiles must be unique.
         */
        quantiles?: number[] | null;
        /**
         * The name of the column that the Model is to predict values for. This column must be unavailable at forecast.
         */
        targetColumn?: string | null;
        /**
         * The name of the column that identifies time order in the time series. This column must be available at forecast.
         */
        timeColumn?: string | null;
        /**
         * Column names that should be used as attribute columns. The value of these columns does not vary as a function of time. For example, store ID or item color.
         */
        timeSeriesAttributeColumns?: string[] | null;
        /**
         * The name of the column that identifies the time series.
         */
        timeSeriesIdentifierColumn?: string | null;
        /**
         * Required. The train budget of creating this model, expressed in milli node hours i.e. 1,000 value in this field means 1 node hour. The training cost of the model will not exceed this budget. The final cost will be attempted to be close to the budget, though may end up being (even) noticeably smaller - at the backend's discretion. This especially may happen when further model training ceases to provide any improvements. If the budget is set to a value known to be insufficient to train a model for the given dataset, the training won't be attempted and will error. The train budget must be between 1,000 and 72,000 milli node hours, inclusive.
         */
        trainBudgetMilliNodeHours?: string | null;
        /**
         * Each transformation will apply transform function to given input column. And the result will be used for training. When creating transformation for BigQuery Struct column, the column should be flattened using "." as the delimiter.
         */
        transformations?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformation[];
        /**
         * Names of columns that are unavailable when a forecast is requested. This column contains information for the given entity (identified by the time_series_identifier_column) that is unknown before the forecast For example, actual weather on a given day.
         */
        unavailableAtForecastColumns?: string[] | null;
        /**
         * Validation options for the data validation component. The available options are: * "fail-pipeline" - default, will validate against the validation and fail the pipeline if it fails. * "ignore-validation" - ignore the results of the validation and continue
         */
        validationOptions?: string | null;
        /**
         * Column name that should be used as the weight column. Higher values in this column give more importance to the row during model training. The column must have numeric values between 0 and 10000 inclusively; 0 means the row is ignored for training. If weight column field is not set, then all rows are assumed to have equal weight of 1. This column must be available at forecast.
         */
        weightColumn?: string | null;
        /**
         * Config containing strategy for generating sliding windows.
         */
        windowConfig?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionWindowConfig;
    }
    /**
     * A duration of time expressed in time granularity units.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsGranularity {
        /**
         * The number of granularity_units between data points in the training data. If `granularity_unit` is `minute`, can be 1, 5, 10, 15, or 30. For all other values of `granularity_unit`, must be 1.
         */
        quantity?: string | null;
        /**
         * The time granularity unit of this time period. The supported units are: * "minute" * "hour" * "day" * "week" * "month" * "year"
         */
        unit?: string | null;
    }
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformation {
        auto?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformationAutoTransformation;
        categorical?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformationCategoricalTransformation;
        numeric?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformationNumericTransformation;
        text?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformationTextTransformation;
        timestamp?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformationTimestampTransformation;
    }
    /**
     * Training pipeline will infer the proper transformation based on the statistic of dataset.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformationAutoTransformation {
        columnName?: string | null;
    }
    /**
     * Training pipeline will perform following transformation functions. * The categorical string as is--no change to case, punctuation, spelling, tense, and so on. * Convert the category name to a dictionary lookup index and generate an embedding for each index. * Categories that appear less than 5 times in the training dataset are treated as the "unknown" category. The "unknown" category gets its own special lookup index and resulting embedding.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformationCategoricalTransformation {
        columnName?: string | null;
    }
    /**
     * Training pipeline will perform following transformation functions. * The value converted to float32. * The z_score of the value. * log(value+1) when the value is greater than or equal to 0. Otherwise, this transformation is not applied and the value is considered a missing value. * z_score of log(value+1) when the value is greater than or equal to 0. Otherwise, this transformation is not applied and the value is considered a missing value.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformationNumericTransformation {
        columnName?: string | null;
    }
    /**
     * Training pipeline will perform following transformation functions. * The text as is--no change to case, punctuation, spelling, tense, and so on. * Convert the category name to a dictionary lookup index and generate an embedding for each index.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformationTextTransformation {
        columnName?: string | null;
    }
    /**
     * Training pipeline will perform following transformation functions. * Apply the transformation functions for Numerical columns. * Determine the year, month, day,and weekday. Treat each value from the timestamp as a Categorical column. * Invalid numerical values (for example, values that fall outside of a typical timestamp range, or are extreme values) receive no special treatment and are not removed.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformationTimestampTransformation {
        columnName?: string | null;
        /**
         * The format in which that time field is expressed. The time_format must either be one of: * `unix-seconds` * `unix-milliseconds` * `unix-microseconds` * `unix-nanoseconds` (for respectively number of seconds, milliseconds, microseconds and nanoseconds since start of the Unix epoch); or be written in `strftime` syntax. If time_format is not set, then the default format is RFC 3339 `date-time` format, where `time-offset` = `"Z"` (e.g. 1985-04-12T23:20:50.52Z)
         */
        timeFormat?: string | null;
    }
    /**
     * Model metadata specific to Seq2Seq Plus Forecasting.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingMetadata {
        /**
         * BigQuery destination uri for exported evaluated examples.
         */
        evaluatedDataItemsBigqueryUri?: string | null;
        /**
         * Output only. The actual training cost of the model, expressed in milli node hours, i.e. 1,000 value in this field means 1 node hour. Guaranteed to not exceed the train budget.
         */
        trainCostMilliNodeHours?: string | null;
    }
    /**
     * A TrainingJob that trains and uploads an AutoML Forecasting Model.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecasting {
        /**
         * The input parameters of this TrainingJob.
         */
        inputs?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputs;
        /**
         * The metadata information.
         */
        metadata?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingMetadata;
    }
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputs {
        /**
         * Additional experiment flags for the time series forcasting training.
         */
        additionalExperiments?: string[] | null;
        /**
         * Names of columns that are available and provided when a forecast is requested. These columns contain information for the given entity (identified by the time_series_identifier_column column) that is known at forecast. For example, predicted weather for a specific day.
         */
        availableAtForecastColumns?: string[] | null;
        /**
         * The amount of time into the past training and prediction data is used for model training and prediction respectively. Expressed in number of units defined by the `data_granularity` field.
         */
        contextWindow?: string | null;
        /**
         * Expected difference in time granularity between rows in the data.
         */
        dataGranularity?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputsGranularity;
        /**
         * Configuration for exporting test set predictions to a BigQuery table. If this configuration is absent, then the export is not performed.
         */
        exportEvaluatedDataItemsConfig?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionExportEvaluatedDataItemsConfig;
        /**
         * The amount of time into the future for which forecasted values for the target are returned. Expressed in number of units defined by the `data_granularity` field.
         */
        forecastHorizon?: string | null;
        /**
         * Configuration that defines the hierarchical relationship of time series and parameters for hierarchical forecasting strategies.
         */
        hierarchyConfig?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHierarchyConfig;
        /**
         * The geographical region based on which the holiday effect is applied in modeling by adding holiday categorical array feature that include all holidays matching the date. This option only allowed when data_granularity is day. By default, holiday effect modeling is disabled. To turn it on, specify the holiday region using this option.
         */
        holidayRegions?: string[] | null;
        /**
         * Objective function the model is optimizing towards. The training process creates a model that optimizes the value of the objective function over the validation set. The supported optimization objectives: * "minimize-rmse" (default) - Minimize root-mean-squared error (RMSE). * "minimize-mae" - Minimize mean-absolute error (MAE). * "minimize-rmsle" - Minimize root-mean-squared log error (RMSLE). * "minimize-rmspe" - Minimize root-mean-squared percentage error (RMSPE). * "minimize-wape-mae" - Minimize the combination of weighted absolute percentage error (WAPE) and mean-absolute-error (MAE). * "minimize-quantile-loss" - Minimize the quantile loss at the quantiles defined in `quantiles`. * "minimize-mape" - Minimize the mean absolute percentage error.
         */
        optimizationObjective?: string | null;
        /**
         * Quantiles to use for minimize-quantile-loss `optimization_objective`. Up to 5 quantiles are allowed of values between 0 and 1, exclusive. Required if the value of optimization_objective is minimize-quantile-loss. Represents the percent quantiles to use for that objective. Quantiles must be unique.
         */
        quantiles?: number[] | null;
        /**
         * The name of the column that the Model is to predict values for. This column must be unavailable at forecast.
         */
        targetColumn?: string | null;
        /**
         * The name of the column that identifies time order in the time series. This column must be available at forecast.
         */
        timeColumn?: string | null;
        /**
         * Column names that should be used as attribute columns. The value of these columns does not vary as a function of time. For example, store ID or item color.
         */
        timeSeriesAttributeColumns?: string[] | null;
        /**
         * The name of the column that identifies the time series.
         */
        timeSeriesIdentifierColumn?: string | null;
        /**
         * Required. The train budget of creating this model, expressed in milli node hours i.e. 1,000 value in this field means 1 node hour. The training cost of the model will not exceed this budget. The final cost will be attempted to be close to the budget, though may end up being (even) noticeably smaller - at the backend's discretion. This especially may happen when further model training ceases to provide any improvements. If the budget is set to a value known to be insufficient to train a model for the given dataset, the training won't be attempted and will error. The train budget must be between 1,000 and 72,000 milli node hours, inclusive.
         */
        trainBudgetMilliNodeHours?: string | null;
        /**
         * Each transformation will apply transform function to given input column. And the result will be used for training. When creating transformation for BigQuery Struct column, the column should be flattened using "." as the delimiter.
         */
        transformations?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputsTransformation[];
        /**
         * Names of columns that are unavailable when a forecast is requested. This column contains information for the given entity (identified by the time_series_identifier_column) that is unknown before the forecast For example, actual weather on a given day.
         */
        unavailableAtForecastColumns?: string[] | null;
        /**
         * Validation options for the data validation component. The available options are: * "fail-pipeline" - default, will validate against the validation and fail the pipeline if it fails. * "ignore-validation" - ignore the results of the validation and continue
         */
        validationOptions?: string | null;
        /**
         * Column name that should be used as the weight column. Higher values in this column give more importance to the row during model training. The column must have numeric values between 0 and 10000 inclusively; 0 means the row is ignored for training. If weight column field is not set, then all rows are assumed to have equal weight of 1. This column must be available at forecast.
         */
        weightColumn?: string | null;
        /**
         * Config containing strategy for generating sliding windows.
         */
        windowConfig?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionWindowConfig;
    }
    /**
     * A duration of time expressed in time granularity units.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputsGranularity {
        /**
         * The number of granularity_units between data points in the training data. If `granularity_unit` is `minute`, can be 1, 5, 10, 15, or 30. For all other values of `granularity_unit`, must be 1.
         */
        quantity?: string | null;
        /**
         * The time granularity unit of this time period. The supported units are: * "minute" * "hour" * "day" * "week" * "month" * "year"
         */
        unit?: string | null;
    }
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputsTransformation {
        auto?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputsTransformationAutoTransformation;
        categorical?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputsTransformationCategoricalTransformation;
        numeric?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputsTransformationNumericTransformation;
        text?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputsTransformationTextTransformation;
        timestamp?: Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputsTransformationTimestampTransformation;
    }
    /**
     * Training pipeline will infer the proper transformation based on the statistic of dataset.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputsTransformationAutoTransformation {
        columnName?: string | null;
    }
    /**
     * Training pipeline will perform following transformation functions. * The categorical string as is--no change to case, punctuation, spelling, tense, and so on. * Convert the category name to a dictionary lookup index and generate an embedding for each index. * Categories that appear less than 5 times in the training dataset are treated as the "unknown" category. The "unknown" category gets its own special lookup index and resulting embedding.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputsTransformationCategoricalTransformation {
        columnName?: string | null;
    }
    /**
     * Training pipeline will perform following transformation functions. * The value converted to float32. * The z_score of the value. * log(value+1) when the value is greater than or equal to 0. Otherwise, this transformation is not applied and the value is considered a missing value. * z_score of log(value+1) when the value is greater than or equal to 0. Otherwise, this transformation is not applied and the value is considered a missing value.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputsTransformationNumericTransformation {
        columnName?: string | null;
    }
    /**
     * Training pipeline will perform following transformation functions. * The text as is--no change to case, punctuation, spelling, tense, and so on. * Convert the category name to a dictionary lookup index and generate an embedding for each index.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputsTransformationTextTransformation {
        columnName?: string | null;
    }
    /**
     * Training pipeline will perform following transformation functions. * Apply the transformation functions for Numerical columns. * Determine the year, month, day,and weekday. Treat each value from the timestamp as a Categorical column. * Invalid numerical values (for example, values that fall outside of a typical timestamp range, or are extreme values) receive no special treatment and are not removed.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputsTransformationTimestampTransformation {
        columnName?: string | null;
        /**
         * The format in which that time field is expressed. The time_format must either be one of: * `unix-seconds` * `unix-milliseconds` * `unix-microseconds` * `unix-nanoseconds` (for respectively number of seconds, milliseconds, microseconds and nanoseconds since start of the Unix epoch); or be written in `strftime` syntax. If time_format is not set, then the default format is RFC 3339 `date-time` format, where `time-offset` = `"Z"` (e.g. 1985-04-12T23:20:50.52Z)
         */
        timeFormat?: string | null;
    }
    /**
     * Model metadata specific to TFT Forecasting.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingMetadata {
        /**
         * BigQuery destination uri for exported evaluated examples.
         */
        evaluatedDataItemsBigqueryUri?: string | null;
        /**
         * Output only. The actual training cost of the model, expressed in milli node hours, i.e. 1,000 value in this field means 1 node hour. Guaranteed to not exceed the train budget.
         */
        trainCostMilliNodeHours?: string | null;
    }
    /**
     * Config that contains the strategy used to generate sliding windows in time series training. A window is a series of rows that comprise the context up to the time of prediction, and the horizon following. The corresponding row for each window marks the start of the forecast horizon. Each window is used as an input example for training/evaluation.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaTrainingjobDefinitionWindowConfig {
        /**
         * Name of the column that should be used to generate sliding windows. The column should contain either booleans or string booleans; if the value of the row is True, generate a sliding window with the horizon starting at that row. The column will not be used as a feature in training.
         */
        column?: string | null;
        /**
         * Maximum number of windows that should be generated across all time series.
         */
        maxCount?: string | null;
        /**
         * Stride length used to generate input examples. Within one time series, every {$STRIDE_LENGTH\} rows will be used to generate a sliding window.
         */
        strideLength?: string | null;
    }
    /**
     * A vertex represents a 2D point in the image. NOTE: the normalized vertex coordinates are relative to the original image and range from 0 to 1.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaVertex {
        /**
         * X coordinate.
         */
        x?: number | null;
        /**
         * Y coordinate.
         */
        y?: number | null;
    }
    /**
     * Annotation details specific to video action recognition.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaVideoActionRecognitionAnnotation {
        /**
         * The resource Id of the AnnotationSpec that this Annotation pertains to.
         */
        annotationSpecId?: string | null;
        /**
         * The display name of the AnnotationSpec that this Annotation pertains to.
         */
        displayName?: string | null;
        /**
         * This Annotation applies to the time period represented by the TimeSegment. If it's not set, the Annotation applies to the whole video.
         */
        timeSegment?: Schema$GoogleCloudAiplatformV1SchemaTimeSegment;
    }
    /**
     * Annotation details specific to video classification.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaVideoClassificationAnnotation {
        /**
         * The resource Id of the AnnotationSpec that this Annotation pertains to.
         */
        annotationSpecId?: string | null;
        /**
         * The display name of the AnnotationSpec that this Annotation pertains to.
         */
        displayName?: string | null;
        /**
         * This Annotation applies to the time period represented by the TimeSegment. If it's not set, the Annotation applies to the whole video.
         */
        timeSegment?: Schema$GoogleCloudAiplatformV1SchemaTimeSegment;
    }
    /**
     * Payload of Video DataItem.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaVideoDataItem {
        /**
         * Required. Google Cloud Storage URI points to the original video in user's bucket. The video is up to 50 GB in size and up to 3 hour in duration.
         */
        gcsUri?: string | null;
        /**
         * Output only. The mime type of the content of the video. Only the videos in below listed mime types are supported. Supported mime_type: - video/mp4 - video/avi - video/quicktime
         */
        mimeType?: string | null;
    }
    /**
     * The metadata of Datasets that contain Video DataItems.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaVideoDatasetMetadata {
        /**
         * Points to a YAML file stored on Google Cloud Storage describing payload of the Video DataItems that belong to this Dataset.
         */
        dataItemSchemaUri?: string | null;
        /**
         * Google Cloud Storage Bucket name that contains the blob data of this Dataset.
         */
        gcsBucket?: string | null;
    }
    /**
     * Annotation details specific to video object tracking.
     */
    export interface Schema$GoogleCloudAiplatformV1SchemaVideoObjectTrackingAnnotation {
        /**
         * The resource Id of the AnnotationSpec that this Annotation pertains to.
         */
        annotationSpecId?: string | null;
        /**
         * The display name of the AnnotationSpec that this Annotation pertains to.
         */
        displayName?: string | null;
        /**
         * The instance of the object, expressed as a positive integer. Used to track the same object across different frames.
         */
        instanceId?: string | null;
        /**
         * A time (frame) of a video to which this annotation pertains. Represented as the duration since the video's start.
         */
        timeOffset?: string | null;
        /**
         * The rightmost coordinate of the bounding box.
         */
        xMax?: number | null;
        /**
         * The leftmost coordinate of the bounding box.
         */
        xMin?: number | null;
        /**
         * The bottommost coordinate of the bounding box.
         */
        yMax?: number | null;
        /**
         * The topmost coordinate of the bounding box.
         */
        yMin?: number | null;
    }
    export interface Schema$GoogleCloudAiplatformV1SchemaVisualInspectionClassificationLabelSavedQueryMetadata {
        /**
         * Whether or not the classification label is multi_label.
         */
        multiLabel?: boolean | null;
    }
    export interface Schema$GoogleCloudAiplatformV1SchemaVisualInspectionMaskSavedQueryMetadata {
    }
    /**
     * Response message for DatasetService.SearchDataItems.
     */
    export interface Schema$GoogleCloudAiplatformV1SearchDataItemsResponse {
        /**
         * The DataItemViews read.
         */
        dataItemViews?: Schema$GoogleCloudAiplatformV1DataItemView[];
        /**
         * A token to retrieve next page of results. Pass to SearchDataItemsRequest.page_token to obtain that page.
         */
        nextPageToken?: string | null;
    }
    /**
     * Response message for FeaturestoreService.SearchFeatures.
     */
    export interface Schema$GoogleCloudAiplatformV1SearchFeaturesResponse {
        /**
         * The Features matching the request. Fields returned: * `name` * `description` * `labels` * `create_time` * `update_time`
         */
        features?: Schema$GoogleCloudAiplatformV1Feature[];
        /**
         * A token, which can be sent as SearchFeaturesRequest.page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.
         */
        nextPageToken?: string | null;
    }
    /**
     * Request message for MigrationService.SearchMigratableResources.
     */
    export interface Schema$GoogleCloudAiplatformV1SearchMigratableResourcesRequest {
        /**
         * A filter for your search. You can use the following types of filters: * Resource type filters. The following strings filter for a specific type of MigratableResource: * `ml_engine_model_version:*` * `automl_model:*` * `automl_dataset:*` * `data_labeling_dataset:*` * "Migrated or not" filters. The following strings filter for resources that either have or have not already been migrated: * `last_migrate_time:*` filters for migrated resources. * `NOT last_migrate_time:*` filters for not yet migrated resources.
         */
        filter?: string | null;
        /**
         * The standard page size. The default and maximum value is 100.
         */
        pageSize?: number | null;
        /**
         * The standard page token.
         */
        pageToken?: string | null;
    }
    /**
     * Response message for MigrationService.SearchMigratableResources.
     */
    export interface Schema$GoogleCloudAiplatformV1SearchMigratableResourcesResponse {
        /**
         * All migratable resources that can be migrated to the location specified in the request.
         */
        migratableResources?: Schema$GoogleCloudAiplatformV1MigratableResource[];
        /**
         * The standard next-page token. The migratable_resources may not fill page_size in SearchMigratableResourcesRequest even when there are subsequent pages.
         */
        nextPageToken?: string | null;
    }
    /**
     * Request message for JobService.SearchModelDeploymentMonitoringStatsAnomalies.
     */
    export interface Schema$GoogleCloudAiplatformV1SearchModelDeploymentMonitoringStatsAnomaliesRequest {
        /**
         * Required. The DeployedModel ID of the [ModelDeploymentMonitoringObjectiveConfig.deployed_model_id].
         */
        deployedModelId?: string | null;
        /**
         * The latest timestamp of stats being generated. If not set, indicates feching stats till the latest possible one.
         */
        endTime?: string | null;
        /**
         * The feature display name. If specified, only return the stats belonging to this feature. Format: ModelMonitoringStatsAnomalies.FeatureHistoricStatsAnomalies.feature_display_name, example: "user_destination".
         */
        featureDisplayName?: string | null;
        /**
         * Required. Objectives of the stats to retrieve.
         */
        objectives?: Schema$GoogleCloudAiplatformV1SearchModelDeploymentMonitoringStatsAnomaliesRequestStatsAnomaliesObjective[];
        /**
         * The standard list page size.
         */
        pageSize?: number | null;
        /**
         * A page token received from a previous JobService.SearchModelDeploymentMonitoringStatsAnomalies call.
         */
        pageToken?: string | null;
        /**
         * The earliest timestamp of stats being generated. If not set, indicates fetching stats till the earliest possible one.
         */
        startTime?: string | null;
    }
    /**
     * Stats requested for specific objective.
     */
    export interface Schema$GoogleCloudAiplatformV1SearchModelDeploymentMonitoringStatsAnomaliesRequestStatsAnomaliesObjective {
        /**
         * If set, all attribution scores between SearchModelDeploymentMonitoringStatsAnomaliesRequest.start_time and SearchModelDeploymentMonitoringStatsAnomaliesRequest.end_time are fetched, and page token doesn't take effect in this case. Only used to retrieve attribution score for the top Features which has the highest attribution score in the latest monitoring run.
         */
        topFeatureCount?: number | null;
        type?: string | null;
    }
    /**
     * Response message for JobService.SearchModelDeploymentMonitoringStatsAnomalies.
     */
    export interface Schema$GoogleCloudAiplatformV1SearchModelDeploymentMonitoringStatsAnomaliesResponse {
        /**
         * Stats retrieved for requested objectives. There are at most 1000 ModelMonitoringStatsAnomalies.FeatureHistoricStatsAnomalies.prediction_stats in the response.
         */
        monitoringStats?: Schema$GoogleCloudAiplatformV1ModelMonitoringStatsAnomalies[];
        /**
         * The page token that can be used by the next JobService.SearchModelDeploymentMonitoringStatsAnomalies call.
         */
        nextPageToken?: string | null;
    }
    /**
     * Config for SmoothGrad approximation of gradients. When enabled, the gradients are approximated by averaging the gradients from noisy samples in the vicinity of the inputs. Adding noise can help improve the computed gradients. Refer to this paper for more details: https://arxiv.org/pdf/1706.03825.pdf
     */
    export interface Schema$GoogleCloudAiplatformV1SmoothGradConfig {
        /**
         * This is similar to noise_sigma, but provides additional flexibility. A separate noise sigma can be provided for each feature, which is useful if their distributions are different. No noise is added to features that are not set. If this field is unset, noise_sigma will be used for all features.
         */
        featureNoiseSigma?: Schema$GoogleCloudAiplatformV1FeatureNoiseSigma;
        /**
         * This is a single float value and will be used to add noise to all the features. Use this field when all features are normalized to have the same distribution: scale to range [0, 1], [-1, 1] or z-scoring, where features are normalized to have 0-mean and 1-variance. Learn more about [normalization](https://developers.google.com/machine-learning/data-prep/transform/normalization). For best results the recommended value is about 10% - 20% of the standard deviation of the input feature. Refer to section 3.2 of the SmoothGrad paper: https://arxiv.org/pdf/1706.03825.pdf. Defaults to 0.1. If the distribution is different per feature, set feature_noise_sigma instead for each feature.
         */
        noiseSigma?: number | null;
        /**
         * The number of gradient samples to use for approximation. The higher this number, the more accurate the gradient is, but the runtime complexity increases by this factor as well. Valid range of its value is [1, 50]. Defaults to 3.
         */
        noisySampleCount?: number | null;
    }
    /**
     * SpecialistPool represents customers' own workforce to work on their data labeling jobs. It includes a group of specialist managers and workers. Managers are responsible for managing the workers in this pool as well as customers' data labeling jobs associated with this pool. Customers create specialist pool as well as start data labeling jobs on Cloud, managers and workers handle the jobs using CrowdCompute console.
     */
    export interface Schema$GoogleCloudAiplatformV1SpecialistPool {
        /**
         * Required. The user-defined name of the SpecialistPool. The name can be up to 128 characters long and can consist of any UTF-8 characters. This field should be unique on project-level.
         */
        displayName?: string | null;
        /**
         * Required. The resource name of the SpecialistPool.
         */
        name?: string | null;
        /**
         * Output only. The resource name of the pending data labeling jobs.
         */
        pendingDataLabelingJobs?: string[] | null;
        /**
         * The email addresses of the managers in the SpecialistPool.
         */
        specialistManagerEmails?: string[] | null;
        /**
         * Output only. The number of managers in this SpecialistPool.
         */
        specialistManagersCount?: number | null;
        /**
         * The email addresses of workers in the SpecialistPool.
         */
        specialistWorkerEmails?: string[] | null;
    }
    /**
     * Metadata information for NotebookService.StartNotebookRuntime.
     */
    export interface Schema$GoogleCloudAiplatformV1StartNotebookRuntimeOperationMetadata {
        /**
         * The operation generic information.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
        /**
         * A human-readable message that shows the intermediate progress details of NotebookRuntime.
         */
        progressMessage?: string | null;
    }
    /**
     * Request message for NotebookService.StartNotebookRuntime.
     */
    export interface Schema$GoogleCloudAiplatformV1StartNotebookRuntimeRequest {
    }
    /**
     * Request message for VizierService.StopTrial.
     */
    export interface Schema$GoogleCloudAiplatformV1StopTrialRequest {
    }
    /**
     * Assigns input data to the training, validation, and test sets so that the distribution of values found in the categorical column (as specified by the `key` field) is mirrored within each split. The fraction values determine the relative sizes of the splits. For example, if the specified column has three values, with 50% of the rows having value "A", 25% value "B", and 25% value "C", and the split fractions are specified as 80/10/10, then the training set will constitute 80% of the training data, with about 50% of the training set rows having the value "A" for the specified column, about 25% having the value "B", and about 25% having the value "C". Only the top 500 occurring values are used; any values not in the top 500 values are randomly assigned to a split. If less than three rows contain a specific value, those rows are randomly assigned. Supported only for tabular Datasets.
     */
    export interface Schema$GoogleCloudAiplatformV1StratifiedSplit {
        /**
         * Required. The key is a name of one of the Dataset's data columns. The key provided must be for a categorical column.
         */
        key?: string | null;
        /**
         * The fraction of the input data that is to be used to evaluate the Model.
         */
        testFraction?: number | null;
        /**
         * The fraction of the input data that is to be used to train the Model.
         */
        trainingFraction?: number | null;
        /**
         * The fraction of the input data that is to be used to validate the Model.
         */
        validationFraction?: number | null;
    }
    /**
     * Request message for PredictionService.StreamingPredict. The first message must contain endpoint field and optionally input. The subsequent messages must contain input.
     */
    export interface Schema$GoogleCloudAiplatformV1StreamingPredictRequest {
        /**
         * The prediction input.
         */
        inputs?: Schema$GoogleCloudAiplatformV1Tensor[];
        /**
         * The parameters that govern the prediction.
         */
        parameters?: Schema$GoogleCloudAiplatformV1Tensor;
    }
    /**
     * Response message for PredictionService.StreamingPredict.
     */
    export interface Schema$GoogleCloudAiplatformV1StreamingPredictResponse {
        /**
         * The prediction output.
         */
        outputs?: Schema$GoogleCloudAiplatformV1Tensor[];
        /**
         * The parameters that govern the prediction.
         */
        parameters?: Schema$GoogleCloudAiplatformV1Tensor;
    }
    /**
     * Request message for FeaturestoreOnlineServingService.StreamingFeatureValuesRead.
     */
    export interface Schema$GoogleCloudAiplatformV1StreamingReadFeatureValuesRequest {
        /**
         * Required. IDs of entities to read Feature values of. The maximum number of IDs is 100. For example, for a machine learning model predicting user clicks on a website, an entity ID could be `user_123`.
         */
        entityIds?: string[] | null;
        /**
         * Required. Selector choosing Features of the target EntityType. Feature IDs will be deduplicated.
         */
        featureSelector?: Schema$GoogleCloudAiplatformV1FeatureSelector;
    }
    /**
     * A list of string values.
     */
    export interface Schema$GoogleCloudAiplatformV1StringArray {
        /**
         * A list of string values.
         */
        values?: string[] | null;
    }
    /**
     * A message representing a Study.
     */
    export interface Schema$GoogleCloudAiplatformV1Study {
        /**
         * Output only. Time at which the study was created.
         */
        createTime?: string | null;
        /**
         * Required. Describes the Study, default value is empty string.
         */
        displayName?: string | null;
        /**
         * Output only. A human readable reason why the Study is inactive. This should be empty if a study is ACTIVE or COMPLETED.
         */
        inactiveReason?: string | null;
        /**
         * Output only. The name of a study. The study's globally unique identifier. Format: `projects/{project\}/locations/{location\}/studies/{study\}`
         */
        name?: string | null;
        /**
         * Output only. The detailed state of a Study.
         */
        state?: string | null;
        /**
         * Required. Configuration of the Study.
         */
        studySpec?: Schema$GoogleCloudAiplatformV1StudySpec;
    }
    /**
     * Represents specification of a Study.
     */
    export interface Schema$GoogleCloudAiplatformV1StudySpec {
        /**
         * The search algorithm specified for the Study.
         */
        algorithm?: string | null;
        /**
         * The automated early stopping spec using convex stopping rule.
         */
        convexAutomatedStoppingSpec?: Schema$GoogleCloudAiplatformV1StudySpecConvexAutomatedStoppingSpec;
        /**
         * The automated early stopping spec using decay curve rule.
         */
        decayCurveStoppingSpec?: Schema$GoogleCloudAiplatformV1StudySpecDecayCurveAutomatedStoppingSpec;
        /**
         * Describe which measurement selection type will be used
         */
        measurementSelectionType?: string | null;
        /**
         * The automated early stopping spec using median rule.
         */
        medianAutomatedStoppingSpec?: Schema$GoogleCloudAiplatformV1StudySpecMedianAutomatedStoppingSpec;
        /**
         * Required. Metric specs for the Study.
         */
        metrics?: Schema$GoogleCloudAiplatformV1StudySpecMetricSpec[];
        /**
         * The observation noise level of the study. Currently only supported by the Vertex AI Vizier service. Not supported by HyperparameterTuningJob or TrainingPipeline.
         */
        observationNoise?: string | null;
        /**
         * Required. The set of parameters to tune.
         */
        parameters?: Schema$GoogleCloudAiplatformV1StudySpecParameterSpec[];
    }
    /**
     * Configuration for ConvexAutomatedStoppingSpec. When there are enough completed trials (configured by min_measurement_count), for pending trials with enough measurements and steps, the policy first computes an overestimate of the objective value at max_num_steps according to the slope of the incomplete objective value curve. No prediction can be made if the curve is completely flat. If the overestimation is worse than the best objective value of the completed trials, this pending trial will be early-stopped, but a last measurement will be added to the pending trial with max_num_steps and predicted objective value from the autoregression model.
     */
    export interface Schema$GoogleCloudAiplatformV1StudySpecConvexAutomatedStoppingSpec {
        /**
         * The hyper-parameter name used in the tuning job that stands for learning rate. Leave it blank if learning rate is not in a parameter in tuning. The learning_rate is used to estimate the objective value of the ongoing trial.
         */
        learningRateParameterName?: string | null;
        /**
         * Steps used in predicting the final objective for early stopped trials. In general, it's set to be the same as the defined steps in training / tuning. If not defined, it will learn it from the completed trials. When use_steps is false, this field is set to the maximum elapsed seconds.
         */
        maxStepCount?: string | null;
        /**
         * The minimal number of measurements in a Trial. Early-stopping checks will not trigger if less than min_measurement_count+1 completed trials or pending trials with less than min_measurement_count measurements. If not defined, the default value is 5.
         */
        minMeasurementCount?: string | null;
        /**
         * Minimum number of steps for a trial to complete. Trials which do not have a measurement with step_count \> min_step_count won't be considered for early stopping. It's ok to set it to 0, and a trial can be early stopped at any stage. By default, min_step_count is set to be one-tenth of the max_step_count. When use_elapsed_duration is true, this field is set to the minimum elapsed seconds.
         */
        minStepCount?: string | null;
        /**
         * ConvexAutomatedStoppingSpec by default only updates the trials that needs to be early stopped using a newly trained auto-regressive model. When this flag is set to True, all stopped trials from the beginning are potentially updated in terms of their `final_measurement`. Also, note that the training logic of autoregressive models is different in this case. Enabling this option has shown better results and this may be the default option in the future.
         */
        updateAllStoppedTrials?: boolean | null;
        /**
         * This bool determines whether or not the rule is applied based on elapsed_secs or steps. If use_elapsed_duration==false, the early stopping decision is made according to the predicted objective values according to the target steps. If use_elapsed_duration==true, elapsed_secs is used instead of steps. Also, in this case, the parameters max_num_steps and min_num_steps are overloaded to contain max_elapsed_seconds and min_elapsed_seconds.
         */
        useElapsedDuration?: boolean | null;
    }
    /**
     * The decay curve automated stopping rule builds a Gaussian Process Regressor to predict the final objective value of a Trial based on the already completed Trials and the intermediate measurements of the current Trial. Early stopping is requested for the current Trial if there is very low probability to exceed the optimal value found so far.
     */
    export interface Schema$GoogleCloudAiplatformV1StudySpecDecayCurveAutomatedStoppingSpec {
        /**
         * True if Measurement.elapsed_duration is used as the x-axis of each Trials Decay Curve. Otherwise, Measurement.step_count will be used as the x-axis.
         */
        useElapsedDuration?: boolean | null;
    }
    /**
     * The median automated stopping rule stops a pending Trial if the Trial's best objective_value is strictly below the median 'performance' of all completed Trials reported up to the Trial's last measurement. Currently, 'performance' refers to the running average of the objective values reported by the Trial in each measurement.
     */
    export interface Schema$GoogleCloudAiplatformV1StudySpecMedianAutomatedStoppingSpec {
        /**
         * True if median automated stopping rule applies on Measurement.elapsed_duration. It means that elapsed_duration field of latest measurement of current Trial is used to compute median objective value for each completed Trials.
         */
        useElapsedDuration?: boolean | null;
    }
    /**
     * Represents a metric to optimize.
     */
    export interface Schema$GoogleCloudAiplatformV1StudySpecMetricSpec {
        /**
         * Required. The optimization goal of the metric.
         */
        goal?: string | null;
        /**
         * Required. The ID of the metric. Must not contain whitespaces and must be unique amongst all MetricSpecs.
         */
        metricId?: string | null;
        /**
         * Used for safe search. In the case, the metric will be a safety metric. You must provide a separate metric for objective metric.
         */
        safetyConfig?: Schema$GoogleCloudAiplatformV1StudySpecMetricSpecSafetyMetricConfig;
    }
    /**
     * Used in safe optimization to specify threshold levels and risk tolerance.
     */
    export interface Schema$GoogleCloudAiplatformV1StudySpecMetricSpecSafetyMetricConfig {
        /**
         * Desired minimum fraction of safe trials (over total number of trials) that should be targeted by the algorithm at any time during the study (best effort). This should be between 0.0 and 1.0 and a value of 0.0 means that there is no minimum and an algorithm proceeds without targeting any specific fraction. A value of 1.0 means that the algorithm attempts to only Suggest safe Trials.
         */
        desiredMinSafeTrialsFraction?: number | null;
        /**
         * Safety threshold (boundary value between safe and unsafe). NOTE that if you leave SafetyMetricConfig unset, a default value of 0 will be used.
         */
        safetyThreshold?: number | null;
    }
    /**
     * Represents a single parameter to optimize.
     */
    export interface Schema$GoogleCloudAiplatformV1StudySpecParameterSpec {
        /**
         * The value spec for a 'CATEGORICAL' parameter.
         */
        categoricalValueSpec?: Schema$GoogleCloudAiplatformV1StudySpecParameterSpecCategoricalValueSpec;
        /**
         * A conditional parameter node is active if the parameter's value matches the conditional node's parent_value_condition. If two items in conditional_parameter_specs have the same name, they must have disjoint parent_value_condition.
         */
        conditionalParameterSpecs?: Schema$GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpec[];
        /**
         * The value spec for a 'DISCRETE' parameter.
         */
        discreteValueSpec?: Schema$GoogleCloudAiplatformV1StudySpecParameterSpecDiscreteValueSpec;
        /**
         * The value spec for a 'DOUBLE' parameter.
         */
        doubleValueSpec?: Schema$GoogleCloudAiplatformV1StudySpecParameterSpecDoubleValueSpec;
        /**
         * The value spec for an 'INTEGER' parameter.
         */
        integerValueSpec?: Schema$GoogleCloudAiplatformV1StudySpecParameterSpecIntegerValueSpec;
        /**
         * Required. The ID of the parameter. Must not contain whitespaces and must be unique amongst all ParameterSpecs.
         */
        parameterId?: string | null;
        /**
         * How the parameter should be scaled. Leave unset for `CATEGORICAL` parameters.
         */
        scaleType?: string | null;
    }
    /**
     * Value specification for a parameter in `CATEGORICAL` type.
     */
    export interface Schema$GoogleCloudAiplatformV1StudySpecParameterSpecCategoricalValueSpec {
        /**
         * A default value for a `CATEGORICAL` parameter that is assumed to be a relatively good starting point. Unset value signals that there is no offered starting point. Currently only supported by the Vertex AI Vizier service. Not supported by HyperparameterTuningJob or TrainingPipeline.
         */
        defaultValue?: string | null;
        /**
         * Required. The list of possible categories.
         */
        values?: string[] | null;
    }
    /**
     * Represents a parameter spec with condition from its parent parameter.
     */
    export interface Schema$GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpec {
        /**
         * Required. The spec for a conditional parameter.
         */
        parameterSpec?: Schema$GoogleCloudAiplatformV1StudySpecParameterSpec;
        /**
         * The spec for matching values from a parent parameter of `CATEGORICAL` type.
         */
        parentCategoricalValues?: Schema$GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpecCategoricalValueCondition;
        /**
         * The spec for matching values from a parent parameter of `DISCRETE` type.
         */
        parentDiscreteValues?: Schema$GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpecDiscreteValueCondition;
        /**
         * The spec for matching values from a parent parameter of `INTEGER` type.
         */
        parentIntValues?: Schema$GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpecIntValueCondition;
    }
    /**
     * Represents the spec to match categorical values from parent parameter.
     */
    export interface Schema$GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpecCategoricalValueCondition {
        /**
         * Required. Matches values of the parent parameter of 'CATEGORICAL' type. All values must exist in `categorical_value_spec` of parent parameter.
         */
        values?: string[] | null;
    }
    /**
     * Represents the spec to match discrete values from parent parameter.
     */
    export interface Schema$GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpecDiscreteValueCondition {
        /**
         * Required. Matches values of the parent parameter of 'DISCRETE' type. All values must exist in `discrete_value_spec` of parent parameter. The Epsilon of the value matching is 1e-10.
         */
        values?: number[] | null;
    }
    /**
     * Represents the spec to match integer values from parent parameter.
     */
    export interface Schema$GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpecIntValueCondition {
        /**
         * Required. Matches values of the parent parameter of 'INTEGER' type. All values must lie in `integer_value_spec` of parent parameter.
         */
        values?: string[] | null;
    }
    /**
     * Value specification for a parameter in `DISCRETE` type.
     */
    export interface Schema$GoogleCloudAiplatformV1StudySpecParameterSpecDiscreteValueSpec {
        /**
         * A default value for a `DISCRETE` parameter that is assumed to be a relatively good starting point. Unset value signals that there is no offered starting point. It automatically rounds to the nearest feasible discrete point. Currently only supported by the Vertex AI Vizier service. Not supported by HyperparameterTuningJob or TrainingPipeline.
         */
        defaultValue?: number | null;
        /**
         * Required. A list of possible values. The list should be in increasing order and at least 1e-10 apart. For instance, this parameter might have possible settings of 1.5, 2.5, and 4.0. This list should not contain more than 1,000 values.
         */
        values?: number[] | null;
    }
    /**
     * Value specification for a parameter in `DOUBLE` type.
     */
    export interface Schema$GoogleCloudAiplatformV1StudySpecParameterSpecDoubleValueSpec {
        /**
         * A default value for a `DOUBLE` parameter that is assumed to be a relatively good starting point. Unset value signals that there is no offered starting point. Currently only supported by the Vertex AI Vizier service. Not supported by HyperparameterTuningJob or TrainingPipeline.
         */
        defaultValue?: number | null;
        /**
         * Required. Inclusive maximum value of the parameter.
         */
        maxValue?: number | null;
        /**
         * Required. Inclusive minimum value of the parameter.
         */
        minValue?: number | null;
    }
    /**
     * Value specification for a parameter in `INTEGER` type.
     */
    export interface Schema$GoogleCloudAiplatformV1StudySpecParameterSpecIntegerValueSpec {
        /**
         * A default value for an `INTEGER` parameter that is assumed to be a relatively good starting point. Unset value signals that there is no offered starting point. Currently only supported by the Vertex AI Vizier service. Not supported by HyperparameterTuningJob or TrainingPipeline.
         */
        defaultValue?: string | null;
        /**
         * Required. Inclusive maximum value of the parameter.
         */
        maxValue?: string | null;
        /**
         * Required. Inclusive minimum value of the parameter.
         */
        minValue?: string | null;
    }
    /**
     * Details of operations that perform Trials suggestion.
     */
    export interface Schema$GoogleCloudAiplatformV1SuggestTrialsMetadata {
        /**
         * The identifier of the client that is requesting the suggestion. If multiple SuggestTrialsRequests have the same `client_id`, the service will return the identical suggested Trial if the Trial is pending, and provide a new Trial if the last suggested Trial was completed.
         */
        clientId?: string | null;
        /**
         * Operation metadata for suggesting Trials.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
    }
    /**
     * Request message for VizierService.SuggestTrials.
     */
    export interface Schema$GoogleCloudAiplatformV1SuggestTrialsRequest {
        /**
         * Required. The identifier of the client that is requesting the suggestion. If multiple SuggestTrialsRequests have the same `client_id`, the service will return the identical suggested Trial if the Trial is pending, and provide a new Trial if the last suggested Trial was completed.
         */
        clientId?: string | null;
        /**
         * Optional. This allows you to specify the "context" for a Trial; a context is a slice (a subspace) of the search space. Typical uses for contexts: 1) You are using Vizier to tune a server for best performance, but there's a strong weekly cycle. The context specifies the day-of-week. This allows Tuesday to generalize from Wednesday without assuming that everything is identical. 2) Imagine you're optimizing some medical treatment for people. As they walk in the door, you know certain facts about them (e.g. sex, weight, height, blood-pressure). Put that information in the context, and Vizier will adapt its suggestions to the patient. 3) You want to do a fair A/B test efficiently. Specify the "A" and "B" conditions as contexts, and Vizier will generalize between "A" and "B" conditions. If they are similar, this will allow Vizier to converge to the optimum faster than if "A" and "B" were separate Studies. NOTE: You can also enter contexts as REQUESTED Trials, e.g. via the CreateTrial() RPC; that's the asynchronous option where you don't need a close association between contexts and suggestions. NOTE: All the Parameters you set in a context MUST be defined in the Study. NOTE: You must supply 0 or $suggestion_count contexts. If you don't supply any contexts, Vizier will make suggestions from the full search space specified in the StudySpec; if you supply a full set of context, each suggestion will match the corresponding context. NOTE: A Context with no features set matches anything, and allows suggestions from the full search space. NOTE: Contexts MUST lie within the search space specified in the StudySpec. It's an error if they don't. NOTE: Contexts preferentially match ACTIVE then REQUESTED trials before new suggestions are generated. NOTE: Generation of suggestions involves a match between a Context and (optionally) a REQUESTED trial; if that match is not fully specified, a suggestion will be geneated in the merged subspace.
         */
        contexts?: Schema$GoogleCloudAiplatformV1TrialContext[];
        /**
         * Required. The number of suggestions requested. It must be positive.
         */
        suggestionCount?: number | null;
    }
    /**
     * Response message for VizierService.SuggestTrials.
     */
    export interface Schema$GoogleCloudAiplatformV1SuggestTrialsResponse {
        /**
         * The time at which operation processing completed.
         */
        endTime?: string | null;
        /**
         * The time at which the operation was started.
         */
        startTime?: string | null;
        /**
         * The state of the Study.
         */
        studyState?: string | null;
        /**
         * A list of Trials.
         */
        trials?: Schema$GoogleCloudAiplatformV1Trial[];
    }
    /**
     * A tensor value type.
     */
    export interface Schema$GoogleCloudAiplatformV1Tensor {
        /**
         * Type specific representations that make it easy to create tensor protos in all languages. Only the representation corresponding to "dtype" can be set. The values hold the flattened representation of the tensor in row major order. BOOL
         */
        boolVal?: boolean[] | null;
        /**
         * STRING
         */
        bytesVal?: string[] | null;
        /**
         * DOUBLE
         */
        doubleVal?: number[] | null;
        /**
         * The data type of tensor.
         */
        dtype?: string | null;
        /**
         * FLOAT
         */
        floatVal?: number[] | null;
        /**
         * INT64
         */
        int64Val?: string[] | null;
        /**
         * INT_8 INT_16 INT_32
         */
        intVal?: number[] | null;
        /**
         * A list of tensor values.
         */
        listVal?: Schema$GoogleCloudAiplatformV1Tensor[];
        /**
         * Shape of the tensor.
         */
        shape?: string[] | null;
        /**
         * STRING
         */
        stringVal?: string[] | null;
        /**
         * A map of string to tensor.
         */
        structVal?: {
            [key: string]: Schema$GoogleCloudAiplatformV1Tensor;
        } | null;
        /**
         * Serialized raw tensor content.
         */
        tensorVal?: string | null;
        /**
         * UINT64
         */
        uint64Val?: string[] | null;
        /**
         * UINT8 UINT16 UINT32
         */
        uintVal?: number[] | null;
    }
    /**
     * Tensorboard is a physical database that stores users' training metrics. A default Tensorboard is provided in each region of a Google Cloud project. If needed users can also create extra Tensorboards in their projects.
     */
    export interface Schema$GoogleCloudAiplatformV1Tensorboard {
        /**
         * Output only. Consumer project Cloud Storage path prefix used to store blob data, which can either be a bucket or directory. Does not end with a '/'.
         */
        blobStoragePathPrefix?: string | null;
        /**
         * Output only. Timestamp when this Tensorboard was created.
         */
        createTime?: string | null;
        /**
         * Description of this Tensorboard.
         */
        description?: string | null;
        /**
         * Required. User provided name of this Tensorboard.
         */
        displayName?: string | null;
        /**
         * Customer-managed encryption key spec for a Tensorboard. If set, this Tensorboard and all sub-resources of this Tensorboard will be secured by this key.
         */
        encryptionSpec?: Schema$GoogleCloudAiplatformV1EncryptionSpec;
        /**
         * Used to perform a consistent read-modify-write updates. If not set, a blind "overwrite" update happens.
         */
        etag?: string | null;
        /**
         * Used to indicate if the TensorBoard instance is the default one. Each project & region can have at most one default TensorBoard instance. Creation of a default TensorBoard instance and updating an existing TensorBoard instance to be default will mark all other TensorBoard instances (if any) as non default.
         */
        isDefault?: boolean | null;
        /**
         * The labels with user-defined metadata to organize your Tensorboards. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. No more than 64 user labels can be associated with one Tensorboard (System labels are excluded). See https://goo.gl/xmQnxf for more information and examples of labels. System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * Output only. Name of the Tensorboard. Format: `projects/{project\}/locations/{location\}/tensorboards/{tensorboard\}`
         */
        name?: string | null;
        /**
         * Output only. The number of Runs stored in this Tensorboard.
         */
        runCount?: number | null;
        /**
         * Output only. Timestamp when this Tensorboard was last updated.
         */
        updateTime?: string | null;
    }
    /**
     * One blob (e.g, image, graph) viewable on a blob metric plot.
     */
    export interface Schema$GoogleCloudAiplatformV1TensorboardBlob {
        /**
         * Optional. The bytes of the blob is not present unless it's returned by the ReadTensorboardBlobData endpoint.
         */
        data?: string | null;
        /**
         * Output only. A URI safe key uniquely identifying a blob. Can be used to locate the blob stored in the Cloud Storage bucket of the consumer project.
         */
        id?: string | null;
    }
    /**
     * One point viewable on a blob metric plot, but mostly just a wrapper message to work around repeated fields can't be used directly within `oneof` fields.
     */
    export interface Schema$GoogleCloudAiplatformV1TensorboardBlobSequence {
        /**
         * List of blobs contained within the sequence.
         */
        values?: Schema$GoogleCloudAiplatformV1TensorboardBlob[];
    }
    /**
     * A TensorboardExperiment is a group of TensorboardRuns, that are typically the results of a training job run, in a Tensorboard.
     */
    export interface Schema$GoogleCloudAiplatformV1TensorboardExperiment {
        /**
         * Output only. Timestamp when this TensorboardExperiment was created.
         */
        createTime?: string | null;
        /**
         * Description of this TensorboardExperiment.
         */
        description?: string | null;
        /**
         * User provided name of this TensorboardExperiment.
         */
        displayName?: string | null;
        /**
         * Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens.
         */
        etag?: string | null;
        /**
         * The labels with user-defined metadata to organize your TensorboardExperiment. Label keys and values cannot be longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. No more than 64 user labels can be associated with one Dataset (System labels are excluded). See https://goo.gl/xmQnxf for more information and examples of labels. System reserved label keys are prefixed with `aiplatform.googleapis.com/` and are immutable. The following system labels exist for each Dataset: * `aiplatform.googleapis.com/dataset_metadata_schema`: output only. Its value is the metadata_schema's title.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * Output only. Name of the TensorboardExperiment. Format: `projects/{project\}/locations/{location\}/tensorboards/{tensorboard\}/experiments/{experiment\}`
         */
        name?: string | null;
        /**
         * Immutable. Source of the TensorboardExperiment. Example: a custom training job.
         */
        source?: string | null;
        /**
         * Output only. Timestamp when this TensorboardExperiment was last updated.
         */
        updateTime?: string | null;
    }
    /**
     * TensorboardRun maps to a specific execution of a training job with a given set of hyperparameter values, model definition, dataset, etc
     */
    export interface Schema$GoogleCloudAiplatformV1TensorboardRun {
        /**
         * Output only. Timestamp when this TensorboardRun was created.
         */
        createTime?: string | null;
        /**
         * Description of this TensorboardRun.
         */
        description?: string | null;
        /**
         * Required. User provided name of this TensorboardRun. This value must be unique among all TensorboardRuns belonging to the same parent TensorboardExperiment.
         */
        displayName?: string | null;
        /**
         * Used to perform a consistent read-modify-write updates. If not set, a blind "overwrite" update happens.
         */
        etag?: string | null;
        /**
         * The labels with user-defined metadata to organize your TensorboardRuns. This field will be used to filter and visualize Runs in the Tensorboard UI. For example, a Vertex AI training job can set a label aiplatform.googleapis.com/training_job_id=xxxxx to all the runs created within that job. An end user can set a label experiment_id=xxxxx for all the runs produced in a Jupyter notebook. These runs can be grouped by a label value and visualized together in the Tensorboard UI. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. No more than 64 user labels can be associated with one TensorboardRun (System labels are excluded). See https://goo.gl/xmQnxf for more information and examples of labels. System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * Output only. Name of the TensorboardRun. Format: `projects/{project\}/locations/{location\}/tensorboards/{tensorboard\}/experiments/{experiment\}/runs/{run\}`
         */
        name?: string | null;
        /**
         * Output only. Timestamp when this TensorboardRun was last updated.
         */
        updateTime?: string | null;
    }
    /**
     * One point viewable on a tensor metric plot.
     */
    export interface Schema$GoogleCloudAiplatformV1TensorboardTensor {
        /**
         * Required. Serialized form of https://github.com/tensorflow/tensorflow/blob/master/tensorflow/core/framework/tensor.proto
         */
        value?: string | null;
        /**
         * Optional. Version number of TensorProto used to serialize value.
         */
        versionNumber?: number | null;
    }
    /**
     * TensorboardTimeSeries maps to times series produced in training runs
     */
    export interface Schema$GoogleCloudAiplatformV1TensorboardTimeSeries {
        /**
         * Output only. Timestamp when this TensorboardTimeSeries was created.
         */
        createTime?: string | null;
        /**
         * Description of this TensorboardTimeSeries.
         */
        description?: string | null;
        /**
         * Required. User provided name of this TensorboardTimeSeries. This value should be unique among all TensorboardTimeSeries resources belonging to the same TensorboardRun resource (parent resource).
         */
        displayName?: string | null;
        /**
         * Used to perform a consistent read-modify-write updates. If not set, a blind "overwrite" update happens.
         */
        etag?: string | null;
        /**
         * Output only. Scalar, Tensor, or Blob metadata for this TensorboardTimeSeries.
         */
        metadata?: Schema$GoogleCloudAiplatformV1TensorboardTimeSeriesMetadata;
        /**
         * Output only. Name of the TensorboardTimeSeries.
         */
        name?: string | null;
        /**
         * Data of the current plugin, with the size limited to 65KB.
         */
        pluginData?: string | null;
        /**
         * Immutable. Name of the plugin this time series pertain to. Such as Scalar, Tensor, Blob
         */
        pluginName?: string | null;
        /**
         * Output only. Timestamp when this TensorboardTimeSeries was last updated.
         */
        updateTime?: string | null;
        /**
         * Required. Immutable. Type of TensorboardTimeSeries value.
         */
        valueType?: string | null;
    }
    /**
     * Describes metadata for a TensorboardTimeSeries.
     */
    export interface Schema$GoogleCloudAiplatformV1TensorboardTimeSeriesMetadata {
        /**
         * Output only. The largest blob sequence length (number of blobs) of all data points in this time series, if its ValueType is BLOB_SEQUENCE.
         */
        maxBlobSequenceLength?: string | null;
        /**
         * Output only. Max step index of all data points within a TensorboardTimeSeries.
         */
        maxStep?: string | null;
        /**
         * Output only. Max wall clock timestamp of all data points within a TensorboardTimeSeries.
         */
        maxWallTime?: string | null;
    }
    /**
     * The storage details for TFRecord output content.
     */
    export interface Schema$GoogleCloudAiplatformV1TFRecordDestination {
        /**
         * Required. Google Cloud Storage location.
         */
        gcsDestination?: Schema$GoogleCloudAiplatformV1GcsDestination;
    }
    /**
     * The config for feature monitoring threshold.
     */
    export interface Schema$GoogleCloudAiplatformV1ThresholdConfig {
        /**
         * Specify a threshold value that can trigger the alert. If this threshold config is for feature distribution distance: 1. For categorical feature, the distribution distance is calculated by L-inifinity norm. 2. For numerical feature, the distribution distance is calculated by Jensen–Shannon divergence. Each feature must have a non-zero threshold if they need to be monitored. Otherwise no alert will be triggered for that feature.
         */
        value?: number | null;
    }
    /**
     * All the data stored in a TensorboardTimeSeries.
     */
    export interface Schema$GoogleCloudAiplatformV1TimeSeriesData {
        /**
         * Required. The ID of the TensorboardTimeSeries, which will become the final component of the TensorboardTimeSeries' resource name
         */
        tensorboardTimeSeriesId?: string | null;
        /**
         * Required. Data points in this time series.
         */
        values?: Schema$GoogleCloudAiplatformV1TimeSeriesDataPoint[];
        /**
         * Required. Immutable. The value type of this time series. All the values in this time series data must match this value type.
         */
        valueType?: string | null;
    }
    /**
     * A TensorboardTimeSeries data point.
     */
    export interface Schema$GoogleCloudAiplatformV1TimeSeriesDataPoint {
        /**
         * A blob sequence value.
         */
        blobs?: Schema$GoogleCloudAiplatformV1TensorboardBlobSequence;
        /**
         * A scalar value.
         */
        scalar?: Schema$GoogleCloudAiplatformV1Scalar;
        /**
         * Step index of this data point within the run.
         */
        step?: string | null;
        /**
         * A tensor value.
         */
        tensor?: Schema$GoogleCloudAiplatformV1TensorboardTensor;
        /**
         * Wall clock timestamp when this data point is generated by the end user.
         */
        wallTime?: string | null;
    }
    /**
     * Assigns input data to training, validation, and test sets based on a provided timestamps. The youngest data pieces are assigned to training set, next to validation set, and the oldest to the test set. Supported only for tabular Datasets.
     */
    export interface Schema$GoogleCloudAiplatformV1TimestampSplit {
        /**
         * Required. The key is a name of one of the Dataset's data columns. The values of the key (the values in the column) must be in RFC 3339 `date-time` format, where `time-offset` = `"Z"` (e.g. 1985-04-12T23:20:50.52Z). If for a piece of data the key is not present or has an invalid value, that piece is ignored by the pipeline.
         */
        key?: string | null;
        /**
         * The fraction of the input data that is to be used to evaluate the Model.
         */
        testFraction?: number | null;
        /**
         * The fraction of the input data that is to be used to train the Model.
         */
        trainingFraction?: number | null;
        /**
         * The fraction of the input data that is to be used to validate the Model.
         */
        validationFraction?: number | null;
    }
    /**
     * CMLE training config. For every active learning labeling iteration, system will train a machine learning model on CMLE. The trained model will be used by data sampling algorithm to select DataItems.
     */
    export interface Schema$GoogleCloudAiplatformV1TrainingConfig {
        /**
         * The timeout hours for the CMLE training job, expressed in milli hours i.e. 1,000 value in this field means 1 hour.
         */
        timeoutTrainingMilliHours?: string | null;
    }
    /**
     * The TrainingPipeline orchestrates tasks associated with training a Model. It always executes the training task, and optionally may also export data from Vertex AI's Dataset which becomes the training input, upload the Model to Vertex AI, and evaluate the Model.
     */
    export interface Schema$GoogleCloudAiplatformV1TrainingPipeline {
        /**
         * Output only. Time when the TrainingPipeline was created.
         */
        createTime?: string | null;
        /**
         * Required. The user-defined name of this TrainingPipeline.
         */
        displayName?: string | null;
        /**
         * Customer-managed encryption key spec for a TrainingPipeline. If set, this TrainingPipeline will be secured by this key. Note: Model trained by this TrainingPipeline is also secured by this key if model_to_upload is not set separately.
         */
        encryptionSpec?: Schema$GoogleCloudAiplatformV1EncryptionSpec;
        /**
         * Output only. Time when the TrainingPipeline entered any of the following states: `PIPELINE_STATE_SUCCEEDED`, `PIPELINE_STATE_FAILED`, `PIPELINE_STATE_CANCELLED`.
         */
        endTime?: string | null;
        /**
         * Output only. Only populated when the pipeline's state is `PIPELINE_STATE_FAILED` or `PIPELINE_STATE_CANCELLED`.
         */
        error?: Schema$GoogleRpcStatus;
        /**
         * Specifies Vertex AI owned input data that may be used for training the Model. The TrainingPipeline's training_task_definition should make clear whether this config is used and if there are any special requirements on how it should be filled. If nothing about this config is mentioned in the training_task_definition, then it should be assumed that the TrainingPipeline does not depend on this configuration.
         */
        inputDataConfig?: Schema$GoogleCloudAiplatformV1InputDataConfig;
        /**
         * The labels with user-defined metadata to organize TrainingPipelines. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * Optional. The ID to use for the uploaded Model, which will become the final component of the model resource name. This value may be up to 63 characters, and valid characters are `[a-z0-9_-]`. The first character cannot be a number or hyphen.
         */
        modelId?: string | null;
        /**
         * Describes the Model that may be uploaded (via ModelService.UploadModel) by this TrainingPipeline. The TrainingPipeline's training_task_definition should make clear whether this Model description should be populated, and if there are any special requirements regarding how it should be filled. If nothing is mentioned in the training_task_definition, then it should be assumed that this field should not be filled and the training task either uploads the Model without a need of this information, or that training task does not support uploading a Model as part of the pipeline. When the Pipeline's state becomes `PIPELINE_STATE_SUCCEEDED` and the trained Model had been uploaded into Vertex AI, then the model_to_upload's resource name is populated. The Model is always uploaded into the Project and Location in which this pipeline is.
         */
        modelToUpload?: Schema$GoogleCloudAiplatformV1Model;
        /**
         * Output only. Resource name of the TrainingPipeline.
         */
        name?: string | null;
        /**
         * Optional. When specify this field, the `model_to_upload` will not be uploaded as a new model, instead, it will become a new version of this `parent_model`.
         */
        parentModel?: string | null;
        /**
         * Output only. Time when the TrainingPipeline for the first time entered the `PIPELINE_STATE_RUNNING` state.
         */
        startTime?: string | null;
        /**
         * Output only. The detailed state of the pipeline.
         */
        state?: string | null;
        /**
         * Required. A Google Cloud Storage path to the YAML file that defines the training task which is responsible for producing the model artifact, and may also include additional auxiliary work. The definition files that can be used here are found in gs://google-cloud-aiplatform/schema/trainingjob/definition/. Note: The URI given on output will be immutable and probably different, including the URI scheme, than the one given on input. The output URI will point to a location where the user only has a read access.
         */
        trainingTaskDefinition?: string | null;
        /**
         * Required. The training task's parameter(s), as specified in the training_task_definition's `inputs`.
         */
        trainingTaskInputs?: any | null;
        /**
         * Output only. The metadata information as specified in the training_task_definition's `metadata`. This metadata is an auxiliary runtime and final information about the training task. While the pipeline is running this information is populated only at a best effort basis. Only present if the pipeline's training_task_definition contains `metadata` object.
         */
        trainingTaskMetadata?: any | null;
        /**
         * Output only. Time when the TrainingPipeline was most recently updated.
         */
        updateTime?: string | null;
    }
    /**
     * A message representing a Trial. A Trial contains a unique set of Parameters that has been or will be evaluated, along with the objective metrics got by running the Trial.
     */
    export interface Schema$GoogleCloudAiplatformV1Trial {
        /**
         * Output only. The identifier of the client that originally requested this Trial. Each client is identified by a unique client_id. When a client asks for a suggestion, Vertex AI Vizier will assign it a Trial. The client should evaluate the Trial, complete it, and report back to Vertex AI Vizier. If suggestion is asked again by same client_id before the Trial is completed, the same Trial will be returned. Multiple clients with different client_ids can ask for suggestions simultaneously, each of them will get their own Trial.
         */
        clientId?: string | null;
        /**
         * Output only. The CustomJob name linked to the Trial. It's set for a HyperparameterTuningJob's Trial.
         */
        customJob?: string | null;
        /**
         * Output only. Time when the Trial's status changed to `SUCCEEDED` or `INFEASIBLE`.
         */
        endTime?: string | null;
        /**
         * Output only. The final measurement containing the objective value.
         */
        finalMeasurement?: Schema$GoogleCloudAiplatformV1Measurement;
        /**
         * Output only. The identifier of the Trial assigned by the service.
         */
        id?: string | null;
        /**
         * Output only. A human readable string describing why the Trial is infeasible. This is set only if Trial state is `INFEASIBLE`.
         */
        infeasibleReason?: string | null;
        /**
         * Output only. A list of measurements that are strictly lexicographically ordered by their induced tuples (steps, elapsed_duration). These are used for early stopping computations.
         */
        measurements?: Schema$GoogleCloudAiplatformV1Measurement[];
        /**
         * Output only. Resource name of the Trial assigned by the service.
         */
        name?: string | null;
        /**
         * Output only. The parameters of the Trial.
         */
        parameters?: Schema$GoogleCloudAiplatformV1TrialParameter[];
        /**
         * Output only. Time when the Trial was started.
         */
        startTime?: string | null;
        /**
         * Output only. The detailed state of the Trial.
         */
        state?: string | null;
        /**
         * Output only. URIs for accessing [interactive shells](https://cloud.google.com/vertex-ai/docs/training/monitor-debug-interactive-shell) (one URI for each training node). Only available if this trial is part of a HyperparameterTuningJob and the job's trial_job_spec.enable_web_access field is `true`. The keys are names of each node used for the trial; for example, `workerpool0-0` for the primary node, `workerpool1-0` for the first node in the second worker pool, and `workerpool1-1` for the second node in the second worker pool. The values are the URIs for each node's interactive shell.
         */
        webAccessUris?: {
            [key: string]: string;
        } | null;
    }
    /**
     * Next ID: 3
     */
    export interface Schema$GoogleCloudAiplatformV1TrialContext {
        /**
         * A human-readable field which can store a description of this context. This will become part of the resulting Trial's description field.
         */
        description?: string | null;
        /**
         * If/when a Trial is generated or selected from this Context, its Parameters will match any parameters specified here. (I.e. if this context specifies parameter name:'a' int_value:3, then a resulting Trial will have int_value:3 for its parameter named 'a'.) Note that we first attempt to match existing REQUESTED Trials with contexts, and if there are no matches, we generate suggestions in the subspace defined by the parameters specified here. NOTE: a Context without any Parameters matches the entire feasible search space.
         */
        parameters?: Schema$GoogleCloudAiplatformV1TrialParameter[];
    }
    /**
     * A message representing a parameter to be tuned.
     */
    export interface Schema$GoogleCloudAiplatformV1TrialParameter {
        /**
         * Output only. The ID of the parameter. The parameter should be defined in StudySpec's Parameters.
         */
        parameterId?: string | null;
        /**
         * Output only. The value of the parameter. `number_value` will be set if a parameter defined in StudySpec is in type 'INTEGER', 'DOUBLE' or 'DISCRETE'. `string_value` will be set if a parameter defined in StudySpec is in type 'CATEGORICAL'.
         */
        value?: any | null;
    }
    /**
     * Runtime operation information for IndexEndpointService.UndeployIndex.
     */
    export interface Schema$GoogleCloudAiplatformV1UndeployIndexOperationMetadata {
        /**
         * The operation generic information.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
    }
    /**
     * Request message for IndexEndpointService.UndeployIndex.
     */
    export interface Schema$GoogleCloudAiplatformV1UndeployIndexRequest {
        /**
         * Required. The ID of the DeployedIndex to be undeployed from the IndexEndpoint.
         */
        deployedIndexId?: string | null;
    }
    /**
     * Response message for IndexEndpointService.UndeployIndex.
     */
    export interface Schema$GoogleCloudAiplatformV1UndeployIndexResponse {
    }
    /**
     * Runtime operation information for EndpointService.UndeployModel.
     */
    export interface Schema$GoogleCloudAiplatformV1UndeployModelOperationMetadata {
        /**
         * The operation generic information.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
    }
    /**
     * Request message for EndpointService.UndeployModel.
     */
    export interface Schema$GoogleCloudAiplatformV1UndeployModelRequest {
        /**
         * Required. The ID of the DeployedModel to be undeployed from the Endpoint.
         */
        deployedModelId?: string | null;
        /**
         * If this field is provided, then the Endpoint's traffic_split will be overwritten with it. If last DeployedModel is being undeployed from the Endpoint, the [Endpoint.traffic_split] will always end up empty when this call returns. A DeployedModel will be successfully undeployed only if it doesn't have any traffic assigned to it when this method executes, or if this field unassigns any traffic to it.
         */
        trafficSplit?: {
            [key: string]: number;
        } | null;
    }
    /**
     * Response message for EndpointService.UndeployModel.
     */
    export interface Schema$GoogleCloudAiplatformV1UndeployModelResponse {
    }
    /**
     * Contains model information necessary to perform batch prediction without requiring a full model import.
     */
    export interface Schema$GoogleCloudAiplatformV1UnmanagedContainerModel {
        /**
         * The path to the directory containing the Model artifact and any of its supporting files.
         */
        artifactUri?: string | null;
        /**
         * Input only. The specification of the container that is to be used when deploying this Model.
         */
        containerSpec?: Schema$GoogleCloudAiplatformV1ModelContainerSpec;
        /**
         * Contains the schemata used in Model's predictions and explanations
         */
        predictSchemata?: Schema$GoogleCloudAiplatformV1PredictSchemata;
    }
    /**
     * Runtime operation information for ModelService.UpdateExplanationDataset.
     */
    export interface Schema$GoogleCloudAiplatformV1UpdateExplanationDatasetOperationMetadata {
        /**
         * The common part of the operation metadata.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
    }
    /**
     * Request message for ModelService.UpdateExplanationDataset.
     */
    export interface Schema$GoogleCloudAiplatformV1UpdateExplanationDatasetRequest {
        /**
         * The example config containing the location of the dataset.
         */
        examples?: Schema$GoogleCloudAiplatformV1Examples;
    }
    /**
     * Response message of ModelService.UpdateExplanationDataset operation.
     */
    export interface Schema$GoogleCloudAiplatformV1UpdateExplanationDatasetResponse {
    }
    /**
     * Details of operations that perform update Featurestore.
     */
    export interface Schema$GoogleCloudAiplatformV1UpdateFeaturestoreOperationMetadata {
        /**
         * Operation metadata for Featurestore.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
    }
    /**
     * Runtime operation information for IndexService.UpdateIndex.
     */
    export interface Schema$GoogleCloudAiplatformV1UpdateIndexOperationMetadata {
        /**
         * The operation generic information.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
        /**
         * The operation metadata with regard to Matching Engine Index operation.
         */
        nearestNeighborSearchOperationMetadata?: Schema$GoogleCloudAiplatformV1NearestNeighborSearchOperationMetadata;
    }
    /**
     * Runtime operation information for JobService.UpdateModelDeploymentMonitoringJob.
     */
    export interface Schema$GoogleCloudAiplatformV1UpdateModelDeploymentMonitoringJobOperationMetadata {
        /**
         * The operation generic information.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
    }
    /**
     * Runtime operation metadata for SpecialistPoolService.UpdateSpecialistPool.
     */
    export interface Schema$GoogleCloudAiplatformV1UpdateSpecialistPoolOperationMetadata {
        /**
         * The operation generic information.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
        /**
         * Output only. The name of the SpecialistPool to which the specialists are being added. Format: `projects/{project_id\}/locations/{location_id\}/specialistPools/{specialist_pool\}`
         */
        specialistPool?: string | null;
    }
    /**
     * Details of operations that perform update Tensorboard.
     */
    export interface Schema$GoogleCloudAiplatformV1UpdateTensorboardOperationMetadata {
        /**
         * Operation metadata for Tensorboard.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
    }
    /**
     * Details of ModelService.UploadModel operation.
     */
    export interface Schema$GoogleCloudAiplatformV1UploadModelOperationMetadata {
        /**
         * The common part of the operation metadata.
         */
        genericMetadata?: Schema$GoogleCloudAiplatformV1GenericOperationMetadata;
    }
    /**
     * Request message for ModelService.UploadModel.
     */
    export interface Schema$GoogleCloudAiplatformV1UploadModelRequest {
        /**
         * Required. The Model to create.
         */
        model?: Schema$GoogleCloudAiplatformV1Model;
        /**
         * Optional. The ID to use for the uploaded Model, which will become the final component of the model resource name. This value may be up to 63 characters, and valid characters are `[a-z0-9_-]`. The first character cannot be a number or hyphen.
         */
        modelId?: string | null;
        /**
         * Optional. The resource name of the model into which to upload the version. Only specify this field when uploading a new version.
         */
        parentModel?: string | null;
        /**
         * Optional. The user-provided custom service account to use to do the model upload. If empty, [Vertex AI Service Agent](https://cloud.google.com/vertex-ai/docs/general/access-control#service-agents) will be used. Users uploading the Model must have the `iam.serviceAccounts.actAs` permission on this service account. Also, this account must belong to the project specified in the `parent` field and have all necessary read permissions.
         */
        serviceAccount?: string | null;
    }
    /**
     * Response message of ModelService.UploadModel operation.
     */
    export interface Schema$GoogleCloudAiplatformV1UploadModelResponse {
        /**
         * The name of the uploaded Model resource. Format: `projects/{project\}/locations/{location\}/models/{model\}`
         */
        model?: string | null;
        /**
         * Output only. The version ID of the model that is uploaded.
         */
        modelVersionId?: string | null;
    }
    /**
     * Request message for IndexService.UpsertDatapoints
     */
    export interface Schema$GoogleCloudAiplatformV1UpsertDatapointsRequest {
        /**
         * A list of datapoints to be created/updated.
         */
        datapoints?: Schema$GoogleCloudAiplatformV1IndexDatapoint[];
    }
    /**
     * Response message for IndexService.UpsertDatapoints
     */
    export interface Schema$GoogleCloudAiplatformV1UpsertDatapointsResponse {
    }
    /**
     * References an API call. It contains more information about long running operation and Jobs that are triggered by the API call.
     */
    export interface Schema$GoogleCloudAiplatformV1UserActionReference {
        /**
         * For API calls that start a LabelingJob. Resource name of the LabelingJob. Format: `projects/{project\}/locations/{location\}/dataLabelingJobs/{data_labeling_job\}`
         */
        dataLabelingJob?: string | null;
        /**
         * The method name of the API RPC call. For example, "/google.cloud.aiplatform.{apiVersion\}.DatasetService.CreateDataset"
         */
        method?: string | null;
        /**
         * For API calls that return a long running operation. Resource name of the long running operation. Format: `projects/{project\}/locations/{location\}/operations/{operation\}`
         */
        operation?: string | null;
    }
    /**
     * Value is the value of the field.
     */
    export interface Schema$GoogleCloudAiplatformV1Value {
        /**
         * A double value.
         */
        doubleValue?: number | null;
        /**
         * An integer value.
         */
        intValue?: string | null;
        /**
         * A string value.
         */
        stringValue?: string | null;
    }
    /**
     * Represents the spec of a worker pool in a job.
     */
    export interface Schema$GoogleCloudAiplatformV1WorkerPoolSpec {
        /**
         * The custom container task.
         */
        containerSpec?: Schema$GoogleCloudAiplatformV1ContainerSpec;
        /**
         * Disk spec.
         */
        diskSpec?: Schema$GoogleCloudAiplatformV1DiskSpec;
        /**
         * Optional. Immutable. The specification of a single machine.
         */
        machineSpec?: Schema$GoogleCloudAiplatformV1MachineSpec;
        /**
         * Optional. List of NFS mount spec.
         */
        nfsMounts?: Schema$GoogleCloudAiplatformV1NfsMount[];
        /**
         * The Python packaged task.
         */
        pythonPackageSpec?: Schema$GoogleCloudAiplatformV1PythonPackageSpec;
        /**
         * Optional. The number of worker replicas to use for this worker pool.
         */
        replicaCount?: string | null;
    }
    /**
     * Contains Feature values to be written for a specific entity.
     */
    export interface Schema$GoogleCloudAiplatformV1WriteFeatureValuesPayload {
        /**
         * Required. The ID of the entity.
         */
        entityId?: string | null;
        /**
         * Required. Feature values to be written, mapping from Feature ID to value. Up to 100,000 `feature_values` entries may be written across all payloads. The feature generation time, aligned by days, must be no older than five years (1825 days) and no later than one year (366 days) in the future.
         */
        featureValues?: {
            [key: string]: Schema$GoogleCloudAiplatformV1FeatureValue;
        } | null;
    }
    /**
     * Request message for FeaturestoreOnlineServingService.WriteFeatureValues.
     */
    export interface Schema$GoogleCloudAiplatformV1WriteFeatureValuesRequest {
        /**
         * Required. The entities to be written. Up to 100,000 feature values can be written across all `payloads`.
         */
        payloads?: Schema$GoogleCloudAiplatformV1WriteFeatureValuesPayload[];
    }
    /**
     * Response message for FeaturestoreOnlineServingService.WriteFeatureValues.
     */
    export interface Schema$GoogleCloudAiplatformV1WriteFeatureValuesResponse {
    }
    /**
     * Request message for TensorboardService.WriteTensorboardExperimentData.
     */
    export interface Schema$GoogleCloudAiplatformV1WriteTensorboardExperimentDataRequest {
        /**
         * Required. Requests containing per-run TensorboardTimeSeries data to write.
         */
        writeRunDataRequests?: Schema$GoogleCloudAiplatformV1WriteTensorboardRunDataRequest[];
    }
    /**
     * Response message for TensorboardService.WriteTensorboardExperimentData.
     */
    export interface Schema$GoogleCloudAiplatformV1WriteTensorboardExperimentDataResponse {
    }
    /**
     * Request message for TensorboardService.WriteTensorboardRunData.
     */
    export interface Schema$GoogleCloudAiplatformV1WriteTensorboardRunDataRequest {
        /**
         * Required. The resource name of the TensorboardRun to write data to. Format: `projects/{project\}/locations/{location\}/tensorboards/{tensorboard\}/experiments/{experiment\}/runs/{run\}`
         */
        tensorboardRun?: string | null;
        /**
         * Required. The TensorboardTimeSeries data to write. Values with in a time series are indexed by their step value. Repeated writes to the same step will overwrite the existing value for that step. The upper limit of data points per write request is 5000.
         */
        timeSeriesData?: Schema$GoogleCloudAiplatformV1TimeSeriesData[];
    }
    /**
     * Response message for TensorboardService.WriteTensorboardRunData.
     */
    export interface Schema$GoogleCloudAiplatformV1WriteTensorboardRunDataResponse {
    }
    /**
     * An explanation method that redistributes Integrated Gradients attributions to segmented regions, taking advantage of the model's fully differentiable structure. Refer to this paper for more details: https://arxiv.org/abs/1906.02825 Supported only by image Models.
     */
    export interface Schema$GoogleCloudAiplatformV1XraiAttribution {
        /**
         * Config for XRAI with blur baseline. When enabled, a linear path from the maximally blurred image to the input image is created. Using a blurred baseline instead of zero (black image) is motivated by the BlurIG approach explained here: https://arxiv.org/abs/2004.03383
         */
        blurBaselineConfig?: Schema$GoogleCloudAiplatformV1BlurBaselineConfig;
        /**
         * Config for SmoothGrad approximation of gradients. When enabled, the gradients are approximated by averaging the gradients from noisy samples in the vicinity of the inputs. Adding noise can help improve the computed gradients. Refer to this paper for more details: https://arxiv.org/pdf/1706.03825.pdf
         */
        smoothGradConfig?: Schema$GoogleCloudAiplatformV1SmoothGradConfig;
        /**
         * Required. The number of steps for approximating the path integral. A good value to start is 50 and gradually increase until the sum to diff property is met within the desired error range. Valid range of its value is [1, 100], inclusively.
         */
        stepCount?: number | null;
    }
    /**
     * The response message for Locations.ListLocations.
     */
    export interface Schema$GoogleCloudLocationListLocationsResponse {
        /**
         * A list of locations that matches the specified filter in the request.
         */
        locations?: Schema$GoogleCloudLocationLocation[];
        /**
         * The standard List next-page token.
         */
        nextPageToken?: string | null;
    }
    /**
     * A resource that represents a Google Cloud location.
     */
    export interface Schema$GoogleCloudLocationLocation {
        /**
         * The friendly name for this location, typically a nearby city name. For example, "Tokyo".
         */
        displayName?: string | null;
        /**
         * Cross-service attributes for the location. For example {"cloud.googleapis.com/region": "us-east1"\}
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * The canonical id for this location. For example: `"us-east1"`.
         */
        locationId?: string | null;
        /**
         * Service-specific metadata. For example the available capacity at the given location.
         */
        metadata?: {
            [key: string]: any;
        } | null;
        /**
         * Resource name for the location, which may vary between implementations. For example: `"projects/example-project/locations/us-east1"`
         */
        name?: string | null;
    }
    /**
     * Associates `members`, or principals, with a `role`.
     */
    export interface Schema$GoogleIamV1Binding {
        /**
         * The condition that is associated with this binding. If the condition evaluates to `true`, then this binding applies to the current request. If the condition evaluates to `false`, then this binding does not apply to the current request. However, a different role binding might grant the same role to one or more of the principals in this binding. To learn which resources support conditions in their IAM policies, see the [IAM documentation](https://cloud.google.com/iam/help/conditions/resource-policies).
         */
        condition?: Schema$GoogleTypeExpr;
        /**
         * Specifies the principals requesting access for a Google Cloud resource. `members` can have the following values: * `allUsers`: A special identifier that represents anyone who is on the internet; with or without a Google account. * `allAuthenticatedUsers`: A special identifier that represents anyone who is authenticated with a Google account or a service account. Does not include identities that come from external identity providers (IdPs) through identity federation. * `user:{emailid\}`: An email address that represents a specific Google account. For example, `alice@example.com` . * `serviceAccount:{emailid\}`: An email address that represents a Google service account. For example, `my-other-app@appspot.gserviceaccount.com`. * `serviceAccount:{projectid\}.svc.id.goog[{namespace\}/{kubernetes-sa\}]`: An identifier for a [Kubernetes service account](https://cloud.google.com/kubernetes-engine/docs/how-to/kubernetes-service-accounts). For example, `my-project.svc.id.goog[my-namespace/my-kubernetes-sa]`. * `group:{emailid\}`: An email address that represents a Google group. For example, `admins@example.com`. * `domain:{domain\}`: The G Suite domain (primary) that represents all the users of that domain. For example, `google.com` or `example.com`. * `deleted:user:{emailid\}?uid={uniqueid\}`: An email address (plus unique identifier) representing a user that has been recently deleted. For example, `alice@example.com?uid=123456789012345678901`. If the user is recovered, this value reverts to `user:{emailid\}` and the recovered user retains the role in the binding. * `deleted:serviceAccount:{emailid\}?uid={uniqueid\}`: An email address (plus unique identifier) representing a service account that has been recently deleted. For example, `my-other-app@appspot.gserviceaccount.com?uid=123456789012345678901`. If the service account is undeleted, this value reverts to `serviceAccount:{emailid\}` and the undeleted service account retains the role in the binding. * `deleted:group:{emailid\}?uid={uniqueid\}`: An email address (plus unique identifier) representing a Google group that has been recently deleted. For example, `admins@example.com?uid=123456789012345678901`. If the group is recovered, this value reverts to `group:{emailid\}` and the recovered group retains the role in the binding.
         */
        members?: string[] | null;
        /**
         * Role that is assigned to the list of `members`, or principals. For example, `roles/viewer`, `roles/editor`, or `roles/owner`.
         */
        role?: string | null;
    }
    /**
     * An Identity and Access Management (IAM) policy, which specifies access controls for Google Cloud resources. A `Policy` is a collection of `bindings`. A `binding` binds one or more `members`, or principals, to a single `role`. Principals can be user accounts, service accounts, Google groups, and domains (such as G Suite). A `role` is a named list of permissions; each `role` can be an IAM predefined role or a user-created custom role. For some types of Google Cloud resources, a `binding` can also specify a `condition`, which is a logical expression that allows access to a resource only if the expression evaluates to `true`. A condition can add constraints based on attributes of the request, the resource, or both. To learn which resources support conditions in their IAM policies, see the [IAM documentation](https://cloud.google.com/iam/help/conditions/resource-policies). **JSON example:** ``` { "bindings": [ { "role": "roles/resourcemanager.organizationAdmin", "members": [ "user:mike@example.com", "group:admins@example.com", "domain:google.com", "serviceAccount:my-project-id@appspot.gserviceaccount.com" ] \}, { "role": "roles/resourcemanager.organizationViewer", "members": [ "user:eve@example.com" ], "condition": { "title": "expirable access", "description": "Does not grant access after Sep 2020", "expression": "request.time < timestamp('2020-10-01T00:00:00.000Z')", \} \} ], "etag": "BwWWja0YfJA=", "version": 3 \} ``` **YAML example:** ``` bindings: - members: - user:mike@example.com - group:admins@example.com - domain:google.com - serviceAccount:my-project-id@appspot.gserviceaccount.com role: roles/resourcemanager.organizationAdmin - members: - user:eve@example.com role: roles/resourcemanager.organizationViewer condition: title: expirable access description: Does not grant access after Sep 2020 expression: request.time < timestamp('2020-10-01T00:00:00.000Z') etag: BwWWja0YfJA= version: 3 ``` For a description of IAM and its features, see the [IAM documentation](https://cloud.google.com/iam/docs/).
     */
    export interface Schema$GoogleIamV1Policy {
        /**
         * Associates a list of `members`, or principals, with a `role`. Optionally, may specify a `condition` that determines how and when the `bindings` are applied. Each of the `bindings` must contain at least one principal. The `bindings` in a `Policy` can refer to up to 1,500 principals; up to 250 of these principals can be Google groups. Each occurrence of a principal counts towards these limits. For example, if the `bindings` grant 50 different roles to `user:alice@example.com`, and not to any other principal, then you can add another 1,450 principals to the `bindings` in the `Policy`.
         */
        bindings?: Schema$GoogleIamV1Binding[];
        /**
         * `etag` is used for optimistic concurrency control as a way to help prevent simultaneous updates of a policy from overwriting each other. It is strongly suggested that systems make use of the `etag` in the read-modify-write cycle to perform policy updates in order to avoid race conditions: An `etag` is returned in the response to `getIamPolicy`, and systems are expected to put that etag in the request to `setIamPolicy` to ensure that their change will be applied to the same version of the policy. **Important:** If you use IAM Conditions, you must include the `etag` field whenever you call `setIamPolicy`. If you omit this field, then IAM allows you to overwrite a version `3` policy with a version `1` policy, and all of the conditions in the version `3` policy are lost.
         */
        etag?: string | null;
        /**
         * Specifies the format of the policy. Valid values are `0`, `1`, and `3`. Requests that specify an invalid value are rejected. Any operation that affects conditional role bindings must specify version `3`. This requirement applies to the following operations: * Getting a policy that includes a conditional role binding * Adding a conditional role binding to a policy * Changing a conditional role binding in a policy * Removing any role binding, with or without a condition, from a policy that includes conditions **Important:** If you use IAM Conditions, you must include the `etag` field whenever you call `setIamPolicy`. If you omit this field, then IAM allows you to overwrite a version `3` policy with a version `1` policy, and all of the conditions in the version `3` policy are lost. If a policy does not include any conditions, operations on that policy may specify any valid version or leave the field unset. To learn which resources support conditions in their IAM policies, see the [IAM documentation](https://cloud.google.com/iam/help/conditions/resource-policies).
         */
        version?: number | null;
    }
    /**
     * Request message for `SetIamPolicy` method.
     */
    export interface Schema$GoogleIamV1SetIamPolicyRequest {
        /**
         * REQUIRED: The complete policy to be applied to the `resource`. The size of the policy is limited to a few 10s of KB. An empty policy is a valid policy but certain Google Cloud services (such as Projects) might reject them.
         */
        policy?: Schema$GoogleIamV1Policy;
    }
    /**
     * Response message for `TestIamPermissions` method.
     */
    export interface Schema$GoogleIamV1TestIamPermissionsResponse {
        /**
         * A subset of `TestPermissionsRequest.permissions` that the caller is allowed.
         */
        permissions?: string[] | null;
    }
    /**
     * The response message for Operations.ListOperations.
     */
    export interface Schema$GoogleLongrunningListOperationsResponse {
        /**
         * The standard List next-page token.
         */
        nextPageToken?: string | null;
        /**
         * A list of operations that matches the specified filter in the request.
         */
        operations?: Schema$GoogleLongrunningOperation[];
    }
    /**
     * This resource represents a long-running operation that is the result of a network API call.
     */
    export interface Schema$GoogleLongrunningOperation {
        /**
         * If the value is `false`, it means the operation is still in progress. If `true`, the operation is completed, and either `error` or `response` is available.
         */
        done?: boolean | null;
        /**
         * The error result of the operation in case of failure or cancellation.
         */
        error?: Schema$GoogleRpcStatus;
        /**
         * Service-specific metadata associated with the operation. It typically contains progress information and common metadata such as create time. Some services might not provide such metadata. Any method that returns a long-running operation should document the metadata type, if any.
         */
        metadata?: {
            [key: string]: any;
        } | null;
        /**
         * The server-assigned name, which is only unique within the same service that originally returns it. If you use the default HTTP mapping, the `name` should be a resource name ending with `operations/{unique_id\}`.
         */
        name?: string | null;
        /**
         * The normal, successful response of the operation. If the original method returns no data on success, such as `Delete`, the response is `google.protobuf.Empty`. If the original method is standard `Get`/`Create`/`Update`, the response should be the resource. For other methods, the response should have the type `XxxResponse`, where `Xxx` is the original method name. For example, if the original method name is `TakeSnapshot()`, the inferred response type is `TakeSnapshotResponse`.
         */
        response?: {
            [key: string]: any;
        } | null;
    }
    /**
     * A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs. A typical example is to use it as the request or the response type of an API method. For instance: service Foo { rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty); \}
     */
    export interface Schema$GoogleProtobufEmpty {
    }
    /**
     * The `Status` type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by [gRPC](https://github.com/grpc). Each `Status` message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the [API Design Guide](https://cloud.google.com/apis/design/errors).
     */
    export interface Schema$GoogleRpcStatus {
        /**
         * The status code, which should be an enum value of google.rpc.Code.
         */
        code?: number | null;
        /**
         * A list of messages that carry the error details. There is a common set of message types for APIs to use.
         */
        details?: Array<{
            [key: string]: any;
        }> | null;
        /**
         * A developer-facing error message, which should be in English. Any user-facing error message should be localized and sent in the google.rpc.Status.details field, or localized by the client.
         */
        message?: string | null;
    }
    /**
     * Represents a color in the RGBA color space. This representation is designed for simplicity of conversion to and from color representations in various languages over compactness. For example, the fields of this representation can be trivially provided to the constructor of `java.awt.Color` in Java; it can also be trivially provided to UIColor's `+colorWithRed:green:blue:alpha` method in iOS; and, with just a little work, it can be easily formatted into a CSS `rgba()` string in JavaScript. This reference page doesn't have information about the absolute color space that should be used to interpret the RGB value—for example, sRGB, Adobe RGB, DCI-P3, and BT.2020. By default, applications should assume the sRGB color space. When color equality needs to be decided, implementations, unless documented otherwise, treat two colors as equal if all their red, green, blue, and alpha values each differ by at most `1e-5`. Example (Java): import com.google.type.Color; // ... public static java.awt.Color fromProto(Color protocolor) { float alpha = protocolor.hasAlpha() ? protocolor.getAlpha().getValue() : 1.0; return new java.awt.Color( protocolor.getRed(), protocolor.getGreen(), protocolor.getBlue(), alpha); \} public static Color toProto(java.awt.Color color) { float red = (float) color.getRed(); float green = (float) color.getGreen(); float blue = (float) color.getBlue(); float denominator = 255.0; Color.Builder resultBuilder = Color .newBuilder() .setRed(red / denominator) .setGreen(green / denominator) .setBlue(blue / denominator); int alpha = color.getAlpha(); if (alpha != 255) { result.setAlpha( FloatValue .newBuilder() .setValue(((float) alpha) / denominator) .build()); \} return resultBuilder.build(); \} // ... Example (iOS / Obj-C): // ... static UIColor* fromProto(Color* protocolor) { float red = [protocolor red]; float green = [protocolor green]; float blue = [protocolor blue]; FloatValue* alpha_wrapper = [protocolor alpha]; float alpha = 1.0; if (alpha_wrapper != nil) { alpha = [alpha_wrapper value]; \} return [UIColor colorWithRed:red green:green blue:blue alpha:alpha]; \} static Color* toProto(UIColor* color) { CGFloat red, green, blue, alpha; if (![color getRed:&red green:&green blue:&blue alpha:&alpha]) { return nil; \} Color* result = [[Color alloc] init]; [result setRed:red]; [result setGreen:green]; [result setBlue:blue]; if (alpha <= 0.9999) { [result setAlpha:floatWrapperWithValue(alpha)]; \} [result autorelease]; return result; \} // ... Example (JavaScript): // ... var protoToCssColor = function(rgb_color) { var redFrac = rgb_color.red || 0.0; var greenFrac = rgb_color.green || 0.0; var blueFrac = rgb_color.blue || 0.0; var red = Math.floor(redFrac * 255); var green = Math.floor(greenFrac * 255); var blue = Math.floor(blueFrac * 255); if (!('alpha' in rgb_color)) { return rgbToCssColor(red, green, blue); \} var alphaFrac = rgb_color.alpha.value || 0.0; var rgbParams = [red, green, blue].join(','); return ['rgba(', rgbParams, ',', alphaFrac, ')'].join(''); \}; var rgbToCssColor = function(red, green, blue) { var rgbNumber = new Number((red << 16) | (green << 8) | blue); var hexString = rgbNumber.toString(16); var missingZeros = 6 - hexString.length; var resultBuilder = ['#']; for (var i = 0; i < missingZeros; i++) { resultBuilder.push('0'); \} resultBuilder.push(hexString); return resultBuilder.join(''); \}; // ...
     */
    export interface Schema$GoogleTypeColor {
        /**
         * The fraction of this color that should be applied to the pixel. That is, the final pixel color is defined by the equation: `pixel color = alpha * (this color) + (1.0 - alpha) * (background color)` This means that a value of 1.0 corresponds to a solid color, whereas a value of 0.0 corresponds to a completely transparent color. This uses a wrapper message rather than a simple float scalar so that it is possible to distinguish between a default value and the value being unset. If omitted, this color object is rendered as a solid color (as if the alpha value had been explicitly given a value of 1.0).
         */
        alpha?: number | null;
        /**
         * The amount of blue in the color as a value in the interval [0, 1].
         */
        blue?: number | null;
        /**
         * The amount of green in the color as a value in the interval [0, 1].
         */
        green?: number | null;
        /**
         * The amount of red in the color as a value in the interval [0, 1].
         */
        red?: number | null;
    }
    /**
     * Represents a textual expression in the Common Expression Language (CEL) syntax. CEL is a C-like expression language. The syntax and semantics of CEL are documented at https://github.com/google/cel-spec. Example (Comparison): title: "Summary size limit" description: "Determines if a summary is less than 100 chars" expression: "document.summary.size() < 100" Example (Equality): title: "Requestor is owner" description: "Determines if requestor is the document owner" expression: "document.owner == request.auth.claims.email" Example (Logic): title: "Public documents" description: "Determine whether the document should be publicly visible" expression: "document.type != 'private' && document.type != 'internal'" Example (Data Manipulation): title: "Notification string" description: "Create a notification string with a timestamp." expression: "'New message received at ' + string(document.create_time)" The exact variables and functions that may be referenced within an expression are determined by the service that evaluates it. See the service documentation for additional information.
     */
    export interface Schema$GoogleTypeExpr {
        /**
         * Optional. Description of the expression. This is a longer text which describes the expression, e.g. when hovered over it in a UI.
         */
        description?: string | null;
        /**
         * Textual representation of an expression in Common Expression Language syntax.
         */
        expression?: string | null;
        /**
         * Optional. String indicating the location of the expression for error reporting, e.g. a file name and a position in the file.
         */
        location?: string | null;
        /**
         * Optional. Title for the expression, i.e. a short string describing its purpose. This can be used e.g. in UIs which allow to enter the expression.
         */
        title?: string | null;
    }
    /**
     * Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time.
     */
    export interface Schema$GoogleTypeInterval {
        /**
         * Optional. Exclusive end of the interval. If specified, a Timestamp matching this interval will have to be before the end.
         */
        endTime?: string | null;
        /**
         * Optional. Inclusive start of the interval. If specified, a Timestamp matching this interval will have to be the same or after the start.
         */
        startTime?: string | null;
    }
    /**
     * Represents an amount of money with its currency type.
     */
    export interface Schema$GoogleTypeMoney {
        /**
         * The three-letter currency code defined in ISO 4217.
         */
        currencyCode?: string | null;
        /**
         * Number of nano (10^-9) units of the amount. The value must be between -999,999,999 and +999,999,999 inclusive. If `units` is positive, `nanos` must be positive or zero. If `units` is zero, `nanos` can be positive, zero, or negative. If `units` is negative, `nanos` must be negative or zero. For example $-1.75 is represented as `units`=-1 and `nanos`=-750,000,000.
         */
        nanos?: number | null;
        /**
         * The whole units of the amount. For example if `currencyCode` is `"USD"`, then 1 unit is one US dollar.
         */
        units?: string | null;
    }
    export class Resource$Projects {
        context: APIRequestContext;
        locations: Resource$Projects$Locations;
        constructor(context: APIRequestContext);
    }
    export class Resource$Projects$Locations {
        context: APIRequestContext;
        batchPredictionJobs: Resource$Projects$Locations$Batchpredictionjobs;
        customJobs: Resource$Projects$Locations$Customjobs;
        dataLabelingJobs: Resource$Projects$Locations$Datalabelingjobs;
        datasets: Resource$Projects$Locations$Datasets;
        deploymentResourcePools: Resource$Projects$Locations$Deploymentresourcepools;
        endpoints: Resource$Projects$Locations$Endpoints;
        featurestores: Resource$Projects$Locations$Featurestores;
        hyperparameterTuningJobs: Resource$Projects$Locations$Hyperparametertuningjobs;
        indexEndpoints: Resource$Projects$Locations$Indexendpoints;
        indexes: Resource$Projects$Locations$Indexes;
        metadataStores: Resource$Projects$Locations$Metadatastores;
        migratableResources: Resource$Projects$Locations$Migratableresources;
        modelDeploymentMonitoringJobs: Resource$Projects$Locations$Modeldeploymentmonitoringjobs;
        models: Resource$Projects$Locations$Models;
        nasJobs: Resource$Projects$Locations$Nasjobs;
        notebookRuntimes: Resource$Projects$Locations$Notebookruntimes;
        notebookRuntimeTemplates: Resource$Projects$Locations$Notebookruntimetemplates;
        operations: Resource$Projects$Locations$Operations;
        pipelineJobs: Resource$Projects$Locations$Pipelinejobs;
        publishers: Resource$Projects$Locations$Publishers;
        schedules: Resource$Projects$Locations$Schedules;
        specialistPools: Resource$Projects$Locations$Specialistpools;
        studies: Resource$Projects$Locations$Studies;
        tensorboards: Resource$Projects$Locations$Tensorboards;
        trainingPipelines: Resource$Projects$Locations$Trainingpipelines;
        constructor(context: APIRequestContext);
        /**
         * Gets information about a location.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudLocationLocation>;
        get(params: Params$Resource$Projects$Locations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudLocationLocation>, callback: BodyResponseCallback<Schema$GoogleCloudLocationLocation>): void;
        get(params: Params$Resource$Projects$Locations$Get, callback: BodyResponseCallback<Schema$GoogleCloudLocationLocation>): void;
        get(callback: BodyResponseCallback<Schema$GoogleCloudLocationLocation>): void;
        /**
         * Lists information about the supported locations for this service.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudLocationListLocationsResponse>;
        list(params: Params$Resource$Projects$Locations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudLocationListLocationsResponse>, callback: BodyResponseCallback<Schema$GoogleCloudLocationListLocationsResponse>): void;
        list(params: Params$Resource$Projects$Locations$List, callback: BodyResponseCallback<Schema$GoogleCloudLocationListLocationsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleCloudLocationListLocationsResponse>): void;
    }
    export interface Params$Resource$Projects$Locations$Get extends StandardParameters {
        /**
         * Resource name for the location.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$List extends StandardParameters {
        /**
         * A filter to narrow down results to a preferred subset. The filtering language accepts strings like `"displayName=tokyo"`, and is documented in more detail in [AIP-160](https://google.aip.dev/160).
         */
        filter?: string;
        /**
         * The resource that owns the locations collection, if applicable.
         */
        name?: string;
        /**
         * The maximum number of results to return. If not set, the service selects a default.
         */
        pageSize?: number;
        /**
         * A page token received from the `next_page_token` field in the response. Send that page token to receive the subsequent page.
         */
        pageToken?: string;
    }
    export class Resource$Projects$Locations$Batchpredictionjobs {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Cancels a BatchPredictionJob. Starts asynchronous cancellation on the BatchPredictionJob. The server makes the best effort to cancel the job, but success is not guaranteed. Clients can use JobService.GetBatchPredictionJob or other methods to check whether the cancellation succeeded or whether the job completed despite cancellation. On a successful cancellation, the BatchPredictionJob is not deleted;instead its BatchPredictionJob.state is set to `CANCELLED`. Any files already outputted by the job are not deleted.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Projects$Locations$Batchpredictionjobs$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Projects$Locations$Batchpredictionjobs$Cancel, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        cancel(params: Params$Resource$Projects$Locations$Batchpredictionjobs$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Projects$Locations$Batchpredictionjobs$Cancel, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(params: Params$Resource$Projects$Locations$Batchpredictionjobs$Cancel, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Creates a BatchPredictionJob. A BatchPredictionJob once created will right away be attempted to start.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        create(params: Params$Resource$Projects$Locations$Batchpredictionjobs$Create, options: StreamMethodOptions): GaxiosPromise<Readable>;
        create(params?: Params$Resource$Projects$Locations$Batchpredictionjobs$Create, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1BatchPredictionJob>;
        create(params: Params$Resource$Projects$Locations$Batchpredictionjobs$Create, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        create(params: Params$Resource$Projects$Locations$Batchpredictionjobs$Create, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1BatchPredictionJob>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1BatchPredictionJob>): void;
        create(params: Params$Resource$Projects$Locations$Batchpredictionjobs$Create, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1BatchPredictionJob>): void;
        create(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1BatchPredictionJob>): void;
        /**
         * Deletes a BatchPredictionJob. Can only be called on jobs that already finished.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Batchpredictionjobs$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Batchpredictionjobs$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        delete(params: Params$Resource$Projects$Locations$Batchpredictionjobs$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Batchpredictionjobs$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(params: Params$Resource$Projects$Locations$Batchpredictionjobs$Delete, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Gets a BatchPredictionJob
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Batchpredictionjobs$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Batchpredictionjobs$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1BatchPredictionJob>;
        get(params: Params$Resource$Projects$Locations$Batchpredictionjobs$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Batchpredictionjobs$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1BatchPredictionJob>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1BatchPredictionJob>): void;
        get(params: Params$Resource$Projects$Locations$Batchpredictionjobs$Get, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1BatchPredictionJob>): void;
        get(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1BatchPredictionJob>): void;
        /**
         * Lists BatchPredictionJobs in a Location.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Batchpredictionjobs$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Batchpredictionjobs$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListBatchPredictionJobsResponse>;
        list(params: Params$Resource$Projects$Locations$Batchpredictionjobs$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Batchpredictionjobs$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListBatchPredictionJobsResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListBatchPredictionJobsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Batchpredictionjobs$List, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListBatchPredictionJobsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListBatchPredictionJobsResponse>): void;
    }
    export interface Params$Resource$Projects$Locations$Batchpredictionjobs$Cancel extends StandardParameters {
        /**
         * Required. The name of the BatchPredictionJob to cancel. Format: `projects/{project\}/locations/{location\}/batchPredictionJobs/{batch_prediction_job\}`
         */
        name?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1CancelBatchPredictionJobRequest;
    }
    export interface Params$Resource$Projects$Locations$Batchpredictionjobs$Create extends StandardParameters {
        /**
         * Required. The resource name of the Location to create the BatchPredictionJob in. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1BatchPredictionJob;
    }
    export interface Params$Resource$Projects$Locations$Batchpredictionjobs$Delete extends StandardParameters {
        /**
         * Required. The name of the BatchPredictionJob resource to be deleted. Format: `projects/{project\}/locations/{location\}/batchPredictionJobs/{batch_prediction_job\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Batchpredictionjobs$Get extends StandardParameters {
        /**
         * Required. The name of the BatchPredictionJob resource. Format: `projects/{project\}/locations/{location\}/batchPredictionJobs/{batch_prediction_job\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Batchpredictionjobs$List extends StandardParameters {
        /**
         * The standard list filter. Supported fields: * `display_name` supports `=`, `!=` comparisons, and `:` wildcard. * `model_display_name` supports `=`, `!=` comparisons. * `state` supports `=`, `!=` comparisons. * `create_time` supports `=`, `!=`,`<`, `<=`,`\>`, `\>=` comparisons. `create_time` must be in RFC 3339 format. * `labels` supports general map functions that is: `labels.key=value` - key:value equality `labels.key:* - key existence Some examples of using the filter are: * `state="JOB_STATE_SUCCEEDED" AND display_name:"my_job_*"` * `state!="JOB_STATE_FAILED" OR display_name="my_job"` * `NOT display_name="my_job"` * `create_time\>"2021-05-18T00:00:00Z"` * `labels.keyA=valueA` * `labels.keyB:*`
         */
        filter?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token. Typically obtained via ListBatchPredictionJobsResponse.next_page_token of the previous JobService.ListBatchPredictionJobs call.
         */
        pageToken?: string;
        /**
         * Required. The resource name of the Location to list the BatchPredictionJobs from. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Mask specifying which fields to read.
         */
        readMask?: string;
    }
    export class Resource$Projects$Locations$Customjobs {
        context: APIRequestContext;
        operations: Resource$Projects$Locations$Customjobs$Operations;
        constructor(context: APIRequestContext);
        /**
         * Cancels a CustomJob. Starts asynchronous cancellation on the CustomJob. The server makes a best effort to cancel the job, but success is not guaranteed. Clients can use JobService.GetCustomJob or other methods to check whether the cancellation succeeded or whether the job completed despite cancellation. On successful cancellation, the CustomJob is not deleted; instead it becomes a job with a CustomJob.error value with a google.rpc.Status.code of 1, corresponding to `Code.CANCELLED`, and CustomJob.state is set to `CANCELLED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Projects$Locations$Customjobs$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Projects$Locations$Customjobs$Cancel, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        cancel(params: Params$Resource$Projects$Locations$Customjobs$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Projects$Locations$Customjobs$Cancel, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(params: Params$Resource$Projects$Locations$Customjobs$Cancel, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Creates a CustomJob. A created CustomJob right away will be attempted to be run.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        create(params: Params$Resource$Projects$Locations$Customjobs$Create, options: StreamMethodOptions): GaxiosPromise<Readable>;
        create(params?: Params$Resource$Projects$Locations$Customjobs$Create, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1CustomJob>;
        create(params: Params$Resource$Projects$Locations$Customjobs$Create, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        create(params: Params$Resource$Projects$Locations$Customjobs$Create, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1CustomJob>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1CustomJob>): void;
        create(params: Params$Resource$Projects$Locations$Customjobs$Create, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1CustomJob>): void;
        create(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1CustomJob>): void;
        /**
         * Deletes a CustomJob.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Customjobs$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Customjobs$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        delete(params: Params$Resource$Projects$Locations$Customjobs$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Customjobs$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(params: Params$Resource$Projects$Locations$Customjobs$Delete, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Gets a CustomJob.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Customjobs$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Customjobs$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1CustomJob>;
        get(params: Params$Resource$Projects$Locations$Customjobs$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Customjobs$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1CustomJob>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1CustomJob>): void;
        get(params: Params$Resource$Projects$Locations$Customjobs$Get, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1CustomJob>): void;
        get(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1CustomJob>): void;
        /**
         * Lists CustomJobs in a Location.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Customjobs$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Customjobs$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListCustomJobsResponse>;
        list(params: Params$Resource$Projects$Locations$Customjobs$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Customjobs$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListCustomJobsResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListCustomJobsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Customjobs$List, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListCustomJobsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListCustomJobsResponse>): void;
    }
    export interface Params$Resource$Projects$Locations$Customjobs$Cancel extends StandardParameters {
        /**
         * Required. The name of the CustomJob to cancel. Format: `projects/{project\}/locations/{location\}/customJobs/{custom_job\}`
         */
        name?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1CancelCustomJobRequest;
    }
    export interface Params$Resource$Projects$Locations$Customjobs$Create extends StandardParameters {
        /**
         * Required. The resource name of the Location to create the CustomJob in. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1CustomJob;
    }
    export interface Params$Resource$Projects$Locations$Customjobs$Delete extends StandardParameters {
        /**
         * Required. The name of the CustomJob resource to be deleted. Format: `projects/{project\}/locations/{location\}/customJobs/{custom_job\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Customjobs$Get extends StandardParameters {
        /**
         * Required. The name of the CustomJob resource. Format: `projects/{project\}/locations/{location\}/customJobs/{custom_job\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Customjobs$List extends StandardParameters {
        /**
         * The standard list filter. Supported fields: * `display_name` supports `=`, `!=` comparisons, and `:` wildcard. * `state` supports `=`, `!=` comparisons. * `create_time` supports `=`, `!=`,`<`, `<=`,`\>`, `\>=` comparisons. `create_time` must be in RFC 3339 format. * `labels` supports general map functions that is: `labels.key=value` - key:value equality `labels.key:* - key existence Some examples of using the filter are: * `state="JOB_STATE_SUCCEEDED" AND display_name:"my_job_*"` * `state!="JOB_STATE_FAILED" OR display_name="my_job"` * `NOT display_name="my_job"` * `create_time\>"2021-05-18T00:00:00Z"` * `labels.keyA=valueA` * `labels.keyB:*`
         */
        filter?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token. Typically obtained via ListCustomJobsResponse.next_page_token of the previous JobService.ListCustomJobs call.
         */
        pageToken?: string;
        /**
         * Required. The resource name of the Location to list the CustomJobs from. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Mask specifying which fields to read.
         */
        readMask?: string;
    }
    export class Resource$Projects$Locations$Customjobs$Operations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to `Code.CANCELLED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Projects$Locations$Customjobs$Operations$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Projects$Locations$Customjobs$Operations$Cancel, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        cancel(params: Params$Resource$Projects$Locations$Customjobs$Operations$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Projects$Locations$Customjobs$Operations$Cancel, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(params: Params$Resource$Projects$Locations$Customjobs$Operations$Cancel, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Customjobs$Operations$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Customjobs$Operations$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        delete(params: Params$Resource$Projects$Locations$Customjobs$Operations$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Customjobs$Operations$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(params: Params$Resource$Projects$Locations$Customjobs$Operations$Delete, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Customjobs$Operations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Customjobs$Operations$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        get(params: Params$Resource$Projects$Locations$Customjobs$Operations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Customjobs$Operations$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(params: Params$Resource$Projects$Locations$Customjobs$Operations$Get, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns `UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Customjobs$Operations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Customjobs$Operations$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningListOperationsResponse>;
        list(params: Params$Resource$Projects$Locations$Customjobs$Operations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Customjobs$Operations$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Customjobs$Operations$List, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        /**
         * Waits until the specified long-running operation is done or reaches at most a specified timeout, returning the latest state. If the operation is already done, the latest state is immediately returned. If the timeout specified is greater than the default HTTP/RPC timeout, the HTTP/RPC timeout is used. If the server does not support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Note that this method is on a best-effort basis. It may return the latest state before the specified timeout (including immediately), meaning even an immediate response is no guarantee that the operation is done.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        wait(params: Params$Resource$Projects$Locations$Customjobs$Operations$Wait, options: StreamMethodOptions): GaxiosPromise<Readable>;
        wait(params?: Params$Resource$Projects$Locations$Customjobs$Operations$Wait, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        wait(params: Params$Resource$Projects$Locations$Customjobs$Operations$Wait, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        wait(params: Params$Resource$Projects$Locations$Customjobs$Operations$Wait, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(params: Params$Resource$Projects$Locations$Customjobs$Operations$Wait, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
    }
    export interface Params$Resource$Projects$Locations$Customjobs$Operations$Cancel extends StandardParameters {
        /**
         * The name of the operation resource to be cancelled.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Customjobs$Operations$Delete extends StandardParameters {
        /**
         * The name of the operation resource to be deleted.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Customjobs$Operations$Get extends StandardParameters {
        /**
         * The name of the operation resource.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Customjobs$Operations$List extends StandardParameters {
        /**
         * The standard list filter.
         */
        filter?: string;
        /**
         * The name of the operation's parent resource.
         */
        name?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token.
         */
        pageToken?: string;
    }
    export interface Params$Resource$Projects$Locations$Customjobs$Operations$Wait extends StandardParameters {
        /**
         * The name of the operation resource to wait on.
         */
        name?: string;
        /**
         * The maximum duration to wait before timing out. If left blank, the wait will be at most the time permitted by the underlying HTTP/RPC protocol. If RPC context deadline is also specified, the shorter one will be used.
         */
        timeout?: string;
    }
    export class Resource$Projects$Locations$Datalabelingjobs {
        context: APIRequestContext;
        operations: Resource$Projects$Locations$Datalabelingjobs$Operations;
        constructor(context: APIRequestContext);
        /**
         * Cancels a DataLabelingJob. Success of cancellation is not guaranteed.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Projects$Locations$Datalabelingjobs$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Projects$Locations$Datalabelingjobs$Cancel, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        cancel(params: Params$Resource$Projects$Locations$Datalabelingjobs$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Projects$Locations$Datalabelingjobs$Cancel, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(params: Params$Resource$Projects$Locations$Datalabelingjobs$Cancel, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Creates a DataLabelingJob.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        create(params: Params$Resource$Projects$Locations$Datalabelingjobs$Create, options: StreamMethodOptions): GaxiosPromise<Readable>;
        create(params?: Params$Resource$Projects$Locations$Datalabelingjobs$Create, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1DataLabelingJob>;
        create(params: Params$Resource$Projects$Locations$Datalabelingjobs$Create, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        create(params: Params$Resource$Projects$Locations$Datalabelingjobs$Create, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1DataLabelingJob>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1DataLabelingJob>): void;
        create(params: Params$Resource$Projects$Locations$Datalabelingjobs$Create, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1DataLabelingJob>): void;
        create(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1DataLabelingJob>): void;
        /**
         * Deletes a DataLabelingJob.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Datalabelingjobs$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Datalabelingjobs$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        delete(params: Params$Resource$Projects$Locations$Datalabelingjobs$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Datalabelingjobs$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(params: Params$Resource$Projects$Locations$Datalabelingjobs$Delete, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Gets a DataLabelingJob.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Datalabelingjobs$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Datalabelingjobs$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1DataLabelingJob>;
        get(params: Params$Resource$Projects$Locations$Datalabelingjobs$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Datalabelingjobs$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1DataLabelingJob>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1DataLabelingJob>): void;
        get(params: Params$Resource$Projects$Locations$Datalabelingjobs$Get, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1DataLabelingJob>): void;
        get(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1DataLabelingJob>): void;
        /**
         * Lists DataLabelingJobs in a Location.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Datalabelingjobs$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Datalabelingjobs$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListDataLabelingJobsResponse>;
        list(params: Params$Resource$Projects$Locations$Datalabelingjobs$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Datalabelingjobs$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListDataLabelingJobsResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListDataLabelingJobsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Datalabelingjobs$List, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListDataLabelingJobsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListDataLabelingJobsResponse>): void;
    }
    export interface Params$Resource$Projects$Locations$Datalabelingjobs$Cancel extends StandardParameters {
        /**
         * Required. The name of the DataLabelingJob. Format: `projects/{project\}/locations/{location\}/dataLabelingJobs/{data_labeling_job\}`
         */
        name?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1CancelDataLabelingJobRequest;
    }
    export interface Params$Resource$Projects$Locations$Datalabelingjobs$Create extends StandardParameters {
        /**
         * Required. The parent of the DataLabelingJob. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1DataLabelingJob;
    }
    export interface Params$Resource$Projects$Locations$Datalabelingjobs$Delete extends StandardParameters {
        /**
         * Required. The name of the DataLabelingJob to be deleted. Format: `projects/{project\}/locations/{location\}/dataLabelingJobs/{data_labeling_job\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Datalabelingjobs$Get extends StandardParameters {
        /**
         * Required. The name of the DataLabelingJob. Format: `projects/{project\}/locations/{location\}/dataLabelingJobs/{data_labeling_job\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Datalabelingjobs$List extends StandardParameters {
        /**
         * The standard list filter. Supported fields: * `display_name` supports `=`, `!=` comparisons, and `:` wildcard. * `state` supports `=`, `!=` comparisons. * `create_time` supports `=`, `!=`,`<`, `<=`,`\>`, `\>=` comparisons. `create_time` must be in RFC 3339 format. * `labels` supports general map functions that is: `labels.key=value` - key:value equality `labels.key:* - key existence Some examples of using the filter are: * `state="JOB_STATE_SUCCEEDED" AND display_name:"my_job_*"` * `state!="JOB_STATE_FAILED" OR display_name="my_job"` * `NOT display_name="my_job"` * `create_time\>"2021-05-18T00:00:00Z"` * `labels.keyA=valueA` * `labels.keyB:*`
         */
        filter?: string;
        /**
         * A comma-separated list of fields to order by, sorted in ascending order by default. Use `desc` after a field name for descending.
         */
        orderBy?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token.
         */
        pageToken?: string;
        /**
         * Required. The parent of the DataLabelingJob. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Mask specifying which fields to read. FieldMask represents a set of symbolic field paths. For example, the mask can be `paths: "name"`. The "name" here is a field in DataLabelingJob. If this field is not set, all fields of the DataLabelingJob are returned.
         */
        readMask?: string;
    }
    export class Resource$Projects$Locations$Datalabelingjobs$Operations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to `Code.CANCELLED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Projects$Locations$Datalabelingjobs$Operations$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Projects$Locations$Datalabelingjobs$Operations$Cancel, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        cancel(params: Params$Resource$Projects$Locations$Datalabelingjobs$Operations$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Projects$Locations$Datalabelingjobs$Operations$Cancel, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(params: Params$Resource$Projects$Locations$Datalabelingjobs$Operations$Cancel, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Datalabelingjobs$Operations$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Datalabelingjobs$Operations$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        delete(params: Params$Resource$Projects$Locations$Datalabelingjobs$Operations$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Datalabelingjobs$Operations$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(params: Params$Resource$Projects$Locations$Datalabelingjobs$Operations$Delete, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Datalabelingjobs$Operations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Datalabelingjobs$Operations$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        get(params: Params$Resource$Projects$Locations$Datalabelingjobs$Operations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Datalabelingjobs$Operations$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(params: Params$Resource$Projects$Locations$Datalabelingjobs$Operations$Get, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns `UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Datalabelingjobs$Operations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Datalabelingjobs$Operations$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningListOperationsResponse>;
        list(params: Params$Resource$Projects$Locations$Datalabelingjobs$Operations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Datalabelingjobs$Operations$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Datalabelingjobs$Operations$List, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        /**
         * Waits until the specified long-running operation is done or reaches at most a specified timeout, returning the latest state. If the operation is already done, the latest state is immediately returned. If the timeout specified is greater than the default HTTP/RPC timeout, the HTTP/RPC timeout is used. If the server does not support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Note that this method is on a best-effort basis. It may return the latest state before the specified timeout (including immediately), meaning even an immediate response is no guarantee that the operation is done.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        wait(params: Params$Resource$Projects$Locations$Datalabelingjobs$Operations$Wait, options: StreamMethodOptions): GaxiosPromise<Readable>;
        wait(params?: Params$Resource$Projects$Locations$Datalabelingjobs$Operations$Wait, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        wait(params: Params$Resource$Projects$Locations$Datalabelingjobs$Operations$Wait, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        wait(params: Params$Resource$Projects$Locations$Datalabelingjobs$Operations$Wait, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(params: Params$Resource$Projects$Locations$Datalabelingjobs$Operations$Wait, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
    }
    export interface Params$Resource$Projects$Locations$Datalabelingjobs$Operations$Cancel extends StandardParameters {
        /**
         * The name of the operation resource to be cancelled.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Datalabelingjobs$Operations$Delete extends StandardParameters {
        /**
         * The name of the operation resource to be deleted.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Datalabelingjobs$Operations$Get extends StandardParameters {
        /**
         * The name of the operation resource.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Datalabelingjobs$Operations$List extends StandardParameters {
        /**
         * The standard list filter.
         */
        filter?: string;
        /**
         * The name of the operation's parent resource.
         */
        name?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token.
         */
        pageToken?: string;
    }
    export interface Params$Resource$Projects$Locations$Datalabelingjobs$Operations$Wait extends StandardParameters {
        /**
         * The name of the operation resource to wait on.
         */
        name?: string;
        /**
         * The maximum duration to wait before timing out. If left blank, the wait will be at most the time permitted by the underlying HTTP/RPC protocol. If RPC context deadline is also specified, the shorter one will be used.
         */
        timeout?: string;
    }
    export class Resource$Projects$Locations$Datasets {
        context: APIRequestContext;
        annotationSpecs: Resource$Projects$Locations$Datasets$Annotationspecs;
        dataItems: Resource$Projects$Locations$Datasets$Dataitems;
        datasetVersions: Resource$Projects$Locations$Datasets$Datasetversions;
        operations: Resource$Projects$Locations$Datasets$Operations;
        savedQueries: Resource$Projects$Locations$Datasets$Savedqueries;
        constructor(context: APIRequestContext);
        /**
         * Creates a Dataset.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        create(params: Params$Resource$Projects$Locations$Datasets$Create, options: StreamMethodOptions): GaxiosPromise<Readable>;
        create(params?: Params$Resource$Projects$Locations$Datasets$Create, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        create(params: Params$Resource$Projects$Locations$Datasets$Create, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        create(params: Params$Resource$Projects$Locations$Datasets$Create, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        create(params: Params$Resource$Projects$Locations$Datasets$Create, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        create(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Deletes a Dataset.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Datasets$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Datasets$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        delete(params: Params$Resource$Projects$Locations$Datasets$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Datasets$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(params: Params$Resource$Projects$Locations$Datasets$Delete, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Exports data from a Dataset.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        export(params: Params$Resource$Projects$Locations$Datasets$Export, options: StreamMethodOptions): GaxiosPromise<Readable>;
        export(params?: Params$Resource$Projects$Locations$Datasets$Export, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        export(params: Params$Resource$Projects$Locations$Datasets$Export, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        export(params: Params$Resource$Projects$Locations$Datasets$Export, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        export(params: Params$Resource$Projects$Locations$Datasets$Export, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        export(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Gets a Dataset.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Datasets$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Datasets$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1Dataset>;
        get(params: Params$Resource$Projects$Locations$Datasets$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Datasets$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1Dataset>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Dataset>): void;
        get(params: Params$Resource$Projects$Locations$Datasets$Get, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Dataset>): void;
        get(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Dataset>): void;
        /**
         * Imports data into a Dataset.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        import(params: Params$Resource$Projects$Locations$Datasets$Import, options: StreamMethodOptions): GaxiosPromise<Readable>;
        import(params?: Params$Resource$Projects$Locations$Datasets$Import, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        import(params: Params$Resource$Projects$Locations$Datasets$Import, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        import(params: Params$Resource$Projects$Locations$Datasets$Import, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        import(params: Params$Resource$Projects$Locations$Datasets$Import, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        import(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Lists Datasets in a Location.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Datasets$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Datasets$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListDatasetsResponse>;
        list(params: Params$Resource$Projects$Locations$Datasets$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Datasets$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListDatasetsResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListDatasetsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Datasets$List, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListDatasetsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListDatasetsResponse>): void;
        /**
         * Updates a Dataset.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Projects$Locations$Datasets$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Projects$Locations$Datasets$Patch, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1Dataset>;
        patch(params: Params$Resource$Projects$Locations$Datasets$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Projects$Locations$Datasets$Patch, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1Dataset>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Dataset>): void;
        patch(params: Params$Resource$Projects$Locations$Datasets$Patch, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Dataset>): void;
        patch(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Dataset>): void;
        /**
         * Searches DataItems in a Dataset.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        searchDataItems(params: Params$Resource$Projects$Locations$Datasets$Searchdataitems, options: StreamMethodOptions): GaxiosPromise<Readable>;
        searchDataItems(params?: Params$Resource$Projects$Locations$Datasets$Searchdataitems, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1SearchDataItemsResponse>;
        searchDataItems(params: Params$Resource$Projects$Locations$Datasets$Searchdataitems, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        searchDataItems(params: Params$Resource$Projects$Locations$Datasets$Searchdataitems, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1SearchDataItemsResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1SearchDataItemsResponse>): void;
        searchDataItems(params: Params$Resource$Projects$Locations$Datasets$Searchdataitems, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1SearchDataItemsResponse>): void;
        searchDataItems(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1SearchDataItemsResponse>): void;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Create extends StandardParameters {
        /**
         * Required. The resource name of the Location to create the Dataset in. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1Dataset;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Delete extends StandardParameters {
        /**
         * Required. The resource name of the Dataset to delete. Format: `projects/{project\}/locations/{location\}/datasets/{dataset\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Export extends StandardParameters {
        /**
         * Required. The name of the Dataset resource. Format: `projects/{project\}/locations/{location\}/datasets/{dataset\}`
         */
        name?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1ExportDataRequest;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Get extends StandardParameters {
        /**
         * Required. The name of the Dataset resource.
         */
        name?: string;
        /**
         * Mask specifying which fields to read.
         */
        readMask?: string;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Import extends StandardParameters {
        /**
         * Required. The name of the Dataset resource. Format: `projects/{project\}/locations/{location\}/datasets/{dataset\}`
         */
        name?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1ImportDataRequest;
    }
    export interface Params$Resource$Projects$Locations$Datasets$List extends StandardParameters {
        /**
         * An expression for filtering the results of the request. For field names both snake_case and camelCase are supported. * `display_name`: supports = and != * `metadata_schema_uri`: supports = and != * `labels` supports general map functions that is: * `labels.key=value` - key:value equality * `labels.key:* or labels:key - key existence * A key including a space must be quoted. `labels."a key"`. Some examples: * `displayName="myDisplayName"` * `labels.myKey="myValue"`
         */
        filter?: string;
        /**
         * A comma-separated list of fields to order by, sorted in ascending order. Use "desc" after a field name for descending. Supported fields: * `display_name` * `create_time` * `update_time`
         */
        orderBy?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token.
         */
        pageToken?: string;
        /**
         * Required. The name of the Dataset's parent resource. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Mask specifying which fields to read.
         */
        readMask?: string;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Patch extends StandardParameters {
        /**
         * Output only. The resource name of the Dataset.
         */
        name?: string;
        /**
         * Required. The update mask applies to the resource. For the `FieldMask` definition, see google.protobuf.FieldMask. Updatable fields: * `display_name` * `description` * `labels`
         */
        updateMask?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1Dataset;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Searchdataitems extends StandardParameters {
        /**
         * An expression that specifies what Annotations will be returned per DataItem. Annotations satisfied either of the conditions will be returned. * `annotation_spec_id` - for = or !=. Must specify `saved_query_id=` - saved query id that annotations should belong to.
         */
        annotationFilters?: string[];
        /**
         * An expression for filtering the Annotations that will be returned per DataItem. * `annotation_spec_id` - for = or !=.
         */
        annotationsFilter?: string;
        /**
         * If set, only up to this many of Annotations will be returned per DataItemView. The maximum value is 1000. If not set, the maximum value will be used.
         */
        annotationsLimit?: number;
        /**
         * An expression for filtering the DataItem that will be returned. * `data_item_id` - for = or !=. * `labeled` - for = or !=. * `has_annotation(ANNOTATION_SPEC_ID)` - true only for DataItem that have at least one annotation with annotation_spec_id = `ANNOTATION_SPEC_ID` in the context of SavedQuery or DataLabelingJob. For example: * `data_item=1` * `has_annotation(5)`
         */
        dataItemFilter?: string;
        /**
         * The resource name of a DataLabelingJob. Format: `projects/{project\}/locations/{location\}/dataLabelingJobs/{data_labeling_job\}` If this field is set, all of the search will be done in the context of this DataLabelingJob.
         */
        dataLabelingJob?: string;
        /**
         * Required. The resource name of the Dataset from which to search DataItems. Format: `projects/{project\}/locations/{location\}/datasets/{dataset\}`
         */
        dataset?: string;
        /**
         * Mask specifying which fields of DataItemView to read.
         */
        fieldMask?: string;
        /**
         * A comma-separated list of fields to order by, sorted in ascending order. Use "desc" after a field name for descending.
         */
        orderBy?: string;
        /**
         * A comma-separated list of annotation fields to order by, sorted in ascending order. Use "desc" after a field name for descending. Must also specify saved_query.
         */
        'orderByAnnotation.orderBy'?: string;
        /**
         * Required. Saved query of the Annotation. Only Annotations belong to this saved query will be considered for ordering.
         */
        'orderByAnnotation.savedQuery'?: string;
        /**
         * A comma-separated list of data item fields to order by, sorted in ascending order. Use "desc" after a field name for descending.
         */
        orderByDataItem?: string;
        /**
         * Requested page size. Server may return fewer results than requested. Default and maximum page size is 100.
         */
        pageSize?: number;
        /**
         * A token identifying a page of results for the server to return Typically obtained via SearchDataItemsResponse.next_page_token of the previous DatasetService.SearchDataItems call.
         */
        pageToken?: string;
        /**
         * The resource name of a SavedQuery(annotation set in UI). Format: `projects/{project\}/locations/{location\}/datasets/{dataset\}/savedQueries/{saved_query\}` All of the search will be done in the context of this SavedQuery.
         */
        savedQuery?: string;
    }
    export class Resource$Projects$Locations$Datasets$Annotationspecs {
        context: APIRequestContext;
        operations: Resource$Projects$Locations$Datasets$Annotationspecs$Operations;
        constructor(context: APIRequestContext);
        /**
         * Gets an AnnotationSpec.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Datasets$Annotationspecs$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Datasets$Annotationspecs$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1AnnotationSpec>;
        get(params: Params$Resource$Projects$Locations$Datasets$Annotationspecs$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Datasets$Annotationspecs$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1AnnotationSpec>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1AnnotationSpec>): void;
        get(params: Params$Resource$Projects$Locations$Datasets$Annotationspecs$Get, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1AnnotationSpec>): void;
        get(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1AnnotationSpec>): void;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Annotationspecs$Get extends StandardParameters {
        /**
         * Required. The name of the AnnotationSpec resource. Format: `projects/{project\}/locations/{location\}/datasets/{dataset\}/annotationSpecs/{annotation_spec\}`
         */
        name?: string;
        /**
         * Mask specifying which fields to read.
         */
        readMask?: string;
    }
    export class Resource$Projects$Locations$Datasets$Annotationspecs$Operations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to `Code.CANCELLED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Projects$Locations$Datasets$Annotationspecs$Operations$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Projects$Locations$Datasets$Annotationspecs$Operations$Cancel, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        cancel(params: Params$Resource$Projects$Locations$Datasets$Annotationspecs$Operations$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Projects$Locations$Datasets$Annotationspecs$Operations$Cancel, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(params: Params$Resource$Projects$Locations$Datasets$Annotationspecs$Operations$Cancel, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Datasets$Annotationspecs$Operations$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Datasets$Annotationspecs$Operations$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        delete(params: Params$Resource$Projects$Locations$Datasets$Annotationspecs$Operations$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Datasets$Annotationspecs$Operations$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(params: Params$Resource$Projects$Locations$Datasets$Annotationspecs$Operations$Delete, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Datasets$Annotationspecs$Operations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Datasets$Annotationspecs$Operations$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        get(params: Params$Resource$Projects$Locations$Datasets$Annotationspecs$Operations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Datasets$Annotationspecs$Operations$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(params: Params$Resource$Projects$Locations$Datasets$Annotationspecs$Operations$Get, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns `UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Datasets$Annotationspecs$Operations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Datasets$Annotationspecs$Operations$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningListOperationsResponse>;
        list(params: Params$Resource$Projects$Locations$Datasets$Annotationspecs$Operations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Datasets$Annotationspecs$Operations$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Datasets$Annotationspecs$Operations$List, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        /**
         * Waits until the specified long-running operation is done or reaches at most a specified timeout, returning the latest state. If the operation is already done, the latest state is immediately returned. If the timeout specified is greater than the default HTTP/RPC timeout, the HTTP/RPC timeout is used. If the server does not support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Note that this method is on a best-effort basis. It may return the latest state before the specified timeout (including immediately), meaning even an immediate response is no guarantee that the operation is done.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        wait(params: Params$Resource$Projects$Locations$Datasets$Annotationspecs$Operations$Wait, options: StreamMethodOptions): GaxiosPromise<Readable>;
        wait(params?: Params$Resource$Projects$Locations$Datasets$Annotationspecs$Operations$Wait, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        wait(params: Params$Resource$Projects$Locations$Datasets$Annotationspecs$Operations$Wait, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        wait(params: Params$Resource$Projects$Locations$Datasets$Annotationspecs$Operations$Wait, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(params: Params$Resource$Projects$Locations$Datasets$Annotationspecs$Operations$Wait, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Annotationspecs$Operations$Cancel extends StandardParameters {
        /**
         * The name of the operation resource to be cancelled.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Annotationspecs$Operations$Delete extends StandardParameters {
        /**
         * The name of the operation resource to be deleted.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Annotationspecs$Operations$Get extends StandardParameters {
        /**
         * The name of the operation resource.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Annotationspecs$Operations$List extends StandardParameters {
        /**
         * The standard list filter.
         */
        filter?: string;
        /**
         * The name of the operation's parent resource.
         */
        name?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token.
         */
        pageToken?: string;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Annotationspecs$Operations$Wait extends StandardParameters {
        /**
         * The name of the operation resource to wait on.
         */
        name?: string;
        /**
         * The maximum duration to wait before timing out. If left blank, the wait will be at most the time permitted by the underlying HTTP/RPC protocol. If RPC context deadline is also specified, the shorter one will be used.
         */
        timeout?: string;
    }
    export class Resource$Projects$Locations$Datasets$Dataitems {
        context: APIRequestContext;
        annotations: Resource$Projects$Locations$Datasets$Dataitems$Annotations;
        operations: Resource$Projects$Locations$Datasets$Dataitems$Operations;
        constructor(context: APIRequestContext);
        /**
         * Lists DataItems in a Dataset.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Datasets$Dataitems$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Datasets$Dataitems$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListDataItemsResponse>;
        list(params: Params$Resource$Projects$Locations$Datasets$Dataitems$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Datasets$Dataitems$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListDataItemsResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListDataItemsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Datasets$Dataitems$List, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListDataItemsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListDataItemsResponse>): void;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Dataitems$List extends StandardParameters {
        /**
         * The standard list filter.
         */
        filter?: string;
        /**
         * A comma-separated list of fields to order by, sorted in ascending order. Use "desc" after a field name for descending.
         */
        orderBy?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token.
         */
        pageToken?: string;
        /**
         * Required. The resource name of the Dataset to list DataItems from. Format: `projects/{project\}/locations/{location\}/datasets/{dataset\}`
         */
        parent?: string;
        /**
         * Mask specifying which fields to read.
         */
        readMask?: string;
    }
    export class Resource$Projects$Locations$Datasets$Dataitems$Annotations {
        context: APIRequestContext;
        operations: Resource$Projects$Locations$Datasets$Dataitems$Annotations$Operations;
        constructor(context: APIRequestContext);
        /**
         * Lists Annotations belongs to a dataitem
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Annotations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Datasets$Dataitems$Annotations$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListAnnotationsResponse>;
        list(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Annotations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Annotations$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListAnnotationsResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListAnnotationsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Annotations$List, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListAnnotationsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListAnnotationsResponse>): void;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Dataitems$Annotations$List extends StandardParameters {
        /**
         * The standard list filter.
         */
        filter?: string;
        /**
         * A comma-separated list of fields to order by, sorted in ascending order. Use "desc" after a field name for descending.
         */
        orderBy?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token.
         */
        pageToken?: string;
        /**
         * Required. The resource name of the DataItem to list Annotations from. Format: `projects/{project\}/locations/{location\}/datasets/{dataset\}/dataItems/{data_item\}`
         */
        parent?: string;
        /**
         * Mask specifying which fields to read.
         */
        readMask?: string;
    }
    export class Resource$Projects$Locations$Datasets$Dataitems$Annotations$Operations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to `Code.CANCELLED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Annotations$Operations$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Projects$Locations$Datasets$Dataitems$Annotations$Operations$Cancel, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        cancel(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Annotations$Operations$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Annotations$Operations$Cancel, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Annotations$Operations$Cancel, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Annotations$Operations$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Datasets$Dataitems$Annotations$Operations$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        delete(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Annotations$Operations$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Annotations$Operations$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Annotations$Operations$Delete, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Annotations$Operations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Datasets$Dataitems$Annotations$Operations$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        get(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Annotations$Operations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Annotations$Operations$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Annotations$Operations$Get, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns `UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Annotations$Operations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Datasets$Dataitems$Annotations$Operations$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningListOperationsResponse>;
        list(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Annotations$Operations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Annotations$Operations$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Annotations$Operations$List, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        /**
         * Waits until the specified long-running operation is done or reaches at most a specified timeout, returning the latest state. If the operation is already done, the latest state is immediately returned. If the timeout specified is greater than the default HTTP/RPC timeout, the HTTP/RPC timeout is used. If the server does not support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Note that this method is on a best-effort basis. It may return the latest state before the specified timeout (including immediately), meaning even an immediate response is no guarantee that the operation is done.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        wait(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Annotations$Operations$Wait, options: StreamMethodOptions): GaxiosPromise<Readable>;
        wait(params?: Params$Resource$Projects$Locations$Datasets$Dataitems$Annotations$Operations$Wait, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        wait(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Annotations$Operations$Wait, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        wait(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Annotations$Operations$Wait, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Annotations$Operations$Wait, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Dataitems$Annotations$Operations$Cancel extends StandardParameters {
        /**
         * The name of the operation resource to be cancelled.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Dataitems$Annotations$Operations$Delete extends StandardParameters {
        /**
         * The name of the operation resource to be deleted.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Dataitems$Annotations$Operations$Get extends StandardParameters {
        /**
         * The name of the operation resource.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Dataitems$Annotations$Operations$List extends StandardParameters {
        /**
         * The standard list filter.
         */
        filter?: string;
        /**
         * The name of the operation's parent resource.
         */
        name?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token.
         */
        pageToken?: string;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Dataitems$Annotations$Operations$Wait extends StandardParameters {
        /**
         * The name of the operation resource to wait on.
         */
        name?: string;
        /**
         * The maximum duration to wait before timing out. If left blank, the wait will be at most the time permitted by the underlying HTTP/RPC protocol. If RPC context deadline is also specified, the shorter one will be used.
         */
        timeout?: string;
    }
    export class Resource$Projects$Locations$Datasets$Dataitems$Operations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to `Code.CANCELLED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Operations$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Projects$Locations$Datasets$Dataitems$Operations$Cancel, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        cancel(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Operations$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Operations$Cancel, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Operations$Cancel, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Operations$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Datasets$Dataitems$Operations$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        delete(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Operations$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Operations$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Operations$Delete, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Operations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Datasets$Dataitems$Operations$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        get(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Operations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Operations$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Operations$Get, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns `UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Operations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Datasets$Dataitems$Operations$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningListOperationsResponse>;
        list(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Operations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Operations$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Operations$List, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        /**
         * Waits until the specified long-running operation is done or reaches at most a specified timeout, returning the latest state. If the operation is already done, the latest state is immediately returned. If the timeout specified is greater than the default HTTP/RPC timeout, the HTTP/RPC timeout is used. If the server does not support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Note that this method is on a best-effort basis. It may return the latest state before the specified timeout (including immediately), meaning even an immediate response is no guarantee that the operation is done.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        wait(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Operations$Wait, options: StreamMethodOptions): GaxiosPromise<Readable>;
        wait(params?: Params$Resource$Projects$Locations$Datasets$Dataitems$Operations$Wait, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        wait(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Operations$Wait, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        wait(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Operations$Wait, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(params: Params$Resource$Projects$Locations$Datasets$Dataitems$Operations$Wait, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Dataitems$Operations$Cancel extends StandardParameters {
        /**
         * The name of the operation resource to be cancelled.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Dataitems$Operations$Delete extends StandardParameters {
        /**
         * The name of the operation resource to be deleted.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Dataitems$Operations$Get extends StandardParameters {
        /**
         * The name of the operation resource.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Dataitems$Operations$List extends StandardParameters {
        /**
         * The standard list filter.
         */
        filter?: string;
        /**
         * The name of the operation's parent resource.
         */
        name?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token.
         */
        pageToken?: string;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Dataitems$Operations$Wait extends StandardParameters {
        /**
         * The name of the operation resource to wait on.
         */
        name?: string;
        /**
         * The maximum duration to wait before timing out. If left blank, the wait will be at most the time permitted by the underlying HTTP/RPC protocol. If RPC context deadline is also specified, the shorter one will be used.
         */
        timeout?: string;
    }
    export class Resource$Projects$Locations$Datasets$Datasetversions {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Create a version from a Dataset.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        create(params: Params$Resource$Projects$Locations$Datasets$Datasetversions$Create, options: StreamMethodOptions): GaxiosPromise<Readable>;
        create(params?: Params$Resource$Projects$Locations$Datasets$Datasetversions$Create, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        create(params: Params$Resource$Projects$Locations$Datasets$Datasetversions$Create, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        create(params: Params$Resource$Projects$Locations$Datasets$Datasetversions$Create, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        create(params: Params$Resource$Projects$Locations$Datasets$Datasetversions$Create, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        create(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Deletes a Dataset version.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Datasets$Datasetversions$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Datasets$Datasetversions$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        delete(params: Params$Resource$Projects$Locations$Datasets$Datasetversions$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Datasets$Datasetversions$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(params: Params$Resource$Projects$Locations$Datasets$Datasetversions$Delete, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Gets a Dataset version.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Datasets$Datasetversions$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Datasets$Datasetversions$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1DatasetVersion>;
        get(params: Params$Resource$Projects$Locations$Datasets$Datasetversions$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Datasets$Datasetversions$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1DatasetVersion>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1DatasetVersion>): void;
        get(params: Params$Resource$Projects$Locations$Datasets$Datasetversions$Get, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1DatasetVersion>): void;
        get(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1DatasetVersion>): void;
        /**
         * Lists DatasetVersions in a Dataset.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Datasets$Datasetversions$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Datasets$Datasetversions$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListDatasetVersionsResponse>;
        list(params: Params$Resource$Projects$Locations$Datasets$Datasetversions$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Datasets$Datasetversions$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListDatasetVersionsResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListDatasetVersionsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Datasets$Datasetversions$List, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListDatasetVersionsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListDatasetVersionsResponse>): void;
        /**
         * Restores a dataset version.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        restore(params: Params$Resource$Projects$Locations$Datasets$Datasetversions$Restore, options: StreamMethodOptions): GaxiosPromise<Readable>;
        restore(params?: Params$Resource$Projects$Locations$Datasets$Datasetversions$Restore, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        restore(params: Params$Resource$Projects$Locations$Datasets$Datasetversions$Restore, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        restore(params: Params$Resource$Projects$Locations$Datasets$Datasetversions$Restore, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        restore(params: Params$Resource$Projects$Locations$Datasets$Datasetversions$Restore, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        restore(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Datasetversions$Create extends StandardParameters {
        /**
         * Required. The name of the Dataset resource. Format: `projects/{project\}/locations/{location\}/datasets/{dataset\}`
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1DatasetVersion;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Datasetversions$Delete extends StandardParameters {
        /**
         * Required. The resource name of the Dataset version to delete. Format: `projects/{project\}/locations/{location\}/datasets/{dataset\}/datasetVersions/{dataset_version\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Datasetversions$Get extends StandardParameters {
        /**
         * Required. The resource name of the Dataset version to delete. Format: `projects/{project\}/locations/{location\}/datasets/{dataset\}/datasetVersions/{dataset_version\}`
         */
        name?: string;
        /**
         * Mask specifying which fields to read.
         */
        readMask?: string;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Datasetversions$List extends StandardParameters {
        /**
         * Optional. The standard list filter.
         */
        filter?: string;
        /**
         * Optional. A comma-separated list of fields to order by, sorted in ascending order. Use "desc" after a field name for descending.
         */
        orderBy?: string;
        /**
         * Optional. The standard list page size.
         */
        pageSize?: number;
        /**
         * Optional. The standard list page token.
         */
        pageToken?: string;
        /**
         * Required. The resource name of the Dataset to list DatasetVersions from. Format: `projects/{project\}/locations/{location\}/datasets/{dataset\}`
         */
        parent?: string;
        /**
         * Optional. Mask specifying which fields to read.
         */
        readMask?: string;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Datasetversions$Restore extends StandardParameters {
        /**
         * Required. The name of the DatasetVersion resource. Format: `projects/{project\}/locations/{location\}/datasets/{dataset\}/datasetVersions/{dataset_version\}`
         */
        name?: string;
    }
    export class Resource$Projects$Locations$Datasets$Operations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to `Code.CANCELLED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Projects$Locations$Datasets$Operations$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Projects$Locations$Datasets$Operations$Cancel, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        cancel(params: Params$Resource$Projects$Locations$Datasets$Operations$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Projects$Locations$Datasets$Operations$Cancel, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(params: Params$Resource$Projects$Locations$Datasets$Operations$Cancel, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Datasets$Operations$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Datasets$Operations$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        delete(params: Params$Resource$Projects$Locations$Datasets$Operations$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Datasets$Operations$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(params: Params$Resource$Projects$Locations$Datasets$Operations$Delete, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Datasets$Operations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Datasets$Operations$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        get(params: Params$Resource$Projects$Locations$Datasets$Operations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Datasets$Operations$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(params: Params$Resource$Projects$Locations$Datasets$Operations$Get, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns `UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Datasets$Operations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Datasets$Operations$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningListOperationsResponse>;
        list(params: Params$Resource$Projects$Locations$Datasets$Operations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Datasets$Operations$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Datasets$Operations$List, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        /**
         * Waits until the specified long-running operation is done or reaches at most a specified timeout, returning the latest state. If the operation is already done, the latest state is immediately returned. If the timeout specified is greater than the default HTTP/RPC timeout, the HTTP/RPC timeout is used. If the server does not support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Note that this method is on a best-effort basis. It may return the latest state before the specified timeout (including immediately), meaning even an immediate response is no guarantee that the operation is done.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        wait(params: Params$Resource$Projects$Locations$Datasets$Operations$Wait, options: StreamMethodOptions): GaxiosPromise<Readable>;
        wait(params?: Params$Resource$Projects$Locations$Datasets$Operations$Wait, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        wait(params: Params$Resource$Projects$Locations$Datasets$Operations$Wait, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        wait(params: Params$Resource$Projects$Locations$Datasets$Operations$Wait, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(params: Params$Resource$Projects$Locations$Datasets$Operations$Wait, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Operations$Cancel extends StandardParameters {
        /**
         * The name of the operation resource to be cancelled.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Operations$Delete extends StandardParameters {
        /**
         * The name of the operation resource to be deleted.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Operations$Get extends StandardParameters {
        /**
         * The name of the operation resource.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Operations$List extends StandardParameters {
        /**
         * The standard list filter.
         */
        filter?: string;
        /**
         * The name of the operation's parent resource.
         */
        name?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token.
         */
        pageToken?: string;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Operations$Wait extends StandardParameters {
        /**
         * The name of the operation resource to wait on.
         */
        name?: string;
        /**
         * The maximum duration to wait before timing out. If left blank, the wait will be at most the time permitted by the underlying HTTP/RPC protocol. If RPC context deadline is also specified, the shorter one will be used.
         */
        timeout?: string;
    }
    export class Resource$Projects$Locations$Datasets$Savedqueries {
        context: APIRequestContext;
        operations: Resource$Projects$Locations$Datasets$Savedqueries$Operations;
        constructor(context: APIRequestContext);
        /**
         * Deletes a SavedQuery.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Datasets$Savedqueries$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Datasets$Savedqueries$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        delete(params: Params$Resource$Projects$Locations$Datasets$Savedqueries$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Datasets$Savedqueries$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(params: Params$Resource$Projects$Locations$Datasets$Savedqueries$Delete, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Lists SavedQueries in a Dataset.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Datasets$Savedqueries$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Datasets$Savedqueries$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListSavedQueriesResponse>;
        list(params: Params$Resource$Projects$Locations$Datasets$Savedqueries$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Datasets$Savedqueries$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListSavedQueriesResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListSavedQueriesResponse>): void;
        list(params: Params$Resource$Projects$Locations$Datasets$Savedqueries$List, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListSavedQueriesResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListSavedQueriesResponse>): void;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Savedqueries$Delete extends StandardParameters {
        /**
         * Required. The resource name of the SavedQuery to delete. Format: `projects/{project\}/locations/{location\}/datasets/{dataset\}/savedQueries/{saved_query\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Savedqueries$List extends StandardParameters {
        /**
         * The standard list filter.
         */
        filter?: string;
        /**
         * A comma-separated list of fields to order by, sorted in ascending order. Use "desc" after a field name for descending.
         */
        orderBy?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token.
         */
        pageToken?: string;
        /**
         * Required. The resource name of the Dataset to list SavedQueries from. Format: `projects/{project\}/locations/{location\}/datasets/{dataset\}`
         */
        parent?: string;
        /**
         * Mask specifying which fields to read.
         */
        readMask?: string;
    }
    export class Resource$Projects$Locations$Datasets$Savedqueries$Operations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to `Code.CANCELLED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Projects$Locations$Datasets$Savedqueries$Operations$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Projects$Locations$Datasets$Savedqueries$Operations$Cancel, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        cancel(params: Params$Resource$Projects$Locations$Datasets$Savedqueries$Operations$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Projects$Locations$Datasets$Savedqueries$Operations$Cancel, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(params: Params$Resource$Projects$Locations$Datasets$Savedqueries$Operations$Cancel, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Datasets$Savedqueries$Operations$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Datasets$Savedqueries$Operations$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        delete(params: Params$Resource$Projects$Locations$Datasets$Savedqueries$Operations$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Datasets$Savedqueries$Operations$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(params: Params$Resource$Projects$Locations$Datasets$Savedqueries$Operations$Delete, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Datasets$Savedqueries$Operations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Datasets$Savedqueries$Operations$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        get(params: Params$Resource$Projects$Locations$Datasets$Savedqueries$Operations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Datasets$Savedqueries$Operations$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(params: Params$Resource$Projects$Locations$Datasets$Savedqueries$Operations$Get, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns `UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Datasets$Savedqueries$Operations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Datasets$Savedqueries$Operations$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningListOperationsResponse>;
        list(params: Params$Resource$Projects$Locations$Datasets$Savedqueries$Operations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Datasets$Savedqueries$Operations$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Datasets$Savedqueries$Operations$List, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        /**
         * Waits until the specified long-running operation is done or reaches at most a specified timeout, returning the latest state. If the operation is already done, the latest state is immediately returned. If the timeout specified is greater than the default HTTP/RPC timeout, the HTTP/RPC timeout is used. If the server does not support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Note that this method is on a best-effort basis. It may return the latest state before the specified timeout (including immediately), meaning even an immediate response is no guarantee that the operation is done.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        wait(params: Params$Resource$Projects$Locations$Datasets$Savedqueries$Operations$Wait, options: StreamMethodOptions): GaxiosPromise<Readable>;
        wait(params?: Params$Resource$Projects$Locations$Datasets$Savedqueries$Operations$Wait, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        wait(params: Params$Resource$Projects$Locations$Datasets$Savedqueries$Operations$Wait, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        wait(params: Params$Resource$Projects$Locations$Datasets$Savedqueries$Operations$Wait, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(params: Params$Resource$Projects$Locations$Datasets$Savedqueries$Operations$Wait, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Savedqueries$Operations$Cancel extends StandardParameters {
        /**
         * The name of the operation resource to be cancelled.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Savedqueries$Operations$Delete extends StandardParameters {
        /**
         * The name of the operation resource to be deleted.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Savedqueries$Operations$Get extends StandardParameters {
        /**
         * The name of the operation resource.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Savedqueries$Operations$List extends StandardParameters {
        /**
         * The standard list filter.
         */
        filter?: string;
        /**
         * The name of the operation's parent resource.
         */
        name?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token.
         */
        pageToken?: string;
    }
    export interface Params$Resource$Projects$Locations$Datasets$Savedqueries$Operations$Wait extends StandardParameters {
        /**
         * The name of the operation resource to wait on.
         */
        name?: string;
        /**
         * The maximum duration to wait before timing out. If left blank, the wait will be at most the time permitted by the underlying HTTP/RPC protocol. If RPC context deadline is also specified, the shorter one will be used.
         */
        timeout?: string;
    }
    export class Resource$Projects$Locations$Deploymentresourcepools {
        context: APIRequestContext;
        operations: Resource$Projects$Locations$Deploymentresourcepools$Operations;
        constructor(context: APIRequestContext);
    }
    export class Resource$Projects$Locations$Deploymentresourcepools$Operations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to `Code.CANCELLED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Projects$Locations$Deploymentresourcepools$Operations$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Projects$Locations$Deploymentresourcepools$Operations$Cancel, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        cancel(params: Params$Resource$Projects$Locations$Deploymentresourcepools$Operations$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Projects$Locations$Deploymentresourcepools$Operations$Cancel, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(params: Params$Resource$Projects$Locations$Deploymentresourcepools$Operations$Cancel, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Deploymentresourcepools$Operations$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Deploymentresourcepools$Operations$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        delete(params: Params$Resource$Projects$Locations$Deploymentresourcepools$Operations$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Deploymentresourcepools$Operations$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(params: Params$Resource$Projects$Locations$Deploymentresourcepools$Operations$Delete, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Deploymentresourcepools$Operations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Deploymentresourcepools$Operations$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        get(params: Params$Resource$Projects$Locations$Deploymentresourcepools$Operations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Deploymentresourcepools$Operations$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(params: Params$Resource$Projects$Locations$Deploymentresourcepools$Operations$Get, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns `UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Deploymentresourcepools$Operations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Deploymentresourcepools$Operations$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningListOperationsResponse>;
        list(params: Params$Resource$Projects$Locations$Deploymentresourcepools$Operations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Deploymentresourcepools$Operations$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Deploymentresourcepools$Operations$List, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        /**
         * Waits until the specified long-running operation is done or reaches at most a specified timeout, returning the latest state. If the operation is already done, the latest state is immediately returned. If the timeout specified is greater than the default HTTP/RPC timeout, the HTTP/RPC timeout is used. If the server does not support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Note that this method is on a best-effort basis. It may return the latest state before the specified timeout (including immediately), meaning even an immediate response is no guarantee that the operation is done.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        wait(params: Params$Resource$Projects$Locations$Deploymentresourcepools$Operations$Wait, options: StreamMethodOptions): GaxiosPromise<Readable>;
        wait(params?: Params$Resource$Projects$Locations$Deploymentresourcepools$Operations$Wait, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        wait(params: Params$Resource$Projects$Locations$Deploymentresourcepools$Operations$Wait, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        wait(params: Params$Resource$Projects$Locations$Deploymentresourcepools$Operations$Wait, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(params: Params$Resource$Projects$Locations$Deploymentresourcepools$Operations$Wait, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
    }
    export interface Params$Resource$Projects$Locations$Deploymentresourcepools$Operations$Cancel extends StandardParameters {
        /**
         * The name of the operation resource to be cancelled.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Deploymentresourcepools$Operations$Delete extends StandardParameters {
        /**
         * The name of the operation resource to be deleted.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Deploymentresourcepools$Operations$Get extends StandardParameters {
        /**
         * The name of the operation resource.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Deploymentresourcepools$Operations$List extends StandardParameters {
        /**
         * The standard list filter.
         */
        filter?: string;
        /**
         * The name of the operation's parent resource.
         */
        name?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token.
         */
        pageToken?: string;
    }
    export interface Params$Resource$Projects$Locations$Deploymentresourcepools$Operations$Wait extends StandardParameters {
        /**
         * The name of the operation resource to wait on.
         */
        name?: string;
        /**
         * The maximum duration to wait before timing out. If left blank, the wait will be at most the time permitted by the underlying HTTP/RPC protocol. If RPC context deadline is also specified, the shorter one will be used.
         */
        timeout?: string;
    }
    export class Resource$Projects$Locations$Endpoints {
        context: APIRequestContext;
        operations: Resource$Projects$Locations$Endpoints$Operations;
        constructor(context: APIRequestContext);
        /**
         * Creates an Endpoint.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        create(params: Params$Resource$Projects$Locations$Endpoints$Create, options: StreamMethodOptions): GaxiosPromise<Readable>;
        create(params?: Params$Resource$Projects$Locations$Endpoints$Create, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        create(params: Params$Resource$Projects$Locations$Endpoints$Create, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        create(params: Params$Resource$Projects$Locations$Endpoints$Create, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        create(params: Params$Resource$Projects$Locations$Endpoints$Create, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        create(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Deletes an Endpoint.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Endpoints$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Endpoints$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        delete(params: Params$Resource$Projects$Locations$Endpoints$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Endpoints$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(params: Params$Resource$Projects$Locations$Endpoints$Delete, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Deploys a Model into this Endpoint, creating a DeployedModel within it.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        deployModel(params: Params$Resource$Projects$Locations$Endpoints$Deploymodel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        deployModel(params?: Params$Resource$Projects$Locations$Endpoints$Deploymodel, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        deployModel(params: Params$Resource$Projects$Locations$Endpoints$Deploymodel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        deployModel(params: Params$Resource$Projects$Locations$Endpoints$Deploymodel, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        deployModel(params: Params$Resource$Projects$Locations$Endpoints$Deploymodel, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        deployModel(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Perform an online explanation. If deployed_model_id is specified, the corresponding DeployModel must have explanation_spec populated. If deployed_model_id is not specified, all DeployedModels must have explanation_spec populated.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        explain(params: Params$Resource$Projects$Locations$Endpoints$Explain, options: StreamMethodOptions): GaxiosPromise<Readable>;
        explain(params?: Params$Resource$Projects$Locations$Endpoints$Explain, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ExplainResponse>;
        explain(params: Params$Resource$Projects$Locations$Endpoints$Explain, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        explain(params: Params$Resource$Projects$Locations$Endpoints$Explain, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ExplainResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ExplainResponse>): void;
        explain(params: Params$Resource$Projects$Locations$Endpoints$Explain, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ExplainResponse>): void;
        explain(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ExplainResponse>): void;
        /**
         * Gets an Endpoint.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Endpoints$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Endpoints$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1Endpoint>;
        get(params: Params$Resource$Projects$Locations$Endpoints$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Endpoints$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1Endpoint>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Endpoint>): void;
        get(params: Params$Resource$Projects$Locations$Endpoints$Get, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Endpoint>): void;
        get(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Endpoint>): void;
        /**
         * Lists Endpoints in a Location.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Endpoints$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Endpoints$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListEndpointsResponse>;
        list(params: Params$Resource$Projects$Locations$Endpoints$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Endpoints$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListEndpointsResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListEndpointsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Endpoints$List, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListEndpointsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListEndpointsResponse>): void;
        /**
         * Updates an existing deployed model. Updatable fields include `min_replica_count`, `max_replica_count`, `autoscaling_metric_specs`, `disable_container_logging` (v1 only), and `enable_container_logging` (v1beta1 only).
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        mutateDeployedModel(params: Params$Resource$Projects$Locations$Endpoints$Mutatedeployedmodel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        mutateDeployedModel(params?: Params$Resource$Projects$Locations$Endpoints$Mutatedeployedmodel, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        mutateDeployedModel(params: Params$Resource$Projects$Locations$Endpoints$Mutatedeployedmodel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        mutateDeployedModel(params: Params$Resource$Projects$Locations$Endpoints$Mutatedeployedmodel, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        mutateDeployedModel(params: Params$Resource$Projects$Locations$Endpoints$Mutatedeployedmodel, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        mutateDeployedModel(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Updates an Endpoint.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Projects$Locations$Endpoints$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Projects$Locations$Endpoints$Patch, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1Endpoint>;
        patch(params: Params$Resource$Projects$Locations$Endpoints$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Projects$Locations$Endpoints$Patch, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1Endpoint>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Endpoint>): void;
        patch(params: Params$Resource$Projects$Locations$Endpoints$Patch, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Endpoint>): void;
        patch(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Endpoint>): void;
        /**
         * Perform an online prediction.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        predict(params: Params$Resource$Projects$Locations$Endpoints$Predict, options: StreamMethodOptions): GaxiosPromise<Readable>;
        predict(params?: Params$Resource$Projects$Locations$Endpoints$Predict, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1PredictResponse>;
        predict(params: Params$Resource$Projects$Locations$Endpoints$Predict, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        predict(params: Params$Resource$Projects$Locations$Endpoints$Predict, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1PredictResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1PredictResponse>): void;
        predict(params: Params$Resource$Projects$Locations$Endpoints$Predict, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1PredictResponse>): void;
        predict(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1PredictResponse>): void;
        /**
         * Perform an online prediction with an arbitrary HTTP payload. The response includes the following HTTP headers: * `X-Vertex-AI-Endpoint-Id`: ID of the Endpoint that served this prediction. * `X-Vertex-AI-Deployed-Model-Id`: ID of the Endpoint's DeployedModel that served this prediction.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        rawPredict(params: Params$Resource$Projects$Locations$Endpoints$Rawpredict, options: StreamMethodOptions): GaxiosPromise<Readable>;
        rawPredict(params?: Params$Resource$Projects$Locations$Endpoints$Rawpredict, options?: MethodOptions): GaxiosPromise<Schema$GoogleApiHttpBody>;
        rawPredict(params: Params$Resource$Projects$Locations$Endpoints$Rawpredict, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        rawPredict(params: Params$Resource$Projects$Locations$Endpoints$Rawpredict, options: MethodOptions | BodyResponseCallback<Schema$GoogleApiHttpBody>, callback: BodyResponseCallback<Schema$GoogleApiHttpBody>): void;
        rawPredict(params: Params$Resource$Projects$Locations$Endpoints$Rawpredict, callback: BodyResponseCallback<Schema$GoogleApiHttpBody>): void;
        rawPredict(callback: BodyResponseCallback<Schema$GoogleApiHttpBody>): void;
        /**
         * Perform a server-side streaming online prediction request for Vertex LLM streaming.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        serverStreamingPredict(params: Params$Resource$Projects$Locations$Endpoints$Serverstreamingpredict, options: StreamMethodOptions): GaxiosPromise<Readable>;
        serverStreamingPredict(params?: Params$Resource$Projects$Locations$Endpoints$Serverstreamingpredict, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1StreamingPredictResponse>;
        serverStreamingPredict(params: Params$Resource$Projects$Locations$Endpoints$Serverstreamingpredict, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        serverStreamingPredict(params: Params$Resource$Projects$Locations$Endpoints$Serverstreamingpredict, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1StreamingPredictResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1StreamingPredictResponse>): void;
        serverStreamingPredict(params: Params$Resource$Projects$Locations$Endpoints$Serverstreamingpredict, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1StreamingPredictResponse>): void;
        serverStreamingPredict(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1StreamingPredictResponse>): void;
        /**
         * Undeploys a Model from an Endpoint, removing a DeployedModel from it, and freeing all resources it's using.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        undeployModel(params: Params$Resource$Projects$Locations$Endpoints$Undeploymodel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        undeployModel(params?: Params$Resource$Projects$Locations$Endpoints$Undeploymodel, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        undeployModel(params: Params$Resource$Projects$Locations$Endpoints$Undeploymodel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        undeployModel(params: Params$Resource$Projects$Locations$Endpoints$Undeploymodel, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        undeployModel(params: Params$Resource$Projects$Locations$Endpoints$Undeploymodel, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        undeployModel(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
    }
    export interface Params$Resource$Projects$Locations$Endpoints$Create extends StandardParameters {
        /**
         * Immutable. The ID to use for endpoint, which will become the final component of the endpoint resource name. If not provided, Vertex AI will generate a value for this ID. If the first character is a letter, this value may be up to 63 characters, and valid characters are `[a-z0-9-]`. The last character must be a letter or number. If the first character is a number, this value may be up to 9 characters, and valid characters are `[0-9]` with no leading zeros. When using HTTP/JSON, this field is populated based on a query string argument, such as `?endpoint_id=12345`. This is the fallback for fields that are not included in either the URI or the body.
         */
        endpointId?: string;
        /**
         * Required. The resource name of the Location to create the Endpoint in. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1Endpoint;
    }
    export interface Params$Resource$Projects$Locations$Endpoints$Delete extends StandardParameters {
        /**
         * Required. The name of the Endpoint resource to be deleted. Format: `projects/{project\}/locations/{location\}/endpoints/{endpoint\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Endpoints$Deploymodel extends StandardParameters {
        /**
         * Required. The name of the Endpoint resource into which to deploy a Model. Format: `projects/{project\}/locations/{location\}/endpoints/{endpoint\}`
         */
        endpoint?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1DeployModelRequest;
    }
    export interface Params$Resource$Projects$Locations$Endpoints$Explain extends StandardParameters {
        /**
         * Required. The name of the Endpoint requested to serve the explanation. Format: `projects/{project\}/locations/{location\}/endpoints/{endpoint\}`
         */
        endpoint?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1ExplainRequest;
    }
    export interface Params$Resource$Projects$Locations$Endpoints$Get extends StandardParameters {
        /**
         * Required. The name of the Endpoint resource. Format: `projects/{project\}/locations/{location\}/endpoints/{endpoint\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Endpoints$List extends StandardParameters {
        /**
         * Optional. An expression for filtering the results of the request. For field names both snake_case and camelCase are supported. * `endpoint` supports = and !=. `endpoint` represents the Endpoint ID, i.e. the last segment of the Endpoint's resource name. * `display_name` supports = and, != * `labels` supports general map functions that is: * `labels.key=value` - key:value equality * `labels.key:* or labels:key - key existence * A key including a space must be quoted. `labels."a key"`. Some examples: * `endpoint=1` * `displayName="myDisplayName"` * `labels.myKey="myValue"`
         */
        filter?: string;
        /**
         * A comma-separated list of fields to order by, sorted in ascending order. Use "desc" after a field name for descending. Supported fields: * `display_name` * `create_time` * `update_time` Example: `display_name, create_time desc`.
         */
        orderBy?: string;
        /**
         * Optional. The standard list page size.
         */
        pageSize?: number;
        /**
         * Optional. The standard list page token. Typically obtained via ListEndpointsResponse.next_page_token of the previous EndpointService.ListEndpoints call.
         */
        pageToken?: string;
        /**
         * Required. The resource name of the Location from which to list the Endpoints. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Optional. Mask specifying which fields to read.
         */
        readMask?: string;
    }
    export interface Params$Resource$Projects$Locations$Endpoints$Mutatedeployedmodel extends StandardParameters {
        /**
         * Required. The name of the Endpoint resource into which to mutate a DeployedModel. Format: `projects/{project\}/locations/{location\}/endpoints/{endpoint\}`
         */
        endpoint?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1MutateDeployedModelRequest;
    }
    export interface Params$Resource$Projects$Locations$Endpoints$Patch extends StandardParameters {
        /**
         * Output only. The resource name of the Endpoint.
         */
        name?: string;
        /**
         * Required. The update mask applies to the resource. See google.protobuf.FieldMask.
         */
        updateMask?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1Endpoint;
    }
    export interface Params$Resource$Projects$Locations$Endpoints$Predict extends StandardParameters {
        /**
         * Required. The name of the Endpoint requested to serve the prediction. Format: `projects/{project\}/locations/{location\}/endpoints/{endpoint\}`
         */
        endpoint?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1PredictRequest;
    }
    export interface Params$Resource$Projects$Locations$Endpoints$Rawpredict extends StandardParameters {
        /**
         * Required. The name of the Endpoint requested to serve the prediction. Format: `projects/{project\}/locations/{location\}/endpoints/{endpoint\}`
         */
        endpoint?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1RawPredictRequest;
    }
    export interface Params$Resource$Projects$Locations$Endpoints$Serverstreamingpredict extends StandardParameters {
        /**
         * Required. The name of the Endpoint requested to serve the prediction. Format: `projects/{project\}/locations/{location\}/endpoints/{endpoint\}`
         */
        endpoint?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1StreamingPredictRequest;
    }
    export interface Params$Resource$Projects$Locations$Endpoints$Undeploymodel extends StandardParameters {
        /**
         * Required. The name of the Endpoint resource from which to undeploy a Model. Format: `projects/{project\}/locations/{location\}/endpoints/{endpoint\}`
         */
        endpoint?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1UndeployModelRequest;
    }
    export class Resource$Projects$Locations$Endpoints$Operations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to `Code.CANCELLED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Projects$Locations$Endpoints$Operations$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Projects$Locations$Endpoints$Operations$Cancel, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        cancel(params: Params$Resource$Projects$Locations$Endpoints$Operations$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Projects$Locations$Endpoints$Operations$Cancel, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(params: Params$Resource$Projects$Locations$Endpoints$Operations$Cancel, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Endpoints$Operations$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Endpoints$Operations$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        delete(params: Params$Resource$Projects$Locations$Endpoints$Operations$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Endpoints$Operations$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(params: Params$Resource$Projects$Locations$Endpoints$Operations$Delete, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Endpoints$Operations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Endpoints$Operations$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        get(params: Params$Resource$Projects$Locations$Endpoints$Operations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Endpoints$Operations$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(params: Params$Resource$Projects$Locations$Endpoints$Operations$Get, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns `UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Endpoints$Operations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Endpoints$Operations$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningListOperationsResponse>;
        list(params: Params$Resource$Projects$Locations$Endpoints$Operations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Endpoints$Operations$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Endpoints$Operations$List, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        /**
         * Waits until the specified long-running operation is done or reaches at most a specified timeout, returning the latest state. If the operation is already done, the latest state is immediately returned. If the timeout specified is greater than the default HTTP/RPC timeout, the HTTP/RPC timeout is used. If the server does not support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Note that this method is on a best-effort basis. It may return the latest state before the specified timeout (including immediately), meaning even an immediate response is no guarantee that the operation is done.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        wait(params: Params$Resource$Projects$Locations$Endpoints$Operations$Wait, options: StreamMethodOptions): GaxiosPromise<Readable>;
        wait(params?: Params$Resource$Projects$Locations$Endpoints$Operations$Wait, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        wait(params: Params$Resource$Projects$Locations$Endpoints$Operations$Wait, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        wait(params: Params$Resource$Projects$Locations$Endpoints$Operations$Wait, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(params: Params$Resource$Projects$Locations$Endpoints$Operations$Wait, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
    }
    export interface Params$Resource$Projects$Locations$Endpoints$Operations$Cancel extends StandardParameters {
        /**
         * The name of the operation resource to be cancelled.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Endpoints$Operations$Delete extends StandardParameters {
        /**
         * The name of the operation resource to be deleted.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Endpoints$Operations$Get extends StandardParameters {
        /**
         * The name of the operation resource.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Endpoints$Operations$List extends StandardParameters {
        /**
         * The standard list filter.
         */
        filter?: string;
        /**
         * The name of the operation's parent resource.
         */
        name?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token.
         */
        pageToken?: string;
    }
    export interface Params$Resource$Projects$Locations$Endpoints$Operations$Wait extends StandardParameters {
        /**
         * The name of the operation resource to wait on.
         */
        name?: string;
        /**
         * The maximum duration to wait before timing out. If left blank, the wait will be at most the time permitted by the underlying HTTP/RPC protocol. If RPC context deadline is also specified, the shorter one will be used.
         */
        timeout?: string;
    }
    export class Resource$Projects$Locations$Featurestores {
        context: APIRequestContext;
        entityTypes: Resource$Projects$Locations$Featurestores$Entitytypes;
        operations: Resource$Projects$Locations$Featurestores$Operations;
        constructor(context: APIRequestContext);
        /**
         * Batch reads Feature values from a Featurestore. This API enables batch reading Feature values, where each read instance in the batch may read Feature values of entities from one or more EntityTypes. Point-in-time correctness is guaranteed for Feature values of each read instance as of each instance's read timestamp.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        batchReadFeatureValues(params: Params$Resource$Projects$Locations$Featurestores$Batchreadfeaturevalues, options: StreamMethodOptions): GaxiosPromise<Readable>;
        batchReadFeatureValues(params?: Params$Resource$Projects$Locations$Featurestores$Batchreadfeaturevalues, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        batchReadFeatureValues(params: Params$Resource$Projects$Locations$Featurestores$Batchreadfeaturevalues, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        batchReadFeatureValues(params: Params$Resource$Projects$Locations$Featurestores$Batchreadfeaturevalues, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        batchReadFeatureValues(params: Params$Resource$Projects$Locations$Featurestores$Batchreadfeaturevalues, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        batchReadFeatureValues(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Creates a new Featurestore in a given project and location.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        create(params: Params$Resource$Projects$Locations$Featurestores$Create, options: StreamMethodOptions): GaxiosPromise<Readable>;
        create(params?: Params$Resource$Projects$Locations$Featurestores$Create, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        create(params: Params$Resource$Projects$Locations$Featurestores$Create, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        create(params: Params$Resource$Projects$Locations$Featurestores$Create, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        create(params: Params$Resource$Projects$Locations$Featurestores$Create, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        create(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Deletes a single Featurestore. The Featurestore must not contain any EntityTypes or `force` must be set to true for the request to succeed.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Featurestores$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Featurestores$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        delete(params: Params$Resource$Projects$Locations$Featurestores$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Featurestores$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(params: Params$Resource$Projects$Locations$Featurestores$Delete, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Gets details of a single Featurestore.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Featurestores$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Featurestores$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1Featurestore>;
        get(params: Params$Resource$Projects$Locations$Featurestores$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Featurestores$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1Featurestore>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Featurestore>): void;
        get(params: Params$Resource$Projects$Locations$Featurestores$Get, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Featurestore>): void;
        get(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Featurestore>): void;
        /**
         * Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getIamPolicy(params: Params$Resource$Projects$Locations$Featurestores$Getiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getIamPolicy(params?: Params$Resource$Projects$Locations$Featurestores$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$GoogleIamV1Policy>;
        getIamPolicy(params: Params$Resource$Projects$Locations$Featurestores$Getiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getIamPolicy(params: Params$Resource$Projects$Locations$Featurestores$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$GoogleIamV1Policy>, callback: BodyResponseCallback<Schema$GoogleIamV1Policy>): void;
        getIamPolicy(params: Params$Resource$Projects$Locations$Featurestores$Getiampolicy, callback: BodyResponseCallback<Schema$GoogleIamV1Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$GoogleIamV1Policy>): void;
        /**
         * Lists Featurestores in a given project and location.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Featurestores$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Featurestores$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListFeaturestoresResponse>;
        list(params: Params$Resource$Projects$Locations$Featurestores$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Featurestores$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListFeaturestoresResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListFeaturestoresResponse>): void;
        list(params: Params$Resource$Projects$Locations$Featurestores$List, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListFeaturestoresResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListFeaturestoresResponse>): void;
        /**
         * Updates the parameters of a single Featurestore.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Projects$Locations$Featurestores$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Projects$Locations$Featurestores$Patch, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        patch(params: Params$Resource$Projects$Locations$Featurestores$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Projects$Locations$Featurestores$Patch, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        patch(params: Params$Resource$Projects$Locations$Featurestores$Patch, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        patch(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Searches Features matching a query in a given project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        searchFeatures(params: Params$Resource$Projects$Locations$Featurestores$Searchfeatures, options: StreamMethodOptions): GaxiosPromise<Readable>;
        searchFeatures(params?: Params$Resource$Projects$Locations$Featurestores$Searchfeatures, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1SearchFeaturesResponse>;
        searchFeatures(params: Params$Resource$Projects$Locations$Featurestores$Searchfeatures, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        searchFeatures(params: Params$Resource$Projects$Locations$Featurestores$Searchfeatures, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1SearchFeaturesResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1SearchFeaturesResponse>): void;
        searchFeatures(params: Params$Resource$Projects$Locations$Featurestores$Searchfeatures, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1SearchFeaturesResponse>): void;
        searchFeatures(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1SearchFeaturesResponse>): void;
        /**
         * Sets the access control policy on the specified resource. Replaces any existing policy. Can return `NOT_FOUND`, `INVALID_ARGUMENT`, and `PERMISSION_DENIED` errors.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setIamPolicy(params: Params$Resource$Projects$Locations$Featurestores$Setiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setIamPolicy(params?: Params$Resource$Projects$Locations$Featurestores$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$GoogleIamV1Policy>;
        setIamPolicy(params: Params$Resource$Projects$Locations$Featurestores$Setiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setIamPolicy(params: Params$Resource$Projects$Locations$Featurestores$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$GoogleIamV1Policy>, callback: BodyResponseCallback<Schema$GoogleIamV1Policy>): void;
        setIamPolicy(params: Params$Resource$Projects$Locations$Featurestores$Setiampolicy, callback: BodyResponseCallback<Schema$GoogleIamV1Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$GoogleIamV1Policy>): void;
        /**
         * Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a `NOT_FOUND` error. Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may "fail open" without warning.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Projects$Locations$Featurestores$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Projects$Locations$Featurestores$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$GoogleIamV1TestIamPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Projects$Locations$Featurestores$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Projects$Locations$Featurestores$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$GoogleIamV1TestIamPermissionsResponse>, callback: BodyResponseCallback<Schema$GoogleIamV1TestIamPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Projects$Locations$Featurestores$Testiampermissions, callback: BodyResponseCallback<Schema$GoogleIamV1TestIamPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$GoogleIamV1TestIamPermissionsResponse>): void;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Batchreadfeaturevalues extends StandardParameters {
        /**
         * Required. The resource name of the Featurestore from which to query Feature values. Format: `projects/{project\}/locations/{location\}/featurestores/{featurestore\}`
         */
        featurestore?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1BatchReadFeatureValuesRequest;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Create extends StandardParameters {
        /**
         * Required. The ID to use for this Featurestore, which will become the final component of the Featurestore's resource name. This value may be up to 60 characters, and valid characters are `[a-z0-9_]`. The first character cannot be a number. The value must be unique within the project and location.
         */
        featurestoreId?: string;
        /**
         * Required. The resource name of the Location to create Featurestores. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1Featurestore;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Delete extends StandardParameters {
        /**
         * If set to true, any EntityTypes and Features for this Featurestore will also be deleted. (Otherwise, the request will only work if the Featurestore has no EntityTypes.)
         */
        force?: boolean;
        /**
         * Required. The name of the Featurestore to be deleted. Format: `projects/{project\}/locations/{location\}/featurestores/{featurestore\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Get extends StandardParameters {
        /**
         * Required. The name of the Featurestore resource.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Getiampolicy extends StandardParameters {
        /**
         * Optional. The maximum policy version that will be used to format the policy. Valid values are 0, 1, and 3. Requests specifying an invalid value will be rejected. Requests for policies with any conditional role bindings must specify version 3. Policies with no conditional role bindings may specify any valid value or leave the field unset. The policy in the response might use the policy version that you specified, or it might use a lower policy version. For example, if you specify version 3, but the policy has no conditional role bindings, the response uses version 1. To learn which resources support conditions in their IAM policies, see the [IAM documentation](https://cloud.google.com/iam/help/conditions/resource-policies).
         */
        'options.requestedPolicyVersion'?: number;
        /**
         * REQUIRED: The resource for which the policy is being requested. See [Resource names](https://cloud.google.com/apis/design/resource_names) for the appropriate value for this field.
         */
        resource?: string;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$List extends StandardParameters {
        /**
         * Lists the featurestores that match the filter expression. The following fields are supported: * `create_time`: Supports `=`, `!=`, `<`, `\>`, `<=`, and `\>=` comparisons. Values must be in RFC 3339 format. * `update_time`: Supports `=`, `!=`, `<`, `\>`, `<=`, and `\>=` comparisons. Values must be in RFC 3339 format. * `online_serving_config.fixed_node_count`: Supports `=`, `!=`, `<`, `\>`, `<=`, and `\>=` comparisons. * `labels`: Supports key-value equality and key presence. Examples: * `create_time \> "2020-01-01" OR update_time \> "2020-01-01"` Featurestores created or updated after 2020-01-01. * `labels.env = "prod"` Featurestores with label "env" set to "prod".
         */
        filter?: string;
        /**
         * A comma-separated list of fields to order by, sorted in ascending order. Use "desc" after a field name for descending. Supported Fields: * `create_time` * `update_time` * `online_serving_config.fixed_node_count`
         */
        orderBy?: string;
        /**
         * The maximum number of Featurestores to return. The service may return fewer than this value. If unspecified, at most 100 Featurestores will be returned. The maximum value is 100; any value greater than 100 will be coerced to 100.
         */
        pageSize?: number;
        /**
         * A page token, received from a previous FeaturestoreService.ListFeaturestores call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to FeaturestoreService.ListFeaturestores must match the call that provided the page token.
         */
        pageToken?: string;
        /**
         * Required. The resource name of the Location to list Featurestores. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Mask specifying which fields to read.
         */
        readMask?: string;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Patch extends StandardParameters {
        /**
         * Output only. Name of the Featurestore. Format: `projects/{project\}/locations/{location\}/featurestores/{featurestore\}`
         */
        name?: string;
        /**
         * Field mask is used to specify the fields to be overwritten in the Featurestore resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask. If the user does not provide a mask then only the non-empty fields present in the request will be overwritten. Set the update_mask to `*` to override all fields. Updatable fields: * `labels` * `online_serving_config.fixed_node_count` * `online_serving_config.scaling` * `online_storage_ttl_days`
         */
        updateMask?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1Featurestore;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Searchfeatures extends StandardParameters {
        /**
         * Required. The resource name of the Location to search Features. Format: `projects/{project\}/locations/{location\}`
         */
        location?: string;
        /**
         * The maximum number of Features to return. The service may return fewer than this value. If unspecified, at most 100 Features will be returned. The maximum value is 100; any value greater than 100 will be coerced to 100.
         */
        pageSize?: number;
        /**
         * A page token, received from a previous FeaturestoreService.SearchFeatures call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to FeaturestoreService.SearchFeatures, except `page_size`, must match the call that provided the page token.
         */
        pageToken?: string;
        /**
         * Query string that is a conjunction of field-restricted queries and/or field-restricted filters. Field-restricted queries and filters can be combined using `AND` to form a conjunction. A field query is in the form FIELD:QUERY. This implicitly checks if QUERY exists as a substring within Feature's FIELD. The QUERY and the FIELD are converted to a sequence of words (i.e. tokens) for comparison. This is done by: * Removing leading/trailing whitespace and tokenizing the search value. Characters that are not one of alphanumeric `[a-zA-Z0-9]`, underscore `_`, or asterisk `*` are treated as delimiters for tokens. `*` is treated as a wildcard that matches characters within a token. * Ignoring case. * Prepending an asterisk to the first and appending an asterisk to the last token in QUERY. A QUERY must be either a singular token or a phrase. A phrase is one or multiple words enclosed in double quotation marks ("). With phrases, the order of the words is important. Words in the phrase must be matching in order and consecutively. Supported FIELDs for field-restricted queries: * `feature_id` * `description` * `entity_type_id` Examples: * `feature_id: foo` --\> Matches a Feature with ID containing the substring `foo` (eg. `foo`, `foofeature`, `barfoo`). * `feature_id: foo*feature` --\> Matches a Feature with ID containing the substring `foo*feature` (eg. `foobarfeature`). * `feature_id: foo AND description: bar` --\> Matches a Feature with ID containing the substring `foo` and description containing the substring `bar`. Besides field queries, the following exact-match filters are supported. The exact-match filters do not support wildcards. Unlike field-restricted queries, exact-match filters are case-sensitive. * `feature_id`: Supports = comparisons. * `description`: Supports = comparisons. Multi-token filters should be enclosed in quotes. * `entity_type_id`: Supports = comparisons. * `value_type`: Supports = and != comparisons. * `labels`: Supports key-value equality as well as key presence. * `featurestore_id`: Supports = comparisons. Examples: * `description = "foo bar"` --\> Any Feature with description exactly equal to `foo bar` * `value_type = DOUBLE` --\> Features whose type is DOUBLE. * `labels.active = yes AND labels.env = prod` --\> Features having both (active: yes) and (env: prod) labels. * `labels.env: *` --\> Any Feature which has a label with `env` as the key.
         */
        query?: string;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Setiampolicy extends StandardParameters {
        /**
         * REQUIRED: The resource for which the policy is being specified. See [Resource names](https://cloud.google.com/apis/design/resource_names) for the appropriate value for this field.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleIamV1SetIamPolicyRequest;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Testiampermissions extends StandardParameters {
        /**
         * The set of permissions to check for the `resource`. Permissions with wildcards (such as `*` or `storage.*`) are not allowed. For more information see [IAM Overview](https://cloud.google.com/iam/docs/overview#permissions).
         */
        permissions?: string[];
        /**
         * REQUIRED: The resource for which the policy detail is being requested. See [Resource names](https://cloud.google.com/apis/design/resource_names) for the appropriate value for this field.
         */
        resource?: string;
    }
    export class Resource$Projects$Locations$Featurestores$Entitytypes {
        context: APIRequestContext;
        features: Resource$Projects$Locations$Featurestores$Entitytypes$Features;
        operations: Resource$Projects$Locations$Featurestores$Entitytypes$Operations;
        constructor(context: APIRequestContext);
        /**
         * Creates a new EntityType in a given Featurestore.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        create(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Create, options: StreamMethodOptions): GaxiosPromise<Readable>;
        create(params?: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Create, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        create(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Create, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        create(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Create, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        create(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Create, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        create(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Deletes a single EntityType. The EntityType must not have any Features or `force` must be set to true for the request to succeed.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        delete(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Delete, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Delete Feature values from Featurestore. The progress of the deletion is tracked by the returned operation. The deleted feature values are guaranteed to be invisible to subsequent read operations after the operation is marked as successfully done. If a delete feature values operation fails, the feature values returned from reads and exports may be inconsistent. If consistency is required, the caller must retry the same delete request again and wait till the new operation returned is marked as successfully done.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        deleteFeatureValues(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Deletefeaturevalues, options: StreamMethodOptions): GaxiosPromise<Readable>;
        deleteFeatureValues(params?: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Deletefeaturevalues, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        deleteFeatureValues(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Deletefeaturevalues, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        deleteFeatureValues(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Deletefeaturevalues, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        deleteFeatureValues(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Deletefeaturevalues, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        deleteFeatureValues(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Exports Feature values from all the entities of a target EntityType.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        exportFeatureValues(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Exportfeaturevalues, options: StreamMethodOptions): GaxiosPromise<Readable>;
        exportFeatureValues(params?: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Exportfeaturevalues, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        exportFeatureValues(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Exportfeaturevalues, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        exportFeatureValues(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Exportfeaturevalues, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        exportFeatureValues(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Exportfeaturevalues, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        exportFeatureValues(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Gets details of a single EntityType.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1EntityType>;
        get(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1EntityType>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1EntityType>): void;
        get(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Get, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1EntityType>): void;
        get(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1EntityType>): void;
        /**
         * Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getIamPolicy(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Getiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getIamPolicy(params?: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$GoogleIamV1Policy>;
        getIamPolicy(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Getiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getIamPolicy(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$GoogleIamV1Policy>, callback: BodyResponseCallback<Schema$GoogleIamV1Policy>): void;
        getIamPolicy(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Getiampolicy, callback: BodyResponseCallback<Schema$GoogleIamV1Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$GoogleIamV1Policy>): void;
        /**
         * Imports Feature values into the Featurestore from a source storage. The progress of the import is tracked by the returned operation. The imported features are guaranteed to be visible to subsequent read operations after the operation is marked as successfully done. If an import operation fails, the Feature values returned from reads and exports may be inconsistent. If consistency is required, the caller must retry the same import request again and wait till the new operation returned is marked as successfully done. There are also scenarios where the caller can cause inconsistency. - Source data for import contains multiple distinct Feature values for the same entity ID and timestamp. - Source is modified during an import. This includes adding, updating, or removing source data and/or metadata. Examples of updating metadata include but are not limited to changing storage location, storage class, or retention policy. - Online serving cluster is under-provisioned.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        importFeatureValues(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Importfeaturevalues, options: StreamMethodOptions): GaxiosPromise<Readable>;
        importFeatureValues(params?: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Importfeaturevalues, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        importFeatureValues(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Importfeaturevalues, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        importFeatureValues(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Importfeaturevalues, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        importFeatureValues(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Importfeaturevalues, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        importFeatureValues(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Lists EntityTypes in a given Featurestore.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Featurestores$Entitytypes$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListEntityTypesResponse>;
        list(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListEntityTypesResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListEntityTypesResponse>): void;
        list(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$List, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListEntityTypesResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListEntityTypesResponse>): void;
        /**
         * Updates the parameters of a single EntityType.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Patch, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1EntityType>;
        patch(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Patch, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1EntityType>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1EntityType>): void;
        patch(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Patch, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1EntityType>): void;
        patch(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1EntityType>): void;
        /**
         * Reads Feature values of a specific entity of an EntityType. For reading feature values of multiple entities of an EntityType, please use StreamingReadFeatureValues.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        readFeatureValues(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Readfeaturevalues, options: StreamMethodOptions): GaxiosPromise<Readable>;
        readFeatureValues(params?: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Readfeaturevalues, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ReadFeatureValuesResponse>;
        readFeatureValues(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Readfeaturevalues, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        readFeatureValues(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Readfeaturevalues, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ReadFeatureValuesResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ReadFeatureValuesResponse>): void;
        readFeatureValues(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Readfeaturevalues, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ReadFeatureValuesResponse>): void;
        readFeatureValues(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ReadFeatureValuesResponse>): void;
        /**
         * Sets the access control policy on the specified resource. Replaces any existing policy. Can return `NOT_FOUND`, `INVALID_ARGUMENT`, and `PERMISSION_DENIED` errors.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setIamPolicy(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Setiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setIamPolicy(params?: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$GoogleIamV1Policy>;
        setIamPolicy(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Setiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setIamPolicy(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$GoogleIamV1Policy>, callback: BodyResponseCallback<Schema$GoogleIamV1Policy>): void;
        setIamPolicy(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Setiampolicy, callback: BodyResponseCallback<Schema$GoogleIamV1Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$GoogleIamV1Policy>): void;
        /**
         * Reads Feature values for multiple entities. Depending on their size, data for different entities may be broken up across multiple responses.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        streamingReadFeatureValues(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Streamingreadfeaturevalues, options: StreamMethodOptions): GaxiosPromise<Readable>;
        streamingReadFeatureValues(params?: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Streamingreadfeaturevalues, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ReadFeatureValuesResponse>;
        streamingReadFeatureValues(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Streamingreadfeaturevalues, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        streamingReadFeatureValues(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Streamingreadfeaturevalues, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ReadFeatureValuesResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ReadFeatureValuesResponse>): void;
        streamingReadFeatureValues(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Streamingreadfeaturevalues, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ReadFeatureValuesResponse>): void;
        streamingReadFeatureValues(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ReadFeatureValuesResponse>): void;
        /**
         * Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a `NOT_FOUND` error. Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may "fail open" without warning.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$GoogleIamV1TestIamPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$GoogleIamV1TestIamPermissionsResponse>, callback: BodyResponseCallback<Schema$GoogleIamV1TestIamPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Testiampermissions, callback: BodyResponseCallback<Schema$GoogleIamV1TestIamPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$GoogleIamV1TestIamPermissionsResponse>): void;
        /**
         * Writes Feature values of one or more entities of an EntityType. The Feature values are merged into existing entities if any. The Feature values to be written must have timestamp within the online storage retention.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        writeFeatureValues(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Writefeaturevalues, options: StreamMethodOptions): GaxiosPromise<Readable>;
        writeFeatureValues(params?: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Writefeaturevalues, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1WriteFeatureValuesResponse>;
        writeFeatureValues(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Writefeaturevalues, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        writeFeatureValues(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Writefeaturevalues, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1WriteFeatureValuesResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1WriteFeatureValuesResponse>): void;
        writeFeatureValues(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Writefeaturevalues, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1WriteFeatureValuesResponse>): void;
        writeFeatureValues(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1WriteFeatureValuesResponse>): void;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Entitytypes$Create extends StandardParameters {
        /**
         * Required. The ID to use for the EntityType, which will become the final component of the EntityType's resource name. This value may be up to 60 characters, and valid characters are `[a-z0-9_]`. The first character cannot be a number. The value must be unique within a featurestore.
         */
        entityTypeId?: string;
        /**
         * Required. The resource name of the Featurestore to create EntityTypes. Format: `projects/{project\}/locations/{location\}/featurestores/{featurestore\}`
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1EntityType;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Entitytypes$Delete extends StandardParameters {
        /**
         * If set to true, any Features for this EntityType will also be deleted. (Otherwise, the request will only work if the EntityType has no Features.)
         */
        force?: boolean;
        /**
         * Required. The name of the EntityType to be deleted. Format: `projects/{project\}/locations/{location\}/featurestores/{featurestore\}/entityTypes/{entity_type\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Entitytypes$Deletefeaturevalues extends StandardParameters {
        /**
         * Required. The resource name of the EntityType grouping the Features for which values are being deleted from. Format: `projects/{project\}/locations/{location\}/featurestores/{featurestore\}/entityTypes/{entityType\}`
         */
        entityType?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1DeleteFeatureValuesRequest;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Entitytypes$Exportfeaturevalues extends StandardParameters {
        /**
         * Required. The resource name of the EntityType from which to export Feature values. Format: `projects/{project\}/locations/{location\}/featurestores/{featurestore\}/entityTypes/{entity_type\}`
         */
        entityType?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1ExportFeatureValuesRequest;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Entitytypes$Get extends StandardParameters {
        /**
         * Required. The name of the EntityType resource. Format: `projects/{project\}/locations/{location\}/featurestores/{featurestore\}/entityTypes/{entity_type\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Entitytypes$Getiampolicy extends StandardParameters {
        /**
         * Optional. The maximum policy version that will be used to format the policy. Valid values are 0, 1, and 3. Requests specifying an invalid value will be rejected. Requests for policies with any conditional role bindings must specify version 3. Policies with no conditional role bindings may specify any valid value or leave the field unset. The policy in the response might use the policy version that you specified, or it might use a lower policy version. For example, if you specify version 3, but the policy has no conditional role bindings, the response uses version 1. To learn which resources support conditions in their IAM policies, see the [IAM documentation](https://cloud.google.com/iam/help/conditions/resource-policies).
         */
        'options.requestedPolicyVersion'?: number;
        /**
         * REQUIRED: The resource for which the policy is being requested. See [Resource names](https://cloud.google.com/apis/design/resource_names) for the appropriate value for this field.
         */
        resource?: string;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Entitytypes$Importfeaturevalues extends StandardParameters {
        /**
         * Required. The resource name of the EntityType grouping the Features for which values are being imported. Format: `projects/{project\}/locations/{location\}/featurestores/{featurestore\}/entityTypes/{entityType\}`
         */
        entityType?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1ImportFeatureValuesRequest;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Entitytypes$List extends StandardParameters {
        /**
         * Lists the EntityTypes that match the filter expression. The following filters are supported: * `create_time`: Supports `=`, `!=`, `<`, `\>`, `\>=`, and `<=` comparisons. Values must be in RFC 3339 format. * `update_time`: Supports `=`, `!=`, `<`, `\>`, `\>=`, and `<=` comparisons. Values must be in RFC 3339 format. * `labels`: Supports key-value equality as well as key presence. Examples: * `create_time \> \"2020-01-31T15:30:00.000000Z\" OR update_time \> \"2020-01-31T15:30:00.000000Z\"` --\> EntityTypes created or updated after 2020-01-31T15:30:00.000000Z. * `labels.active = yes AND labels.env = prod` --\> EntityTypes having both (active: yes) and (env: prod) labels. * `labels.env: *` --\> Any EntityType which has a label with 'env' as the key.
         */
        filter?: string;
        /**
         * A comma-separated list of fields to order by, sorted in ascending order. Use "desc" after a field name for descending. Supported fields: * `entity_type_id` * `create_time` * `update_time`
         */
        orderBy?: string;
        /**
         * The maximum number of EntityTypes to return. The service may return fewer than this value. If unspecified, at most 1000 EntityTypes will be returned. The maximum value is 1000; any value greater than 1000 will be coerced to 1000.
         */
        pageSize?: number;
        /**
         * A page token, received from a previous FeaturestoreService.ListEntityTypes call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to FeaturestoreService.ListEntityTypes must match the call that provided the page token.
         */
        pageToken?: string;
        /**
         * Required. The resource name of the Featurestore to list EntityTypes. Format: `projects/{project\}/locations/{location\}/featurestores/{featurestore\}`
         */
        parent?: string;
        /**
         * Mask specifying which fields to read.
         */
        readMask?: string;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Entitytypes$Patch extends StandardParameters {
        /**
         * Immutable. Name of the EntityType. Format: `projects/{project\}/locations/{location\}/featurestores/{featurestore\}/entityTypes/{entity_type\}` The last part entity_type is assigned by the client. The entity_type can be up to 64 characters long and can consist only of ASCII Latin letters A-Z and a-z and underscore(_), and ASCII digits 0-9 starting with a letter. The value will be unique given a featurestore.
         */
        name?: string;
        /**
         * Field mask is used to specify the fields to be overwritten in the EntityType resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask. If the user does not provide a mask then only the non-empty fields present in the request will be overwritten. Set the update_mask to `*` to override all fields. Updatable fields: * `description` * `labels` * `monitoring_config.snapshot_analysis.disabled` * `monitoring_config.snapshot_analysis.monitoring_interval_days` * `monitoring_config.snapshot_analysis.staleness_days` * `monitoring_config.import_features_analysis.state` * `monitoring_config.import_features_analysis.anomaly_detection_baseline` * `monitoring_config.numerical_threshold_config.value` * `monitoring_config.categorical_threshold_config.value` * `offline_storage_ttl_days`
         */
        updateMask?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1EntityType;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Entitytypes$Readfeaturevalues extends StandardParameters {
        /**
         * Required. The resource name of the EntityType for the entity being read. Value format: `projects/{project\}/locations/{location\}/featurestores/{featurestore\}/entityTypes/{entityType\}`. For example, for a machine learning model predicting user clicks on a website, an EntityType ID could be `user`.
         */
        entityType?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1ReadFeatureValuesRequest;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Entitytypes$Setiampolicy extends StandardParameters {
        /**
         * REQUIRED: The resource for which the policy is being specified. See [Resource names](https://cloud.google.com/apis/design/resource_names) for the appropriate value for this field.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleIamV1SetIamPolicyRequest;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Entitytypes$Streamingreadfeaturevalues extends StandardParameters {
        /**
         * Required. The resource name of the entities' type. Value format: `projects/{project\}/locations/{location\}/featurestores/{featurestore\}/entityTypes/{entityType\}`. For example, for a machine learning model predicting user clicks on a website, an EntityType ID could be `user`.
         */
        entityType?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1StreamingReadFeatureValuesRequest;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Entitytypes$Testiampermissions extends StandardParameters {
        /**
         * The set of permissions to check for the `resource`. Permissions with wildcards (such as `*` or `storage.*`) are not allowed. For more information see [IAM Overview](https://cloud.google.com/iam/docs/overview#permissions).
         */
        permissions?: string[];
        /**
         * REQUIRED: The resource for which the policy detail is being requested. See [Resource names](https://cloud.google.com/apis/design/resource_names) for the appropriate value for this field.
         */
        resource?: string;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Entitytypes$Writefeaturevalues extends StandardParameters {
        /**
         * Required. The resource name of the EntityType for the entities being written. Value format: `projects/{project\}/locations/{location\}/featurestores/ {featurestore\}/entityTypes/{entityType\}`. For example, for a machine learning model predicting user clicks on a website, an EntityType ID could be `user`.
         */
        entityType?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1WriteFeatureValuesRequest;
    }
    export class Resource$Projects$Locations$Featurestores$Entitytypes$Features {
        context: APIRequestContext;
        operations: Resource$Projects$Locations$Featurestores$Entitytypes$Features$Operations;
        constructor(context: APIRequestContext);
        /**
         * Creates a batch of Features in a given EntityType.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        batchCreate(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Batchcreate, options: StreamMethodOptions): GaxiosPromise<Readable>;
        batchCreate(params?: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Batchcreate, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        batchCreate(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Batchcreate, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        batchCreate(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Batchcreate, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        batchCreate(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Batchcreate, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        batchCreate(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Creates a new Feature in a given EntityType.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        create(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Create, options: StreamMethodOptions): GaxiosPromise<Readable>;
        create(params?: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Create, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        create(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Create, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        create(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Create, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        create(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Create, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        create(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Deletes a single Feature.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        delete(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Delete, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Gets details of a single Feature.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1Feature>;
        get(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1Feature>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Feature>): void;
        get(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Get, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Feature>): void;
        get(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Feature>): void;
        /**
         * Lists Features in a given EntityType.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListFeaturesResponse>;
        list(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListFeaturesResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListFeaturesResponse>): void;
        list(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$List, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListFeaturesResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListFeaturesResponse>): void;
        /**
         * Updates the parameters of a single Feature.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Patch, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1Feature>;
        patch(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Patch, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1Feature>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Feature>): void;
        patch(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Patch, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Feature>): void;
        patch(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Feature>): void;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Batchcreate extends StandardParameters {
        /**
         * Required. The resource name of the EntityType to create the batch of Features under. Format: `projects/{project\}/locations/{location\}/featurestores/{featurestore\}/entityTypes/{entity_type\}`
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1BatchCreateFeaturesRequest;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Create extends StandardParameters {
        /**
         * Required. The ID to use for the Feature, which will become the final component of the Feature's resource name. This value may be up to 128 characters, and valid characters are `[a-z0-9_]`. The first character cannot be a number. The value must be unique within an EntityType/FeatureGroup.
         */
        featureId?: string;
        /**
         *
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1Feature;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Delete extends StandardParameters {
        /**
         * Required. The name of the Features to be deleted. Format: `projects/{project\}/locations/{location\}/featurestores/{featurestore\}/entityTypes/{entity_type\}/features/{feature\}` `projects/{project\}/locations/{location\}/featureGroups/{feature_group\}/features/{feature\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Get extends StandardParameters {
        /**
         * Required. The name of the Feature resource. Format: `projects/{project\}/locations/{location\}/featurestores/{featurestore\}/entityTypes/{entity_type\}` `projects/{project\}/locations/{location\}/featureGroups/{feature_group\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$List extends StandardParameters {
        /**
         * Lists the Features that match the filter expression. The following filters are supported: * `value_type`: Supports = and != comparisons. * `create_time`: Supports =, !=, <, \>, \>=, and <= comparisons. Values must be in RFC 3339 format. * `update_time`: Supports =, !=, <, \>, \>=, and <= comparisons. Values must be in RFC 3339 format. * `labels`: Supports key-value equality as well as key presence. Examples: * `value_type = DOUBLE` --\> Features whose type is DOUBLE. * `create_time \> \"2020-01-31T15:30:00.000000Z\" OR update_time \> \"2020-01-31T15:30:00.000000Z\"` --\> EntityTypes created or updated after 2020-01-31T15:30:00.000000Z. * `labels.active = yes AND labels.env = prod` --\> Features having both (active: yes) and (env: prod) labels. * `labels.env: *` --\> Any Feature which has a label with 'env' as the key.
         */
        filter?: string;
        /**
         * If set, return the most recent ListFeaturesRequest.latest_stats_count of stats for each Feature in response. Valid value is [0, 10]. If number of stats exists < ListFeaturesRequest.latest_stats_count, return all existing stats.
         */
        latestStatsCount?: number;
        /**
         * A comma-separated list of fields to order by, sorted in ascending order. Use "desc" after a field name for descending. Supported fields: * `feature_id` * `value_type` (Not supported for FeatureRegistry Feature) * `create_time` * `update_time`
         */
        orderBy?: string;
        /**
         * The maximum number of Features to return. The service may return fewer than this value. If unspecified, at most 1000 Features will be returned. The maximum value is 1000; any value greater than 1000 will be coerced to 1000.
         */
        pageSize?: number;
        /**
         * A page token, received from a previous FeaturestoreService.ListFeatures call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to FeaturestoreService.ListFeatures must match the call that provided the page token.
         */
        pageToken?: string;
        /**
         * Required. The resource name of the Location to list Features. Format: `projects/{project\}/locations/{location\}/featurestores/{featurestore\}/entityTypes/{entity_type\}` `projects/{project\}/locations/{location\}/featureGroups/{feature_group\}`
         */
        parent?: string;
        /**
         * Mask specifying which fields to read.
         */
        readMask?: string;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Patch extends StandardParameters {
        /**
         * Immutable. Name of the Feature. Format: `projects/{project\}/locations/{location\}/featurestores/{featurestore\}/entityTypes/{entity_type\}/features/{feature\}` The last part feature is assigned by the client. The feature can be up to 64 characters long and can consist only of ASCII Latin letters A-Z and a-z, underscore(_), and ASCII digits 0-9 starting with a letter. The value will be unique given an entity type.
         */
        name?: string;
        /**
         * Field mask is used to specify the fields to be overwritten in the Features resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask. If the user does not provide a mask then only the non-empty fields present in the request will be overwritten. Set the update_mask to `*` to override all fields. Updatable fields: * `description` * `labels` * `disable_monitoring`
         */
        updateMask?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1Feature;
    }
    export class Resource$Projects$Locations$Featurestores$Entitytypes$Features$Operations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to `Code.CANCELLED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Operations$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Operations$Cancel, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        cancel(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Operations$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Operations$Cancel, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Operations$Cancel, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Operations$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Operations$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        delete(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Operations$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Operations$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Operations$Delete, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Operations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Operations$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        get(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Operations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Operations$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Operations$Get, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns `UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Operations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Operations$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningListOperationsResponse>;
        list(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Operations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Operations$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Operations$List, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        /**
         * Waits until the specified long-running operation is done or reaches at most a specified timeout, returning the latest state. If the operation is already done, the latest state is immediately returned. If the timeout specified is greater than the default HTTP/RPC timeout, the HTTP/RPC timeout is used. If the server does not support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Note that this method is on a best-effort basis. It may return the latest state before the specified timeout (including immediately), meaning even an immediate response is no guarantee that the operation is done.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        wait(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Operations$Wait, options: StreamMethodOptions): GaxiosPromise<Readable>;
        wait(params?: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Operations$Wait, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        wait(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Operations$Wait, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        wait(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Operations$Wait, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Operations$Wait, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Operations$Cancel extends StandardParameters {
        /**
         * The name of the operation resource to be cancelled.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Operations$Delete extends StandardParameters {
        /**
         * The name of the operation resource to be deleted.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Operations$Get extends StandardParameters {
        /**
         * The name of the operation resource.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Operations$List extends StandardParameters {
        /**
         * The standard list filter.
         */
        filter?: string;
        /**
         * The name of the operation's parent resource.
         */
        name?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token.
         */
        pageToken?: string;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Entitytypes$Features$Operations$Wait extends StandardParameters {
        /**
         * The name of the operation resource to wait on.
         */
        name?: string;
        /**
         * The maximum duration to wait before timing out. If left blank, the wait will be at most the time permitted by the underlying HTTP/RPC protocol. If RPC context deadline is also specified, the shorter one will be used.
         */
        timeout?: string;
    }
    export class Resource$Projects$Locations$Featurestores$Entitytypes$Operations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to `Code.CANCELLED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Operations$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Operations$Cancel, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        cancel(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Operations$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Operations$Cancel, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Operations$Cancel, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Operations$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Operations$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        delete(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Operations$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Operations$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Operations$Delete, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Operations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Operations$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        get(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Operations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Operations$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Operations$Get, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns `UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Operations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Operations$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningListOperationsResponse>;
        list(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Operations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Operations$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Operations$List, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        /**
         * Waits until the specified long-running operation is done or reaches at most a specified timeout, returning the latest state. If the operation is already done, the latest state is immediately returned. If the timeout specified is greater than the default HTTP/RPC timeout, the HTTP/RPC timeout is used. If the server does not support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Note that this method is on a best-effort basis. It may return the latest state before the specified timeout (including immediately), meaning even an immediate response is no guarantee that the operation is done.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        wait(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Operations$Wait, options: StreamMethodOptions): GaxiosPromise<Readable>;
        wait(params?: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Operations$Wait, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        wait(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Operations$Wait, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        wait(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Operations$Wait, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(params: Params$Resource$Projects$Locations$Featurestores$Entitytypes$Operations$Wait, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Entitytypes$Operations$Cancel extends StandardParameters {
        /**
         * The name of the operation resource to be cancelled.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Entitytypes$Operations$Delete extends StandardParameters {
        /**
         * The name of the operation resource to be deleted.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Entitytypes$Operations$Get extends StandardParameters {
        /**
         * The name of the operation resource.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Entitytypes$Operations$List extends StandardParameters {
        /**
         * The standard list filter.
         */
        filter?: string;
        /**
         * The name of the operation's parent resource.
         */
        name?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token.
         */
        pageToken?: string;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Entitytypes$Operations$Wait extends StandardParameters {
        /**
         * The name of the operation resource to wait on.
         */
        name?: string;
        /**
         * The maximum duration to wait before timing out. If left blank, the wait will be at most the time permitted by the underlying HTTP/RPC protocol. If RPC context deadline is also specified, the shorter one will be used.
         */
        timeout?: string;
    }
    export class Resource$Projects$Locations$Featurestores$Operations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to `Code.CANCELLED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Projects$Locations$Featurestores$Operations$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Projects$Locations$Featurestores$Operations$Cancel, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        cancel(params: Params$Resource$Projects$Locations$Featurestores$Operations$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Projects$Locations$Featurestores$Operations$Cancel, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(params: Params$Resource$Projects$Locations$Featurestores$Operations$Cancel, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Featurestores$Operations$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Featurestores$Operations$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        delete(params: Params$Resource$Projects$Locations$Featurestores$Operations$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Featurestores$Operations$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(params: Params$Resource$Projects$Locations$Featurestores$Operations$Delete, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Featurestores$Operations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Featurestores$Operations$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        get(params: Params$Resource$Projects$Locations$Featurestores$Operations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Featurestores$Operations$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(params: Params$Resource$Projects$Locations$Featurestores$Operations$Get, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns `UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Featurestores$Operations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Featurestores$Operations$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningListOperationsResponse>;
        list(params: Params$Resource$Projects$Locations$Featurestores$Operations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Featurestores$Operations$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Featurestores$Operations$List, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        /**
         * Waits until the specified long-running operation is done or reaches at most a specified timeout, returning the latest state. If the operation is already done, the latest state is immediately returned. If the timeout specified is greater than the default HTTP/RPC timeout, the HTTP/RPC timeout is used. If the server does not support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Note that this method is on a best-effort basis. It may return the latest state before the specified timeout (including immediately), meaning even an immediate response is no guarantee that the operation is done.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        wait(params: Params$Resource$Projects$Locations$Featurestores$Operations$Wait, options: StreamMethodOptions): GaxiosPromise<Readable>;
        wait(params?: Params$Resource$Projects$Locations$Featurestores$Operations$Wait, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        wait(params: Params$Resource$Projects$Locations$Featurestores$Operations$Wait, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        wait(params: Params$Resource$Projects$Locations$Featurestores$Operations$Wait, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(params: Params$Resource$Projects$Locations$Featurestores$Operations$Wait, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Operations$Cancel extends StandardParameters {
        /**
         * The name of the operation resource to be cancelled.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Operations$Delete extends StandardParameters {
        /**
         * The name of the operation resource to be deleted.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Operations$Get extends StandardParameters {
        /**
         * The name of the operation resource.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Operations$List extends StandardParameters {
        /**
         * The standard list filter.
         */
        filter?: string;
        /**
         * The name of the operation's parent resource.
         */
        name?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token.
         */
        pageToken?: string;
    }
    export interface Params$Resource$Projects$Locations$Featurestores$Operations$Wait extends StandardParameters {
        /**
         * The name of the operation resource to wait on.
         */
        name?: string;
        /**
         * The maximum duration to wait before timing out. If left blank, the wait will be at most the time permitted by the underlying HTTP/RPC protocol. If RPC context deadline is also specified, the shorter one will be used.
         */
        timeout?: string;
    }
    export class Resource$Projects$Locations$Hyperparametertuningjobs {
        context: APIRequestContext;
        operations: Resource$Projects$Locations$Hyperparametertuningjobs$Operations;
        constructor(context: APIRequestContext);
        /**
         * Cancels a HyperparameterTuningJob. Starts asynchronous cancellation on the HyperparameterTuningJob. The server makes a best effort to cancel the job, but success is not guaranteed. Clients can use JobService.GetHyperparameterTuningJob or other methods to check whether the cancellation succeeded or whether the job completed despite cancellation. On successful cancellation, the HyperparameterTuningJob is not deleted; instead it becomes a job with a HyperparameterTuningJob.error value with a google.rpc.Status.code of 1, corresponding to `Code.CANCELLED`, and HyperparameterTuningJob.state is set to `CANCELLED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Cancel, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        cancel(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Cancel, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Cancel, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Creates a HyperparameterTuningJob
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        create(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Create, options: StreamMethodOptions): GaxiosPromise<Readable>;
        create(params?: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Create, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1HyperparameterTuningJob>;
        create(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Create, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        create(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Create, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1HyperparameterTuningJob>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1HyperparameterTuningJob>): void;
        create(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Create, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1HyperparameterTuningJob>): void;
        create(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1HyperparameterTuningJob>): void;
        /**
         * Deletes a HyperparameterTuningJob.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        delete(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Delete, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Gets a HyperparameterTuningJob
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1HyperparameterTuningJob>;
        get(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1HyperparameterTuningJob>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1HyperparameterTuningJob>): void;
        get(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Get, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1HyperparameterTuningJob>): void;
        get(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1HyperparameterTuningJob>): void;
        /**
         * Lists HyperparameterTuningJobs in a Location.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Hyperparametertuningjobs$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListHyperparameterTuningJobsResponse>;
        list(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListHyperparameterTuningJobsResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListHyperparameterTuningJobsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$List, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListHyperparameterTuningJobsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListHyperparameterTuningJobsResponse>): void;
    }
    export interface Params$Resource$Projects$Locations$Hyperparametertuningjobs$Cancel extends StandardParameters {
        /**
         * Required. The name of the HyperparameterTuningJob to cancel. Format: `projects/{project\}/locations/{location\}/hyperparameterTuningJobs/{hyperparameter_tuning_job\}`
         */
        name?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1CancelHyperparameterTuningJobRequest;
    }
    export interface Params$Resource$Projects$Locations$Hyperparametertuningjobs$Create extends StandardParameters {
        /**
         * Required. The resource name of the Location to create the HyperparameterTuningJob in. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1HyperparameterTuningJob;
    }
    export interface Params$Resource$Projects$Locations$Hyperparametertuningjobs$Delete extends StandardParameters {
        /**
         * Required. The name of the HyperparameterTuningJob resource to be deleted. Format: `projects/{project\}/locations/{location\}/hyperparameterTuningJobs/{hyperparameter_tuning_job\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Hyperparametertuningjobs$Get extends StandardParameters {
        /**
         * Required. The name of the HyperparameterTuningJob resource. Format: `projects/{project\}/locations/{location\}/hyperparameterTuningJobs/{hyperparameter_tuning_job\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Hyperparametertuningjobs$List extends StandardParameters {
        /**
         * The standard list filter. Supported fields: * `display_name` supports `=`, `!=` comparisons, and `:` wildcard. * `state` supports `=`, `!=` comparisons. * `create_time` supports `=`, `!=`,`<`, `<=`,`\>`, `\>=` comparisons. `create_time` must be in RFC 3339 format. * `labels` supports general map functions that is: `labels.key=value` - key:value equality `labels.key:* - key existence Some examples of using the filter are: * `state="JOB_STATE_SUCCEEDED" AND display_name:"my_job_*"` * `state!="JOB_STATE_FAILED" OR display_name="my_job"` * `NOT display_name="my_job"` * `create_time\>"2021-05-18T00:00:00Z"` * `labels.keyA=valueA` * `labels.keyB:*`
         */
        filter?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token. Typically obtained via ListHyperparameterTuningJobsResponse.next_page_token of the previous JobService.ListHyperparameterTuningJobs call.
         */
        pageToken?: string;
        /**
         * Required. The resource name of the Location to list the HyperparameterTuningJobs from. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Mask specifying which fields to read.
         */
        readMask?: string;
    }
    export class Resource$Projects$Locations$Hyperparametertuningjobs$Operations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to `Code.CANCELLED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Operations$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Operations$Cancel, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        cancel(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Operations$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Operations$Cancel, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Operations$Cancel, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Operations$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Operations$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        delete(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Operations$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Operations$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Operations$Delete, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Operations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Operations$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        get(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Operations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Operations$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Operations$Get, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns `UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Operations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Operations$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningListOperationsResponse>;
        list(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Operations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Operations$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Operations$List, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        /**
         * Waits until the specified long-running operation is done or reaches at most a specified timeout, returning the latest state. If the operation is already done, the latest state is immediately returned. If the timeout specified is greater than the default HTTP/RPC timeout, the HTTP/RPC timeout is used. If the server does not support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Note that this method is on a best-effort basis. It may return the latest state before the specified timeout (including immediately), meaning even an immediate response is no guarantee that the operation is done.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        wait(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Operations$Wait, options: StreamMethodOptions): GaxiosPromise<Readable>;
        wait(params?: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Operations$Wait, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        wait(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Operations$Wait, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        wait(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Operations$Wait, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(params: Params$Resource$Projects$Locations$Hyperparametertuningjobs$Operations$Wait, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
    }
    export interface Params$Resource$Projects$Locations$Hyperparametertuningjobs$Operations$Cancel extends StandardParameters {
        /**
         * The name of the operation resource to be cancelled.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Hyperparametertuningjobs$Operations$Delete extends StandardParameters {
        /**
         * The name of the operation resource to be deleted.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Hyperparametertuningjobs$Operations$Get extends StandardParameters {
        /**
         * The name of the operation resource.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Hyperparametertuningjobs$Operations$List extends StandardParameters {
        /**
         * The standard list filter.
         */
        filter?: string;
        /**
         * The name of the operation's parent resource.
         */
        name?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token.
         */
        pageToken?: string;
    }
    export interface Params$Resource$Projects$Locations$Hyperparametertuningjobs$Operations$Wait extends StandardParameters {
        /**
         * The name of the operation resource to wait on.
         */
        name?: string;
        /**
         * The maximum duration to wait before timing out. If left blank, the wait will be at most the time permitted by the underlying HTTP/RPC protocol. If RPC context deadline is also specified, the shorter one will be used.
         */
        timeout?: string;
    }
    export class Resource$Projects$Locations$Indexendpoints {
        context: APIRequestContext;
        operations: Resource$Projects$Locations$Indexendpoints$Operations;
        constructor(context: APIRequestContext);
        /**
         * Creates an IndexEndpoint.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        create(params: Params$Resource$Projects$Locations$Indexendpoints$Create, options: StreamMethodOptions): GaxiosPromise<Readable>;
        create(params?: Params$Resource$Projects$Locations$Indexendpoints$Create, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        create(params: Params$Resource$Projects$Locations$Indexendpoints$Create, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        create(params: Params$Resource$Projects$Locations$Indexendpoints$Create, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        create(params: Params$Resource$Projects$Locations$Indexendpoints$Create, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        create(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Deletes an IndexEndpoint.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Indexendpoints$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Indexendpoints$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        delete(params: Params$Resource$Projects$Locations$Indexendpoints$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Indexendpoints$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(params: Params$Resource$Projects$Locations$Indexendpoints$Delete, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Deploys an Index into this IndexEndpoint, creating a DeployedIndex within it. Only non-empty Indexes can be deployed.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        deployIndex(params: Params$Resource$Projects$Locations$Indexendpoints$Deployindex, options: StreamMethodOptions): GaxiosPromise<Readable>;
        deployIndex(params?: Params$Resource$Projects$Locations$Indexendpoints$Deployindex, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        deployIndex(params: Params$Resource$Projects$Locations$Indexendpoints$Deployindex, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        deployIndex(params: Params$Resource$Projects$Locations$Indexendpoints$Deployindex, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        deployIndex(params: Params$Resource$Projects$Locations$Indexendpoints$Deployindex, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        deployIndex(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Finds the nearest neighbors of each vector within the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        findNeighbors(params: Params$Resource$Projects$Locations$Indexendpoints$Findneighbors, options: StreamMethodOptions): GaxiosPromise<Readable>;
        findNeighbors(params?: Params$Resource$Projects$Locations$Indexendpoints$Findneighbors, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1FindNeighborsResponse>;
        findNeighbors(params: Params$Resource$Projects$Locations$Indexendpoints$Findneighbors, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        findNeighbors(params: Params$Resource$Projects$Locations$Indexendpoints$Findneighbors, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1FindNeighborsResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1FindNeighborsResponse>): void;
        findNeighbors(params: Params$Resource$Projects$Locations$Indexendpoints$Findneighbors, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1FindNeighborsResponse>): void;
        findNeighbors(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1FindNeighborsResponse>): void;
        /**
         * Gets an IndexEndpoint.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Indexendpoints$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Indexendpoints$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1IndexEndpoint>;
        get(params: Params$Resource$Projects$Locations$Indexendpoints$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Indexendpoints$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1IndexEndpoint>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1IndexEndpoint>): void;
        get(params: Params$Resource$Projects$Locations$Indexendpoints$Get, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1IndexEndpoint>): void;
        get(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1IndexEndpoint>): void;
        /**
         * Lists IndexEndpoints in a Location.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Indexendpoints$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Indexendpoints$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListIndexEndpointsResponse>;
        list(params: Params$Resource$Projects$Locations$Indexendpoints$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Indexendpoints$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListIndexEndpointsResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListIndexEndpointsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Indexendpoints$List, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListIndexEndpointsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListIndexEndpointsResponse>): void;
        /**
         * Update an existing DeployedIndex under an IndexEndpoint.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        mutateDeployedIndex(params: Params$Resource$Projects$Locations$Indexendpoints$Mutatedeployedindex, options: StreamMethodOptions): GaxiosPromise<Readable>;
        mutateDeployedIndex(params?: Params$Resource$Projects$Locations$Indexendpoints$Mutatedeployedindex, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        mutateDeployedIndex(params: Params$Resource$Projects$Locations$Indexendpoints$Mutatedeployedindex, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        mutateDeployedIndex(params: Params$Resource$Projects$Locations$Indexendpoints$Mutatedeployedindex, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        mutateDeployedIndex(params: Params$Resource$Projects$Locations$Indexendpoints$Mutatedeployedindex, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        mutateDeployedIndex(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Updates an IndexEndpoint.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Projects$Locations$Indexendpoints$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Projects$Locations$Indexendpoints$Patch, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1IndexEndpoint>;
        patch(params: Params$Resource$Projects$Locations$Indexendpoints$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Projects$Locations$Indexendpoints$Patch, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1IndexEndpoint>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1IndexEndpoint>): void;
        patch(params: Params$Resource$Projects$Locations$Indexendpoints$Patch, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1IndexEndpoint>): void;
        patch(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1IndexEndpoint>): void;
        /**
         * Reads the datapoints/vectors of the given IDs. A maximum of 1000 datapoints can be retrieved in a batch.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        readIndexDatapoints(params: Params$Resource$Projects$Locations$Indexendpoints$Readindexdatapoints, options: StreamMethodOptions): GaxiosPromise<Readable>;
        readIndexDatapoints(params?: Params$Resource$Projects$Locations$Indexendpoints$Readindexdatapoints, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ReadIndexDatapointsResponse>;
        readIndexDatapoints(params: Params$Resource$Projects$Locations$Indexendpoints$Readindexdatapoints, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        readIndexDatapoints(params: Params$Resource$Projects$Locations$Indexendpoints$Readindexdatapoints, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ReadIndexDatapointsResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ReadIndexDatapointsResponse>): void;
        readIndexDatapoints(params: Params$Resource$Projects$Locations$Indexendpoints$Readindexdatapoints, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ReadIndexDatapointsResponse>): void;
        readIndexDatapoints(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ReadIndexDatapointsResponse>): void;
        /**
         * Undeploys an Index from an IndexEndpoint, removing a DeployedIndex from it, and freeing all resources it's using.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        undeployIndex(params: Params$Resource$Projects$Locations$Indexendpoints$Undeployindex, options: StreamMethodOptions): GaxiosPromise<Readable>;
        undeployIndex(params?: Params$Resource$Projects$Locations$Indexendpoints$Undeployindex, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        undeployIndex(params: Params$Resource$Projects$Locations$Indexendpoints$Undeployindex, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        undeployIndex(params: Params$Resource$Projects$Locations$Indexendpoints$Undeployindex, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        undeployIndex(params: Params$Resource$Projects$Locations$Indexendpoints$Undeployindex, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        undeployIndex(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
    }
    export interface Params$Resource$Projects$Locations$Indexendpoints$Create extends StandardParameters {
        /**
         * Required. The resource name of the Location to create the IndexEndpoint in. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1IndexEndpoint;
    }
    export interface Params$Resource$Projects$Locations$Indexendpoints$Delete extends StandardParameters {
        /**
         * Required. The name of the IndexEndpoint resource to be deleted. Format: `projects/{project\}/locations/{location\}/indexEndpoints/{index_endpoint\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Indexendpoints$Deployindex extends StandardParameters {
        /**
         * Required. The name of the IndexEndpoint resource into which to deploy an Index. Format: `projects/{project\}/locations/{location\}/indexEndpoints/{index_endpoint\}`
         */
        indexEndpoint?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1DeployIndexRequest;
    }
    export interface Params$Resource$Projects$Locations$Indexendpoints$Findneighbors extends StandardParameters {
        /**
         * Required. The name of the index endpoint. Format: `projects/{project\}/locations/{location\}/indexEndpoints/{index_endpoint\}`
         */
        indexEndpoint?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1FindNeighborsRequest;
    }
    export interface Params$Resource$Projects$Locations$Indexendpoints$Get extends StandardParameters {
        /**
         * Required. The name of the IndexEndpoint resource. Format: `projects/{project\}/locations/{location\}/indexEndpoints/{index_endpoint\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Indexendpoints$List extends StandardParameters {
        /**
         * Optional. An expression for filtering the results of the request. For field names both snake_case and camelCase are supported. * `index_endpoint` supports = and !=. `index_endpoint` represents the IndexEndpoint ID, ie. the last segment of the IndexEndpoint's resourcename. * `display_name` supports =, != and regex() (uses [re2](https://github.com/google/re2/wiki/Syntax) syntax) * `labels` supports general map functions that is: `labels.key=value` - key:value equality `labels.key:* or labels:key - key existence A key including a space must be quoted. `labels."a key"`. Some examples: * `index_endpoint="1"` * `display_name="myDisplayName"` * `regex(display_name, "^A") -\> The display name starts with an A. * `labels.myKey="myValue"`
         */
        filter?: string;
        /**
         * Optional. The standard list page size.
         */
        pageSize?: number;
        /**
         * Optional. The standard list page token. Typically obtained via ListIndexEndpointsResponse.next_page_token of the previous IndexEndpointService.ListIndexEndpoints call.
         */
        pageToken?: string;
        /**
         * Required. The resource name of the Location from which to list the IndexEndpoints. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Optional. Mask specifying which fields to read.
         */
        readMask?: string;
    }
    export interface Params$Resource$Projects$Locations$Indexendpoints$Mutatedeployedindex extends StandardParameters {
        /**
         * Required. The name of the IndexEndpoint resource into which to deploy an Index. Format: `projects/{project\}/locations/{location\}/indexEndpoints/{index_endpoint\}`
         */
        indexEndpoint?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1DeployedIndex;
    }
    export interface Params$Resource$Projects$Locations$Indexendpoints$Patch extends StandardParameters {
        /**
         * Output only. The resource name of the IndexEndpoint.
         */
        name?: string;
        /**
         * Required. The update mask applies to the resource. See google.protobuf.FieldMask.
         */
        updateMask?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1IndexEndpoint;
    }
    export interface Params$Resource$Projects$Locations$Indexendpoints$Readindexdatapoints extends StandardParameters {
        /**
         * Required. The name of the index endpoint. Format: `projects/{project\}/locations/{location\}/indexEndpoints/{index_endpoint\}`
         */
        indexEndpoint?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1ReadIndexDatapointsRequest;
    }
    export interface Params$Resource$Projects$Locations$Indexendpoints$Undeployindex extends StandardParameters {
        /**
         * Required. The name of the IndexEndpoint resource from which to undeploy an Index. Format: `projects/{project\}/locations/{location\}/indexEndpoints/{index_endpoint\}`
         */
        indexEndpoint?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1UndeployIndexRequest;
    }
    export class Resource$Projects$Locations$Indexendpoints$Operations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to `Code.CANCELLED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Projects$Locations$Indexendpoints$Operations$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Projects$Locations$Indexendpoints$Operations$Cancel, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        cancel(params: Params$Resource$Projects$Locations$Indexendpoints$Operations$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Projects$Locations$Indexendpoints$Operations$Cancel, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(params: Params$Resource$Projects$Locations$Indexendpoints$Operations$Cancel, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Indexendpoints$Operations$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Indexendpoints$Operations$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        delete(params: Params$Resource$Projects$Locations$Indexendpoints$Operations$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Indexendpoints$Operations$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(params: Params$Resource$Projects$Locations$Indexendpoints$Operations$Delete, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Indexendpoints$Operations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Indexendpoints$Operations$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        get(params: Params$Resource$Projects$Locations$Indexendpoints$Operations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Indexendpoints$Operations$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(params: Params$Resource$Projects$Locations$Indexendpoints$Operations$Get, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns `UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Indexendpoints$Operations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Indexendpoints$Operations$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningListOperationsResponse>;
        list(params: Params$Resource$Projects$Locations$Indexendpoints$Operations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Indexendpoints$Operations$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Indexendpoints$Operations$List, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        /**
         * Waits until the specified long-running operation is done or reaches at most a specified timeout, returning the latest state. If the operation is already done, the latest state is immediately returned. If the timeout specified is greater than the default HTTP/RPC timeout, the HTTP/RPC timeout is used. If the server does not support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Note that this method is on a best-effort basis. It may return the latest state before the specified timeout (including immediately), meaning even an immediate response is no guarantee that the operation is done.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        wait(params: Params$Resource$Projects$Locations$Indexendpoints$Operations$Wait, options: StreamMethodOptions): GaxiosPromise<Readable>;
        wait(params?: Params$Resource$Projects$Locations$Indexendpoints$Operations$Wait, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        wait(params: Params$Resource$Projects$Locations$Indexendpoints$Operations$Wait, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        wait(params: Params$Resource$Projects$Locations$Indexendpoints$Operations$Wait, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(params: Params$Resource$Projects$Locations$Indexendpoints$Operations$Wait, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
    }
    export interface Params$Resource$Projects$Locations$Indexendpoints$Operations$Cancel extends StandardParameters {
        /**
         * The name of the operation resource to be cancelled.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Indexendpoints$Operations$Delete extends StandardParameters {
        /**
         * The name of the operation resource to be deleted.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Indexendpoints$Operations$Get extends StandardParameters {
        /**
         * The name of the operation resource.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Indexendpoints$Operations$List extends StandardParameters {
        /**
         * The standard list filter.
         */
        filter?: string;
        /**
         * The name of the operation's parent resource.
         */
        name?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token.
         */
        pageToken?: string;
    }
    export interface Params$Resource$Projects$Locations$Indexendpoints$Operations$Wait extends StandardParameters {
        /**
         * The name of the operation resource to wait on.
         */
        name?: string;
        /**
         * The maximum duration to wait before timing out. If left blank, the wait will be at most the time permitted by the underlying HTTP/RPC protocol. If RPC context deadline is also specified, the shorter one will be used.
         */
        timeout?: string;
    }
    export class Resource$Projects$Locations$Indexes {
        context: APIRequestContext;
        operations: Resource$Projects$Locations$Indexes$Operations;
        constructor(context: APIRequestContext);
        /**
         * Creates an Index.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        create(params: Params$Resource$Projects$Locations$Indexes$Create, options: StreamMethodOptions): GaxiosPromise<Readable>;
        create(params?: Params$Resource$Projects$Locations$Indexes$Create, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        create(params: Params$Resource$Projects$Locations$Indexes$Create, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        create(params: Params$Resource$Projects$Locations$Indexes$Create, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        create(params: Params$Resource$Projects$Locations$Indexes$Create, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        create(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Deletes an Index. An Index can only be deleted when all its DeployedIndexes had been undeployed.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Indexes$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Indexes$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        delete(params: Params$Resource$Projects$Locations$Indexes$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Indexes$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(params: Params$Resource$Projects$Locations$Indexes$Delete, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Gets an Index.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Indexes$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Indexes$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1Index>;
        get(params: Params$Resource$Projects$Locations$Indexes$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Indexes$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1Index>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Index>): void;
        get(params: Params$Resource$Projects$Locations$Indexes$Get, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Index>): void;
        get(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Index>): void;
        /**
         * Lists Indexes in a Location.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Indexes$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Indexes$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListIndexesResponse>;
        list(params: Params$Resource$Projects$Locations$Indexes$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Indexes$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListIndexesResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListIndexesResponse>): void;
        list(params: Params$Resource$Projects$Locations$Indexes$List, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListIndexesResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListIndexesResponse>): void;
        /**
         * Updates an Index.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Projects$Locations$Indexes$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Projects$Locations$Indexes$Patch, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        patch(params: Params$Resource$Projects$Locations$Indexes$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Projects$Locations$Indexes$Patch, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        patch(params: Params$Resource$Projects$Locations$Indexes$Patch, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        patch(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Remove Datapoints from an Index.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        removeDatapoints(params: Params$Resource$Projects$Locations$Indexes$Removedatapoints, options: StreamMethodOptions): GaxiosPromise<Readable>;
        removeDatapoints(params?: Params$Resource$Projects$Locations$Indexes$Removedatapoints, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1RemoveDatapointsResponse>;
        removeDatapoints(params: Params$Resource$Projects$Locations$Indexes$Removedatapoints, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        removeDatapoints(params: Params$Resource$Projects$Locations$Indexes$Removedatapoints, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1RemoveDatapointsResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1RemoveDatapointsResponse>): void;
        removeDatapoints(params: Params$Resource$Projects$Locations$Indexes$Removedatapoints, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1RemoveDatapointsResponse>): void;
        removeDatapoints(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1RemoveDatapointsResponse>): void;
        /**
         * Add/update Datapoints into an Index.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        upsertDatapoints(params: Params$Resource$Projects$Locations$Indexes$Upsertdatapoints, options: StreamMethodOptions): GaxiosPromise<Readable>;
        upsertDatapoints(params?: Params$Resource$Projects$Locations$Indexes$Upsertdatapoints, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1UpsertDatapointsResponse>;
        upsertDatapoints(params: Params$Resource$Projects$Locations$Indexes$Upsertdatapoints, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        upsertDatapoints(params: Params$Resource$Projects$Locations$Indexes$Upsertdatapoints, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1UpsertDatapointsResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1UpsertDatapointsResponse>): void;
        upsertDatapoints(params: Params$Resource$Projects$Locations$Indexes$Upsertdatapoints, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1UpsertDatapointsResponse>): void;
        upsertDatapoints(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1UpsertDatapointsResponse>): void;
    }
    export interface Params$Resource$Projects$Locations$Indexes$Create extends StandardParameters {
        /**
         * Required. The resource name of the Location to create the Index in. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1Index;
    }
    export interface Params$Resource$Projects$Locations$Indexes$Delete extends StandardParameters {
        /**
         * Required. The name of the Index resource to be deleted. Format: `projects/{project\}/locations/{location\}/indexes/{index\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Indexes$Get extends StandardParameters {
        /**
         * Required. The name of the Index resource. Format: `projects/{project\}/locations/{location\}/indexes/{index\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Indexes$List extends StandardParameters {
        /**
         * The standard list filter.
         */
        filter?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token. Typically obtained via ListIndexesResponse.next_page_token of the previous IndexService.ListIndexes call.
         */
        pageToken?: string;
        /**
         * Required. The resource name of the Location from which to list the Indexes. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Mask specifying which fields to read.
         */
        readMask?: string;
    }
    export interface Params$Resource$Projects$Locations$Indexes$Patch extends StandardParameters {
        /**
         * Output only. The resource name of the Index.
         */
        name?: string;
        /**
         * The update mask applies to the resource. For the `FieldMask` definition, see google.protobuf.FieldMask.
         */
        updateMask?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1Index;
    }
    export interface Params$Resource$Projects$Locations$Indexes$Removedatapoints extends StandardParameters {
        /**
         * Required. The name of the Index resource to be updated. Format: `projects/{project\}/locations/{location\}/indexes/{index\}`
         */
        index?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1RemoveDatapointsRequest;
    }
    export interface Params$Resource$Projects$Locations$Indexes$Upsertdatapoints extends StandardParameters {
        /**
         * Required. The name of the Index resource to be updated. Format: `projects/{project\}/locations/{location\}/indexes/{index\}`
         */
        index?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1UpsertDatapointsRequest;
    }
    export class Resource$Projects$Locations$Indexes$Operations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to `Code.CANCELLED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Projects$Locations$Indexes$Operations$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Projects$Locations$Indexes$Operations$Cancel, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        cancel(params: Params$Resource$Projects$Locations$Indexes$Operations$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Projects$Locations$Indexes$Operations$Cancel, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(params: Params$Resource$Projects$Locations$Indexes$Operations$Cancel, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Indexes$Operations$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Indexes$Operations$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        delete(params: Params$Resource$Projects$Locations$Indexes$Operations$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Indexes$Operations$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(params: Params$Resource$Projects$Locations$Indexes$Operations$Delete, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Indexes$Operations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Indexes$Operations$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        get(params: Params$Resource$Projects$Locations$Indexes$Operations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Indexes$Operations$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(params: Params$Resource$Projects$Locations$Indexes$Operations$Get, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns `UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Indexes$Operations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Indexes$Operations$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningListOperationsResponse>;
        list(params: Params$Resource$Projects$Locations$Indexes$Operations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Indexes$Operations$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Indexes$Operations$List, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        /**
         * Waits until the specified long-running operation is done or reaches at most a specified timeout, returning the latest state. If the operation is already done, the latest state is immediately returned. If the timeout specified is greater than the default HTTP/RPC timeout, the HTTP/RPC timeout is used. If the server does not support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Note that this method is on a best-effort basis. It may return the latest state before the specified timeout (including immediately), meaning even an immediate response is no guarantee that the operation is done.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        wait(params: Params$Resource$Projects$Locations$Indexes$Operations$Wait, options: StreamMethodOptions): GaxiosPromise<Readable>;
        wait(params?: Params$Resource$Projects$Locations$Indexes$Operations$Wait, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        wait(params: Params$Resource$Projects$Locations$Indexes$Operations$Wait, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        wait(params: Params$Resource$Projects$Locations$Indexes$Operations$Wait, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(params: Params$Resource$Projects$Locations$Indexes$Operations$Wait, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
    }
    export interface Params$Resource$Projects$Locations$Indexes$Operations$Cancel extends StandardParameters {
        /**
         * The name of the operation resource to be cancelled.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Indexes$Operations$Delete extends StandardParameters {
        /**
         * The name of the operation resource to be deleted.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Indexes$Operations$Get extends StandardParameters {
        /**
         * The name of the operation resource.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Indexes$Operations$List extends StandardParameters {
        /**
         * The standard list filter.
         */
        filter?: string;
        /**
         * The name of the operation's parent resource.
         */
        name?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token.
         */
        pageToken?: string;
    }
    export interface Params$Resource$Projects$Locations$Indexes$Operations$Wait extends StandardParameters {
        /**
         * The name of the operation resource to wait on.
         */
        name?: string;
        /**
         * The maximum duration to wait before timing out. If left blank, the wait will be at most the time permitted by the underlying HTTP/RPC protocol. If RPC context deadline is also specified, the shorter one will be used.
         */
        timeout?: string;
    }
    export class Resource$Projects$Locations$Metadatastores {
        context: APIRequestContext;
        artifacts: Resource$Projects$Locations$Metadatastores$Artifacts;
        contexts: Resource$Projects$Locations$Metadatastores$Contexts;
        executions: Resource$Projects$Locations$Metadatastores$Executions;
        metadataSchemas: Resource$Projects$Locations$Metadatastores$Metadataschemas;
        constructor(context: APIRequestContext);
        /**
         * Initializes a MetadataStore, including allocation of resources.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        create(params: Params$Resource$Projects$Locations$Metadatastores$Create, options: StreamMethodOptions): GaxiosPromise<Readable>;
        create(params?: Params$Resource$Projects$Locations$Metadatastores$Create, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        create(params: Params$Resource$Projects$Locations$Metadatastores$Create, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        create(params: Params$Resource$Projects$Locations$Metadatastores$Create, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        create(params: Params$Resource$Projects$Locations$Metadatastores$Create, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        create(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Deletes a single MetadataStore and all its child resources (Artifacts, Executions, and Contexts).
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Metadatastores$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Metadatastores$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        delete(params: Params$Resource$Projects$Locations$Metadatastores$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Metadatastores$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(params: Params$Resource$Projects$Locations$Metadatastores$Delete, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Retrieves a specific MetadataStore.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Metadatastores$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Metadatastores$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1MetadataStore>;
        get(params: Params$Resource$Projects$Locations$Metadatastores$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Metadatastores$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1MetadataStore>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1MetadataStore>): void;
        get(params: Params$Resource$Projects$Locations$Metadatastores$Get, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1MetadataStore>): void;
        get(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1MetadataStore>): void;
        /**
         * Lists MetadataStores for a Location.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Metadatastores$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Metadatastores$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListMetadataStoresResponse>;
        list(params: Params$Resource$Projects$Locations$Metadatastores$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Metadatastores$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListMetadataStoresResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListMetadataStoresResponse>): void;
        list(params: Params$Resource$Projects$Locations$Metadatastores$List, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListMetadataStoresResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListMetadataStoresResponse>): void;
    }
    export interface Params$Resource$Projects$Locations$Metadatastores$Create extends StandardParameters {
        /**
         * The {metadatastore\} portion of the resource name with the format: `projects/{project\}/locations/{location\}/metadataStores/{metadatastore\}` If not provided, the MetadataStore's ID will be a UUID generated by the service. Must be 4-128 characters in length. Valid characters are `/a-z-/`. Must be unique across all MetadataStores in the parent Location. (Otherwise the request will fail with ALREADY_EXISTS, or PERMISSION_DENIED if the caller can't view the preexisting MetadataStore.)
         */
        metadataStoreId?: string;
        /**
         * Required. The resource name of the Location where the MetadataStore should be created. Format: `projects/{project\}/locations/{location\}/`
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1MetadataStore;
    }
    export interface Params$Resource$Projects$Locations$Metadatastores$Delete extends StandardParameters {
        /**
         * Deprecated: Field is no longer supported.
         */
        force?: boolean;
        /**
         * Required. The resource name of the MetadataStore to delete. Format: `projects/{project\}/locations/{location\}/metadataStores/{metadatastore\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Metadatastores$Get extends StandardParameters {
        /**
         * Required. The resource name of the MetadataStore to retrieve. Format: `projects/{project\}/locations/{location\}/metadataStores/{metadatastore\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Metadatastores$List extends StandardParameters {
        /**
         * The maximum number of Metadata Stores to return. The service may return fewer. Must be in range 1-1000, inclusive. Defaults to 100.
         */
        pageSize?: number;
        /**
         * A page token, received from a previous MetadataService.ListMetadataStores call. Provide this to retrieve the subsequent page. When paginating, all other provided parameters must match the call that provided the page token. (Otherwise the request will fail with INVALID_ARGUMENT error.)
         */
        pageToken?: string;
        /**
         * Required. The Location whose MetadataStores should be listed. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
    }
    export class Resource$Projects$Locations$Metadatastores$Artifacts {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Creates an Artifact associated with a MetadataStore.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        create(params: Params$Resource$Projects$Locations$Metadatastores$Artifacts$Create, options: StreamMethodOptions): GaxiosPromise<Readable>;
        create(params?: Params$Resource$Projects$Locations$Metadatastores$Artifacts$Create, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1Artifact>;
        create(params: Params$Resource$Projects$Locations$Metadatastores$Artifacts$Create, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        create(params: Params$Resource$Projects$Locations$Metadatastores$Artifacts$Create, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1Artifact>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Artifact>): void;
        create(params: Params$Resource$Projects$Locations$Metadatastores$Artifacts$Create, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Artifact>): void;
        create(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Artifact>): void;
        /**
         * Deletes an Artifact.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Metadatastores$Artifacts$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Metadatastores$Artifacts$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        delete(params: Params$Resource$Projects$Locations$Metadatastores$Artifacts$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Metadatastores$Artifacts$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(params: Params$Resource$Projects$Locations$Metadatastores$Artifacts$Delete, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Retrieves a specific Artifact.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Metadatastores$Artifacts$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Metadatastores$Artifacts$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1Artifact>;
        get(params: Params$Resource$Projects$Locations$Metadatastores$Artifacts$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Metadatastores$Artifacts$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1Artifact>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Artifact>): void;
        get(params: Params$Resource$Projects$Locations$Metadatastores$Artifacts$Get, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Artifact>): void;
        get(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Artifact>): void;
        /**
         * Lists Artifacts in the MetadataStore.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Metadatastores$Artifacts$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Metadatastores$Artifacts$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListArtifactsResponse>;
        list(params: Params$Resource$Projects$Locations$Metadatastores$Artifacts$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Metadatastores$Artifacts$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListArtifactsResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListArtifactsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Metadatastores$Artifacts$List, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListArtifactsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListArtifactsResponse>): void;
        /**
         * Updates a stored Artifact.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Projects$Locations$Metadatastores$Artifacts$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Projects$Locations$Metadatastores$Artifacts$Patch, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1Artifact>;
        patch(params: Params$Resource$Projects$Locations$Metadatastores$Artifacts$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Projects$Locations$Metadatastores$Artifacts$Patch, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1Artifact>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Artifact>): void;
        patch(params: Params$Resource$Projects$Locations$Metadatastores$Artifacts$Patch, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Artifact>): void;
        patch(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Artifact>): void;
        /**
         * Purges Artifacts.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        purge(params: Params$Resource$Projects$Locations$Metadatastores$Artifacts$Purge, options: StreamMethodOptions): GaxiosPromise<Readable>;
        purge(params?: Params$Resource$Projects$Locations$Metadatastores$Artifacts$Purge, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        purge(params: Params$Resource$Projects$Locations$Metadatastores$Artifacts$Purge, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        purge(params: Params$Resource$Projects$Locations$Metadatastores$Artifacts$Purge, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        purge(params: Params$Resource$Projects$Locations$Metadatastores$Artifacts$Purge, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        purge(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Retrieves lineage of an Artifact represented through Artifacts and Executions connected by Event edges and returned as a LineageSubgraph.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        queryArtifactLineageSubgraph(params: Params$Resource$Projects$Locations$Metadatastores$Artifacts$Queryartifactlineagesubgraph, options: StreamMethodOptions): GaxiosPromise<Readable>;
        queryArtifactLineageSubgraph(params?: Params$Resource$Projects$Locations$Metadatastores$Artifacts$Queryartifactlineagesubgraph, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1LineageSubgraph>;
        queryArtifactLineageSubgraph(params: Params$Resource$Projects$Locations$Metadatastores$Artifacts$Queryartifactlineagesubgraph, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        queryArtifactLineageSubgraph(params: Params$Resource$Projects$Locations$Metadatastores$Artifacts$Queryartifactlineagesubgraph, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1LineageSubgraph>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1LineageSubgraph>): void;
        queryArtifactLineageSubgraph(params: Params$Resource$Projects$Locations$Metadatastores$Artifacts$Queryartifactlineagesubgraph, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1LineageSubgraph>): void;
        queryArtifactLineageSubgraph(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1LineageSubgraph>): void;
    }
    export interface Params$Resource$Projects$Locations$Metadatastores$Artifacts$Create extends StandardParameters {
        /**
         * The {artifact\} portion of the resource name with the format: `projects/{project\}/locations/{location\}/metadataStores/{metadatastore\}/artifacts/{artifact\}` If not provided, the Artifact's ID will be a UUID generated by the service. Must be 4-128 characters in length. Valid characters are `/a-z-/`. Must be unique across all Artifacts in the parent MetadataStore. (Otherwise the request will fail with ALREADY_EXISTS, or PERMISSION_DENIED if the caller can't view the preexisting Artifact.)
         */
        artifactId?: string;
        /**
         * Required. The resource name of the MetadataStore where the Artifact should be created. Format: `projects/{project\}/locations/{location\}/metadataStores/{metadatastore\}`
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1Artifact;
    }
    export interface Params$Resource$Projects$Locations$Metadatastores$Artifacts$Delete extends StandardParameters {
        /**
         * Optional. The etag of the Artifact to delete. If this is provided, it must match the server's etag. Otherwise, the request will fail with a FAILED_PRECONDITION.
         */
        etag?: string;
        /**
         * Required. The resource name of the Artifact to delete. Format: `projects/{project\}/locations/{location\}/metadataStores/{metadatastore\}/artifacts/{artifact\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Metadatastores$Artifacts$Get extends StandardParameters {
        /**
         * Required. The resource name of the Artifact to retrieve. Format: `projects/{project\}/locations/{location\}/metadataStores/{metadatastore\}/artifacts/{artifact\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Metadatastores$Artifacts$List extends StandardParameters {
        /**
         * Filter specifying the boolean condition for the Artifacts to satisfy in order to be part of the result set. The syntax to define filter query is based on https://google.aip.dev/160. The supported set of filters include the following: * **Attribute filtering**: For example: `display_name = "test"`. Supported fields include: `name`, `display_name`, `uri`, `state`, `schema_title`, `create_time`, and `update_time`. Time fields, such as `create_time` and `update_time`, require values specified in RFC-3339 format. For example: `create_time = "2020-11-19T11:30:00-04:00"` * **Metadata field**: To filter on metadata fields use traversal operation as follows: `metadata..`. For example: `metadata.field_1.number_value = 10.0` In case the field name contains special characters (such as colon), one can embed it inside double quote. For example: `metadata."field:1".number_value = 10.0` * **Context based filtering**: To filter Artifacts based on the contexts to which they belong, use the function operator with the full resource name `in_context()`. For example: `in_context("projects//locations//metadataStores//contexts/")` Each of the above supported filter types can be combined together using logical operators (`AND` & `OR`). Maximum nested expression depth allowed is 5. For example: `display_name = "test" AND metadata.field1.bool_value = true`.
         */
        filter?: string;
        /**
         * How the list of messages is ordered. Specify the values to order by and an ordering operation. The default sorting order is ascending. To specify descending order for a field, users append a " desc" suffix; for example: "foo desc, bar". Subfields are specified with a `.` character, such as foo.bar. see https://google.aip.dev/132#ordering for more details.
         */
        orderBy?: string;
        /**
         * The maximum number of Artifacts to return. The service may return fewer. Must be in range 1-1000, inclusive. Defaults to 100.
         */
        pageSize?: number;
        /**
         * A page token, received from a previous MetadataService.ListArtifacts call. Provide this to retrieve the subsequent page. When paginating, all other provided parameters must match the call that provided the page token. (Otherwise the request will fail with INVALID_ARGUMENT error.)
         */
        pageToken?: string;
        /**
         * Required. The MetadataStore whose Artifacts should be listed. Format: `projects/{project\}/locations/{location\}/metadataStores/{metadatastore\}`
         */
        parent?: string;
    }
    export interface Params$Resource$Projects$Locations$Metadatastores$Artifacts$Patch extends StandardParameters {
        /**
         * If set to true, and the Artifact is not found, a new Artifact is created.
         */
        allowMissing?: boolean;
        /**
         * Output only. The resource name of the Artifact.
         */
        name?: string;
        /**
         * Optional. A FieldMask indicating which fields should be updated.
         */
        updateMask?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1Artifact;
    }
    export interface Params$Resource$Projects$Locations$Metadatastores$Artifacts$Purge extends StandardParameters {
        /**
         * Required. The metadata store to purge Artifacts from. Format: `projects/{project\}/locations/{location\}/metadataStores/{metadatastore\}`
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1PurgeArtifactsRequest;
    }
    export interface Params$Resource$Projects$Locations$Metadatastores$Artifacts$Queryartifactlineagesubgraph extends StandardParameters {
        /**
         * Required. The resource name of the Artifact whose Lineage needs to be retrieved as a LineageSubgraph. Format: `projects/{project\}/locations/{location\}/metadataStores/{metadatastore\}/artifacts/{artifact\}` The request may error with FAILED_PRECONDITION if the number of Artifacts, the number of Executions, or the number of Events that would be returned for the Context exceeds 1000.
         */
        artifact?: string;
        /**
         * Filter specifying the boolean condition for the Artifacts to satisfy in order to be part of the Lineage Subgraph. The syntax to define filter query is based on https://google.aip.dev/160. The supported set of filters include the following: * **Attribute filtering**: For example: `display_name = "test"` Supported fields include: `name`, `display_name`, `uri`, `state`, `schema_title`, `create_time`, and `update_time`. Time fields, such as `create_time` and `update_time`, require values specified in RFC-3339 format. For example: `create_time = "2020-11-19T11:30:00-04:00"` * **Metadata field**: To filter on metadata fields use traversal operation as follows: `metadata..`. For example: `metadata.field_1.number_value = 10.0` In case the field name contains special characters (such as colon), one can embed it inside double quote. For example: `metadata."field:1".number_value = 10.0` Each of the above supported filter types can be combined together using logical operators (`AND` & `OR`). Maximum nested expression depth allowed is 5. For example: `display_name = "test" AND metadata.field1.bool_value = true`.
         */
        filter?: string;
        /**
         * Specifies the size of the lineage graph in terms of number of hops from the specified artifact. Negative Value: INVALID_ARGUMENT error is returned 0: Only input artifact is returned. No value: Transitive closure is performed to return the complete graph.
         */
        maxHops?: number;
    }
    export class Resource$Projects$Locations$Metadatastores$Contexts {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Adds a set of Artifacts and Executions to a Context. If any of the Artifacts or Executions have already been added to a Context, they are simply skipped.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        addContextArtifactsAndExecutions(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$Addcontextartifactsandexecutions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        addContextArtifactsAndExecutions(params?: Params$Resource$Projects$Locations$Metadatastores$Contexts$Addcontextartifactsandexecutions, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1AddContextArtifactsAndExecutionsResponse>;
        addContextArtifactsAndExecutions(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$Addcontextartifactsandexecutions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        addContextArtifactsAndExecutions(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$Addcontextartifactsandexecutions, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1AddContextArtifactsAndExecutionsResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1AddContextArtifactsAndExecutionsResponse>): void;
        addContextArtifactsAndExecutions(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$Addcontextartifactsandexecutions, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1AddContextArtifactsAndExecutionsResponse>): void;
        addContextArtifactsAndExecutions(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1AddContextArtifactsAndExecutionsResponse>): void;
        /**
         * Adds a set of Contexts as children to a parent Context. If any of the child Contexts have already been added to the parent Context, they are simply skipped. If this call would create a cycle or cause any Context to have more than 10 parents, the request will fail with an INVALID_ARGUMENT error.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        addContextChildren(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$Addcontextchildren, options: StreamMethodOptions): GaxiosPromise<Readable>;
        addContextChildren(params?: Params$Resource$Projects$Locations$Metadatastores$Contexts$Addcontextchildren, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1AddContextChildrenResponse>;
        addContextChildren(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$Addcontextchildren, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        addContextChildren(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$Addcontextchildren, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1AddContextChildrenResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1AddContextChildrenResponse>): void;
        addContextChildren(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$Addcontextchildren, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1AddContextChildrenResponse>): void;
        addContextChildren(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1AddContextChildrenResponse>): void;
        /**
         * Creates a Context associated with a MetadataStore.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        create(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$Create, options: StreamMethodOptions): GaxiosPromise<Readable>;
        create(params?: Params$Resource$Projects$Locations$Metadatastores$Contexts$Create, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1Context>;
        create(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$Create, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        create(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$Create, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1Context>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Context>): void;
        create(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$Create, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Context>): void;
        create(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Context>): void;
        /**
         * Deletes a stored Context.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Metadatastores$Contexts$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        delete(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$Delete, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Retrieves a specific Context.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Metadatastores$Contexts$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1Context>;
        get(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1Context>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Context>): void;
        get(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$Get, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Context>): void;
        get(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Context>): void;
        /**
         * Lists Contexts on the MetadataStore.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Metadatastores$Contexts$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListContextsResponse>;
        list(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListContextsResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListContextsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$List, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListContextsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListContextsResponse>): void;
        /**
         * Updates a stored Context.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Projects$Locations$Metadatastores$Contexts$Patch, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1Context>;
        patch(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$Patch, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1Context>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Context>): void;
        patch(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$Patch, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Context>): void;
        patch(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Context>): void;
        /**
         * Purges Contexts.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        purge(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$Purge, options: StreamMethodOptions): GaxiosPromise<Readable>;
        purge(params?: Params$Resource$Projects$Locations$Metadatastores$Contexts$Purge, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        purge(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$Purge, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        purge(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$Purge, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        purge(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$Purge, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        purge(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Retrieves Artifacts and Executions within the specified Context, connected by Event edges and returned as a LineageSubgraph.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        queryContextLineageSubgraph(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$Querycontextlineagesubgraph, options: StreamMethodOptions): GaxiosPromise<Readable>;
        queryContextLineageSubgraph(params?: Params$Resource$Projects$Locations$Metadatastores$Contexts$Querycontextlineagesubgraph, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1LineageSubgraph>;
        queryContextLineageSubgraph(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$Querycontextlineagesubgraph, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        queryContextLineageSubgraph(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$Querycontextlineagesubgraph, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1LineageSubgraph>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1LineageSubgraph>): void;
        queryContextLineageSubgraph(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$Querycontextlineagesubgraph, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1LineageSubgraph>): void;
        queryContextLineageSubgraph(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1LineageSubgraph>): void;
        /**
         * Remove a set of children contexts from a parent Context. If any of the child Contexts were NOT added to the parent Context, they are simply skipped.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        removeContextChildren(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$Removecontextchildren, options: StreamMethodOptions): GaxiosPromise<Readable>;
        removeContextChildren(params?: Params$Resource$Projects$Locations$Metadatastores$Contexts$Removecontextchildren, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1RemoveContextChildrenResponse>;
        removeContextChildren(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$Removecontextchildren, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        removeContextChildren(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$Removecontextchildren, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1RemoveContextChildrenResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1RemoveContextChildrenResponse>): void;
        removeContextChildren(params: Params$Resource$Projects$Locations$Metadatastores$Contexts$Removecontextchildren, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1RemoveContextChildrenResponse>): void;
        removeContextChildren(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1RemoveContextChildrenResponse>): void;
    }
    export interface Params$Resource$Projects$Locations$Metadatastores$Contexts$Addcontextartifactsandexecutions extends StandardParameters {
        /**
         * Required. The resource name of the Context that the Artifacts and Executions belong to. Format: `projects/{project\}/locations/{location\}/metadataStores/{metadatastore\}/contexts/{context\}`
         */
        context?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1AddContextArtifactsAndExecutionsRequest;
    }
    export interface Params$Resource$Projects$Locations$Metadatastores$Contexts$Addcontextchildren extends StandardParameters {
        /**
         * Required. The resource name of the parent Context. Format: `projects/{project\}/locations/{location\}/metadataStores/{metadatastore\}/contexts/{context\}`
         */
        context?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1AddContextChildrenRequest;
    }
    export interface Params$Resource$Projects$Locations$Metadatastores$Contexts$Create extends StandardParameters {
        /**
         * The {context\} portion of the resource name with the format: `projects/{project\}/locations/{location\}/metadataStores/{metadatastore\}/contexts/{context\}`. If not provided, the Context's ID will be a UUID generated by the service. Must be 4-128 characters in length. Valid characters are `/a-z-/`. Must be unique across all Contexts in the parent MetadataStore. (Otherwise the request will fail with ALREADY_EXISTS, or PERMISSION_DENIED if the caller can't view the preexisting Context.)
         */
        contextId?: string;
        /**
         * Required. The resource name of the MetadataStore where the Context should be created. Format: `projects/{project\}/locations/{location\}/metadataStores/{metadatastore\}`
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1Context;
    }
    export interface Params$Resource$Projects$Locations$Metadatastores$Contexts$Delete extends StandardParameters {
        /**
         * Optional. The etag of the Context to delete. If this is provided, it must match the server's etag. Otherwise, the request will fail with a FAILED_PRECONDITION.
         */
        etag?: string;
        /**
         * The force deletion semantics is still undefined. Users should not use this field.
         */
        force?: boolean;
        /**
         * Required. The resource name of the Context to delete. Format: `projects/{project\}/locations/{location\}/metadataStores/{metadatastore\}/contexts/{context\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Metadatastores$Contexts$Get extends StandardParameters {
        /**
         * Required. The resource name of the Context to retrieve. Format: `projects/{project\}/locations/{location\}/metadataStores/{metadatastore\}/contexts/{context\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Metadatastores$Contexts$List extends StandardParameters {
        /**
         * Filter specifying the boolean condition for the Contexts to satisfy in order to be part of the result set. The syntax to define filter query is based on https://google.aip.dev/160. Following are the supported set of filters: * **Attribute filtering**: For example: `display_name = "test"`. Supported fields include: `name`, `display_name`, `schema_title`, `create_time`, and `update_time`. Time fields, such as `create_time` and `update_time`, require values specified in RFC-3339 format. For example: `create_time = "2020-11-19T11:30:00-04:00"`. * **Metadata field**: To filter on metadata fields use traversal operation as follows: `metadata..`. For example: `metadata.field_1.number_value = 10.0`. In case the field name contains special characters (such as colon), one can embed it inside double quote. For example: `metadata."field:1".number_value = 10.0` * **Parent Child filtering**: To filter Contexts based on parent-child relationship use the HAS operator as follows: ``` parent_contexts: "projects//locations//metadataStores//contexts/" child_contexts: "projects//locations//metadataStores//contexts/" ``` Each of the above supported filters can be combined together using logical operators (`AND` & `OR`). Maximum nested expression depth allowed is 5. For example: `display_name = "test" AND metadata.field1.bool_value = true`.
         */
        filter?: string;
        /**
         * How the list of messages is ordered. Specify the values to order by and an ordering operation. The default sorting order is ascending. To specify descending order for a field, users append a " desc" suffix; for example: "foo desc, bar". Subfields are specified with a `.` character, such as foo.bar. see https://google.aip.dev/132#ordering for more details.
         */
        orderBy?: string;
        /**
         * The maximum number of Contexts to return. The service may return fewer. Must be in range 1-1000, inclusive. Defaults to 100.
         */
        pageSize?: number;
        /**
         * A page token, received from a previous MetadataService.ListContexts call. Provide this to retrieve the subsequent page. When paginating, all other provided parameters must match the call that provided the page token. (Otherwise the request will fail with INVALID_ARGUMENT error.)
         */
        pageToken?: string;
        /**
         * Required. The MetadataStore whose Contexts should be listed. Format: `projects/{project\}/locations/{location\}/metadataStores/{metadatastore\}`
         */
        parent?: string;
    }
    export interface Params$Resource$Projects$Locations$Metadatastores$Contexts$Patch extends StandardParameters {
        /**
         * If set to true, and the Context is not found, a new Context is created.
         */
        allowMissing?: boolean;
        /**
         * Immutable. The resource name of the Context.
         */
        name?: string;
        /**
         * Optional. A FieldMask indicating which fields should be updated.
         */
        updateMask?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1Context;
    }
    export interface Params$Resource$Projects$Locations$Metadatastores$Contexts$Purge extends StandardParameters {
        /**
         * Required. The metadata store to purge Contexts from. Format: `projects/{project\}/locations/{location\}/metadataStores/{metadatastore\}`
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1PurgeContextsRequest;
    }
    export interface Params$Resource$Projects$Locations$Metadatastores$Contexts$Querycontextlineagesubgraph extends StandardParameters {
        /**
         * Required. The resource name of the Context whose Artifacts and Executions should be retrieved as a LineageSubgraph. Format: `projects/{project\}/locations/{location\}/metadataStores/{metadatastore\}/contexts/{context\}` The request may error with FAILED_PRECONDITION if the number of Artifacts, the number of Executions, or the number of Events that would be returned for the Context exceeds 1000.
         */
        context?: string;
    }
    export interface Params$Resource$Projects$Locations$Metadatastores$Contexts$Removecontextchildren extends StandardParameters {
        /**
         * Required. The resource name of the parent Context. Format: `projects/{project\}/locations/{location\}/metadataStores/{metadatastore\}/contexts/{context\}`
         */
        context?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1RemoveContextChildrenRequest;
    }
    export class Resource$Projects$Locations$Metadatastores$Executions {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Adds Events to the specified Execution. An Event indicates whether an Artifact was used as an input or output for an Execution. If an Event already exists between the Execution and the Artifact, the Event is skipped.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        addExecutionEvents(params: Params$Resource$Projects$Locations$Metadatastores$Executions$Addexecutionevents, options: StreamMethodOptions): GaxiosPromise<Readable>;
        addExecutionEvents(params?: Params$Resource$Projects$Locations$Metadatastores$Executions$Addexecutionevents, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1AddExecutionEventsResponse>;
        addExecutionEvents(params: Params$Resource$Projects$Locations$Metadatastores$Executions$Addexecutionevents, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        addExecutionEvents(params: Params$Resource$Projects$Locations$Metadatastores$Executions$Addexecutionevents, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1AddExecutionEventsResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1AddExecutionEventsResponse>): void;
        addExecutionEvents(params: Params$Resource$Projects$Locations$Metadatastores$Executions$Addexecutionevents, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1AddExecutionEventsResponse>): void;
        addExecutionEvents(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1AddExecutionEventsResponse>): void;
        /**
         * Creates an Execution associated with a MetadataStore.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        create(params: Params$Resource$Projects$Locations$Metadatastores$Executions$Create, options: StreamMethodOptions): GaxiosPromise<Readable>;
        create(params?: Params$Resource$Projects$Locations$Metadatastores$Executions$Create, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1Execution>;
        create(params: Params$Resource$Projects$Locations$Metadatastores$Executions$Create, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        create(params: Params$Resource$Projects$Locations$Metadatastores$Executions$Create, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1Execution>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Execution>): void;
        create(params: Params$Resource$Projects$Locations$Metadatastores$Executions$Create, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Execution>): void;
        create(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Execution>): void;
        /**
         * Deletes an Execution.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Metadatastores$Executions$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Metadatastores$Executions$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        delete(params: Params$Resource$Projects$Locations$Metadatastores$Executions$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Metadatastores$Executions$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(params: Params$Resource$Projects$Locations$Metadatastores$Executions$Delete, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Retrieves a specific Execution.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Metadatastores$Executions$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Metadatastores$Executions$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1Execution>;
        get(params: Params$Resource$Projects$Locations$Metadatastores$Executions$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Metadatastores$Executions$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1Execution>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Execution>): void;
        get(params: Params$Resource$Projects$Locations$Metadatastores$Executions$Get, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Execution>): void;
        get(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Execution>): void;
        /**
         * Lists Executions in the MetadataStore.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Metadatastores$Executions$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Metadatastores$Executions$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListExecutionsResponse>;
        list(params: Params$Resource$Projects$Locations$Metadatastores$Executions$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Metadatastores$Executions$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListExecutionsResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListExecutionsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Metadatastores$Executions$List, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListExecutionsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListExecutionsResponse>): void;
        /**
         * Updates a stored Execution.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Projects$Locations$Metadatastores$Executions$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Projects$Locations$Metadatastores$Executions$Patch, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1Execution>;
        patch(params: Params$Resource$Projects$Locations$Metadatastores$Executions$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Projects$Locations$Metadatastores$Executions$Patch, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1Execution>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Execution>): void;
        patch(params: Params$Resource$Projects$Locations$Metadatastores$Executions$Patch, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Execution>): void;
        patch(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Execution>): void;
        /**
         * Purges Executions.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        purge(params: Params$Resource$Projects$Locations$Metadatastores$Executions$Purge, options: StreamMethodOptions): GaxiosPromise<Readable>;
        purge(params?: Params$Resource$Projects$Locations$Metadatastores$Executions$Purge, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        purge(params: Params$Resource$Projects$Locations$Metadatastores$Executions$Purge, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        purge(params: Params$Resource$Projects$Locations$Metadatastores$Executions$Purge, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        purge(params: Params$Resource$Projects$Locations$Metadatastores$Executions$Purge, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        purge(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Obtains the set of input and output Artifacts for this Execution, in the form of LineageSubgraph that also contains the Execution and connecting Events.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        queryExecutionInputsAndOutputs(params: Params$Resource$Projects$Locations$Metadatastores$Executions$Queryexecutioninputsandoutputs, options: StreamMethodOptions): GaxiosPromise<Readable>;
        queryExecutionInputsAndOutputs(params?: Params$Resource$Projects$Locations$Metadatastores$Executions$Queryexecutioninputsandoutputs, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1LineageSubgraph>;
        queryExecutionInputsAndOutputs(params: Params$Resource$Projects$Locations$Metadatastores$Executions$Queryexecutioninputsandoutputs, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        queryExecutionInputsAndOutputs(params: Params$Resource$Projects$Locations$Metadatastores$Executions$Queryexecutioninputsandoutputs, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1LineageSubgraph>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1LineageSubgraph>): void;
        queryExecutionInputsAndOutputs(params: Params$Resource$Projects$Locations$Metadatastores$Executions$Queryexecutioninputsandoutputs, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1LineageSubgraph>): void;
        queryExecutionInputsAndOutputs(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1LineageSubgraph>): void;
    }
    export interface Params$Resource$Projects$Locations$Metadatastores$Executions$Addexecutionevents extends StandardParameters {
        /**
         * Required. The resource name of the Execution that the Events connect Artifacts with. Format: `projects/{project\}/locations/{location\}/metadataStores/{metadatastore\}/executions/{execution\}`
         */
        execution?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1AddExecutionEventsRequest;
    }
    export interface Params$Resource$Projects$Locations$Metadatastores$Executions$Create extends StandardParameters {
        /**
         * The {execution\} portion of the resource name with the format: `projects/{project\}/locations/{location\}/metadataStores/{metadatastore\}/executions/{execution\}` If not provided, the Execution's ID will be a UUID generated by the service. Must be 4-128 characters in length. Valid characters are `/a-z-/`. Must be unique across all Executions in the parent MetadataStore. (Otherwise the request will fail with ALREADY_EXISTS, or PERMISSION_DENIED if the caller can't view the preexisting Execution.)
         */
        executionId?: string;
        /**
         * Required. The resource name of the MetadataStore where the Execution should be created. Format: `projects/{project\}/locations/{location\}/metadataStores/{metadatastore\}`
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1Execution;
    }
    export interface Params$Resource$Projects$Locations$Metadatastores$Executions$Delete extends StandardParameters {
        /**
         * Optional. The etag of the Execution to delete. If this is provided, it must match the server's etag. Otherwise, the request will fail with a FAILED_PRECONDITION.
         */
        etag?: string;
        /**
         * Required. The resource name of the Execution to delete. Format: `projects/{project\}/locations/{location\}/metadataStores/{metadatastore\}/executions/{execution\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Metadatastores$Executions$Get extends StandardParameters {
        /**
         * Required. The resource name of the Execution to retrieve. Format: `projects/{project\}/locations/{location\}/metadataStores/{metadatastore\}/executions/{execution\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Metadatastores$Executions$List extends StandardParameters {
        /**
         * Filter specifying the boolean condition for the Executions to satisfy in order to be part of the result set. The syntax to define filter query is based on https://google.aip.dev/160. Following are the supported set of filters: * **Attribute filtering**: For example: `display_name = "test"`. Supported fields include: `name`, `display_name`, `state`, `schema_title`, `create_time`, and `update_time`. Time fields, such as `create_time` and `update_time`, require values specified in RFC-3339 format. For example: `create_time = "2020-11-19T11:30:00-04:00"`. * **Metadata field**: To filter on metadata fields use traversal operation as follows: `metadata..` For example: `metadata.field_1.number_value = 10.0` In case the field name contains special characters (such as colon), one can embed it inside double quote. For example: `metadata."field:1".number_value = 10.0` * **Context based filtering**: To filter Executions based on the contexts to which they belong use the function operator with the full resource name: `in_context()`. For example: `in_context("projects//locations//metadataStores//contexts/")` Each of the above supported filters can be combined together using logical operators (`AND` & `OR`). Maximum nested expression depth allowed is 5. For example: `display_name = "test" AND metadata.field1.bool_value = true`.
         */
        filter?: string;
        /**
         * How the list of messages is ordered. Specify the values to order by and an ordering operation. The default sorting order is ascending. To specify descending order for a field, users append a " desc" suffix; for example: "foo desc, bar". Subfields are specified with a `.` character, such as foo.bar. see https://google.aip.dev/132#ordering for more details.
         */
        orderBy?: string;
        /**
         * The maximum number of Executions to return. The service may return fewer. Must be in range 1-1000, inclusive. Defaults to 100.
         */
        pageSize?: number;
        /**
         * A page token, received from a previous MetadataService.ListExecutions call. Provide this to retrieve the subsequent page. When paginating, all other provided parameters must match the call that provided the page token. (Otherwise the request will fail with an INVALID_ARGUMENT error.)
         */
        pageToken?: string;
        /**
         * Required. The MetadataStore whose Executions should be listed. Format: `projects/{project\}/locations/{location\}/metadataStores/{metadatastore\}`
         */
        parent?: string;
    }
    export interface Params$Resource$Projects$Locations$Metadatastores$Executions$Patch extends StandardParameters {
        /**
         * If set to true, and the Execution is not found, a new Execution is created.
         */
        allowMissing?: boolean;
        /**
         * Output only. The resource name of the Execution.
         */
        name?: string;
        /**
         * Optional. A FieldMask indicating which fields should be updated.
         */
        updateMask?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1Execution;
    }
    export interface Params$Resource$Projects$Locations$Metadatastores$Executions$Purge extends StandardParameters {
        /**
         * Required. The metadata store to purge Executions from. Format: `projects/{project\}/locations/{location\}/metadataStores/{metadatastore\}`
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1PurgeExecutionsRequest;
    }
    export interface Params$Resource$Projects$Locations$Metadatastores$Executions$Queryexecutioninputsandoutputs extends StandardParameters {
        /**
         * Required. The resource name of the Execution whose input and output Artifacts should be retrieved as a LineageSubgraph. Format: `projects/{project\}/locations/{location\}/metadataStores/{metadatastore\}/executions/{execution\}`
         */
        execution?: string;
    }
    export class Resource$Projects$Locations$Metadatastores$Metadataschemas {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Creates a MetadataSchema.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        create(params: Params$Resource$Projects$Locations$Metadatastores$Metadataschemas$Create, options: StreamMethodOptions): GaxiosPromise<Readable>;
        create(params?: Params$Resource$Projects$Locations$Metadatastores$Metadataschemas$Create, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1MetadataSchema>;
        create(params: Params$Resource$Projects$Locations$Metadatastores$Metadataschemas$Create, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        create(params: Params$Resource$Projects$Locations$Metadatastores$Metadataschemas$Create, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1MetadataSchema>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1MetadataSchema>): void;
        create(params: Params$Resource$Projects$Locations$Metadatastores$Metadataschemas$Create, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1MetadataSchema>): void;
        create(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1MetadataSchema>): void;
        /**
         * Retrieves a specific MetadataSchema.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Metadatastores$Metadataschemas$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Metadatastores$Metadataschemas$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1MetadataSchema>;
        get(params: Params$Resource$Projects$Locations$Metadatastores$Metadataschemas$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Metadatastores$Metadataschemas$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1MetadataSchema>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1MetadataSchema>): void;
        get(params: Params$Resource$Projects$Locations$Metadatastores$Metadataschemas$Get, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1MetadataSchema>): void;
        get(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1MetadataSchema>): void;
        /**
         * Lists MetadataSchemas.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Metadatastores$Metadataschemas$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Metadatastores$Metadataschemas$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListMetadataSchemasResponse>;
        list(params: Params$Resource$Projects$Locations$Metadatastores$Metadataschemas$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Metadatastores$Metadataschemas$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListMetadataSchemasResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListMetadataSchemasResponse>): void;
        list(params: Params$Resource$Projects$Locations$Metadatastores$Metadataschemas$List, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListMetadataSchemasResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListMetadataSchemasResponse>): void;
    }
    export interface Params$Resource$Projects$Locations$Metadatastores$Metadataschemas$Create extends StandardParameters {
        /**
         * The {metadata_schema\} portion of the resource name with the format: `projects/{project\}/locations/{location\}/metadataStores/{metadatastore\}/metadataSchemas/{metadataschema\}` If not provided, the MetadataStore's ID will be a UUID generated by the service. Must be 4-128 characters in length. Valid characters are `/a-z-/`. Must be unique across all MetadataSchemas in the parent Location. (Otherwise the request will fail with ALREADY_EXISTS, or PERMISSION_DENIED if the caller can't view the preexisting MetadataSchema.)
         */
        metadataSchemaId?: string;
        /**
         * Required. The resource name of the MetadataStore where the MetadataSchema should be created. Format: `projects/{project\}/locations/{location\}/metadataStores/{metadatastore\}`
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1MetadataSchema;
    }
    export interface Params$Resource$Projects$Locations$Metadatastores$Metadataschemas$Get extends StandardParameters {
        /**
         * Required. The resource name of the MetadataSchema to retrieve. Format: `projects/{project\}/locations/{location\}/metadataStores/{metadatastore\}/metadataSchemas/{metadataschema\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Metadatastores$Metadataschemas$List extends StandardParameters {
        /**
         * A query to filter available MetadataSchemas for matching results.
         */
        filter?: string;
        /**
         * The maximum number of MetadataSchemas to return. The service may return fewer. Must be in range 1-1000, inclusive. Defaults to 100.
         */
        pageSize?: number;
        /**
         * A page token, received from a previous MetadataService.ListMetadataSchemas call. Provide this to retrieve the next page. When paginating, all other provided parameters must match the call that provided the page token. (Otherwise the request will fail with INVALID_ARGUMENT error.)
         */
        pageToken?: string;
        /**
         * Required. The MetadataStore whose MetadataSchemas should be listed. Format: `projects/{project\}/locations/{location\}/metadataStores/{metadatastore\}`
         */
        parent?: string;
    }
    export class Resource$Projects$Locations$Migratableresources {
        context: APIRequestContext;
        operations: Resource$Projects$Locations$Migratableresources$Operations;
        constructor(context: APIRequestContext);
        /**
         * Batch migrates resources from ml.googleapis.com, automl.googleapis.com, and datalabeling.googleapis.com to Vertex AI.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        batchMigrate(params: Params$Resource$Projects$Locations$Migratableresources$Batchmigrate, options: StreamMethodOptions): GaxiosPromise<Readable>;
        batchMigrate(params?: Params$Resource$Projects$Locations$Migratableresources$Batchmigrate, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        batchMigrate(params: Params$Resource$Projects$Locations$Migratableresources$Batchmigrate, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        batchMigrate(params: Params$Resource$Projects$Locations$Migratableresources$Batchmigrate, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        batchMigrate(params: Params$Resource$Projects$Locations$Migratableresources$Batchmigrate, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        batchMigrate(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Searches all of the resources in automl.googleapis.com, datalabeling.googleapis.com and ml.googleapis.com that can be migrated to Vertex AI's given location.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        search(params: Params$Resource$Projects$Locations$Migratableresources$Search, options: StreamMethodOptions): GaxiosPromise<Readable>;
        search(params?: Params$Resource$Projects$Locations$Migratableresources$Search, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1SearchMigratableResourcesResponse>;
        search(params: Params$Resource$Projects$Locations$Migratableresources$Search, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        search(params: Params$Resource$Projects$Locations$Migratableresources$Search, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1SearchMigratableResourcesResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1SearchMigratableResourcesResponse>): void;
        search(params: Params$Resource$Projects$Locations$Migratableresources$Search, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1SearchMigratableResourcesResponse>): void;
        search(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1SearchMigratableResourcesResponse>): void;
    }
    export interface Params$Resource$Projects$Locations$Migratableresources$Batchmigrate extends StandardParameters {
        /**
         * Required. The location of the migrated resource will live in. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1BatchMigrateResourcesRequest;
    }
    export interface Params$Resource$Projects$Locations$Migratableresources$Search extends StandardParameters {
        /**
         * Required. The location that the migratable resources should be searched from. It's the Vertex AI location that the resources can be migrated to, not the resources' original location. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1SearchMigratableResourcesRequest;
    }
    export class Resource$Projects$Locations$Migratableresources$Operations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to `Code.CANCELLED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Projects$Locations$Migratableresources$Operations$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Projects$Locations$Migratableresources$Operations$Cancel, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        cancel(params: Params$Resource$Projects$Locations$Migratableresources$Operations$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Projects$Locations$Migratableresources$Operations$Cancel, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(params: Params$Resource$Projects$Locations$Migratableresources$Operations$Cancel, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Migratableresources$Operations$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Migratableresources$Operations$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        delete(params: Params$Resource$Projects$Locations$Migratableresources$Operations$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Migratableresources$Operations$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(params: Params$Resource$Projects$Locations$Migratableresources$Operations$Delete, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Migratableresources$Operations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Migratableresources$Operations$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        get(params: Params$Resource$Projects$Locations$Migratableresources$Operations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Migratableresources$Operations$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(params: Params$Resource$Projects$Locations$Migratableresources$Operations$Get, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns `UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Migratableresources$Operations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Migratableresources$Operations$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningListOperationsResponse>;
        list(params: Params$Resource$Projects$Locations$Migratableresources$Operations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Migratableresources$Operations$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Migratableresources$Operations$List, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        /**
         * Waits until the specified long-running operation is done or reaches at most a specified timeout, returning the latest state. If the operation is already done, the latest state is immediately returned. If the timeout specified is greater than the default HTTP/RPC timeout, the HTTP/RPC timeout is used. If the server does not support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Note that this method is on a best-effort basis. It may return the latest state before the specified timeout (including immediately), meaning even an immediate response is no guarantee that the operation is done.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        wait(params: Params$Resource$Projects$Locations$Migratableresources$Operations$Wait, options: StreamMethodOptions): GaxiosPromise<Readable>;
        wait(params?: Params$Resource$Projects$Locations$Migratableresources$Operations$Wait, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        wait(params: Params$Resource$Projects$Locations$Migratableresources$Operations$Wait, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        wait(params: Params$Resource$Projects$Locations$Migratableresources$Operations$Wait, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(params: Params$Resource$Projects$Locations$Migratableresources$Operations$Wait, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
    }
    export interface Params$Resource$Projects$Locations$Migratableresources$Operations$Cancel extends StandardParameters {
        /**
         * The name of the operation resource to be cancelled.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Migratableresources$Operations$Delete extends StandardParameters {
        /**
         * The name of the operation resource to be deleted.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Migratableresources$Operations$Get extends StandardParameters {
        /**
         * The name of the operation resource.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Migratableresources$Operations$List extends StandardParameters {
        /**
         * The standard list filter.
         */
        filter?: string;
        /**
         * The name of the operation's parent resource.
         */
        name?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token.
         */
        pageToken?: string;
    }
    export interface Params$Resource$Projects$Locations$Migratableresources$Operations$Wait extends StandardParameters {
        /**
         * The name of the operation resource to wait on.
         */
        name?: string;
        /**
         * The maximum duration to wait before timing out. If left blank, the wait will be at most the time permitted by the underlying HTTP/RPC protocol. If RPC context deadline is also specified, the shorter one will be used.
         */
        timeout?: string;
    }
    export class Resource$Projects$Locations$Modeldeploymentmonitoringjobs {
        context: APIRequestContext;
        operations: Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Operations;
        constructor(context: APIRequestContext);
        /**
         * Creates a ModelDeploymentMonitoringJob. It will run periodically on a configured interval.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        create(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Create, options: StreamMethodOptions): GaxiosPromise<Readable>;
        create(params?: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Create, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ModelDeploymentMonitoringJob>;
        create(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Create, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        create(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Create, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ModelDeploymentMonitoringJob>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ModelDeploymentMonitoringJob>): void;
        create(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Create, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ModelDeploymentMonitoringJob>): void;
        create(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ModelDeploymentMonitoringJob>): void;
        /**
         * Deletes a ModelDeploymentMonitoringJob.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        delete(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Delete, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Gets a ModelDeploymentMonitoringJob.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ModelDeploymentMonitoringJob>;
        get(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ModelDeploymentMonitoringJob>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ModelDeploymentMonitoringJob>): void;
        get(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Get, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ModelDeploymentMonitoringJob>): void;
        get(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ModelDeploymentMonitoringJob>): void;
        /**
         * Lists ModelDeploymentMonitoringJobs in a Location.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListModelDeploymentMonitoringJobsResponse>;
        list(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListModelDeploymentMonitoringJobsResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListModelDeploymentMonitoringJobsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$List, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListModelDeploymentMonitoringJobsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListModelDeploymentMonitoringJobsResponse>): void;
        /**
         * Updates a ModelDeploymentMonitoringJob.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Patch, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        patch(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Patch, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        patch(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Patch, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        patch(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Pauses a ModelDeploymentMonitoringJob. If the job is running, the server makes a best effort to cancel the job. Will mark ModelDeploymentMonitoringJob.state to 'PAUSED'.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        pause(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Pause, options: StreamMethodOptions): GaxiosPromise<Readable>;
        pause(params?: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Pause, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        pause(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Pause, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        pause(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Pause, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        pause(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Pause, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        pause(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Resumes a paused ModelDeploymentMonitoringJob. It will start to run from next scheduled time. A deleted ModelDeploymentMonitoringJob can't be resumed.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        resume(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Resume, options: StreamMethodOptions): GaxiosPromise<Readable>;
        resume(params?: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Resume, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        resume(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Resume, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        resume(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Resume, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        resume(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Resume, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        resume(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Searches Model Monitoring Statistics generated within a given time window.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        searchModelDeploymentMonitoringStatsAnomalies(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Searchmodeldeploymentmonitoringstatsanomalies, options: StreamMethodOptions): GaxiosPromise<Readable>;
        searchModelDeploymentMonitoringStatsAnomalies(params?: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Searchmodeldeploymentmonitoringstatsanomalies, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1SearchModelDeploymentMonitoringStatsAnomaliesResponse>;
        searchModelDeploymentMonitoringStatsAnomalies(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Searchmodeldeploymentmonitoringstatsanomalies, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        searchModelDeploymentMonitoringStatsAnomalies(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Searchmodeldeploymentmonitoringstatsanomalies, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1SearchModelDeploymentMonitoringStatsAnomaliesResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1SearchModelDeploymentMonitoringStatsAnomaliesResponse>): void;
        searchModelDeploymentMonitoringStatsAnomalies(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Searchmodeldeploymentmonitoringstatsanomalies, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1SearchModelDeploymentMonitoringStatsAnomaliesResponse>): void;
        searchModelDeploymentMonitoringStatsAnomalies(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1SearchModelDeploymentMonitoringStatsAnomaliesResponse>): void;
    }
    export interface Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Create extends StandardParameters {
        /**
         * Required. The parent of the ModelDeploymentMonitoringJob. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1ModelDeploymentMonitoringJob;
    }
    export interface Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Delete extends StandardParameters {
        /**
         * Required. The resource name of the model monitoring job to delete. Format: `projects/{project\}/locations/{location\}/modelDeploymentMonitoringJobs/{model_deployment_monitoring_job\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Get extends StandardParameters {
        /**
         * Required. The resource name of the ModelDeploymentMonitoringJob. Format: `projects/{project\}/locations/{location\}/modelDeploymentMonitoringJobs/{model_deployment_monitoring_job\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$List extends StandardParameters {
        /**
         * The standard list filter. Supported fields: * `display_name` supports `=`, `!=` comparisons, and `:` wildcard. * `state` supports `=`, `!=` comparisons. * `create_time` supports `=`, `!=`,`<`, `<=`,`\>`, `\>=` comparisons. `create_time` must be in RFC 3339 format. * `labels` supports general map functions that is: `labels.key=value` - key:value equality `labels.key:* - key existence Some examples of using the filter are: * `state="JOB_STATE_SUCCEEDED" AND display_name:"my_job_*"` * `state!="JOB_STATE_FAILED" OR display_name="my_job"` * `NOT display_name="my_job"` * `create_time\>"2021-05-18T00:00:00Z"` * `labels.keyA=valueA` * `labels.keyB:*`
         */
        filter?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token.
         */
        pageToken?: string;
        /**
         * Required. The parent of the ModelDeploymentMonitoringJob. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Mask specifying which fields to read
         */
        readMask?: string;
    }
    export interface Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Patch extends StandardParameters {
        /**
         * Output only. Resource name of a ModelDeploymentMonitoringJob.
         */
        name?: string;
        /**
         * Required. The update mask is used to specify the fields to be overwritten in the ModelDeploymentMonitoringJob resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask. If the user does not provide a mask then only the non-empty fields present in the request will be overwritten. Set the update_mask to `*` to override all fields. For the objective config, the user can either provide the update mask for model_deployment_monitoring_objective_configs or any combination of its nested fields, such as: model_deployment_monitoring_objective_configs.objective_config.training_dataset. Updatable fields: * `display_name` * `model_deployment_monitoring_schedule_config` * `model_monitoring_alert_config` * `logging_sampling_strategy` * `labels` * `log_ttl` * `enable_monitoring_pipeline_logs` . and * `model_deployment_monitoring_objective_configs` . or * `model_deployment_monitoring_objective_configs.objective_config.training_dataset` * `model_deployment_monitoring_objective_configs.objective_config.training_prediction_skew_detection_config` * `model_deployment_monitoring_objective_configs.objective_config.prediction_drift_detection_config`
         */
        updateMask?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1ModelDeploymentMonitoringJob;
    }
    export interface Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Pause extends StandardParameters {
        /**
         * Required. The resource name of the ModelDeploymentMonitoringJob to pause. Format: `projects/{project\}/locations/{location\}/modelDeploymentMonitoringJobs/{model_deployment_monitoring_job\}`
         */
        name?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1PauseModelDeploymentMonitoringJobRequest;
    }
    export interface Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Resume extends StandardParameters {
        /**
         * Required. The resource name of the ModelDeploymentMonitoringJob to resume. Format: `projects/{project\}/locations/{location\}/modelDeploymentMonitoringJobs/{model_deployment_monitoring_job\}`
         */
        name?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1ResumeModelDeploymentMonitoringJobRequest;
    }
    export interface Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Searchmodeldeploymentmonitoringstatsanomalies extends StandardParameters {
        /**
         * Required. ModelDeploymentMonitoring Job resource name. Format: `projects/{project\}/locations/{location\}/modelDeploymentMonitoringJobs/{model_deployment_monitoring_job\}`
         */
        modelDeploymentMonitoringJob?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1SearchModelDeploymentMonitoringStatsAnomaliesRequest;
    }
    export class Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Operations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to `Code.CANCELLED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Operations$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Operations$Cancel, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        cancel(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Operations$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Operations$Cancel, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Operations$Cancel, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Operations$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Operations$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        delete(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Operations$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Operations$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Operations$Delete, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Operations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Operations$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        get(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Operations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Operations$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Operations$Get, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns `UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Operations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Operations$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningListOperationsResponse>;
        list(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Operations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Operations$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Operations$List, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        /**
         * Waits until the specified long-running operation is done or reaches at most a specified timeout, returning the latest state. If the operation is already done, the latest state is immediately returned. If the timeout specified is greater than the default HTTP/RPC timeout, the HTTP/RPC timeout is used. If the server does not support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Note that this method is on a best-effort basis. It may return the latest state before the specified timeout (including immediately), meaning even an immediate response is no guarantee that the operation is done.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        wait(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Operations$Wait, options: StreamMethodOptions): GaxiosPromise<Readable>;
        wait(params?: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Operations$Wait, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        wait(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Operations$Wait, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        wait(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Operations$Wait, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(params: Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Operations$Wait, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
    }
    export interface Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Operations$Cancel extends StandardParameters {
        /**
         * The name of the operation resource to be cancelled.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Operations$Delete extends StandardParameters {
        /**
         * The name of the operation resource to be deleted.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Operations$Get extends StandardParameters {
        /**
         * The name of the operation resource.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Operations$List extends StandardParameters {
        /**
         * The standard list filter.
         */
        filter?: string;
        /**
         * The name of the operation's parent resource.
         */
        name?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token.
         */
        pageToken?: string;
    }
    export interface Params$Resource$Projects$Locations$Modeldeploymentmonitoringjobs$Operations$Wait extends StandardParameters {
        /**
         * The name of the operation resource to wait on.
         */
        name?: string;
        /**
         * The maximum duration to wait before timing out. If left blank, the wait will be at most the time permitted by the underlying HTTP/RPC protocol. If RPC context deadline is also specified, the shorter one will be used.
         */
        timeout?: string;
    }
    export class Resource$Projects$Locations$Models {
        context: APIRequestContext;
        evaluations: Resource$Projects$Locations$Models$Evaluations;
        operations: Resource$Projects$Locations$Models$Operations;
        constructor(context: APIRequestContext);
        /**
         * Copies an already existing Vertex AI Model into the specified Location. The source Model must exist in the same Project. When copying custom Models, the users themselves are responsible for Model.metadata content to be region-agnostic, as well as making sure that any resources (e.g. files) it depends on remain accessible.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        copy(params: Params$Resource$Projects$Locations$Models$Copy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        copy(params?: Params$Resource$Projects$Locations$Models$Copy, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        copy(params: Params$Resource$Projects$Locations$Models$Copy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        copy(params: Params$Resource$Projects$Locations$Models$Copy, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        copy(params: Params$Resource$Projects$Locations$Models$Copy, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        copy(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Deletes a Model. A model cannot be deleted if any Endpoint resource has a DeployedModel based on the model in its deployed_models field.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Models$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Models$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        delete(params: Params$Resource$Projects$Locations$Models$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Models$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(params: Params$Resource$Projects$Locations$Models$Delete, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Deletes a Model version. Model version can only be deleted if there are no DeployedModels created from it. Deleting the only version in the Model is not allowed. Use DeleteModel for deleting the Model instead.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        deleteVersion(params: Params$Resource$Projects$Locations$Models$Deleteversion, options: StreamMethodOptions): GaxiosPromise<Readable>;
        deleteVersion(params?: Params$Resource$Projects$Locations$Models$Deleteversion, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        deleteVersion(params: Params$Resource$Projects$Locations$Models$Deleteversion, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        deleteVersion(params: Params$Resource$Projects$Locations$Models$Deleteversion, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        deleteVersion(params: Params$Resource$Projects$Locations$Models$Deleteversion, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        deleteVersion(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Exports a trained, exportable Model to a location specified by the user. A Model is considered to be exportable if it has at least one supported export format.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        export(params: Params$Resource$Projects$Locations$Models$Export, options: StreamMethodOptions): GaxiosPromise<Readable>;
        export(params?: Params$Resource$Projects$Locations$Models$Export, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        export(params: Params$Resource$Projects$Locations$Models$Export, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        export(params: Params$Resource$Projects$Locations$Models$Export, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        export(params: Params$Resource$Projects$Locations$Models$Export, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        export(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Gets a Model.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Models$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Models$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1Model>;
        get(params: Params$Resource$Projects$Locations$Models$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Models$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1Model>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Model>): void;
        get(params: Params$Resource$Projects$Locations$Models$Get, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Model>): void;
        get(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Model>): void;
        /**
         * Lists Models in a Location.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Models$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Models$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListModelsResponse>;
        list(params: Params$Resource$Projects$Locations$Models$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Models$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListModelsResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListModelsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Models$List, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListModelsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListModelsResponse>): void;
        /**
         * Lists versions of the specified model.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        listVersions(params: Params$Resource$Projects$Locations$Models$Listversions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        listVersions(params?: Params$Resource$Projects$Locations$Models$Listversions, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListModelVersionsResponse>;
        listVersions(params: Params$Resource$Projects$Locations$Models$Listversions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        listVersions(params: Params$Resource$Projects$Locations$Models$Listversions, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListModelVersionsResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListModelVersionsResponse>): void;
        listVersions(params: Params$Resource$Projects$Locations$Models$Listversions, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListModelVersionsResponse>): void;
        listVersions(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListModelVersionsResponse>): void;
        /**
         * Merges a set of aliases for a Model version.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        mergeVersionAliases(params: Params$Resource$Projects$Locations$Models$Mergeversionaliases, options: StreamMethodOptions): GaxiosPromise<Readable>;
        mergeVersionAliases(params?: Params$Resource$Projects$Locations$Models$Mergeversionaliases, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1Model>;
        mergeVersionAliases(params: Params$Resource$Projects$Locations$Models$Mergeversionaliases, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        mergeVersionAliases(params: Params$Resource$Projects$Locations$Models$Mergeversionaliases, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1Model>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Model>): void;
        mergeVersionAliases(params: Params$Resource$Projects$Locations$Models$Mergeversionaliases, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Model>): void;
        mergeVersionAliases(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Model>): void;
        /**
         * Updates a Model.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Projects$Locations$Models$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Projects$Locations$Models$Patch, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1Model>;
        patch(params: Params$Resource$Projects$Locations$Models$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Projects$Locations$Models$Patch, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1Model>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Model>): void;
        patch(params: Params$Resource$Projects$Locations$Models$Patch, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Model>): void;
        patch(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Model>): void;
        /**
         * Incrementally update the dataset used for an examples model.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        updateExplanationDataset(params: Params$Resource$Projects$Locations$Models$Updateexplanationdataset, options: StreamMethodOptions): GaxiosPromise<Readable>;
        updateExplanationDataset(params?: Params$Resource$Projects$Locations$Models$Updateexplanationdataset, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        updateExplanationDataset(params: Params$Resource$Projects$Locations$Models$Updateexplanationdataset, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        updateExplanationDataset(params: Params$Resource$Projects$Locations$Models$Updateexplanationdataset, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        updateExplanationDataset(params: Params$Resource$Projects$Locations$Models$Updateexplanationdataset, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        updateExplanationDataset(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Uploads a Model artifact into Vertex AI.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        upload(params: Params$Resource$Projects$Locations$Models$Upload, options: StreamMethodOptions): GaxiosPromise<Readable>;
        upload(params?: Params$Resource$Projects$Locations$Models$Upload, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        upload(params: Params$Resource$Projects$Locations$Models$Upload, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        upload(params: Params$Resource$Projects$Locations$Models$Upload, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        upload(params: Params$Resource$Projects$Locations$Models$Upload, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        upload(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
    }
    export interface Params$Resource$Projects$Locations$Models$Copy extends StandardParameters {
        /**
         * Required. The resource name of the Location into which to copy the Model. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1CopyModelRequest;
    }
    export interface Params$Resource$Projects$Locations$Models$Delete extends StandardParameters {
        /**
         * Required. The name of the Model resource to be deleted. Format: `projects/{project\}/locations/{location\}/models/{model\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Models$Deleteversion extends StandardParameters {
        /**
         * Required. The name of the model version to be deleted, with a version ID explicitly included. Example: `projects/{project\}/locations/{location\}/models/{model\}@1234`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Models$Export extends StandardParameters {
        /**
         * Required. The resource name of the Model to export. The resource name may contain version id or version alias to specify the version, if no version is specified, the default version will be exported.
         */
        name?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1ExportModelRequest;
    }
    export interface Params$Resource$Projects$Locations$Models$Get extends StandardParameters {
        /**
         * Required. The name of the Model resource. Format: `projects/{project\}/locations/{location\}/models/{model\}` In order to retrieve a specific version of the model, also provide the version ID or version alias. Example: `projects/{project\}/locations/{location\}/models/{model\}@2` or `projects/{project\}/locations/{location\}/models/{model\}@golden` If no version ID or alias is specified, the "default" version will be returned. The "default" version alias is created for the first version of the model, and can be moved to other versions later on. There will be exactly one default version.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Models$List extends StandardParameters {
        /**
         * An expression for filtering the results of the request. For field names both snake_case and camelCase are supported. * `model` supports = and !=. `model` represents the Model ID, i.e. the last segment of the Model's resource name. * `display_name` supports = and != * `labels` supports general map functions that is: * `labels.key=value` - key:value equality * `labels.key:* or labels:key - key existence * A key including a space must be quoted. `labels."a key"`. Some examples: * `model=1234` * `displayName="myDisplayName"` * `labels.myKey="myValue"`
         */
        filter?: string;
        /**
         * A comma-separated list of fields to order by, sorted in ascending order. Use "desc" after a field name for descending. Supported fields: * `display_name` * `create_time` * `update_time` Example: `display_name, create_time desc`.
         */
        orderBy?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token. Typically obtained via ListModelsResponse.next_page_token of the previous ModelService.ListModels call.
         */
        pageToken?: string;
        /**
         * Required. The resource name of the Location to list the Models from. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Mask specifying which fields to read.
         */
        readMask?: string;
    }
    export interface Params$Resource$Projects$Locations$Models$Listversions extends StandardParameters {
        /**
         * An expression for filtering the results of the request. For field names both snake_case and camelCase are supported. * `labels` supports general map functions that is: * `labels.key=value` - key:value equality * `labels.key:* or labels:key - key existence * A key including a space must be quoted. `labels."a key"`. Some examples: * `labels.myKey="myValue"`
         */
        filter?: string;
        /**
         * Required. The name of the model to list versions for.
         */
        name?: string;
        /**
         * A comma-separated list of fields to order by, sorted in ascending order. Use "desc" after a field name for descending. Supported fields: * `create_time` * `update_time` Example: `update_time asc, create_time desc`.
         */
        orderBy?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token. Typically obtained via next_page_token of the previous ListModelVersions call.
         */
        pageToken?: string;
        /**
         * Mask specifying which fields to read.
         */
        readMask?: string;
    }
    export interface Params$Resource$Projects$Locations$Models$Mergeversionaliases extends StandardParameters {
        /**
         * Required. The name of the model version to merge aliases, with a version ID explicitly included. Example: `projects/{project\}/locations/{location\}/models/{model\}@1234`
         */
        name?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1MergeVersionAliasesRequest;
    }
    export interface Params$Resource$Projects$Locations$Models$Patch extends StandardParameters {
        /**
         * The resource name of the Model.
         */
        name?: string;
        /**
         * Required. The update mask applies to the resource. For the `FieldMask` definition, see google.protobuf.FieldMask.
         */
        updateMask?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1Model;
    }
    export interface Params$Resource$Projects$Locations$Models$Updateexplanationdataset extends StandardParameters {
        /**
         * Required. The resource name of the Model to update. Format: `projects/{project\}/locations/{location\}/models/{model\}`
         */
        model?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1UpdateExplanationDatasetRequest;
    }
    export interface Params$Resource$Projects$Locations$Models$Upload extends StandardParameters {
        /**
         * Required. The resource name of the Location into which to upload the Model. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1UploadModelRequest;
    }
    export class Resource$Projects$Locations$Models$Evaluations {
        context: APIRequestContext;
        operations: Resource$Projects$Locations$Models$Evaluations$Operations;
        slices: Resource$Projects$Locations$Models$Evaluations$Slices;
        constructor(context: APIRequestContext);
        /**
         * Gets a ModelEvaluation.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Models$Evaluations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Models$Evaluations$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ModelEvaluation>;
        get(params: Params$Resource$Projects$Locations$Models$Evaluations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Models$Evaluations$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ModelEvaluation>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ModelEvaluation>): void;
        get(params: Params$Resource$Projects$Locations$Models$Evaluations$Get, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ModelEvaluation>): void;
        get(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ModelEvaluation>): void;
        /**
         * Imports an externally generated ModelEvaluation.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        import(params: Params$Resource$Projects$Locations$Models$Evaluations$Import, options: StreamMethodOptions): GaxiosPromise<Readable>;
        import(params?: Params$Resource$Projects$Locations$Models$Evaluations$Import, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ModelEvaluation>;
        import(params: Params$Resource$Projects$Locations$Models$Evaluations$Import, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        import(params: Params$Resource$Projects$Locations$Models$Evaluations$Import, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ModelEvaluation>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ModelEvaluation>): void;
        import(params: Params$Resource$Projects$Locations$Models$Evaluations$Import, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ModelEvaluation>): void;
        import(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ModelEvaluation>): void;
        /**
         * Lists ModelEvaluations in a Model.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Models$Evaluations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Models$Evaluations$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListModelEvaluationsResponse>;
        list(params: Params$Resource$Projects$Locations$Models$Evaluations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Models$Evaluations$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListModelEvaluationsResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListModelEvaluationsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Models$Evaluations$List, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListModelEvaluationsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListModelEvaluationsResponse>): void;
    }
    export interface Params$Resource$Projects$Locations$Models$Evaluations$Get extends StandardParameters {
        /**
         * Required. The name of the ModelEvaluation resource. Format: `projects/{project\}/locations/{location\}/models/{model\}/evaluations/{evaluation\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Models$Evaluations$Import extends StandardParameters {
        /**
         * Required. The name of the parent model resource. Format: `projects/{project\}/locations/{location\}/models/{model\}`
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1ImportModelEvaluationRequest;
    }
    export interface Params$Resource$Projects$Locations$Models$Evaluations$List extends StandardParameters {
        /**
         * The standard list filter.
         */
        filter?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token. Typically obtained via ListModelEvaluationsResponse.next_page_token of the previous ModelService.ListModelEvaluations call.
         */
        pageToken?: string;
        /**
         * Required. The resource name of the Model to list the ModelEvaluations from. Format: `projects/{project\}/locations/{location\}/models/{model\}`
         */
        parent?: string;
        /**
         * Mask specifying which fields to read.
         */
        readMask?: string;
    }
    export class Resource$Projects$Locations$Models$Evaluations$Operations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to `Code.CANCELLED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Projects$Locations$Models$Evaluations$Operations$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Projects$Locations$Models$Evaluations$Operations$Cancel, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        cancel(params: Params$Resource$Projects$Locations$Models$Evaluations$Operations$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Projects$Locations$Models$Evaluations$Operations$Cancel, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(params: Params$Resource$Projects$Locations$Models$Evaluations$Operations$Cancel, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Models$Evaluations$Operations$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Models$Evaluations$Operations$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        delete(params: Params$Resource$Projects$Locations$Models$Evaluations$Operations$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Models$Evaluations$Operations$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(params: Params$Resource$Projects$Locations$Models$Evaluations$Operations$Delete, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Models$Evaluations$Operations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Models$Evaluations$Operations$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        get(params: Params$Resource$Projects$Locations$Models$Evaluations$Operations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Models$Evaluations$Operations$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(params: Params$Resource$Projects$Locations$Models$Evaluations$Operations$Get, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns `UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Models$Evaluations$Operations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Models$Evaluations$Operations$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningListOperationsResponse>;
        list(params: Params$Resource$Projects$Locations$Models$Evaluations$Operations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Models$Evaluations$Operations$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Models$Evaluations$Operations$List, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        /**
         * Waits until the specified long-running operation is done or reaches at most a specified timeout, returning the latest state. If the operation is already done, the latest state is immediately returned. If the timeout specified is greater than the default HTTP/RPC timeout, the HTTP/RPC timeout is used. If the server does not support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Note that this method is on a best-effort basis. It may return the latest state before the specified timeout (including immediately), meaning even an immediate response is no guarantee that the operation is done.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        wait(params: Params$Resource$Projects$Locations$Models$Evaluations$Operations$Wait, options: StreamMethodOptions): GaxiosPromise<Readable>;
        wait(params?: Params$Resource$Projects$Locations$Models$Evaluations$Operations$Wait, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        wait(params: Params$Resource$Projects$Locations$Models$Evaluations$Operations$Wait, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        wait(params: Params$Resource$Projects$Locations$Models$Evaluations$Operations$Wait, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(params: Params$Resource$Projects$Locations$Models$Evaluations$Operations$Wait, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
    }
    export interface Params$Resource$Projects$Locations$Models$Evaluations$Operations$Cancel extends StandardParameters {
        /**
         * The name of the operation resource to be cancelled.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Models$Evaluations$Operations$Delete extends StandardParameters {
        /**
         * The name of the operation resource to be deleted.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Models$Evaluations$Operations$Get extends StandardParameters {
        /**
         * The name of the operation resource.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Models$Evaluations$Operations$List extends StandardParameters {
        /**
         * The standard list filter.
         */
        filter?: string;
        /**
         * The name of the operation's parent resource.
         */
        name?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token.
         */
        pageToken?: string;
    }
    export interface Params$Resource$Projects$Locations$Models$Evaluations$Operations$Wait extends StandardParameters {
        /**
         * The name of the operation resource to wait on.
         */
        name?: string;
        /**
         * The maximum duration to wait before timing out. If left blank, the wait will be at most the time permitted by the underlying HTTP/RPC protocol. If RPC context deadline is also specified, the shorter one will be used.
         */
        timeout?: string;
    }
    export class Resource$Projects$Locations$Models$Evaluations$Slices {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Imports a list of externally generated EvaluatedAnnotations.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        batchImport(params: Params$Resource$Projects$Locations$Models$Evaluations$Slices$Batchimport, options: StreamMethodOptions): GaxiosPromise<Readable>;
        batchImport(params?: Params$Resource$Projects$Locations$Models$Evaluations$Slices$Batchimport, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1BatchImportEvaluatedAnnotationsResponse>;
        batchImport(params: Params$Resource$Projects$Locations$Models$Evaluations$Slices$Batchimport, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        batchImport(params: Params$Resource$Projects$Locations$Models$Evaluations$Slices$Batchimport, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1BatchImportEvaluatedAnnotationsResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1BatchImportEvaluatedAnnotationsResponse>): void;
        batchImport(params: Params$Resource$Projects$Locations$Models$Evaluations$Slices$Batchimport, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1BatchImportEvaluatedAnnotationsResponse>): void;
        batchImport(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1BatchImportEvaluatedAnnotationsResponse>): void;
        /**
         * Gets a ModelEvaluationSlice.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Models$Evaluations$Slices$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Models$Evaluations$Slices$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ModelEvaluationSlice>;
        get(params: Params$Resource$Projects$Locations$Models$Evaluations$Slices$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Models$Evaluations$Slices$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ModelEvaluationSlice>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ModelEvaluationSlice>): void;
        get(params: Params$Resource$Projects$Locations$Models$Evaluations$Slices$Get, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ModelEvaluationSlice>): void;
        get(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ModelEvaluationSlice>): void;
        /**
         * Lists ModelEvaluationSlices in a ModelEvaluation.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Models$Evaluations$Slices$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Models$Evaluations$Slices$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListModelEvaluationSlicesResponse>;
        list(params: Params$Resource$Projects$Locations$Models$Evaluations$Slices$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Models$Evaluations$Slices$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListModelEvaluationSlicesResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListModelEvaluationSlicesResponse>): void;
        list(params: Params$Resource$Projects$Locations$Models$Evaluations$Slices$List, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListModelEvaluationSlicesResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListModelEvaluationSlicesResponse>): void;
    }
    export interface Params$Resource$Projects$Locations$Models$Evaluations$Slices$Batchimport extends StandardParameters {
        /**
         * Required. The name of the parent ModelEvaluationSlice resource. Format: `projects/{project\}/locations/{location\}/models/{model\}/evaluations/{evaluation\}/slices/{slice\}`
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1BatchImportEvaluatedAnnotationsRequest;
    }
    export interface Params$Resource$Projects$Locations$Models$Evaluations$Slices$Get extends StandardParameters {
        /**
         * Required. The name of the ModelEvaluationSlice resource. Format: `projects/{project\}/locations/{location\}/models/{model\}/evaluations/{evaluation\}/slices/{slice\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Models$Evaluations$Slices$List extends StandardParameters {
        /**
         * The standard list filter. * `slice.dimension` - for =.
         */
        filter?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token. Typically obtained via ListModelEvaluationSlicesResponse.next_page_token of the previous ModelService.ListModelEvaluationSlices call.
         */
        pageToken?: string;
        /**
         * Required. The resource name of the ModelEvaluation to list the ModelEvaluationSlices from. Format: `projects/{project\}/locations/{location\}/models/{model\}/evaluations/{evaluation\}`
         */
        parent?: string;
        /**
         * Mask specifying which fields to read.
         */
        readMask?: string;
    }
    export class Resource$Projects$Locations$Models$Operations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to `Code.CANCELLED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Projects$Locations$Models$Operations$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Projects$Locations$Models$Operations$Cancel, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        cancel(params: Params$Resource$Projects$Locations$Models$Operations$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Projects$Locations$Models$Operations$Cancel, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(params: Params$Resource$Projects$Locations$Models$Operations$Cancel, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Models$Operations$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Models$Operations$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        delete(params: Params$Resource$Projects$Locations$Models$Operations$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Models$Operations$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(params: Params$Resource$Projects$Locations$Models$Operations$Delete, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Models$Operations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Models$Operations$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        get(params: Params$Resource$Projects$Locations$Models$Operations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Models$Operations$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(params: Params$Resource$Projects$Locations$Models$Operations$Get, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns `UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Models$Operations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Models$Operations$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningListOperationsResponse>;
        list(params: Params$Resource$Projects$Locations$Models$Operations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Models$Operations$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Models$Operations$List, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        /**
         * Waits until the specified long-running operation is done or reaches at most a specified timeout, returning the latest state. If the operation is already done, the latest state is immediately returned. If the timeout specified is greater than the default HTTP/RPC timeout, the HTTP/RPC timeout is used. If the server does not support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Note that this method is on a best-effort basis. It may return the latest state before the specified timeout (including immediately), meaning even an immediate response is no guarantee that the operation is done.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        wait(params: Params$Resource$Projects$Locations$Models$Operations$Wait, options: StreamMethodOptions): GaxiosPromise<Readable>;
        wait(params?: Params$Resource$Projects$Locations$Models$Operations$Wait, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        wait(params: Params$Resource$Projects$Locations$Models$Operations$Wait, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        wait(params: Params$Resource$Projects$Locations$Models$Operations$Wait, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(params: Params$Resource$Projects$Locations$Models$Operations$Wait, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
    }
    export interface Params$Resource$Projects$Locations$Models$Operations$Cancel extends StandardParameters {
        /**
         * The name of the operation resource to be cancelled.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Models$Operations$Delete extends StandardParameters {
        /**
         * The name of the operation resource to be deleted.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Models$Operations$Get extends StandardParameters {
        /**
         * The name of the operation resource.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Models$Operations$List extends StandardParameters {
        /**
         * The standard list filter.
         */
        filter?: string;
        /**
         * The name of the operation's parent resource.
         */
        name?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token.
         */
        pageToken?: string;
    }
    export interface Params$Resource$Projects$Locations$Models$Operations$Wait extends StandardParameters {
        /**
         * The name of the operation resource to wait on.
         */
        name?: string;
        /**
         * The maximum duration to wait before timing out. If left blank, the wait will be at most the time permitted by the underlying HTTP/RPC protocol. If RPC context deadline is also specified, the shorter one will be used.
         */
        timeout?: string;
    }
    export class Resource$Projects$Locations$Nasjobs {
        context: APIRequestContext;
        nasTrialDetails: Resource$Projects$Locations$Nasjobs$Nastrialdetails;
        constructor(context: APIRequestContext);
        /**
         * Cancels a NasJob. Starts asynchronous cancellation on the NasJob. The server makes a best effort to cancel the job, but success is not guaranteed. Clients can use JobService.GetNasJob or other methods to check whether the cancellation succeeded or whether the job completed despite cancellation. On successful cancellation, the NasJob is not deleted; instead it becomes a job with a NasJob.error value with a google.rpc.Status.code of 1, corresponding to `Code.CANCELLED`, and NasJob.state is set to `CANCELLED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Projects$Locations$Nasjobs$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Projects$Locations$Nasjobs$Cancel, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        cancel(params: Params$Resource$Projects$Locations$Nasjobs$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Projects$Locations$Nasjobs$Cancel, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(params: Params$Resource$Projects$Locations$Nasjobs$Cancel, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Creates a NasJob
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        create(params: Params$Resource$Projects$Locations$Nasjobs$Create, options: StreamMethodOptions): GaxiosPromise<Readable>;
        create(params?: Params$Resource$Projects$Locations$Nasjobs$Create, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1NasJob>;
        create(params: Params$Resource$Projects$Locations$Nasjobs$Create, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        create(params: Params$Resource$Projects$Locations$Nasjobs$Create, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1NasJob>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1NasJob>): void;
        create(params: Params$Resource$Projects$Locations$Nasjobs$Create, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1NasJob>): void;
        create(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1NasJob>): void;
        /**
         * Deletes a NasJob.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Nasjobs$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Nasjobs$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        delete(params: Params$Resource$Projects$Locations$Nasjobs$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Nasjobs$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(params: Params$Resource$Projects$Locations$Nasjobs$Delete, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Gets a NasJob
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Nasjobs$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Nasjobs$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1NasJob>;
        get(params: Params$Resource$Projects$Locations$Nasjobs$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Nasjobs$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1NasJob>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1NasJob>): void;
        get(params: Params$Resource$Projects$Locations$Nasjobs$Get, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1NasJob>): void;
        get(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1NasJob>): void;
        /**
         * Lists NasJobs in a Location.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Nasjobs$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Nasjobs$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListNasJobsResponse>;
        list(params: Params$Resource$Projects$Locations$Nasjobs$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Nasjobs$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListNasJobsResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListNasJobsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Nasjobs$List, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListNasJobsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListNasJobsResponse>): void;
    }
    export interface Params$Resource$Projects$Locations$Nasjobs$Cancel extends StandardParameters {
        /**
         * Required. The name of the NasJob to cancel. Format: `projects/{project\}/locations/{location\}/nasJobs/{nas_job\}`
         */
        name?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1CancelNasJobRequest;
    }
    export interface Params$Resource$Projects$Locations$Nasjobs$Create extends StandardParameters {
        /**
         * Required. The resource name of the Location to create the NasJob in. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1NasJob;
    }
    export interface Params$Resource$Projects$Locations$Nasjobs$Delete extends StandardParameters {
        /**
         * Required. The name of the NasJob resource to be deleted. Format: `projects/{project\}/locations/{location\}/nasJobs/{nas_job\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Nasjobs$Get extends StandardParameters {
        /**
         * Required. The name of the NasJob resource. Format: `projects/{project\}/locations/{location\}/nasJobs/{nas_job\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Nasjobs$List extends StandardParameters {
        /**
         * The standard list filter. Supported fields: * `display_name` supports `=`, `!=` comparisons, and `:` wildcard. * `state` supports `=`, `!=` comparisons. * `create_time` supports `=`, `!=`,`<`, `<=`,`\>`, `\>=` comparisons. `create_time` must be in RFC 3339 format. * `labels` supports general map functions that is: `labels.key=value` - key:value equality `labels.key:* - key existence Some examples of using the filter are: * `state="JOB_STATE_SUCCEEDED" AND display_name:"my_job_*"` * `state!="JOB_STATE_FAILED" OR display_name="my_job"` * `NOT display_name="my_job"` * `create_time\>"2021-05-18T00:00:00Z"` * `labels.keyA=valueA` * `labels.keyB:*`
         */
        filter?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token. Typically obtained via ListNasJobsResponse.next_page_token of the previous JobService.ListNasJobs call.
         */
        pageToken?: string;
        /**
         * Required. The resource name of the Location to list the NasJobs from. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Mask specifying which fields to read.
         */
        readMask?: string;
    }
    export class Resource$Projects$Locations$Nasjobs$Nastrialdetails {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Gets a NasTrialDetail.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Nasjobs$Nastrialdetails$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Nasjobs$Nastrialdetails$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1NasTrialDetail>;
        get(params: Params$Resource$Projects$Locations$Nasjobs$Nastrialdetails$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Nasjobs$Nastrialdetails$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1NasTrialDetail>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1NasTrialDetail>): void;
        get(params: Params$Resource$Projects$Locations$Nasjobs$Nastrialdetails$Get, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1NasTrialDetail>): void;
        get(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1NasTrialDetail>): void;
        /**
         * List top NasTrialDetails of a NasJob.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Nasjobs$Nastrialdetails$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Nasjobs$Nastrialdetails$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListNasTrialDetailsResponse>;
        list(params: Params$Resource$Projects$Locations$Nasjobs$Nastrialdetails$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Nasjobs$Nastrialdetails$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListNasTrialDetailsResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListNasTrialDetailsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Nasjobs$Nastrialdetails$List, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListNasTrialDetailsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListNasTrialDetailsResponse>): void;
    }
    export interface Params$Resource$Projects$Locations$Nasjobs$Nastrialdetails$Get extends StandardParameters {
        /**
         * Required. The name of the NasTrialDetail resource. Format: `projects/{project\}/locations/{location\}/nasJobs/{nas_job\}/nasTrialDetails/{nas_trial_detail\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Nasjobs$Nastrialdetails$List extends StandardParameters {
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token. Typically obtained via ListNasTrialDetailsResponse.next_page_token of the previous JobService.ListNasTrialDetails call.
         */
        pageToken?: string;
        /**
         * Required. The name of the NasJob resource. Format: `projects/{project\}/locations/{location\}/nasJobs/{nas_job\}`
         */
        parent?: string;
    }
    export class Resource$Projects$Locations$Notebookruntimes {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Assigns a NotebookRuntime to a user for a particular Notebook file. This method will either returns an existing assignment or generates a new one.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        assign(params: Params$Resource$Projects$Locations$Notebookruntimes$Assign, options: StreamMethodOptions): GaxiosPromise<Readable>;
        assign(params?: Params$Resource$Projects$Locations$Notebookruntimes$Assign, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        assign(params: Params$Resource$Projects$Locations$Notebookruntimes$Assign, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        assign(params: Params$Resource$Projects$Locations$Notebookruntimes$Assign, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        assign(params: Params$Resource$Projects$Locations$Notebookruntimes$Assign, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        assign(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Deletes a NotebookRuntime.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Notebookruntimes$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Notebookruntimes$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        delete(params: Params$Resource$Projects$Locations$Notebookruntimes$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Notebookruntimes$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(params: Params$Resource$Projects$Locations$Notebookruntimes$Delete, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Gets a NotebookRuntime.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Notebookruntimes$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Notebookruntimes$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1NotebookRuntime>;
        get(params: Params$Resource$Projects$Locations$Notebookruntimes$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Notebookruntimes$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1NotebookRuntime>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1NotebookRuntime>): void;
        get(params: Params$Resource$Projects$Locations$Notebookruntimes$Get, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1NotebookRuntime>): void;
        get(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1NotebookRuntime>): void;
        /**
         * Lists NotebookRuntimes in a Location.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Notebookruntimes$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Notebookruntimes$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListNotebookRuntimesResponse>;
        list(params: Params$Resource$Projects$Locations$Notebookruntimes$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Notebookruntimes$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListNotebookRuntimesResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListNotebookRuntimesResponse>): void;
        list(params: Params$Resource$Projects$Locations$Notebookruntimes$List, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListNotebookRuntimesResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListNotebookRuntimesResponse>): void;
        /**
         * Starts a NotebookRuntime.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        start(params: Params$Resource$Projects$Locations$Notebookruntimes$Start, options: StreamMethodOptions): GaxiosPromise<Readable>;
        start(params?: Params$Resource$Projects$Locations$Notebookruntimes$Start, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        start(params: Params$Resource$Projects$Locations$Notebookruntimes$Start, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        start(params: Params$Resource$Projects$Locations$Notebookruntimes$Start, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        start(params: Params$Resource$Projects$Locations$Notebookruntimes$Start, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        start(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
    }
    export interface Params$Resource$Projects$Locations$Notebookruntimes$Assign extends StandardParameters {
        /**
         * Required. The resource name of the Location to get the NotebookRuntime assignment. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1AssignNotebookRuntimeRequest;
    }
    export interface Params$Resource$Projects$Locations$Notebookruntimes$Delete extends StandardParameters {
        /**
         * Required. The name of the NotebookRuntime resource to be deleted. Instead of checking whether the name is in valid NotebookRuntime resource name format, directly throw NotFound exception if there is no such NotebookRuntime in spanner.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Notebookruntimes$Get extends StandardParameters {
        /**
         * Required. The name of the NotebookRuntime resource. Instead of checking whether the name is in valid NotebookRuntime resource name format, directly throw NotFound exception if there is no such NotebookRuntime in spanner.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Notebookruntimes$List extends StandardParameters {
        /**
         * Optional. An expression for filtering the results of the request. For field names both snake_case and camelCase are supported. * `notebookRuntime` supports = and !=. `notebookRuntime` represents the NotebookRuntime ID, i.e. the last segment of the NotebookRuntime's resource name. * `displayName` supports = and != and regex. * `notebookRuntimeTemplate` supports = and !=. `notebookRuntimeTemplate` represents the NotebookRuntimeTemplate ID, i.e. the last segment of the NotebookRuntimeTemplate's resource name. * `healthState` supports = and !=. healthState enum: [HEALTHY, UNHEALTHY, HEALTH_STATE_UNSPECIFIED]. * `runtimeState` supports = and !=. runtimeState enum: [RUNTIME_STATE_UNSPECIFIED, RUNNING, BEING_STARTED, BEING_STOPPED, STOPPED, BEING_UPGRADED]. * `runtimeUser` supports = and !=. * API version is UI only: `uiState` supports = and !=. uiState enum: [UI_RESOURCE_STATE_UNSPECIFIED, UI_RESOURCE_STATE_BEING_CREATED, UI_RESOURCE_STATE_ACTIVE, UI_RESOURCE_STATE_BEING_DELETED, UI_RESOURCE_STATE_CREATION_FAILED]. * `notebookRuntimeType` supports = and !=. notebookRuntimeType enum: [USER_DEFINED, ONE_CLICK]. Some examples: * `notebookRuntime="notebookRuntime123"` * `displayName="myDisplayName"` and `displayName=~"myDisplayNameRegex"` * `notebookRuntimeTemplate="notebookRuntimeTemplate321"` * `healthState=HEALTHY` * `runtimeState=RUNNING` * `runtimeUser="test@google.com"` * `uiState=UI_RESOURCE_STATE_BEING_DELETED` * `notebookRuntimeType=USER_DEFINED`
         */
        filter?: string;
        /**
         * Optional. A comma-separated list of fields to order by, sorted in ascending order. Use "desc" after a field name for descending. Supported fields: * `display_name` * `create_time` * `update_time` Example: `display_name, create_time desc`.
         */
        orderBy?: string;
        /**
         * Optional. The standard list page size.
         */
        pageSize?: number;
        /**
         * Optional. The standard list page token. Typically obtained via ListNotebookRuntimesResponse.next_page_token of the previous NotebookService.ListNotebookRuntimes call.
         */
        pageToken?: string;
        /**
         * Required. The resource name of the Location from which to list the NotebookRuntimes. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Optional. Mask specifying which fields to read.
         */
        readMask?: string;
    }
    export interface Params$Resource$Projects$Locations$Notebookruntimes$Start extends StandardParameters {
        /**
         * Required. The name of the NotebookRuntime resource to be started. Instead of checking whether the name is in valid NotebookRuntime resource name format, directly throw NotFound exception if there is no such NotebookRuntime in spanner.
         */
        name?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1StartNotebookRuntimeRequest;
    }
    export class Resource$Projects$Locations$Notebookruntimetemplates {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Creates a NotebookRuntimeTemplate.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        create(params: Params$Resource$Projects$Locations$Notebookruntimetemplates$Create, options: StreamMethodOptions): GaxiosPromise<Readable>;
        create(params?: Params$Resource$Projects$Locations$Notebookruntimetemplates$Create, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        create(params: Params$Resource$Projects$Locations$Notebookruntimetemplates$Create, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        create(params: Params$Resource$Projects$Locations$Notebookruntimetemplates$Create, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        create(params: Params$Resource$Projects$Locations$Notebookruntimetemplates$Create, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        create(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Deletes a NotebookRuntimeTemplate.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Notebookruntimetemplates$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Notebookruntimetemplates$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        delete(params: Params$Resource$Projects$Locations$Notebookruntimetemplates$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Notebookruntimetemplates$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(params: Params$Resource$Projects$Locations$Notebookruntimetemplates$Delete, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Gets a NotebookRuntimeTemplate.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Notebookruntimetemplates$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Notebookruntimetemplates$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1NotebookRuntimeTemplate>;
        get(params: Params$Resource$Projects$Locations$Notebookruntimetemplates$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Notebookruntimetemplates$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1NotebookRuntimeTemplate>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1NotebookRuntimeTemplate>): void;
        get(params: Params$Resource$Projects$Locations$Notebookruntimetemplates$Get, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1NotebookRuntimeTemplate>): void;
        get(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1NotebookRuntimeTemplate>): void;
        /**
         * Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getIamPolicy(params: Params$Resource$Projects$Locations$Notebookruntimetemplates$Getiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getIamPolicy(params?: Params$Resource$Projects$Locations$Notebookruntimetemplates$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$GoogleIamV1Policy>;
        getIamPolicy(params: Params$Resource$Projects$Locations$Notebookruntimetemplates$Getiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getIamPolicy(params: Params$Resource$Projects$Locations$Notebookruntimetemplates$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$GoogleIamV1Policy>, callback: BodyResponseCallback<Schema$GoogleIamV1Policy>): void;
        getIamPolicy(params: Params$Resource$Projects$Locations$Notebookruntimetemplates$Getiampolicy, callback: BodyResponseCallback<Schema$GoogleIamV1Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$GoogleIamV1Policy>): void;
        /**
         * Lists NotebookRuntimeTemplates in a Location.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Notebookruntimetemplates$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Notebookruntimetemplates$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListNotebookRuntimeTemplatesResponse>;
        list(params: Params$Resource$Projects$Locations$Notebookruntimetemplates$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Notebookruntimetemplates$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListNotebookRuntimeTemplatesResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListNotebookRuntimeTemplatesResponse>): void;
        list(params: Params$Resource$Projects$Locations$Notebookruntimetemplates$List, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListNotebookRuntimeTemplatesResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListNotebookRuntimeTemplatesResponse>): void;
        /**
         * Sets the access control policy on the specified resource. Replaces any existing policy. Can return `NOT_FOUND`, `INVALID_ARGUMENT`, and `PERMISSION_DENIED` errors.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setIamPolicy(params: Params$Resource$Projects$Locations$Notebookruntimetemplates$Setiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setIamPolicy(params?: Params$Resource$Projects$Locations$Notebookruntimetemplates$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$GoogleIamV1Policy>;
        setIamPolicy(params: Params$Resource$Projects$Locations$Notebookruntimetemplates$Setiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setIamPolicy(params: Params$Resource$Projects$Locations$Notebookruntimetemplates$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$GoogleIamV1Policy>, callback: BodyResponseCallback<Schema$GoogleIamV1Policy>): void;
        setIamPolicy(params: Params$Resource$Projects$Locations$Notebookruntimetemplates$Setiampolicy, callback: BodyResponseCallback<Schema$GoogleIamV1Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$GoogleIamV1Policy>): void;
        /**
         * Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a `NOT_FOUND` error. Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may "fail open" without warning.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Projects$Locations$Notebookruntimetemplates$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Projects$Locations$Notebookruntimetemplates$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$GoogleIamV1TestIamPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Projects$Locations$Notebookruntimetemplates$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Projects$Locations$Notebookruntimetemplates$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$GoogleIamV1TestIamPermissionsResponse>, callback: BodyResponseCallback<Schema$GoogleIamV1TestIamPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Projects$Locations$Notebookruntimetemplates$Testiampermissions, callback: BodyResponseCallback<Schema$GoogleIamV1TestIamPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$GoogleIamV1TestIamPermissionsResponse>): void;
    }
    export interface Params$Resource$Projects$Locations$Notebookruntimetemplates$Create extends StandardParameters {
        /**
         * Optional. User specified ID for the notebook runtime template.
         */
        notebookRuntimeTemplateId?: string;
        /**
         * Required. The resource name of the Location to create the NotebookRuntimeTemplate. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1NotebookRuntimeTemplate;
    }
    export interface Params$Resource$Projects$Locations$Notebookruntimetemplates$Delete extends StandardParameters {
        /**
         * Required. The name of the NotebookRuntimeTemplate resource to be deleted. Format: `projects/{project\}/locations/{location\}/notebookRuntimeTemplates/{notebook_runtime_template\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Notebookruntimetemplates$Get extends StandardParameters {
        /**
         * Required. The name of the NotebookRuntimeTemplate resource. Format: `projects/{project\}/locations/{location\}/notebookRuntimeTemplates/{notebook_runtime_template\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Notebookruntimetemplates$Getiampolicy extends StandardParameters {
        /**
         * Optional. The maximum policy version that will be used to format the policy. Valid values are 0, 1, and 3. Requests specifying an invalid value will be rejected. Requests for policies with any conditional role bindings must specify version 3. Policies with no conditional role bindings may specify any valid value or leave the field unset. The policy in the response might use the policy version that you specified, or it might use a lower policy version. For example, if you specify version 3, but the policy has no conditional role bindings, the response uses version 1. To learn which resources support conditions in their IAM policies, see the [IAM documentation](https://cloud.google.com/iam/help/conditions/resource-policies).
         */
        'options.requestedPolicyVersion'?: number;
        /**
         * REQUIRED: The resource for which the policy is being requested. See [Resource names](https://cloud.google.com/apis/design/resource_names) for the appropriate value for this field.
         */
        resource?: string;
    }
    export interface Params$Resource$Projects$Locations$Notebookruntimetemplates$List extends StandardParameters {
        /**
         * Optional. An expression for filtering the results of the request. For field names both snake_case and camelCase are supported. * `notebookRuntimeTemplate` supports = and !=. `notebookRuntimeTemplate` represents the NotebookRuntimeTemplate ID, i.e. the last segment of the NotebookRuntimeTemplate's resource name. * `display_name` supports = and != * `labels` supports general map functions that is: * `labels.key=value` - key:value equality * `labels.key:* or labels:key - key existence * A key including a space must be quoted. `labels."a key"`. * `notebookRuntimeType` supports = and !=. notebookRuntimeType enum: [USER_DEFINED, ONE_CLICK]. Some examples: * `notebookRuntimeTemplate=notebookRuntimeTemplate123` * `displayName="myDisplayName"` * `labels.myKey="myValue"` * `notebookRuntimeType=USER_DEFINED`
         */
        filter?: string;
        /**
         * Optional. A comma-separated list of fields to order by, sorted in ascending order. Use "desc" after a field name for descending. Supported fields: * `display_name` * `create_time` * `update_time` Example: `display_name, create_time desc`.
         */
        orderBy?: string;
        /**
         * Optional. The standard list page size.
         */
        pageSize?: number;
        /**
         * Optional. The standard list page token. Typically obtained via ListNotebookRuntimeTemplatesResponse.next_page_token of the previous NotebookService.ListNotebookRuntimeTemplates call.
         */
        pageToken?: string;
        /**
         * Required. The resource name of the Location from which to list the NotebookRuntimeTemplates. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Optional. Mask specifying which fields to read.
         */
        readMask?: string;
    }
    export interface Params$Resource$Projects$Locations$Notebookruntimetemplates$Setiampolicy extends StandardParameters {
        /**
         * REQUIRED: The resource for which the policy is being specified. See [Resource names](https://cloud.google.com/apis/design/resource_names) for the appropriate value for this field.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleIamV1SetIamPolicyRequest;
    }
    export interface Params$Resource$Projects$Locations$Notebookruntimetemplates$Testiampermissions extends StandardParameters {
        /**
         * The set of permissions to check for the `resource`. Permissions with wildcards (such as `*` or `storage.*`) are not allowed. For more information see [IAM Overview](https://cloud.google.com/iam/docs/overview#permissions).
         */
        permissions?: string[];
        /**
         * REQUIRED: The resource for which the policy detail is being requested. See [Resource names](https://cloud.google.com/apis/design/resource_names) for the appropriate value for this field.
         */
        resource?: string;
    }
    export class Resource$Projects$Locations$Operations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to `Code.CANCELLED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Projects$Locations$Operations$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Projects$Locations$Operations$Cancel, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        cancel(params: Params$Resource$Projects$Locations$Operations$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Projects$Locations$Operations$Cancel, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(params: Params$Resource$Projects$Locations$Operations$Cancel, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Operations$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Operations$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        delete(params: Params$Resource$Projects$Locations$Operations$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Operations$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(params: Params$Resource$Projects$Locations$Operations$Delete, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Operations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Operations$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        get(params: Params$Resource$Projects$Locations$Operations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Operations$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(params: Params$Resource$Projects$Locations$Operations$Get, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns `UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Operations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Operations$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningListOperationsResponse>;
        list(params: Params$Resource$Projects$Locations$Operations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Operations$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Operations$List, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        /**
         * Waits until the specified long-running operation is done or reaches at most a specified timeout, returning the latest state. If the operation is already done, the latest state is immediately returned. If the timeout specified is greater than the default HTTP/RPC timeout, the HTTP/RPC timeout is used. If the server does not support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Note that this method is on a best-effort basis. It may return the latest state before the specified timeout (including immediately), meaning even an immediate response is no guarantee that the operation is done.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        wait(params: Params$Resource$Projects$Locations$Operations$Wait, options: StreamMethodOptions): GaxiosPromise<Readable>;
        wait(params?: Params$Resource$Projects$Locations$Operations$Wait, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        wait(params: Params$Resource$Projects$Locations$Operations$Wait, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        wait(params: Params$Resource$Projects$Locations$Operations$Wait, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(params: Params$Resource$Projects$Locations$Operations$Wait, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
    }
    export interface Params$Resource$Projects$Locations$Operations$Cancel extends StandardParameters {
        /**
         * The name of the operation resource to be cancelled.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Operations$Delete extends StandardParameters {
        /**
         * The name of the operation resource to be deleted.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Operations$Get extends StandardParameters {
        /**
         * The name of the operation resource.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Operations$List extends StandardParameters {
        /**
         * The standard list filter.
         */
        filter?: string;
        /**
         * The name of the operation's parent resource.
         */
        name?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token.
         */
        pageToken?: string;
    }
    export interface Params$Resource$Projects$Locations$Operations$Wait extends StandardParameters {
        /**
         * The name of the operation resource to wait on.
         */
        name?: string;
        /**
         * The maximum duration to wait before timing out. If left blank, the wait will be at most the time permitted by the underlying HTTP/RPC protocol. If RPC context deadline is also specified, the shorter one will be used.
         */
        timeout?: string;
    }
    export class Resource$Projects$Locations$Pipelinejobs {
        context: APIRequestContext;
        operations: Resource$Projects$Locations$Pipelinejobs$Operations;
        constructor(context: APIRequestContext);
        /**
         * Cancels a PipelineJob. Starts asynchronous cancellation on the PipelineJob. The server makes a best effort to cancel the pipeline, but success is not guaranteed. Clients can use PipelineService.GetPipelineJob or other methods to check whether the cancellation succeeded or whether the pipeline completed despite cancellation. On successful cancellation, the PipelineJob is not deleted; instead it becomes a pipeline with a PipelineJob.error value with a google.rpc.Status.code of 1, corresponding to `Code.CANCELLED`, and PipelineJob.state is set to `CANCELLED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Projects$Locations$Pipelinejobs$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Projects$Locations$Pipelinejobs$Cancel, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        cancel(params: Params$Resource$Projects$Locations$Pipelinejobs$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Projects$Locations$Pipelinejobs$Cancel, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(params: Params$Resource$Projects$Locations$Pipelinejobs$Cancel, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Creates a PipelineJob. A PipelineJob will run immediately when created.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        create(params: Params$Resource$Projects$Locations$Pipelinejobs$Create, options: StreamMethodOptions): GaxiosPromise<Readable>;
        create(params?: Params$Resource$Projects$Locations$Pipelinejobs$Create, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1PipelineJob>;
        create(params: Params$Resource$Projects$Locations$Pipelinejobs$Create, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        create(params: Params$Resource$Projects$Locations$Pipelinejobs$Create, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1PipelineJob>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1PipelineJob>): void;
        create(params: Params$Resource$Projects$Locations$Pipelinejobs$Create, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1PipelineJob>): void;
        create(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1PipelineJob>): void;
        /**
         * Deletes a PipelineJob.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Pipelinejobs$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Pipelinejobs$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        delete(params: Params$Resource$Projects$Locations$Pipelinejobs$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Pipelinejobs$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(params: Params$Resource$Projects$Locations$Pipelinejobs$Delete, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Gets a PipelineJob.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Pipelinejobs$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Pipelinejobs$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1PipelineJob>;
        get(params: Params$Resource$Projects$Locations$Pipelinejobs$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Pipelinejobs$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1PipelineJob>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1PipelineJob>): void;
        get(params: Params$Resource$Projects$Locations$Pipelinejobs$Get, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1PipelineJob>): void;
        get(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1PipelineJob>): void;
        /**
         * Lists PipelineJobs in a Location.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Pipelinejobs$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Pipelinejobs$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListPipelineJobsResponse>;
        list(params: Params$Resource$Projects$Locations$Pipelinejobs$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Pipelinejobs$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListPipelineJobsResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListPipelineJobsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Pipelinejobs$List, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListPipelineJobsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListPipelineJobsResponse>): void;
    }
    export interface Params$Resource$Projects$Locations$Pipelinejobs$Cancel extends StandardParameters {
        /**
         * Required. The name of the PipelineJob to cancel. Format: `projects/{project\}/locations/{location\}/pipelineJobs/{pipeline_job\}`
         */
        name?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1CancelPipelineJobRequest;
    }
    export interface Params$Resource$Projects$Locations$Pipelinejobs$Create extends StandardParameters {
        /**
         * Required. The resource name of the Location to create the PipelineJob in. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * The ID to use for the PipelineJob, which will become the final component of the PipelineJob name. If not provided, an ID will be automatically generated. This value should be less than 128 characters, and valid characters are `/a-z-/`.
         */
        pipelineJobId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1PipelineJob;
    }
    export interface Params$Resource$Projects$Locations$Pipelinejobs$Delete extends StandardParameters {
        /**
         * Required. The name of the PipelineJob resource to be deleted. Format: `projects/{project\}/locations/{location\}/pipelineJobs/{pipeline_job\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Pipelinejobs$Get extends StandardParameters {
        /**
         * Required. The name of the PipelineJob resource. Format: `projects/{project\}/locations/{location\}/pipelineJobs/{pipeline_job\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Pipelinejobs$List extends StandardParameters {
        /**
         * Lists the PipelineJobs that match the filter expression. The following fields are supported: * `pipeline_name`: Supports `=` and `!=` comparisons. * `display_name`: Supports `=`, `!=` comparisons, and `:` wildcard. * `pipeline_job_user_id`: Supports `=`, `!=` comparisons, and `:` wildcard. for example, can check if pipeline's display_name contains *step* by doing display_name:\"*step*\" * `state`: Supports `=` and `!=` comparisons. * `create_time`: Supports `=`, `!=`, `<`, `\>`, `<=`, and `\>=` comparisons. Values must be in RFC 3339 format. * `update_time`: Supports `=`, `!=`, `<`, `\>`, `<=`, and `\>=` comparisons. Values must be in RFC 3339 format. * `end_time`: Supports `=`, `!=`, `<`, `\>`, `<=`, and `\>=` comparisons. Values must be in RFC 3339 format. * `labels`: Supports key-value equality and key presence. * `template_uri`: Supports `=`, `!=` comparisons, and `:` wildcard. * `template_metadata.version`: Supports `=`, `!=` comparisons, and `:` wildcard. Filter expressions can be combined together using logical operators (`AND` & `OR`). For example: `pipeline_name="test" AND create_time\>"2020-05-18T13:30:00Z"`. The syntax to define filter expression is based on https://google.aip.dev/160. Examples: * `create_time\>"2021-05-18T00:00:00Z" OR update_time\>"2020-05-18T00:00:00Z"` PipelineJobs created or updated after 2020-05-18 00:00:00 UTC. * `labels.env = "prod"` PipelineJobs with label "env" set to "prod".
         */
        filter?: string;
        /**
         * A comma-separated list of fields to order by. The default sort order is in ascending order. Use "desc" after a field name for descending. You can have multiple order_by fields provided e.g. "create_time desc, end_time", "end_time, start_time, update_time" For example, using "create_time desc, end_time" will order results by create time in descending order, and if there are multiple jobs having the same create time, order them by the end time in ascending order. if order_by is not specified, it will order by default order is create time in descending order. Supported fields: * `create_time` * `update_time` * `end_time` * `start_time`
         */
        orderBy?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token. Typically obtained via ListPipelineJobsResponse.next_page_token of the previous PipelineService.ListPipelineJobs call.
         */
        pageToken?: string;
        /**
         * Required. The resource name of the Location to list the PipelineJobs from. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Mask specifying which fields to read.
         */
        readMask?: string;
    }
    export class Resource$Projects$Locations$Pipelinejobs$Operations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to `Code.CANCELLED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Projects$Locations$Pipelinejobs$Operations$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Projects$Locations$Pipelinejobs$Operations$Cancel, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        cancel(params: Params$Resource$Projects$Locations$Pipelinejobs$Operations$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Projects$Locations$Pipelinejobs$Operations$Cancel, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(params: Params$Resource$Projects$Locations$Pipelinejobs$Operations$Cancel, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Pipelinejobs$Operations$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Pipelinejobs$Operations$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        delete(params: Params$Resource$Projects$Locations$Pipelinejobs$Operations$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Pipelinejobs$Operations$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(params: Params$Resource$Projects$Locations$Pipelinejobs$Operations$Delete, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Pipelinejobs$Operations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Pipelinejobs$Operations$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        get(params: Params$Resource$Projects$Locations$Pipelinejobs$Operations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Pipelinejobs$Operations$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(params: Params$Resource$Projects$Locations$Pipelinejobs$Operations$Get, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns `UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Pipelinejobs$Operations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Pipelinejobs$Operations$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningListOperationsResponse>;
        list(params: Params$Resource$Projects$Locations$Pipelinejobs$Operations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Pipelinejobs$Operations$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Pipelinejobs$Operations$List, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        /**
         * Waits until the specified long-running operation is done or reaches at most a specified timeout, returning the latest state. If the operation is already done, the latest state is immediately returned. If the timeout specified is greater than the default HTTP/RPC timeout, the HTTP/RPC timeout is used. If the server does not support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Note that this method is on a best-effort basis. It may return the latest state before the specified timeout (including immediately), meaning even an immediate response is no guarantee that the operation is done.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        wait(params: Params$Resource$Projects$Locations$Pipelinejobs$Operations$Wait, options: StreamMethodOptions): GaxiosPromise<Readable>;
        wait(params?: Params$Resource$Projects$Locations$Pipelinejobs$Operations$Wait, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        wait(params: Params$Resource$Projects$Locations$Pipelinejobs$Operations$Wait, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        wait(params: Params$Resource$Projects$Locations$Pipelinejobs$Operations$Wait, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(params: Params$Resource$Projects$Locations$Pipelinejobs$Operations$Wait, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
    }
    export interface Params$Resource$Projects$Locations$Pipelinejobs$Operations$Cancel extends StandardParameters {
        /**
         * The name of the operation resource to be cancelled.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Pipelinejobs$Operations$Delete extends StandardParameters {
        /**
         * The name of the operation resource to be deleted.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Pipelinejobs$Operations$Get extends StandardParameters {
        /**
         * The name of the operation resource.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Pipelinejobs$Operations$List extends StandardParameters {
        /**
         * The standard list filter.
         */
        filter?: string;
        /**
         * The name of the operation's parent resource.
         */
        name?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token.
         */
        pageToken?: string;
    }
    export interface Params$Resource$Projects$Locations$Pipelinejobs$Operations$Wait extends StandardParameters {
        /**
         * The name of the operation resource to wait on.
         */
        name?: string;
        /**
         * The maximum duration to wait before timing out. If left blank, the wait will be at most the time permitted by the underlying HTTP/RPC protocol. If RPC context deadline is also specified, the shorter one will be used.
         */
        timeout?: string;
    }
    export class Resource$Projects$Locations$Publishers {
        context: APIRequestContext;
        models: Resource$Projects$Locations$Publishers$Models;
        constructor(context: APIRequestContext);
    }
    export class Resource$Projects$Locations$Publishers$Models {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Perform an online prediction.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        predict(params: Params$Resource$Projects$Locations$Publishers$Models$Predict, options: StreamMethodOptions): GaxiosPromise<Readable>;
        predict(params?: Params$Resource$Projects$Locations$Publishers$Models$Predict, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1PredictResponse>;
        predict(params: Params$Resource$Projects$Locations$Publishers$Models$Predict, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        predict(params: Params$Resource$Projects$Locations$Publishers$Models$Predict, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1PredictResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1PredictResponse>): void;
        predict(params: Params$Resource$Projects$Locations$Publishers$Models$Predict, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1PredictResponse>): void;
        predict(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1PredictResponse>): void;
        /**
         * Perform an online prediction with an arbitrary HTTP payload. The response includes the following HTTP headers: * `X-Vertex-AI-Endpoint-Id`: ID of the Endpoint that served this prediction. * `X-Vertex-AI-Deployed-Model-Id`: ID of the Endpoint's DeployedModel that served this prediction.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        rawPredict(params: Params$Resource$Projects$Locations$Publishers$Models$Rawpredict, options: StreamMethodOptions): GaxiosPromise<Readable>;
        rawPredict(params?: Params$Resource$Projects$Locations$Publishers$Models$Rawpredict, options?: MethodOptions): GaxiosPromise<Schema$GoogleApiHttpBody>;
        rawPredict(params: Params$Resource$Projects$Locations$Publishers$Models$Rawpredict, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        rawPredict(params: Params$Resource$Projects$Locations$Publishers$Models$Rawpredict, options: MethodOptions | BodyResponseCallback<Schema$GoogleApiHttpBody>, callback: BodyResponseCallback<Schema$GoogleApiHttpBody>): void;
        rawPredict(params: Params$Resource$Projects$Locations$Publishers$Models$Rawpredict, callback: BodyResponseCallback<Schema$GoogleApiHttpBody>): void;
        rawPredict(callback: BodyResponseCallback<Schema$GoogleApiHttpBody>): void;
        /**
         * Perform a server-side streaming online prediction request for Vertex LLM streaming.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        serverStreamingPredict(params: Params$Resource$Projects$Locations$Publishers$Models$Serverstreamingpredict, options: StreamMethodOptions): GaxiosPromise<Readable>;
        serverStreamingPredict(params?: Params$Resource$Projects$Locations$Publishers$Models$Serverstreamingpredict, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1StreamingPredictResponse>;
        serverStreamingPredict(params: Params$Resource$Projects$Locations$Publishers$Models$Serverstreamingpredict, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        serverStreamingPredict(params: Params$Resource$Projects$Locations$Publishers$Models$Serverstreamingpredict, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1StreamingPredictResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1StreamingPredictResponse>): void;
        serverStreamingPredict(params: Params$Resource$Projects$Locations$Publishers$Models$Serverstreamingpredict, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1StreamingPredictResponse>): void;
        serverStreamingPredict(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1StreamingPredictResponse>): void;
    }
    export interface Params$Resource$Projects$Locations$Publishers$Models$Predict extends StandardParameters {
        /**
         * Required. The name of the Endpoint requested to serve the prediction. Format: `projects/{project\}/locations/{location\}/endpoints/{endpoint\}`
         */
        endpoint?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1PredictRequest;
    }
    export interface Params$Resource$Projects$Locations$Publishers$Models$Rawpredict extends StandardParameters {
        /**
         * Required. The name of the Endpoint requested to serve the prediction. Format: `projects/{project\}/locations/{location\}/endpoints/{endpoint\}`
         */
        endpoint?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1RawPredictRequest;
    }
    export interface Params$Resource$Projects$Locations$Publishers$Models$Serverstreamingpredict extends StandardParameters {
        /**
         * Required. The name of the Endpoint requested to serve the prediction. Format: `projects/{project\}/locations/{location\}/endpoints/{endpoint\}`
         */
        endpoint?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1StreamingPredictRequest;
    }
    export class Resource$Projects$Locations$Schedules {
        context: APIRequestContext;
        operations: Resource$Projects$Locations$Schedules$Operations;
        constructor(context: APIRequestContext);
        /**
         * Creates a Schedule.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        create(params: Params$Resource$Projects$Locations$Schedules$Create, options: StreamMethodOptions): GaxiosPromise<Readable>;
        create(params?: Params$Resource$Projects$Locations$Schedules$Create, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1Schedule>;
        create(params: Params$Resource$Projects$Locations$Schedules$Create, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        create(params: Params$Resource$Projects$Locations$Schedules$Create, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1Schedule>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Schedule>): void;
        create(params: Params$Resource$Projects$Locations$Schedules$Create, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Schedule>): void;
        create(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Schedule>): void;
        /**
         * Deletes a Schedule.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Schedules$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Schedules$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        delete(params: Params$Resource$Projects$Locations$Schedules$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Schedules$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(params: Params$Resource$Projects$Locations$Schedules$Delete, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Gets a Schedule.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Schedules$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Schedules$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1Schedule>;
        get(params: Params$Resource$Projects$Locations$Schedules$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Schedules$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1Schedule>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Schedule>): void;
        get(params: Params$Resource$Projects$Locations$Schedules$Get, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Schedule>): void;
        get(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Schedule>): void;
        /**
         * Lists Schedules in a Location.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Schedules$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Schedules$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListSchedulesResponse>;
        list(params: Params$Resource$Projects$Locations$Schedules$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Schedules$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListSchedulesResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListSchedulesResponse>): void;
        list(params: Params$Resource$Projects$Locations$Schedules$List, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListSchedulesResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListSchedulesResponse>): void;
        /**
         * Updates an active or paused Schedule. When the Schedule is updated, new runs will be scheduled starting from the updated next execution time after the update time based on the time_specification in the updated Schedule. All unstarted runs before the update time will be skipped while already created runs will NOT be paused or canceled.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Projects$Locations$Schedules$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Projects$Locations$Schedules$Patch, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1Schedule>;
        patch(params: Params$Resource$Projects$Locations$Schedules$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Projects$Locations$Schedules$Patch, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1Schedule>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Schedule>): void;
        patch(params: Params$Resource$Projects$Locations$Schedules$Patch, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Schedule>): void;
        patch(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Schedule>): void;
        /**
         * Pauses a Schedule. Will mark Schedule.state to 'PAUSED'. If the schedule is paused, no new runs will be created. Already created runs will NOT be paused or canceled.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        pause(params: Params$Resource$Projects$Locations$Schedules$Pause, options: StreamMethodOptions): GaxiosPromise<Readable>;
        pause(params?: Params$Resource$Projects$Locations$Schedules$Pause, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        pause(params: Params$Resource$Projects$Locations$Schedules$Pause, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        pause(params: Params$Resource$Projects$Locations$Schedules$Pause, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        pause(params: Params$Resource$Projects$Locations$Schedules$Pause, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        pause(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Resumes a paused Schedule to start scheduling new runs. Will mark Schedule.state to 'ACTIVE'. Only paused Schedule can be resumed. When the Schedule is resumed, new runs will be scheduled starting from the next execution time after the current time based on the time_specification in the Schedule. If Schedule.catchUp is set up true, all missed runs will be scheduled for backfill first.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        resume(params: Params$Resource$Projects$Locations$Schedules$Resume, options: StreamMethodOptions): GaxiosPromise<Readable>;
        resume(params?: Params$Resource$Projects$Locations$Schedules$Resume, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        resume(params: Params$Resource$Projects$Locations$Schedules$Resume, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        resume(params: Params$Resource$Projects$Locations$Schedules$Resume, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        resume(params: Params$Resource$Projects$Locations$Schedules$Resume, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        resume(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
    }
    export interface Params$Resource$Projects$Locations$Schedules$Create extends StandardParameters {
        /**
         * Required. The resource name of the Location to create the Schedule in. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1Schedule;
    }
    export interface Params$Resource$Projects$Locations$Schedules$Delete extends StandardParameters {
        /**
         * Required. The name of the Schedule resource to be deleted. Format: `projects/{project\}/locations/{location\}/schedules/{schedule\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Schedules$Get extends StandardParameters {
        /**
         * Required. The name of the Schedule resource. Format: `projects/{project\}/locations/{location\}/schedules/{schedule\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Schedules$List extends StandardParameters {
        /**
         * Lists the Schedules that match the filter expression. The following fields are supported: * `display_name`: Supports `=`, `!=` comparisons, and `:` wildcard. * `state`: Supports `=` and `!=` comparisons. * `request`: Supports existence of the check. (e.g. `create_pipeline_job_request:*` --\> Schedule has create_pipeline_job_request). * `create_time`: Supports `=`, `!=`, `<`, `\>`, `<=`, and `\>=` comparisons. Values must be in RFC 3339 format. * `start_time`: Supports `=`, `!=`, `<`, `\>`, `<=`, and `\>=` comparisons. Values must be in RFC 3339 format. * `end_time`: Supports `=`, `!=`, `<`, `\>`, `<=`, `\>=` comparisons and `:*` existence check. Values must be in RFC 3339 format. * `next_run_time`: Supports `=`, `!=`, `<`, `\>`, `<=`, and `\>=` comparisons. Values must be in RFC 3339 format. Filter expressions can be combined together using logical operators (`NOT`, `AND` & `OR`). The syntax to define filter expression is based on https://google.aip.dev/160. Examples: * `state="ACTIVE" AND display_name:"my_schedule_*"` * `NOT display_name="my_schedule"` * `create_time\>"2021-05-18T00:00:00Z"` * `end_time\>"2021-05-18T00:00:00Z" OR NOT end_time:*` * `create_pipeline_job_request:*`
         */
        filter?: string;
        /**
         * A comma-separated list of fields to order by. The default sort order is in ascending order. Use "desc" after a field name for descending. You can have multiple order_by fields provided. For example, using "create_time desc, end_time" will order results by create time in descending order, and if there are multiple schedules having the same create time, order them by the end time in ascending order. If order_by is not specified, it will order by default with create_time in descending order. Supported fields: * `create_time` * `start_time` * `end_time` * `next_run_time`
         */
        orderBy?: string;
        /**
         * The standard list page size. Default to 100 if not specified.
         */
        pageSize?: number;
        /**
         * The standard list page token. Typically obtained via ListSchedulesResponse.next_page_token of the previous ScheduleService.ListSchedules call.
         */
        pageToken?: string;
        /**
         * Required. The resource name of the Location to list the Schedules from. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
    }
    export interface Params$Resource$Projects$Locations$Schedules$Patch extends StandardParameters {
        /**
         * Immutable. The resource name of the Schedule.
         */
        name?: string;
        /**
         * Required. The update mask applies to the resource. See google.protobuf.FieldMask.
         */
        updateMask?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1Schedule;
    }
    export interface Params$Resource$Projects$Locations$Schedules$Pause extends StandardParameters {
        /**
         * Required. The name of the Schedule resource to be paused. Format: `projects/{project\}/locations/{location\}/schedules/{schedule\}`
         */
        name?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1PauseScheduleRequest;
    }
    export interface Params$Resource$Projects$Locations$Schedules$Resume extends StandardParameters {
        /**
         * Required. The name of the Schedule resource to be resumed. Format: `projects/{project\}/locations/{location\}/schedules/{schedule\}`
         */
        name?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1ResumeScheduleRequest;
    }
    export class Resource$Projects$Locations$Schedules$Operations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to `Code.CANCELLED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Projects$Locations$Schedules$Operations$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Projects$Locations$Schedules$Operations$Cancel, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        cancel(params: Params$Resource$Projects$Locations$Schedules$Operations$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Projects$Locations$Schedules$Operations$Cancel, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(params: Params$Resource$Projects$Locations$Schedules$Operations$Cancel, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Schedules$Operations$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Schedules$Operations$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        delete(params: Params$Resource$Projects$Locations$Schedules$Operations$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Schedules$Operations$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(params: Params$Resource$Projects$Locations$Schedules$Operations$Delete, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Schedules$Operations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Schedules$Operations$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        get(params: Params$Resource$Projects$Locations$Schedules$Operations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Schedules$Operations$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(params: Params$Resource$Projects$Locations$Schedules$Operations$Get, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns `UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Schedules$Operations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Schedules$Operations$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningListOperationsResponse>;
        list(params: Params$Resource$Projects$Locations$Schedules$Operations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Schedules$Operations$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Schedules$Operations$List, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        /**
         * Waits until the specified long-running operation is done or reaches at most a specified timeout, returning the latest state. If the operation is already done, the latest state is immediately returned. If the timeout specified is greater than the default HTTP/RPC timeout, the HTTP/RPC timeout is used. If the server does not support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Note that this method is on a best-effort basis. It may return the latest state before the specified timeout (including immediately), meaning even an immediate response is no guarantee that the operation is done.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        wait(params: Params$Resource$Projects$Locations$Schedules$Operations$Wait, options: StreamMethodOptions): GaxiosPromise<Readable>;
        wait(params?: Params$Resource$Projects$Locations$Schedules$Operations$Wait, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        wait(params: Params$Resource$Projects$Locations$Schedules$Operations$Wait, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        wait(params: Params$Resource$Projects$Locations$Schedules$Operations$Wait, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(params: Params$Resource$Projects$Locations$Schedules$Operations$Wait, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
    }
    export interface Params$Resource$Projects$Locations$Schedules$Operations$Cancel extends StandardParameters {
        /**
         * The name of the operation resource to be cancelled.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Schedules$Operations$Delete extends StandardParameters {
        /**
         * The name of the operation resource to be deleted.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Schedules$Operations$Get extends StandardParameters {
        /**
         * The name of the operation resource.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Schedules$Operations$List extends StandardParameters {
        /**
         * The standard list filter.
         */
        filter?: string;
        /**
         * The name of the operation's parent resource.
         */
        name?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token.
         */
        pageToken?: string;
    }
    export interface Params$Resource$Projects$Locations$Schedules$Operations$Wait extends StandardParameters {
        /**
         * The name of the operation resource to wait on.
         */
        name?: string;
        /**
         * The maximum duration to wait before timing out. If left blank, the wait will be at most the time permitted by the underlying HTTP/RPC protocol. If RPC context deadline is also specified, the shorter one will be used.
         */
        timeout?: string;
    }
    export class Resource$Projects$Locations$Specialistpools {
        context: APIRequestContext;
        operations: Resource$Projects$Locations$Specialistpools$Operations;
        constructor(context: APIRequestContext);
        /**
         * Creates a SpecialistPool.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        create(params: Params$Resource$Projects$Locations$Specialistpools$Create, options: StreamMethodOptions): GaxiosPromise<Readable>;
        create(params?: Params$Resource$Projects$Locations$Specialistpools$Create, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        create(params: Params$Resource$Projects$Locations$Specialistpools$Create, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        create(params: Params$Resource$Projects$Locations$Specialistpools$Create, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        create(params: Params$Resource$Projects$Locations$Specialistpools$Create, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        create(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Deletes a SpecialistPool as well as all Specialists in the pool.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Specialistpools$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Specialistpools$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        delete(params: Params$Resource$Projects$Locations$Specialistpools$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Specialistpools$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(params: Params$Resource$Projects$Locations$Specialistpools$Delete, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Gets a SpecialistPool.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Specialistpools$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Specialistpools$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1SpecialistPool>;
        get(params: Params$Resource$Projects$Locations$Specialistpools$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Specialistpools$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1SpecialistPool>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1SpecialistPool>): void;
        get(params: Params$Resource$Projects$Locations$Specialistpools$Get, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1SpecialistPool>): void;
        get(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1SpecialistPool>): void;
        /**
         * Lists SpecialistPools in a Location.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Specialistpools$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Specialistpools$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListSpecialistPoolsResponse>;
        list(params: Params$Resource$Projects$Locations$Specialistpools$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Specialistpools$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListSpecialistPoolsResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListSpecialistPoolsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Specialistpools$List, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListSpecialistPoolsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListSpecialistPoolsResponse>): void;
        /**
         * Updates a SpecialistPool.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Projects$Locations$Specialistpools$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Projects$Locations$Specialistpools$Patch, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        patch(params: Params$Resource$Projects$Locations$Specialistpools$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Projects$Locations$Specialistpools$Patch, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        patch(params: Params$Resource$Projects$Locations$Specialistpools$Patch, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        patch(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
    }
    export interface Params$Resource$Projects$Locations$Specialistpools$Create extends StandardParameters {
        /**
         * Required. The parent Project name for the new SpecialistPool. The form is `projects/{project\}/locations/{location\}`.
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1SpecialistPool;
    }
    export interface Params$Resource$Projects$Locations$Specialistpools$Delete extends StandardParameters {
        /**
         * If set to true, any specialist managers in this SpecialistPool will also be deleted. (Otherwise, the request will only work if the SpecialistPool has no specialist managers.)
         */
        force?: boolean;
        /**
         * Required. The resource name of the SpecialistPool to delete. Format: `projects/{project\}/locations/{location\}/specialistPools/{specialist_pool\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Specialistpools$Get extends StandardParameters {
        /**
         * Required. The name of the SpecialistPool resource. The form is `projects/{project\}/locations/{location\}/specialistPools/{specialist_pool\}`.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Specialistpools$List extends StandardParameters {
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token. Typically obtained by ListSpecialistPoolsResponse.next_page_token of the previous SpecialistPoolService.ListSpecialistPools call. Return first page if empty.
         */
        pageToken?: string;
        /**
         * Required. The name of the SpecialistPool's parent resource. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Mask specifying which fields to read. FieldMask represents a set of
         */
        readMask?: string;
    }
    export interface Params$Resource$Projects$Locations$Specialistpools$Patch extends StandardParameters {
        /**
         * Required. The resource name of the SpecialistPool.
         */
        name?: string;
        /**
         * Required. The update mask applies to the resource.
         */
        updateMask?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1SpecialistPool;
    }
    export class Resource$Projects$Locations$Specialistpools$Operations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to `Code.CANCELLED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Projects$Locations$Specialistpools$Operations$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Projects$Locations$Specialistpools$Operations$Cancel, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        cancel(params: Params$Resource$Projects$Locations$Specialistpools$Operations$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Projects$Locations$Specialistpools$Operations$Cancel, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(params: Params$Resource$Projects$Locations$Specialistpools$Operations$Cancel, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Specialistpools$Operations$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Specialistpools$Operations$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        delete(params: Params$Resource$Projects$Locations$Specialistpools$Operations$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Specialistpools$Operations$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(params: Params$Resource$Projects$Locations$Specialistpools$Operations$Delete, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Specialistpools$Operations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Specialistpools$Operations$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        get(params: Params$Resource$Projects$Locations$Specialistpools$Operations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Specialistpools$Operations$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(params: Params$Resource$Projects$Locations$Specialistpools$Operations$Get, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns `UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Specialistpools$Operations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Specialistpools$Operations$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningListOperationsResponse>;
        list(params: Params$Resource$Projects$Locations$Specialistpools$Operations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Specialistpools$Operations$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Specialistpools$Operations$List, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        /**
         * Waits until the specified long-running operation is done or reaches at most a specified timeout, returning the latest state. If the operation is already done, the latest state is immediately returned. If the timeout specified is greater than the default HTTP/RPC timeout, the HTTP/RPC timeout is used. If the server does not support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Note that this method is on a best-effort basis. It may return the latest state before the specified timeout (including immediately), meaning even an immediate response is no guarantee that the operation is done.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        wait(params: Params$Resource$Projects$Locations$Specialistpools$Operations$Wait, options: StreamMethodOptions): GaxiosPromise<Readable>;
        wait(params?: Params$Resource$Projects$Locations$Specialistpools$Operations$Wait, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        wait(params: Params$Resource$Projects$Locations$Specialistpools$Operations$Wait, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        wait(params: Params$Resource$Projects$Locations$Specialistpools$Operations$Wait, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(params: Params$Resource$Projects$Locations$Specialistpools$Operations$Wait, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
    }
    export interface Params$Resource$Projects$Locations$Specialistpools$Operations$Cancel extends StandardParameters {
        /**
         * The name of the operation resource to be cancelled.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Specialistpools$Operations$Delete extends StandardParameters {
        /**
         * The name of the operation resource to be deleted.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Specialistpools$Operations$Get extends StandardParameters {
        /**
         * The name of the operation resource.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Specialistpools$Operations$List extends StandardParameters {
        /**
         * The standard list filter.
         */
        filter?: string;
        /**
         * The name of the operation's parent resource.
         */
        name?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token.
         */
        pageToken?: string;
    }
    export interface Params$Resource$Projects$Locations$Specialistpools$Operations$Wait extends StandardParameters {
        /**
         * The name of the operation resource to wait on.
         */
        name?: string;
        /**
         * The maximum duration to wait before timing out. If left blank, the wait will be at most the time permitted by the underlying HTTP/RPC protocol. If RPC context deadline is also specified, the shorter one will be used.
         */
        timeout?: string;
    }
    export class Resource$Projects$Locations$Studies {
        context: APIRequestContext;
        operations: Resource$Projects$Locations$Studies$Operations;
        trials: Resource$Projects$Locations$Studies$Trials;
        constructor(context: APIRequestContext);
        /**
         * Creates a Study. A resource name will be generated after creation of the Study.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        create(params: Params$Resource$Projects$Locations$Studies$Create, options: StreamMethodOptions): GaxiosPromise<Readable>;
        create(params?: Params$Resource$Projects$Locations$Studies$Create, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1Study>;
        create(params: Params$Resource$Projects$Locations$Studies$Create, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        create(params: Params$Resource$Projects$Locations$Studies$Create, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1Study>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Study>): void;
        create(params: Params$Resource$Projects$Locations$Studies$Create, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Study>): void;
        create(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Study>): void;
        /**
         * Deletes a Study.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Studies$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Studies$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        delete(params: Params$Resource$Projects$Locations$Studies$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Studies$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(params: Params$Resource$Projects$Locations$Studies$Delete, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Gets a Study by name.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Studies$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Studies$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1Study>;
        get(params: Params$Resource$Projects$Locations$Studies$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Studies$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1Study>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Study>): void;
        get(params: Params$Resource$Projects$Locations$Studies$Get, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Study>): void;
        get(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Study>): void;
        /**
         * Lists all the studies in a region for an associated project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Studies$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Studies$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListStudiesResponse>;
        list(params: Params$Resource$Projects$Locations$Studies$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Studies$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListStudiesResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListStudiesResponse>): void;
        list(params: Params$Resource$Projects$Locations$Studies$List, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListStudiesResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListStudiesResponse>): void;
        /**
         * Looks a study up using the user-defined display_name field instead of the fully qualified resource name.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        lookup(params: Params$Resource$Projects$Locations$Studies$Lookup, options: StreamMethodOptions): GaxiosPromise<Readable>;
        lookup(params?: Params$Resource$Projects$Locations$Studies$Lookup, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1Study>;
        lookup(params: Params$Resource$Projects$Locations$Studies$Lookup, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        lookup(params: Params$Resource$Projects$Locations$Studies$Lookup, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1Study>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Study>): void;
        lookup(params: Params$Resource$Projects$Locations$Studies$Lookup, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Study>): void;
        lookup(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Study>): void;
    }
    export interface Params$Resource$Projects$Locations$Studies$Create extends StandardParameters {
        /**
         * Required. The resource name of the Location to create the CustomJob in. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1Study;
    }
    export interface Params$Resource$Projects$Locations$Studies$Delete extends StandardParameters {
        /**
         * Required. The name of the Study resource to be deleted. Format: `projects/{project\}/locations/{location\}/studies/{study\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Studies$Get extends StandardParameters {
        /**
         * Required. The name of the Study resource. Format: `projects/{project\}/locations/{location\}/studies/{study\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Studies$List extends StandardParameters {
        /**
         * Optional. The maximum number of studies to return per "page" of results. If unspecified, service will pick an appropriate default.
         */
        pageSize?: number;
        /**
         * Optional. A page token to request the next page of results. If unspecified, there are no subsequent pages.
         */
        pageToken?: string;
        /**
         * Required. The resource name of the Location to list the Study from. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
    }
    export interface Params$Resource$Projects$Locations$Studies$Lookup extends StandardParameters {
        /**
         * Required. The resource name of the Location to get the Study from. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1LookupStudyRequest;
    }
    export class Resource$Projects$Locations$Studies$Operations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to `Code.CANCELLED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Projects$Locations$Studies$Operations$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Projects$Locations$Studies$Operations$Cancel, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        cancel(params: Params$Resource$Projects$Locations$Studies$Operations$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Projects$Locations$Studies$Operations$Cancel, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(params: Params$Resource$Projects$Locations$Studies$Operations$Cancel, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Studies$Operations$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Studies$Operations$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        delete(params: Params$Resource$Projects$Locations$Studies$Operations$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Studies$Operations$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(params: Params$Resource$Projects$Locations$Studies$Operations$Delete, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Studies$Operations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Studies$Operations$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        get(params: Params$Resource$Projects$Locations$Studies$Operations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Studies$Operations$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(params: Params$Resource$Projects$Locations$Studies$Operations$Get, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns `UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Studies$Operations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Studies$Operations$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningListOperationsResponse>;
        list(params: Params$Resource$Projects$Locations$Studies$Operations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Studies$Operations$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Studies$Operations$List, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        /**
         * Waits until the specified long-running operation is done or reaches at most a specified timeout, returning the latest state. If the operation is already done, the latest state is immediately returned. If the timeout specified is greater than the default HTTP/RPC timeout, the HTTP/RPC timeout is used. If the server does not support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Note that this method is on a best-effort basis. It may return the latest state before the specified timeout (including immediately), meaning even an immediate response is no guarantee that the operation is done.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        wait(params: Params$Resource$Projects$Locations$Studies$Operations$Wait, options: StreamMethodOptions): GaxiosPromise<Readable>;
        wait(params?: Params$Resource$Projects$Locations$Studies$Operations$Wait, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        wait(params: Params$Resource$Projects$Locations$Studies$Operations$Wait, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        wait(params: Params$Resource$Projects$Locations$Studies$Operations$Wait, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(params: Params$Resource$Projects$Locations$Studies$Operations$Wait, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
    }
    export interface Params$Resource$Projects$Locations$Studies$Operations$Cancel extends StandardParameters {
        /**
         * The name of the operation resource to be cancelled.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Studies$Operations$Delete extends StandardParameters {
        /**
         * The name of the operation resource to be deleted.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Studies$Operations$Get extends StandardParameters {
        /**
         * The name of the operation resource.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Studies$Operations$List extends StandardParameters {
        /**
         * The standard list filter.
         */
        filter?: string;
        /**
         * The name of the operation's parent resource.
         */
        name?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token.
         */
        pageToken?: string;
    }
    export interface Params$Resource$Projects$Locations$Studies$Operations$Wait extends StandardParameters {
        /**
         * The name of the operation resource to wait on.
         */
        name?: string;
        /**
         * The maximum duration to wait before timing out. If left blank, the wait will be at most the time permitted by the underlying HTTP/RPC protocol. If RPC context deadline is also specified, the shorter one will be used.
         */
        timeout?: string;
    }
    export class Resource$Projects$Locations$Studies$Trials {
        context: APIRequestContext;
        operations: Resource$Projects$Locations$Studies$Trials$Operations;
        constructor(context: APIRequestContext);
        /**
         * Adds a measurement of the objective metrics to a Trial. This measurement is assumed to have been taken before the Trial is complete.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        addTrialMeasurement(params: Params$Resource$Projects$Locations$Studies$Trials$Addtrialmeasurement, options: StreamMethodOptions): GaxiosPromise<Readable>;
        addTrialMeasurement(params?: Params$Resource$Projects$Locations$Studies$Trials$Addtrialmeasurement, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1Trial>;
        addTrialMeasurement(params: Params$Resource$Projects$Locations$Studies$Trials$Addtrialmeasurement, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        addTrialMeasurement(params: Params$Resource$Projects$Locations$Studies$Trials$Addtrialmeasurement, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1Trial>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Trial>): void;
        addTrialMeasurement(params: Params$Resource$Projects$Locations$Studies$Trials$Addtrialmeasurement, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Trial>): void;
        addTrialMeasurement(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Trial>): void;
        /**
         * Checks whether a Trial should stop or not. Returns a long-running operation. When the operation is successful, it will contain a CheckTrialEarlyStoppingStateResponse.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        checkTrialEarlyStoppingState(params: Params$Resource$Projects$Locations$Studies$Trials$Checktrialearlystoppingstate, options: StreamMethodOptions): GaxiosPromise<Readable>;
        checkTrialEarlyStoppingState(params?: Params$Resource$Projects$Locations$Studies$Trials$Checktrialearlystoppingstate, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        checkTrialEarlyStoppingState(params: Params$Resource$Projects$Locations$Studies$Trials$Checktrialearlystoppingstate, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        checkTrialEarlyStoppingState(params: Params$Resource$Projects$Locations$Studies$Trials$Checktrialearlystoppingstate, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        checkTrialEarlyStoppingState(params: Params$Resource$Projects$Locations$Studies$Trials$Checktrialearlystoppingstate, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        checkTrialEarlyStoppingState(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Marks a Trial as complete.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        complete(params: Params$Resource$Projects$Locations$Studies$Trials$Complete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        complete(params?: Params$Resource$Projects$Locations$Studies$Trials$Complete, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1Trial>;
        complete(params: Params$Resource$Projects$Locations$Studies$Trials$Complete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        complete(params: Params$Resource$Projects$Locations$Studies$Trials$Complete, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1Trial>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Trial>): void;
        complete(params: Params$Resource$Projects$Locations$Studies$Trials$Complete, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Trial>): void;
        complete(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Trial>): void;
        /**
         * Adds a user provided Trial to a Study.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        create(params: Params$Resource$Projects$Locations$Studies$Trials$Create, options: StreamMethodOptions): GaxiosPromise<Readable>;
        create(params?: Params$Resource$Projects$Locations$Studies$Trials$Create, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1Trial>;
        create(params: Params$Resource$Projects$Locations$Studies$Trials$Create, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        create(params: Params$Resource$Projects$Locations$Studies$Trials$Create, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1Trial>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Trial>): void;
        create(params: Params$Resource$Projects$Locations$Studies$Trials$Create, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Trial>): void;
        create(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Trial>): void;
        /**
         * Deletes a Trial.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Studies$Trials$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Studies$Trials$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        delete(params: Params$Resource$Projects$Locations$Studies$Trials$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Studies$Trials$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(params: Params$Resource$Projects$Locations$Studies$Trials$Delete, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Gets a Trial.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Studies$Trials$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Studies$Trials$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1Trial>;
        get(params: Params$Resource$Projects$Locations$Studies$Trials$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Studies$Trials$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1Trial>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Trial>): void;
        get(params: Params$Resource$Projects$Locations$Studies$Trials$Get, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Trial>): void;
        get(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Trial>): void;
        /**
         * Lists the Trials associated with a Study.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Studies$Trials$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Studies$Trials$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListTrialsResponse>;
        list(params: Params$Resource$Projects$Locations$Studies$Trials$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Studies$Trials$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListTrialsResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListTrialsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Studies$Trials$List, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListTrialsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListTrialsResponse>): void;
        /**
         * Lists the pareto-optimal Trials for multi-objective Study or the optimal Trials for single-objective Study. The definition of pareto-optimal can be checked in wiki page. https://en.wikipedia.org/wiki/Pareto_efficiency
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        listOptimalTrials(params: Params$Resource$Projects$Locations$Studies$Trials$Listoptimaltrials, options: StreamMethodOptions): GaxiosPromise<Readable>;
        listOptimalTrials(params?: Params$Resource$Projects$Locations$Studies$Trials$Listoptimaltrials, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListOptimalTrialsResponse>;
        listOptimalTrials(params: Params$Resource$Projects$Locations$Studies$Trials$Listoptimaltrials, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        listOptimalTrials(params: Params$Resource$Projects$Locations$Studies$Trials$Listoptimaltrials, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListOptimalTrialsResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListOptimalTrialsResponse>): void;
        listOptimalTrials(params: Params$Resource$Projects$Locations$Studies$Trials$Listoptimaltrials, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListOptimalTrialsResponse>): void;
        listOptimalTrials(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListOptimalTrialsResponse>): void;
        /**
         * Stops a Trial.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        stop(params: Params$Resource$Projects$Locations$Studies$Trials$Stop, options: StreamMethodOptions): GaxiosPromise<Readable>;
        stop(params?: Params$Resource$Projects$Locations$Studies$Trials$Stop, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1Trial>;
        stop(params: Params$Resource$Projects$Locations$Studies$Trials$Stop, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        stop(params: Params$Resource$Projects$Locations$Studies$Trials$Stop, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1Trial>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Trial>): void;
        stop(params: Params$Resource$Projects$Locations$Studies$Trials$Stop, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Trial>): void;
        stop(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Trial>): void;
        /**
         * Adds one or more Trials to a Study, with parameter values suggested by Vertex AI Vizier. Returns a long-running operation associated with the generation of Trial suggestions. When this long-running operation succeeds, it will contain a SuggestTrialsResponse.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        suggest(params: Params$Resource$Projects$Locations$Studies$Trials$Suggest, options: StreamMethodOptions): GaxiosPromise<Readable>;
        suggest(params?: Params$Resource$Projects$Locations$Studies$Trials$Suggest, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        suggest(params: Params$Resource$Projects$Locations$Studies$Trials$Suggest, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        suggest(params: Params$Resource$Projects$Locations$Studies$Trials$Suggest, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        suggest(params: Params$Resource$Projects$Locations$Studies$Trials$Suggest, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        suggest(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
    }
    export interface Params$Resource$Projects$Locations$Studies$Trials$Addtrialmeasurement extends StandardParameters {
        /**
         * Required. The name of the trial to add measurement. Format: `projects/{project\}/locations/{location\}/studies/{study\}/trials/{trial\}`
         */
        trialName?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1AddTrialMeasurementRequest;
    }
    export interface Params$Resource$Projects$Locations$Studies$Trials$Checktrialearlystoppingstate extends StandardParameters {
        /**
         * Required. The Trial's name. Format: `projects/{project\}/locations/{location\}/studies/{study\}/trials/{trial\}`
         */
        trialName?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1CheckTrialEarlyStoppingStateRequest;
    }
    export interface Params$Resource$Projects$Locations$Studies$Trials$Complete extends StandardParameters {
        /**
         * Required. The Trial's name. Format: `projects/{project\}/locations/{location\}/studies/{study\}/trials/{trial\}`
         */
        name?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1CompleteTrialRequest;
    }
    export interface Params$Resource$Projects$Locations$Studies$Trials$Create extends StandardParameters {
        /**
         * Required. The resource name of the Study to create the Trial in. Format: `projects/{project\}/locations/{location\}/studies/{study\}`
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1Trial;
    }
    export interface Params$Resource$Projects$Locations$Studies$Trials$Delete extends StandardParameters {
        /**
         * Required. The Trial's name. Format: `projects/{project\}/locations/{location\}/studies/{study\}/trials/{trial\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Studies$Trials$Get extends StandardParameters {
        /**
         * Required. The name of the Trial resource. Format: `projects/{project\}/locations/{location\}/studies/{study\}/trials/{trial\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Studies$Trials$List extends StandardParameters {
        /**
         * Optional. The number of Trials to retrieve per "page" of results. If unspecified, the service will pick an appropriate default.
         */
        pageSize?: number;
        /**
         * Optional. A page token to request the next page of results. If unspecified, there are no subsequent pages.
         */
        pageToken?: string;
        /**
         * Required. The resource name of the Study to list the Trial from. Format: `projects/{project\}/locations/{location\}/studies/{study\}`
         */
        parent?: string;
    }
    export interface Params$Resource$Projects$Locations$Studies$Trials$Listoptimaltrials extends StandardParameters {
        /**
         * Required. The name of the Study that the optimal Trial belongs to.
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1ListOptimalTrialsRequest;
    }
    export interface Params$Resource$Projects$Locations$Studies$Trials$Stop extends StandardParameters {
        /**
         * Required. The Trial's name. Format: `projects/{project\}/locations/{location\}/studies/{study\}/trials/{trial\}`
         */
        name?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1StopTrialRequest;
    }
    export interface Params$Resource$Projects$Locations$Studies$Trials$Suggest extends StandardParameters {
        /**
         * Required. The project and location that the Study belongs to. Format: `projects/{project\}/locations/{location\}/studies/{study\}`
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1SuggestTrialsRequest;
    }
    export class Resource$Projects$Locations$Studies$Trials$Operations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to `Code.CANCELLED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Projects$Locations$Studies$Trials$Operations$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Projects$Locations$Studies$Trials$Operations$Cancel, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        cancel(params: Params$Resource$Projects$Locations$Studies$Trials$Operations$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Projects$Locations$Studies$Trials$Operations$Cancel, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(params: Params$Resource$Projects$Locations$Studies$Trials$Operations$Cancel, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Studies$Trials$Operations$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Studies$Trials$Operations$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        delete(params: Params$Resource$Projects$Locations$Studies$Trials$Operations$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Studies$Trials$Operations$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(params: Params$Resource$Projects$Locations$Studies$Trials$Operations$Delete, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Studies$Trials$Operations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Studies$Trials$Operations$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        get(params: Params$Resource$Projects$Locations$Studies$Trials$Operations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Studies$Trials$Operations$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(params: Params$Resource$Projects$Locations$Studies$Trials$Operations$Get, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns `UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Studies$Trials$Operations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Studies$Trials$Operations$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningListOperationsResponse>;
        list(params: Params$Resource$Projects$Locations$Studies$Trials$Operations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Studies$Trials$Operations$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Studies$Trials$Operations$List, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        /**
         * Waits until the specified long-running operation is done or reaches at most a specified timeout, returning the latest state. If the operation is already done, the latest state is immediately returned. If the timeout specified is greater than the default HTTP/RPC timeout, the HTTP/RPC timeout is used. If the server does not support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Note that this method is on a best-effort basis. It may return the latest state before the specified timeout (including immediately), meaning even an immediate response is no guarantee that the operation is done.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        wait(params: Params$Resource$Projects$Locations$Studies$Trials$Operations$Wait, options: StreamMethodOptions): GaxiosPromise<Readable>;
        wait(params?: Params$Resource$Projects$Locations$Studies$Trials$Operations$Wait, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        wait(params: Params$Resource$Projects$Locations$Studies$Trials$Operations$Wait, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        wait(params: Params$Resource$Projects$Locations$Studies$Trials$Operations$Wait, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(params: Params$Resource$Projects$Locations$Studies$Trials$Operations$Wait, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
    }
    export interface Params$Resource$Projects$Locations$Studies$Trials$Operations$Cancel extends StandardParameters {
        /**
         * The name of the operation resource to be cancelled.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Studies$Trials$Operations$Delete extends StandardParameters {
        /**
         * The name of the operation resource to be deleted.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Studies$Trials$Operations$Get extends StandardParameters {
        /**
         * The name of the operation resource.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Studies$Trials$Operations$List extends StandardParameters {
        /**
         * The standard list filter.
         */
        filter?: string;
        /**
         * The name of the operation's parent resource.
         */
        name?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token.
         */
        pageToken?: string;
    }
    export interface Params$Resource$Projects$Locations$Studies$Trials$Operations$Wait extends StandardParameters {
        /**
         * The name of the operation resource to wait on.
         */
        name?: string;
        /**
         * The maximum duration to wait before timing out. If left blank, the wait will be at most the time permitted by the underlying HTTP/RPC protocol. If RPC context deadline is also specified, the shorter one will be used.
         */
        timeout?: string;
    }
    export class Resource$Projects$Locations$Tensorboards {
        context: APIRequestContext;
        experiments: Resource$Projects$Locations$Tensorboards$Experiments;
        operations: Resource$Projects$Locations$Tensorboards$Operations;
        constructor(context: APIRequestContext);
        /**
         * Creates a Tensorboard.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        create(params: Params$Resource$Projects$Locations$Tensorboards$Create, options: StreamMethodOptions): GaxiosPromise<Readable>;
        create(params?: Params$Resource$Projects$Locations$Tensorboards$Create, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        create(params: Params$Resource$Projects$Locations$Tensorboards$Create, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        create(params: Params$Resource$Projects$Locations$Tensorboards$Create, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        create(params: Params$Resource$Projects$Locations$Tensorboards$Create, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        create(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Deletes a Tensorboard.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Tensorboards$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Tensorboards$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        delete(params: Params$Resource$Projects$Locations$Tensorboards$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Tensorboards$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(params: Params$Resource$Projects$Locations$Tensorboards$Delete, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Gets a Tensorboard.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Tensorboards$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Tensorboards$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1Tensorboard>;
        get(params: Params$Resource$Projects$Locations$Tensorboards$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Tensorboards$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1Tensorboard>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Tensorboard>): void;
        get(params: Params$Resource$Projects$Locations$Tensorboards$Get, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Tensorboard>): void;
        get(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1Tensorboard>): void;
        /**
         * Lists Tensorboards in a Location.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Tensorboards$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Tensorboards$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListTensorboardsResponse>;
        list(params: Params$Resource$Projects$Locations$Tensorboards$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Tensorboards$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListTensorboardsResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListTensorboardsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Tensorboards$List, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListTensorboardsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListTensorboardsResponse>): void;
        /**
         * Updates a Tensorboard.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Projects$Locations$Tensorboards$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Projects$Locations$Tensorboards$Patch, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        patch(params: Params$Resource$Projects$Locations$Tensorboards$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Projects$Locations$Tensorboards$Patch, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        patch(params: Params$Resource$Projects$Locations$Tensorboards$Patch, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        patch(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Returns the storage size for a given TensorBoard instance.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        readSize(params: Params$Resource$Projects$Locations$Tensorboards$Readsize, options: StreamMethodOptions): GaxiosPromise<Readable>;
        readSize(params?: Params$Resource$Projects$Locations$Tensorboards$Readsize, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ReadTensorboardSizeResponse>;
        readSize(params: Params$Resource$Projects$Locations$Tensorboards$Readsize, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        readSize(params: Params$Resource$Projects$Locations$Tensorboards$Readsize, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ReadTensorboardSizeResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ReadTensorboardSizeResponse>): void;
        readSize(params: Params$Resource$Projects$Locations$Tensorboards$Readsize, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ReadTensorboardSizeResponse>): void;
        readSize(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ReadTensorboardSizeResponse>): void;
        /**
         * Returns a list of monthly active users for a given TensorBoard instance.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        readUsage(params: Params$Resource$Projects$Locations$Tensorboards$Readusage, options: StreamMethodOptions): GaxiosPromise<Readable>;
        readUsage(params?: Params$Resource$Projects$Locations$Tensorboards$Readusage, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ReadTensorboardUsageResponse>;
        readUsage(params: Params$Resource$Projects$Locations$Tensorboards$Readusage, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        readUsage(params: Params$Resource$Projects$Locations$Tensorboards$Readusage, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ReadTensorboardUsageResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ReadTensorboardUsageResponse>): void;
        readUsage(params: Params$Resource$Projects$Locations$Tensorboards$Readusage, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ReadTensorboardUsageResponse>): void;
        readUsage(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ReadTensorboardUsageResponse>): void;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Create extends StandardParameters {
        /**
         * Required. The resource name of the Location to create the Tensorboard in. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1Tensorboard;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Delete extends StandardParameters {
        /**
         * Required. The name of the Tensorboard to be deleted. Format: `projects/{project\}/locations/{location\}/tensorboards/{tensorboard\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Get extends StandardParameters {
        /**
         * Required. The name of the Tensorboard resource. Format: `projects/{project\}/locations/{location\}/tensorboards/{tensorboard\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$List extends StandardParameters {
        /**
         * Lists the Tensorboards that match the filter expression.
         */
        filter?: string;
        /**
         * Field to use to sort the list.
         */
        orderBy?: string;
        /**
         * The maximum number of Tensorboards to return. The service may return fewer than this value. If unspecified, at most 100 Tensorboards are returned. The maximum value is 100; values above 100 are coerced to 100.
         */
        pageSize?: number;
        /**
         * A page token, received from a previous TensorboardService.ListTensorboards call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to TensorboardService.ListTensorboards must match the call that provided the page token.
         */
        pageToken?: string;
        /**
         * Required. The resource name of the Location to list Tensorboards. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Mask specifying which fields to read.
         */
        readMask?: string;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Patch extends StandardParameters {
        /**
         * Output only. Name of the Tensorboard. Format: `projects/{project\}/locations/{location\}/tensorboards/{tensorboard\}`
         */
        name?: string;
        /**
         * Required. Field mask is used to specify the fields to be overwritten in the Tensorboard resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. A field is overwritten if it's in the mask. If the user does not provide a mask then all fields are overwritten if new values are specified.
         */
        updateMask?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1Tensorboard;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Readsize extends StandardParameters {
        /**
         * Required. The name of the Tensorboard resource. Format: `projects/{project\}/locations/{location\}/tensorboards/{tensorboard\}`
         */
        tensorboard?: string;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Readusage extends StandardParameters {
        /**
         * Required. The name of the Tensorboard resource. Format: `projects/{project\}/locations/{location\}/tensorboards/{tensorboard\}`
         */
        tensorboard?: string;
    }
    export class Resource$Projects$Locations$Tensorboards$Experiments {
        context: APIRequestContext;
        operations: Resource$Projects$Locations$Tensorboards$Experiments$Operations;
        runs: Resource$Projects$Locations$Tensorboards$Experiments$Runs;
        constructor(context: APIRequestContext);
        /**
         * Creates a TensorboardExperiment.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        create(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Create, options: StreamMethodOptions): GaxiosPromise<Readable>;
        create(params?: Params$Resource$Projects$Locations$Tensorboards$Experiments$Create, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1TensorboardExperiment>;
        create(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Create, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        create(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Create, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1TensorboardExperiment>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1TensorboardExperiment>): void;
        create(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Create, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1TensorboardExperiment>): void;
        create(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1TensorboardExperiment>): void;
        /**
         * Deletes a TensorboardExperiment.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Tensorboards$Experiments$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        delete(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Delete, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Gets a TensorboardExperiment.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Tensorboards$Experiments$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1TensorboardExperiment>;
        get(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1TensorboardExperiment>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1TensorboardExperiment>): void;
        get(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Get, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1TensorboardExperiment>): void;
        get(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1TensorboardExperiment>): void;
        /**
         * Lists TensorboardExperiments in a Location.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Tensorboards$Experiments$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListTensorboardExperimentsResponse>;
        list(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListTensorboardExperimentsResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListTensorboardExperimentsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$List, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListTensorboardExperimentsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListTensorboardExperimentsResponse>): void;
        /**
         * Updates a TensorboardExperiment.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Projects$Locations$Tensorboards$Experiments$Patch, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1TensorboardExperiment>;
        patch(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Patch, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1TensorboardExperiment>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1TensorboardExperiment>): void;
        patch(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Patch, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1TensorboardExperiment>): void;
        patch(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1TensorboardExperiment>): void;
        /**
         * Write time series data points of multiple TensorboardTimeSeries in multiple TensorboardRun's. If any data fail to be ingested, an error is returned.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        write(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Write, options: StreamMethodOptions): GaxiosPromise<Readable>;
        write(params?: Params$Resource$Projects$Locations$Tensorboards$Experiments$Write, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1WriteTensorboardExperimentDataResponse>;
        write(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Write, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        write(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Write, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1WriteTensorboardExperimentDataResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1WriteTensorboardExperimentDataResponse>): void;
        write(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Write, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1WriteTensorboardExperimentDataResponse>): void;
        write(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1WriteTensorboardExperimentDataResponse>): void;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Experiments$Create extends StandardParameters {
        /**
         * Required. The resource name of the Tensorboard to create the TensorboardExperiment in. Format: `projects/{project\}/locations/{location\}/tensorboards/{tensorboard\}`
         */
        parent?: string;
        /**
         * Required. The ID to use for the Tensorboard experiment, which becomes the final component of the Tensorboard experiment's resource name. This value should be 1-128 characters, and valid characters are `/a-z-/`.
         */
        tensorboardExperimentId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1TensorboardExperiment;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Experiments$Delete extends StandardParameters {
        /**
         * Required. The name of the TensorboardExperiment to be deleted. Format: `projects/{project\}/locations/{location\}/tensorboards/{tensorboard\}/experiments/{experiment\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Experiments$Get extends StandardParameters {
        /**
         * Required. The name of the TensorboardExperiment resource. Format: `projects/{project\}/locations/{location\}/tensorboards/{tensorboard\}/experiments/{experiment\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Experiments$List extends StandardParameters {
        /**
         * Lists the TensorboardExperiments that match the filter expression.
         */
        filter?: string;
        /**
         * Field to use to sort the list.
         */
        orderBy?: string;
        /**
         * The maximum number of TensorboardExperiments to return. The service may return fewer than this value. If unspecified, at most 50 TensorboardExperiments are returned. The maximum value is 1000; values above 1000 are coerced to 1000.
         */
        pageSize?: number;
        /**
         * A page token, received from a previous TensorboardService.ListTensorboardExperiments call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to TensorboardService.ListTensorboardExperiments must match the call that provided the page token.
         */
        pageToken?: string;
        /**
         * Required. The resource name of the Tensorboard to list TensorboardExperiments. Format: `projects/{project\}/locations/{location\}/tensorboards/{tensorboard\}`
         */
        parent?: string;
        /**
         * Mask specifying which fields to read.
         */
        readMask?: string;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Experiments$Patch extends StandardParameters {
        /**
         * Output only. Name of the TensorboardExperiment. Format: `projects/{project\}/locations/{location\}/tensorboards/{tensorboard\}/experiments/{experiment\}`
         */
        name?: string;
        /**
         * Required. Field mask is used to specify the fields to be overwritten in the TensorboardExperiment resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. A field is overwritten if it's in the mask. If the user does not provide a mask then all fields are overwritten if new values are specified.
         */
        updateMask?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1TensorboardExperiment;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Experiments$Write extends StandardParameters {
        /**
         * Required. The resource name of the TensorboardExperiment to write data to. Format: `projects/{project\}/locations/{location\}/tensorboards/{tensorboard\}/experiments/{experiment\}`
         */
        tensorboardExperiment?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1WriteTensorboardExperimentDataRequest;
    }
    export class Resource$Projects$Locations$Tensorboards$Experiments$Operations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to `Code.CANCELLED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Operations$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Projects$Locations$Tensorboards$Experiments$Operations$Cancel, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        cancel(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Operations$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Operations$Cancel, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Operations$Cancel, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Operations$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Tensorboards$Experiments$Operations$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        delete(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Operations$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Operations$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Operations$Delete, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Operations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Tensorboards$Experiments$Operations$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        get(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Operations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Operations$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Operations$Get, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns `UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Operations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Tensorboards$Experiments$Operations$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningListOperationsResponse>;
        list(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Operations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Operations$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Operations$List, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        /**
         * Waits until the specified long-running operation is done or reaches at most a specified timeout, returning the latest state. If the operation is already done, the latest state is immediately returned. If the timeout specified is greater than the default HTTP/RPC timeout, the HTTP/RPC timeout is used. If the server does not support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Note that this method is on a best-effort basis. It may return the latest state before the specified timeout (including immediately), meaning even an immediate response is no guarantee that the operation is done.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        wait(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Operations$Wait, options: StreamMethodOptions): GaxiosPromise<Readable>;
        wait(params?: Params$Resource$Projects$Locations$Tensorboards$Experiments$Operations$Wait, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        wait(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Operations$Wait, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        wait(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Operations$Wait, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Operations$Wait, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Experiments$Operations$Cancel extends StandardParameters {
        /**
         * The name of the operation resource to be cancelled.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Experiments$Operations$Delete extends StandardParameters {
        /**
         * The name of the operation resource to be deleted.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Experiments$Operations$Get extends StandardParameters {
        /**
         * The name of the operation resource.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Experiments$Operations$List extends StandardParameters {
        /**
         * The standard list filter.
         */
        filter?: string;
        /**
         * The name of the operation's parent resource.
         */
        name?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token.
         */
        pageToken?: string;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Experiments$Operations$Wait extends StandardParameters {
        /**
         * The name of the operation resource to wait on.
         */
        name?: string;
        /**
         * The maximum duration to wait before timing out. If left blank, the wait will be at most the time permitted by the underlying HTTP/RPC protocol. If RPC context deadline is also specified, the shorter one will be used.
         */
        timeout?: string;
    }
    export class Resource$Projects$Locations$Tensorboards$Experiments$Runs {
        context: APIRequestContext;
        operations: Resource$Projects$Locations$Tensorboards$Experiments$Runs$Operations;
        timeSeries: Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries;
        constructor(context: APIRequestContext);
        /**
         * Batch create TensorboardRuns.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        batchCreate(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Batchcreate, options: StreamMethodOptions): GaxiosPromise<Readable>;
        batchCreate(params?: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Batchcreate, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1BatchCreateTensorboardRunsResponse>;
        batchCreate(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Batchcreate, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        batchCreate(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Batchcreate, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1BatchCreateTensorboardRunsResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1BatchCreateTensorboardRunsResponse>): void;
        batchCreate(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Batchcreate, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1BatchCreateTensorboardRunsResponse>): void;
        batchCreate(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1BatchCreateTensorboardRunsResponse>): void;
        /**
         * Creates a TensorboardRun.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        create(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Create, options: StreamMethodOptions): GaxiosPromise<Readable>;
        create(params?: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Create, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1TensorboardRun>;
        create(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Create, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        create(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Create, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1TensorboardRun>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1TensorboardRun>): void;
        create(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Create, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1TensorboardRun>): void;
        create(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1TensorboardRun>): void;
        /**
         * Deletes a TensorboardRun.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        delete(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Delete, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Gets a TensorboardRun.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1TensorboardRun>;
        get(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1TensorboardRun>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1TensorboardRun>): void;
        get(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Get, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1TensorboardRun>): void;
        get(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1TensorboardRun>): void;
        /**
         * Lists TensorboardRuns in a Location.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListTensorboardRunsResponse>;
        list(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListTensorboardRunsResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListTensorboardRunsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$List, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListTensorboardRunsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListTensorboardRunsResponse>): void;
        /**
         * Updates a TensorboardRun.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Patch, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1TensorboardRun>;
        patch(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Patch, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1TensorboardRun>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1TensorboardRun>): void;
        patch(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Patch, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1TensorboardRun>): void;
        patch(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1TensorboardRun>): void;
        /**
         * Write time series data points into multiple TensorboardTimeSeries under a TensorboardRun. If any data fail to be ingested, an error is returned.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        write(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Write, options: StreamMethodOptions): GaxiosPromise<Readable>;
        write(params?: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Write, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1WriteTensorboardRunDataResponse>;
        write(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Write, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        write(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Write, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1WriteTensorboardRunDataResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1WriteTensorboardRunDataResponse>): void;
        write(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Write, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1WriteTensorboardRunDataResponse>): void;
        write(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1WriteTensorboardRunDataResponse>): void;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Batchcreate extends StandardParameters {
        /**
         * Required. The resource name of the TensorboardExperiment to create the TensorboardRuns in. Format: `projects/{project\}/locations/{location\}/tensorboards/{tensorboard\}/experiments/{experiment\}` The parent field in the CreateTensorboardRunRequest messages must match this field.
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1BatchCreateTensorboardRunsRequest;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Create extends StandardParameters {
        /**
         * Required. The resource name of the TensorboardExperiment to create the TensorboardRun in. Format: `projects/{project\}/locations/{location\}/tensorboards/{tensorboard\}/experiments/{experiment\}`
         */
        parent?: string;
        /**
         * Required. The ID to use for the Tensorboard run, which becomes the final component of the Tensorboard run's resource name. This value should be 1-128 characters, and valid characters are `/a-z-/`.
         */
        tensorboardRunId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1TensorboardRun;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Delete extends StandardParameters {
        /**
         * Required. The name of the TensorboardRun to be deleted. Format: `projects/{project\}/locations/{location\}/tensorboards/{tensorboard\}/experiments/{experiment\}/runs/{run\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Get extends StandardParameters {
        /**
         * Required. The name of the TensorboardRun resource. Format: `projects/{project\}/locations/{location\}/tensorboards/{tensorboard\}/experiments/{experiment\}/runs/{run\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$List extends StandardParameters {
        /**
         * Lists the TensorboardRuns that match the filter expression.
         */
        filter?: string;
        /**
         * Field to use to sort the list.
         */
        orderBy?: string;
        /**
         * The maximum number of TensorboardRuns to return. The service may return fewer than this value. If unspecified, at most 50 TensorboardRuns are returned. The maximum value is 1000; values above 1000 are coerced to 1000.
         */
        pageSize?: number;
        /**
         * A page token, received from a previous TensorboardService.ListTensorboardRuns call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to TensorboardService.ListTensorboardRuns must match the call that provided the page token.
         */
        pageToken?: string;
        /**
         * Required. The resource name of the TensorboardExperiment to list TensorboardRuns. Format: `projects/{project\}/locations/{location\}/tensorboards/{tensorboard\}/experiments/{experiment\}`
         */
        parent?: string;
        /**
         * Mask specifying which fields to read.
         */
        readMask?: string;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Patch extends StandardParameters {
        /**
         * Output only. Name of the TensorboardRun. Format: `projects/{project\}/locations/{location\}/tensorboards/{tensorboard\}/experiments/{experiment\}/runs/{run\}`
         */
        name?: string;
        /**
         * Required. Field mask is used to specify the fields to be overwritten in the TensorboardRun resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. A field is overwritten if it's in the mask. If the user does not provide a mask then all fields are overwritten if new values are specified.
         */
        updateMask?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1TensorboardRun;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Write extends StandardParameters {
        /**
         * Required. The resource name of the TensorboardRun to write data to. Format: `projects/{project\}/locations/{location\}/tensorboards/{tensorboard\}/experiments/{experiment\}/runs/{run\}`
         */
        tensorboardRun?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1WriteTensorboardRunDataRequest;
    }
    export class Resource$Projects$Locations$Tensorboards$Experiments$Runs$Operations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to `Code.CANCELLED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Operations$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Operations$Cancel, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        cancel(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Operations$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Operations$Cancel, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Operations$Cancel, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Operations$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Operations$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        delete(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Operations$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Operations$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Operations$Delete, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Operations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Operations$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        get(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Operations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Operations$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Operations$Get, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns `UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Operations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Operations$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningListOperationsResponse>;
        list(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Operations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Operations$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Operations$List, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        /**
         * Waits until the specified long-running operation is done or reaches at most a specified timeout, returning the latest state. If the operation is already done, the latest state is immediately returned. If the timeout specified is greater than the default HTTP/RPC timeout, the HTTP/RPC timeout is used. If the server does not support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Note that this method is on a best-effort basis. It may return the latest state before the specified timeout (including immediately), meaning even an immediate response is no guarantee that the operation is done.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        wait(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Operations$Wait, options: StreamMethodOptions): GaxiosPromise<Readable>;
        wait(params?: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Operations$Wait, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        wait(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Operations$Wait, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        wait(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Operations$Wait, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Operations$Wait, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Operations$Cancel extends StandardParameters {
        /**
         * The name of the operation resource to be cancelled.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Operations$Delete extends StandardParameters {
        /**
         * The name of the operation resource to be deleted.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Operations$Get extends StandardParameters {
        /**
         * The name of the operation resource.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Operations$List extends StandardParameters {
        /**
         * The standard list filter.
         */
        filter?: string;
        /**
         * The name of the operation's parent resource.
         */
        name?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token.
         */
        pageToken?: string;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Operations$Wait extends StandardParameters {
        /**
         * The name of the operation resource to wait on.
         */
        name?: string;
        /**
         * The maximum duration to wait before timing out. If left blank, the wait will be at most the time permitted by the underlying HTTP/RPC protocol. If RPC context deadline is also specified, the shorter one will be used.
         */
        timeout?: string;
    }
    export class Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries {
        context: APIRequestContext;
        operations: Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Operations;
        constructor(context: APIRequestContext);
        /**
         * Batch create TensorboardTimeSeries that belong to a TensorboardExperiment.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        batchCreate(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Batchcreate, options: StreamMethodOptions): GaxiosPromise<Readable>;
        batchCreate(params?: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Batchcreate, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1BatchCreateTensorboardTimeSeriesResponse>;
        batchCreate(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Batchcreate, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        batchCreate(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Batchcreate, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1BatchCreateTensorboardTimeSeriesResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1BatchCreateTensorboardTimeSeriesResponse>): void;
        batchCreate(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Batchcreate, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1BatchCreateTensorboardTimeSeriesResponse>): void;
        batchCreate(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1BatchCreateTensorboardTimeSeriesResponse>): void;
        /**
         * Reads multiple TensorboardTimeSeries' data. The data point number limit is 1000 for scalars, 100 for tensors and blob references. If the number of data points stored is less than the limit, all data is returned. Otherwise, the number limit of data points is randomly selected from this time series and returned.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        batchRead(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Batchread, options: StreamMethodOptions): GaxiosPromise<Readable>;
        batchRead(params?: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Batchread, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1BatchReadTensorboardTimeSeriesDataResponse>;
        batchRead(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Batchread, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        batchRead(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Batchread, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1BatchReadTensorboardTimeSeriesDataResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1BatchReadTensorboardTimeSeriesDataResponse>): void;
        batchRead(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Batchread, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1BatchReadTensorboardTimeSeriesDataResponse>): void;
        batchRead(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1BatchReadTensorboardTimeSeriesDataResponse>): void;
        /**
         * Creates a TensorboardTimeSeries.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        create(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Create, options: StreamMethodOptions): GaxiosPromise<Readable>;
        create(params?: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Create, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1TensorboardTimeSeries>;
        create(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Create, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        create(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Create, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1TensorboardTimeSeries>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1TensorboardTimeSeries>): void;
        create(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Create, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1TensorboardTimeSeries>): void;
        create(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1TensorboardTimeSeries>): void;
        /**
         * Deletes a TensorboardTimeSeries.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        delete(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Delete, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Exports a TensorboardTimeSeries' data. Data is returned in paginated responses.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        exportTensorboardTimeSeries(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Exporttensorboardtimeseries, options: StreamMethodOptions): GaxiosPromise<Readable>;
        exportTensorboardTimeSeries(params?: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Exporttensorboardtimeseries, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ExportTensorboardTimeSeriesDataResponse>;
        exportTensorboardTimeSeries(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Exporttensorboardtimeseries, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        exportTensorboardTimeSeries(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Exporttensorboardtimeseries, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ExportTensorboardTimeSeriesDataResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ExportTensorboardTimeSeriesDataResponse>): void;
        exportTensorboardTimeSeries(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Exporttensorboardtimeseries, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ExportTensorboardTimeSeriesDataResponse>): void;
        exportTensorboardTimeSeries(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ExportTensorboardTimeSeriesDataResponse>): void;
        /**
         * Gets a TensorboardTimeSeries.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1TensorboardTimeSeries>;
        get(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1TensorboardTimeSeries>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1TensorboardTimeSeries>): void;
        get(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Get, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1TensorboardTimeSeries>): void;
        get(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1TensorboardTimeSeries>): void;
        /**
         * Lists TensorboardTimeSeries in a Location.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListTensorboardTimeSeriesResponse>;
        list(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListTensorboardTimeSeriesResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListTensorboardTimeSeriesResponse>): void;
        list(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$List, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListTensorboardTimeSeriesResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListTensorboardTimeSeriesResponse>): void;
        /**
         * Updates a TensorboardTimeSeries.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Patch, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1TensorboardTimeSeries>;
        patch(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Patch, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1TensorboardTimeSeries>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1TensorboardTimeSeries>): void;
        patch(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Patch, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1TensorboardTimeSeries>): void;
        patch(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1TensorboardTimeSeries>): void;
        /**
         * Reads a TensorboardTimeSeries' data. By default, if the number of data points stored is less than 1000, all data is returned. Otherwise, 1000 data points is randomly selected from this time series and returned. This value can be changed by changing max_data_points, which can't be greater than 10k.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        read(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Read, options: StreamMethodOptions): GaxiosPromise<Readable>;
        read(params?: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Read, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ReadTensorboardTimeSeriesDataResponse>;
        read(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Read, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        read(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Read, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ReadTensorboardTimeSeriesDataResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ReadTensorboardTimeSeriesDataResponse>): void;
        read(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Read, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ReadTensorboardTimeSeriesDataResponse>): void;
        read(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ReadTensorboardTimeSeriesDataResponse>): void;
        /**
         * Gets bytes of TensorboardBlobs. This is to allow reading blob data stored in consumer project's Cloud Storage bucket without users having to obtain Cloud Storage access permission.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        readBlobData(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Readblobdata, options: StreamMethodOptions): GaxiosPromise<Readable>;
        readBlobData(params?: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Readblobdata, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ReadTensorboardBlobDataResponse>;
        readBlobData(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Readblobdata, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        readBlobData(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Readblobdata, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ReadTensorboardBlobDataResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ReadTensorboardBlobDataResponse>): void;
        readBlobData(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Readblobdata, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ReadTensorboardBlobDataResponse>): void;
        readBlobData(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ReadTensorboardBlobDataResponse>): void;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Batchcreate extends StandardParameters {
        /**
         * Required. The resource name of the TensorboardExperiment to create the TensorboardTimeSeries in. Format: `projects/{project\}/locations/{location\}/tensorboards/{tensorboard\}/experiments/{experiment\}` The TensorboardRuns referenced by the parent fields in the CreateTensorboardTimeSeriesRequest messages must be sub resources of this TensorboardExperiment.
         */
        parent?: string;
        /**
         *
         */
        runsId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1BatchCreateTensorboardTimeSeriesRequest;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Batchread extends StandardParameters {
        /**
         *
         */
        experimentsId?: string;
        /**
         *
         */
        runsId?: string;
        /**
         * Required. The resource name of the Tensorboard containing TensorboardTimeSeries to read data from. Format: `projects/{project\}/locations/{location\}/tensorboards/{tensorboard\}`. The TensorboardTimeSeries referenced by time_series must be sub resources of this Tensorboard.
         */
        tensorboard?: string;
        /**
         * Required. The resource names of the TensorboardTimeSeries to read data from. Format: `projects/{project\}/locations/{location\}/tensorboards/{tensorboard\}/experiments/{experiment\}/runs/{run\}/timeSeries/{time_series\}`
         */
        timeSeries?: string[];
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Create extends StandardParameters {
        /**
         * Required. The resource name of the TensorboardRun to create the TensorboardTimeSeries in. Format: `projects/{project\}/locations/{location\}/tensorboards/{tensorboard\}/experiments/{experiment\}/runs/{run\}`
         */
        parent?: string;
        /**
         * Optional. The user specified unique ID to use for the TensorboardTimeSeries, which becomes the final component of the TensorboardTimeSeries's resource name. This value should match "a-z0-9{0, 127\}"
         */
        tensorboardTimeSeriesId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1TensorboardTimeSeries;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Delete extends StandardParameters {
        /**
         * Required. The name of the TensorboardTimeSeries to be deleted. Format: `projects/{project\}/locations/{location\}/tensorboards/{tensorboard\}/experiments/{experiment\}/runs/{run\}/timeSeries/{time_series\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Exporttensorboardtimeseries extends StandardParameters {
        /**
         * Required. The resource name of the TensorboardTimeSeries to export data from. Format: `projects/{project\}/locations/{location\}/tensorboards/{tensorboard\}/experiments/{experiment\}/runs/{run\}/timeSeries/{time_series\}`
         */
        tensorboardTimeSeries?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1ExportTensorboardTimeSeriesDataRequest;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Get extends StandardParameters {
        /**
         * Required. The name of the TensorboardTimeSeries resource. Format: `projects/{project\}/locations/{location\}/tensorboards/{tensorboard\}/experiments/{experiment\}/runs/{run\}/timeSeries/{time_series\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$List extends StandardParameters {
        /**
         * Lists the TensorboardTimeSeries that match the filter expression.
         */
        filter?: string;
        /**
         * Field to use to sort the list.
         */
        orderBy?: string;
        /**
         * The maximum number of TensorboardTimeSeries to return. The service may return fewer than this value. If unspecified, at most 50 TensorboardTimeSeries are returned. The maximum value is 1000; values above 1000 are coerced to 1000.
         */
        pageSize?: number;
        /**
         * A page token, received from a previous TensorboardService.ListTensorboardTimeSeries call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to TensorboardService.ListTensorboardTimeSeries must match the call that provided the page token.
         */
        pageToken?: string;
        /**
         * Required. The resource name of the TensorboardRun to list TensorboardTimeSeries. Format: `projects/{project\}/locations/{location\}/tensorboards/{tensorboard\}/experiments/{experiment\}/runs/{run\}`
         */
        parent?: string;
        /**
         * Mask specifying which fields to read.
         */
        readMask?: string;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Patch extends StandardParameters {
        /**
         * Output only. Name of the TensorboardTimeSeries.
         */
        name?: string;
        /**
         * Required. Field mask is used to specify the fields to be overwritten in the TensorboardTimeSeries resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. A field is overwritten if it's in the mask. If the user does not provide a mask then all fields are overwritten if new values are specified.
         */
        updateMask?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1TensorboardTimeSeries;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Read extends StandardParameters {
        /**
         * Reads the TensorboardTimeSeries' data that match the filter expression.
         */
        filter?: string;
        /**
         * The maximum number of TensorboardTimeSeries' data to return. This value should be a positive integer. This value can be set to -1 to return all data.
         */
        maxDataPoints?: number;
        /**
         * Required. The resource name of the TensorboardTimeSeries to read data from. Format: `projects/{project\}/locations/{location\}/tensorboards/{tensorboard\}/experiments/{experiment\}/runs/{run\}/timeSeries/{time_series\}`
         */
        tensorboardTimeSeries?: string;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Readblobdata extends StandardParameters {
        /**
         * IDs of the blobs to read.
         */
        blobIds?: string[];
        /**
         * Required. The resource name of the TensorboardTimeSeries to list Blobs. Format: `projects/{project\}/locations/{location\}/tensorboards/{tensorboard\}/experiments/{experiment\}/runs/{run\}/timeSeries/{time_series\}`
         */
        timeSeries?: string;
    }
    export class Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Operations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to `Code.CANCELLED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Operations$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Operations$Cancel, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        cancel(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Operations$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Operations$Cancel, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Operations$Cancel, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Operations$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Operations$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        delete(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Operations$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Operations$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Operations$Delete, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Operations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Operations$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        get(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Operations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Operations$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Operations$Get, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns `UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Operations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Operations$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningListOperationsResponse>;
        list(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Operations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Operations$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Operations$List, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        /**
         * Waits until the specified long-running operation is done or reaches at most a specified timeout, returning the latest state. If the operation is already done, the latest state is immediately returned. If the timeout specified is greater than the default HTTP/RPC timeout, the HTTP/RPC timeout is used. If the server does not support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Note that this method is on a best-effort basis. It may return the latest state before the specified timeout (including immediately), meaning even an immediate response is no guarantee that the operation is done.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        wait(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Operations$Wait, options: StreamMethodOptions): GaxiosPromise<Readable>;
        wait(params?: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Operations$Wait, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        wait(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Operations$Wait, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        wait(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Operations$Wait, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(params: Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Operations$Wait, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Operations$Cancel extends StandardParameters {
        /**
         * The name of the operation resource to be cancelled.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Operations$Delete extends StandardParameters {
        /**
         * The name of the operation resource to be deleted.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Operations$Get extends StandardParameters {
        /**
         * The name of the operation resource.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Operations$List extends StandardParameters {
        /**
         * The standard list filter.
         */
        filter?: string;
        /**
         * The name of the operation's parent resource.
         */
        name?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token.
         */
        pageToken?: string;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Experiments$Runs$Timeseries$Operations$Wait extends StandardParameters {
        /**
         * The name of the operation resource to wait on.
         */
        name?: string;
        /**
         * The maximum duration to wait before timing out. If left blank, the wait will be at most the time permitted by the underlying HTTP/RPC protocol. If RPC context deadline is also specified, the shorter one will be used.
         */
        timeout?: string;
    }
    export class Resource$Projects$Locations$Tensorboards$Operations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to `Code.CANCELLED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Projects$Locations$Tensorboards$Operations$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Projects$Locations$Tensorboards$Operations$Cancel, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        cancel(params: Params$Resource$Projects$Locations$Tensorboards$Operations$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Projects$Locations$Tensorboards$Operations$Cancel, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(params: Params$Resource$Projects$Locations$Tensorboards$Operations$Cancel, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Tensorboards$Operations$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Tensorboards$Operations$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        delete(params: Params$Resource$Projects$Locations$Tensorboards$Operations$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Tensorboards$Operations$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(params: Params$Resource$Projects$Locations$Tensorboards$Operations$Delete, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Tensorboards$Operations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Tensorboards$Operations$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        get(params: Params$Resource$Projects$Locations$Tensorboards$Operations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Tensorboards$Operations$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(params: Params$Resource$Projects$Locations$Tensorboards$Operations$Get, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns `UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Tensorboards$Operations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Tensorboards$Operations$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningListOperationsResponse>;
        list(params: Params$Resource$Projects$Locations$Tensorboards$Operations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Tensorboards$Operations$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Tensorboards$Operations$List, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        /**
         * Waits until the specified long-running operation is done or reaches at most a specified timeout, returning the latest state. If the operation is already done, the latest state is immediately returned. If the timeout specified is greater than the default HTTP/RPC timeout, the HTTP/RPC timeout is used. If the server does not support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Note that this method is on a best-effort basis. It may return the latest state before the specified timeout (including immediately), meaning even an immediate response is no guarantee that the operation is done.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        wait(params: Params$Resource$Projects$Locations$Tensorboards$Operations$Wait, options: StreamMethodOptions): GaxiosPromise<Readable>;
        wait(params?: Params$Resource$Projects$Locations$Tensorboards$Operations$Wait, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        wait(params: Params$Resource$Projects$Locations$Tensorboards$Operations$Wait, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        wait(params: Params$Resource$Projects$Locations$Tensorboards$Operations$Wait, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(params: Params$Resource$Projects$Locations$Tensorboards$Operations$Wait, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Operations$Cancel extends StandardParameters {
        /**
         * The name of the operation resource to be cancelled.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Operations$Delete extends StandardParameters {
        /**
         * The name of the operation resource to be deleted.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Operations$Get extends StandardParameters {
        /**
         * The name of the operation resource.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Operations$List extends StandardParameters {
        /**
         * The standard list filter.
         */
        filter?: string;
        /**
         * The name of the operation's parent resource.
         */
        name?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token.
         */
        pageToken?: string;
    }
    export interface Params$Resource$Projects$Locations$Tensorboards$Operations$Wait extends StandardParameters {
        /**
         * The name of the operation resource to wait on.
         */
        name?: string;
        /**
         * The maximum duration to wait before timing out. If left blank, the wait will be at most the time permitted by the underlying HTTP/RPC protocol. If RPC context deadline is also specified, the shorter one will be used.
         */
        timeout?: string;
    }
    export class Resource$Projects$Locations$Trainingpipelines {
        context: APIRequestContext;
        operations: Resource$Projects$Locations$Trainingpipelines$Operations;
        constructor(context: APIRequestContext);
        /**
         * Cancels a TrainingPipeline. Starts asynchronous cancellation on the TrainingPipeline. The server makes a best effort to cancel the pipeline, but success is not guaranteed. Clients can use PipelineService.GetTrainingPipeline or other methods to check whether the cancellation succeeded or whether the pipeline completed despite cancellation. On successful cancellation, the TrainingPipeline is not deleted; instead it becomes a pipeline with a TrainingPipeline.error value with a google.rpc.Status.code of 1, corresponding to `Code.CANCELLED`, and TrainingPipeline.state is set to `CANCELLED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Projects$Locations$Trainingpipelines$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Projects$Locations$Trainingpipelines$Cancel, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        cancel(params: Params$Resource$Projects$Locations$Trainingpipelines$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Projects$Locations$Trainingpipelines$Cancel, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(params: Params$Resource$Projects$Locations$Trainingpipelines$Cancel, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Creates a TrainingPipeline. A created TrainingPipeline right away will be attempted to be run.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        create(params: Params$Resource$Projects$Locations$Trainingpipelines$Create, options: StreamMethodOptions): GaxiosPromise<Readable>;
        create(params?: Params$Resource$Projects$Locations$Trainingpipelines$Create, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1TrainingPipeline>;
        create(params: Params$Resource$Projects$Locations$Trainingpipelines$Create, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        create(params: Params$Resource$Projects$Locations$Trainingpipelines$Create, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1TrainingPipeline>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1TrainingPipeline>): void;
        create(params: Params$Resource$Projects$Locations$Trainingpipelines$Create, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1TrainingPipeline>): void;
        create(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1TrainingPipeline>): void;
        /**
         * Deletes a TrainingPipeline.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Trainingpipelines$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Trainingpipelines$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        delete(params: Params$Resource$Projects$Locations$Trainingpipelines$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Trainingpipelines$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(params: Params$Resource$Projects$Locations$Trainingpipelines$Delete, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Gets a TrainingPipeline.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Trainingpipelines$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Trainingpipelines$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1TrainingPipeline>;
        get(params: Params$Resource$Projects$Locations$Trainingpipelines$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Trainingpipelines$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1TrainingPipeline>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1TrainingPipeline>): void;
        get(params: Params$Resource$Projects$Locations$Trainingpipelines$Get, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1TrainingPipeline>): void;
        get(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1TrainingPipeline>): void;
        /**
         * Lists TrainingPipelines in a Location.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Trainingpipelines$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Trainingpipelines$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1ListTrainingPipelinesResponse>;
        list(params: Params$Resource$Projects$Locations$Trainingpipelines$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Trainingpipelines$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListTrainingPipelinesResponse>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListTrainingPipelinesResponse>): void;
        list(params: Params$Resource$Projects$Locations$Trainingpipelines$List, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListTrainingPipelinesResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1ListTrainingPipelinesResponse>): void;
    }
    export interface Params$Resource$Projects$Locations$Trainingpipelines$Cancel extends StandardParameters {
        /**
         * Required. The name of the TrainingPipeline to cancel. Format: `projects/{project\}/locations/{location\}/trainingPipelines/{training_pipeline\}`
         */
        name?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1CancelTrainingPipelineRequest;
    }
    export interface Params$Resource$Projects$Locations$Trainingpipelines$Create extends StandardParameters {
        /**
         * Required. The resource name of the Location to create the TrainingPipeline in. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GoogleCloudAiplatformV1TrainingPipeline;
    }
    export interface Params$Resource$Projects$Locations$Trainingpipelines$Delete extends StandardParameters {
        /**
         * Required. The name of the TrainingPipeline resource to be deleted. Format: `projects/{project\}/locations/{location\}/trainingPipelines/{training_pipeline\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Trainingpipelines$Get extends StandardParameters {
        /**
         * Required. The name of the TrainingPipeline resource. Format: `projects/{project\}/locations/{location\}/trainingPipelines/{training_pipeline\}`
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Trainingpipelines$List extends StandardParameters {
        /**
         * The standard list filter. Supported fields: * `display_name` supports `=`, `!=` comparisons, and `:` wildcard. * `state` supports `=`, `!=` comparisons. * `training_task_definition` `=`, `!=` comparisons, and `:` wildcard. * `create_time` supports `=`, `!=`,`<`, `<=`,`\>`, `\>=` comparisons. `create_time` must be in RFC 3339 format. * `labels` supports general map functions that is: `labels.key=value` - key:value equality `labels.key:* - key existence Some examples of using the filter are: * `state="PIPELINE_STATE_SUCCEEDED" AND display_name:"my_pipeline_*"` * `state!="PIPELINE_STATE_FAILED" OR display_name="my_pipeline"` * `NOT display_name="my_pipeline"` * `create_time\>"2021-05-18T00:00:00Z"` * `training_task_definition:"*automl_text_classification*"`
         */
        filter?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token. Typically obtained via ListTrainingPipelinesResponse.next_page_token of the previous PipelineService.ListTrainingPipelines call.
         */
        pageToken?: string;
        /**
         * Required. The resource name of the Location to list the TrainingPipelines from. Format: `projects/{project\}/locations/{location\}`
         */
        parent?: string;
        /**
         * Mask specifying which fields to read.
         */
        readMask?: string;
    }
    export class Resource$Projects$Locations$Trainingpipelines$Operations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to `Code.CANCELLED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Projects$Locations$Trainingpipelines$Operations$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Projects$Locations$Trainingpipelines$Operations$Cancel, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        cancel(params: Params$Resource$Projects$Locations$Trainingpipelines$Operations$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Projects$Locations$Trainingpipelines$Operations$Cancel, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(params: Params$Resource$Projects$Locations$Trainingpipelines$Operations$Cancel, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        cancel(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Projects$Locations$Trainingpipelines$Operations$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Projects$Locations$Trainingpipelines$Operations$Delete, options?: MethodOptions): GaxiosPromise<Schema$GoogleProtobufEmpty>;
        delete(params: Params$Resource$Projects$Locations$Trainingpipelines$Operations$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Projects$Locations$Trainingpipelines$Operations$Delete, options: MethodOptions | BodyResponseCallback<Schema$GoogleProtobufEmpty>, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(params: Params$Resource$Projects$Locations$Trainingpipelines$Operations$Delete, callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        delete(callback: BodyResponseCallback<Schema$GoogleProtobufEmpty>): void;
        /**
         * Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Locations$Trainingpipelines$Operations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Locations$Trainingpipelines$Operations$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        get(params: Params$Resource$Projects$Locations$Trainingpipelines$Operations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Locations$Trainingpipelines$Operations$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(params: Params$Resource$Projects$Locations$Trainingpipelines$Operations$Get, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        get(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        /**
         * Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns `UNIMPLEMENTED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Projects$Locations$Trainingpipelines$Operations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Projects$Locations$Trainingpipelines$Operations$List, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningListOperationsResponse>;
        list(params: Params$Resource$Projects$Locations$Trainingpipelines$Operations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Projects$Locations$Trainingpipelines$Operations$List, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(params: Params$Resource$Projects$Locations$Trainingpipelines$Operations$List, callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        list(callback: BodyResponseCallback<Schema$GoogleLongrunningListOperationsResponse>): void;
        /**
         * Waits until the specified long-running operation is done or reaches at most a specified timeout, returning the latest state. If the operation is already done, the latest state is immediately returned. If the timeout specified is greater than the default HTTP/RPC timeout, the HTTP/RPC timeout is used. If the server does not support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Note that this method is on a best-effort basis. It may return the latest state before the specified timeout (including immediately), meaning even an immediate response is no guarantee that the operation is done.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        wait(params: Params$Resource$Projects$Locations$Trainingpipelines$Operations$Wait, options: StreamMethodOptions): GaxiosPromise<Readable>;
        wait(params?: Params$Resource$Projects$Locations$Trainingpipelines$Operations$Wait, options?: MethodOptions): GaxiosPromise<Schema$GoogleLongrunningOperation>;
        wait(params: Params$Resource$Projects$Locations$Trainingpipelines$Operations$Wait, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        wait(params: Params$Resource$Projects$Locations$Trainingpipelines$Operations$Wait, options: MethodOptions | BodyResponseCallback<Schema$GoogleLongrunningOperation>, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(params: Params$Resource$Projects$Locations$Trainingpipelines$Operations$Wait, callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
        wait(callback: BodyResponseCallback<Schema$GoogleLongrunningOperation>): void;
    }
    export interface Params$Resource$Projects$Locations$Trainingpipelines$Operations$Cancel extends StandardParameters {
        /**
         * The name of the operation resource to be cancelled.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Trainingpipelines$Operations$Delete extends StandardParameters {
        /**
         * The name of the operation resource to be deleted.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Trainingpipelines$Operations$Get extends StandardParameters {
        /**
         * The name of the operation resource.
         */
        name?: string;
    }
    export interface Params$Resource$Projects$Locations$Trainingpipelines$Operations$List extends StandardParameters {
        /**
         * The standard list filter.
         */
        filter?: string;
        /**
         * The name of the operation's parent resource.
         */
        name?: string;
        /**
         * The standard list page size.
         */
        pageSize?: number;
        /**
         * The standard list page token.
         */
        pageToken?: string;
    }
    export interface Params$Resource$Projects$Locations$Trainingpipelines$Operations$Wait extends StandardParameters {
        /**
         * The name of the operation resource to wait on.
         */
        name?: string;
        /**
         * The maximum duration to wait before timing out. If left blank, the wait will be at most the time permitted by the underlying HTTP/RPC protocol. If RPC context deadline is also specified, the shorter one will be used.
         */
        timeout?: string;
    }
    export class Resource$Publishers {
        context: APIRequestContext;
        models: Resource$Publishers$Models;
        constructor(context: APIRequestContext);
    }
    export class Resource$Publishers$Models {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Gets a Model Garden publisher model.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Publishers$Models$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Publishers$Models$Get, options?: MethodOptions): GaxiosPromise<Schema$GoogleCloudAiplatformV1PublisherModel>;
        get(params: Params$Resource$Publishers$Models$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Publishers$Models$Get, options: MethodOptions | BodyResponseCallback<Schema$GoogleCloudAiplatformV1PublisherModel>, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1PublisherModel>): void;
        get(params: Params$Resource$Publishers$Models$Get, callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1PublisherModel>): void;
        get(callback: BodyResponseCallback<Schema$GoogleCloudAiplatformV1PublisherModel>): void;
    }
    export interface Params$Resource$Publishers$Models$Get extends StandardParameters {
        /**
         * Optional. The IETF BCP-47 language code representing the language in which the publisher model's text information should be written in (see go/bcp47).
         */
        languageCode?: string;
        /**
         * Required. The name of the PublisherModel resource. Format: `publishers/{publisher\}/models/{publisher_model\}`
         */
        name?: string;
        /**
         * Optional. PublisherModel view specifying which fields to read.
         */
        view?: string;
    }
    export {};
}
