/// <reference types="node" />
import { OAuth2Client, JWT, UserRefreshClient, BaseExternalAccountClient, GaxiosPromise, GoogleConfigurable, MethodOptions, StreamMethodOptions, GlobalOptions, GoogleAuth, BodyResponseCallback, APIRequestContext } from 'googleapis-common';
import { Readable } from 'stream';
export declare namespace compute_alpha {
    export interface Options extends GlobalOptions {
        version: 'alpha';
    }
    interface StandardParameters {
        /**
         * Auth client or API Key for the request
         */
        auth?: string | OAuth2Client | JWT | Compute | UserRefreshClient | BaseExternalAccountClient | GoogleAuth;
        /**
         * V1 error format.
         */
        '$.xgafv'?: string;
        /**
         * OAuth access token.
         */
        access_token?: string;
        /**
         * Data format for response.
         */
        alt?: string;
        /**
         * JSONP
         */
        callback?: string;
        /**
         * Selector specifying which fields to include in a partial response.
         */
        fields?: string;
        /**
         * API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
         */
        key?: string;
        /**
         * OAuth 2.0 token for the current user.
         */
        oauth_token?: string;
        /**
         * Returns response with indentations and line breaks.
         */
        prettyPrint?: boolean;
        /**
         * Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
         */
        quotaUser?: string;
        /**
         * Legacy upload protocol for media (e.g. "media", "multipart").
         */
        uploadType?: string;
        /**
         * Upload protocol for media (e.g. "raw", "multipart").
         */
        upload_protocol?: string;
        /**
         * Legacy name for parameter that has been superseded by `quotaUser`.
         */
        userIp?: string;
    }
    /**
     * Compute Engine API
     *
     * Creates and runs virtual machines on Google Cloud Platform.
     *
     * @example
     * ```js
     * const {google} = require('googleapis');
     * const compute = google.compute('alpha');
     * ```
     */
    export class Compute {
        context: APIRequestContext;
        acceleratorTypes: Resource$Acceleratortypes;
        addresses: Resource$Addresses;
        autoscalers: Resource$Autoscalers;
        backendBuckets: Resource$Backendbuckets;
        backendServices: Resource$Backendservices;
        disks: Resource$Disks;
        diskSettings: Resource$Disksettings;
        diskTypes: Resource$Disktypes;
        externalVpnGateways: Resource$Externalvpngateways;
        firewallPolicies: Resource$Firewallpolicies;
        firewalls: Resource$Firewalls;
        forwardingRules: Resource$Forwardingrules;
        futureReservations: Resource$Futurereservations;
        globalAddresses: Resource$Globaladdresses;
        globalForwardingRules: Resource$Globalforwardingrules;
        globalNetworkEndpointGroups: Resource$Globalnetworkendpointgroups;
        globalOperations: Resource$Globaloperations;
        globalOrganizationOperations: Resource$Globalorganizationoperations;
        globalPublicDelegatedPrefixes: Resource$Globalpublicdelegatedprefixes;
        healthChecks: Resource$Healthchecks;
        httpHealthChecks: Resource$Httphealthchecks;
        httpsHealthChecks: Resource$Httpshealthchecks;
        imageFamilyViews: Resource$Imagefamilyviews;
        images: Resource$Images;
        instanceGroupManagerResizeRequests: Resource$Instancegroupmanagerresizerequests;
        instanceGroupManagers: Resource$Instancegroupmanagers;
        instanceGroups: Resource$Instancegroups;
        instances: Resource$Instances;
        instanceSettings: Resource$Instancesettings;
        instanceTemplates: Resource$Instancetemplates;
        instantSnapshots: Resource$Instantsnapshots;
        interconnectAttachments: Resource$Interconnectattachments;
        interconnectLocations: Resource$Interconnectlocations;
        interconnectRemoteLocations: Resource$Interconnectremotelocations;
        interconnects: Resource$Interconnects;
        licenseCodes: Resource$Licensecodes;
        licenses: Resource$Licenses;
        machineImages: Resource$Machineimages;
        machineTypes: Resource$Machinetypes;
        networkAttachments: Resource$Networkattachments;
        networkEdgeSecurityServices: Resource$Networkedgesecurityservices;
        networkEndpointGroups: Resource$Networkendpointgroups;
        networkFirewallPolicies: Resource$Networkfirewallpolicies;
        networks: Resource$Networks;
        nodeGroups: Resource$Nodegroups;
        nodeTemplates: Resource$Nodetemplates;
        nodeTypes: Resource$Nodetypes;
        organizationSecurityPolicies: Resource$Organizationsecuritypolicies;
        packetMirrorings: Resource$Packetmirrorings;
        projects: Resource$Projects;
        publicAdvertisedPrefixes: Resource$Publicadvertisedprefixes;
        publicDelegatedPrefixes: Resource$Publicdelegatedprefixes;
        regionAutoscalers: Resource$Regionautoscalers;
        regionBackendServices: Resource$Regionbackendservices;
        regionCommitments: Resource$Regioncommitments;
        regionDisks: Resource$Regiondisks;
        regionDiskSettings: Resource$Regiondisksettings;
        regionDiskTypes: Resource$Regiondisktypes;
        regionHealthChecks: Resource$Regionhealthchecks;
        regionHealthCheckServices: Resource$Regionhealthcheckservices;
        regionInstanceGroupManagers: Resource$Regioninstancegroupmanagers;
        regionInstanceGroups: Resource$Regioninstancegroups;
        regionInstances: Resource$Regioninstances;
        regionInstanceTemplates: Resource$Regioninstancetemplates;
        regionInstantSnapshots: Resource$Regioninstantsnapshots;
        regionNetworkEndpointGroups: Resource$Regionnetworkendpointgroups;
        regionNetworkFirewallPolicies: Resource$Regionnetworkfirewallpolicies;
        regionNotificationEndpoints: Resource$Regionnotificationendpoints;
        regionOperations: Resource$Regionoperations;
        regions: Resource$Regions;
        regionSecurityPolicies: Resource$Regionsecuritypolicies;
        regionSnapshots: Resource$Regionsnapshots;
        regionSslCertificates: Resource$Regionsslcertificates;
        regionSslPolicies: Resource$Regionsslpolicies;
        regionTargetHttpProxies: Resource$Regiontargethttpproxies;
        regionTargetHttpsProxies: Resource$Regiontargethttpsproxies;
        regionTargetTcpProxies: Resource$Regiontargettcpproxies;
        regionUrlMaps: Resource$Regionurlmaps;
        regionZones: Resource$Regionzones;
        reservations: Resource$Reservations;
        resourcePolicies: Resource$Resourcepolicies;
        routers: Resource$Routers;
        routes: Resource$Routes;
        securityPolicies: Resource$Securitypolicies;
        serviceAttachments: Resource$Serviceattachments;
        snapshots: Resource$Snapshots;
        snapshotSettings: Resource$Snapshotsettings;
        sslCertificates: Resource$Sslcertificates;
        sslPolicies: Resource$Sslpolicies;
        storagePools: Resource$Storagepools;
        storagePoolTypes: Resource$Storagepooltypes;
        subnetworks: Resource$Subnetworks;
        targetGrpcProxies: Resource$Targetgrpcproxies;
        targetHttpProxies: Resource$Targethttpproxies;
        targetHttpsProxies: Resource$Targethttpsproxies;
        targetInstances: Resource$Targetinstances;
        targetPools: Resource$Targetpools;
        targetSslProxies: Resource$Targetsslproxies;
        targetTcpProxies: Resource$Targettcpproxies;
        targetVpnGateways: Resource$Targetvpngateways;
        urlMaps: Resource$Urlmaps;
        vpnGateways: Resource$Vpngateways;
        vpnTunnels: Resource$Vpntunnels;
        zoneOperations: Resource$Zoneoperations;
        zoneQueuedResources: Resource$Zonequeuedresources;
        zones: Resource$Zones;
        constructor(options: GlobalOptions, google?: GoogleConfigurable);
    }
    /**
     * A specification of the type and number of accelerator cards attached to the instance.
     */
    export interface Schema$AcceleratorConfig {
        /**
         * The number of the guest accelerator cards exposed to this instance.
         */
        acceleratorCount?: number | null;
        /**
         * Full or partial URL of the accelerator type resource to attach to this instance. For example: projects/my-project/zones/us-central1-c/acceleratorTypes/nvidia-tesla-p100 If you are creating an instance template, specify only the accelerator name. See GPUs on Compute Engine for a full list of accelerator types.
         */
        acceleratorType?: string | null;
    }
    /**
     * Represents an Accelerator Type resource. Google Cloud Platform provides graphics processing units (accelerators) that you can add to VM instances to improve or accelerate performance when working with intensive workloads. For more information, read GPUs on Compute Engine.
     */
    export interface Schema$AcceleratorType {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * [Output Only] The deprecation status associated with this accelerator type.
         */
        deprecated?: Schema$DeprecationStatus;
        /**
         * [Output Only] An optional textual description of the resource.
         */
        description?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] The type of the resource. Always compute#acceleratorType for accelerator types.
         */
        kind?: string | null;
        /**
         * [Output Only] Maximum number of accelerator cards allowed per instance.
         */
        maximumCardsPerInstance?: number | null;
        /**
         * [Output Only] Name of the resource.
         */
        name?: string | null;
        /**
         * [Output Only] Server-defined, fully qualified URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource's resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * [Output Only] The name of the zone where the accelerator type resides, such as us-central1-a. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
         */
        zone?: string | null;
    }
    export interface Schema$AcceleratorTypeAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of AcceleratorTypesScopedList resources.
         */
        items?: {
            [key: string]: Schema$AcceleratorTypesScopedList;
        } | null;
        /**
         * [Output Only] Type of resource. Always compute#acceleratorTypeAggregatedList for aggregated lists of accelerator types.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Contains a list of accelerator types.
     */
    export interface Schema$AcceleratorTypeList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of AcceleratorType resources.
         */
        items?: Schema$AcceleratorType[];
        /**
         * [Output Only] Type of resource. Always compute#acceleratorTypeList for lists of accelerator types.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$AcceleratorTypesScopedList {
        /**
         * [Output Only] A list of accelerator types contained in this scope.
         */
        acceleratorTypes?: Schema$AcceleratorType[];
        /**
         * [Output Only] An informational warning that appears when the accelerator types list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * An access configuration attached to an instance's network interface. Only one access config per instance is supported.
     */
    export interface Schema$AccessConfig {
        /**
         * Applies to ipv6AccessConfigs only. The first IPv6 address of the external IPv6 range associated with this instance, prefix length is stored in externalIpv6PrefixLength in ipv6AccessConfig. To use a static external IP address, it must be unused and in the same region as the instance's zone. If not specified, Google Cloud will automatically assign an external IPv6 address from the instance's subnetwork.
         */
        externalIpv6?: string | null;
        /**
         * Applies to ipv6AccessConfigs only. The prefix length of the external IPv6 range.
         */
        externalIpv6PrefixLength?: number | null;
        /**
         * [Output Only] Type of the resource. Always compute#accessConfig for access configs.
         */
        kind?: string | null;
        /**
         * The name of this access configuration. In accessConfigs (IPv4), the default and recommended name is External NAT, but you can use any arbitrary string, such as My external IP or Network Access. In ipv6AccessConfigs, the recommend name is External IPv6.
         */
        name?: string | null;
        /**
         * Applies to accessConfigs (IPv4) only. An external IP address associated with this instance. Specify an unused static external IP address available to the project or leave this field undefined to use an IP from a shared ephemeral IP address pool. If you specify a static external IP address, it must live in the same region as the zone of the instance.
         */
        natIP?: string | null;
        /**
         * This signifies the networking tier used for configuring this access configuration and can only take the following values: PREMIUM, STANDARD. If an AccessConfig is specified without a valid external IP address, an ephemeral IP will be created with this networkTier. If an AccessConfig with a valid external IP address is specified, it must match that of the networkTier associated with the Address resource owning that IP.
         */
        networkTier?: string | null;
        /**
         * [Output Only] The public DNS domain name for the instance.
         */
        publicDnsName?: string | null;
        /**
         * The DNS domain name for the public PTR record. You can set this field only if the `setPublicPtr` field is enabled in accessConfig. If this field is unspecified in ipv6AccessConfig, a default PTR record will be createc for first IP in associated external IPv6 range.
         */
        publicPtrDomainName?: string | null;
        /**
         * [Output Only] The resource URL for the security policy associated with this access config.
         */
        securityPolicy?: string | null;
        /**
         * Specifies whether a public DNS 'A' record should be created for the external IP address of this access configuration.
         */
        setPublicDns?: boolean | null;
        /**
         * Specifies whether a public DNS 'PTR' record should be created to map the external IP address of the instance to a DNS domain name. This field is not used in ipv6AccessConfig. A default PTR record will be created if the VM has external IPv6 range associated.
         */
        setPublicPtr?: boolean | null;
        /**
         * The type of configuration. In accessConfigs (IPv4), the default and only option is ONE_TO_ONE_NAT. In ipv6AccessConfigs, the default and only option is DIRECT_IPV6.
         */
        type?: string | null;
    }
    /**
     * Represents an IP Address resource. Google Compute Engine has two IP Address resources: * [Global (external and internal)](https://cloud.google.com/compute/docs/reference/rest/alpha/globalAddresses) * [Regional (external and internal)](https://cloud.google.com/compute/docs/reference/rest/alpha/addresses) For more information, see Reserving a static external IP address.
     */
    export interface Schema$Address {
        /**
         * The static IP address represented by this resource.
         */
        address?: string | null;
        /**
         * The type of address to reserve, either INTERNAL or EXTERNAL. If unspecified, defaults to EXTERNAL.
         */
        addressType?: string | null;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this field when you create the resource.
         */
        description?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * The endpoint type of this address, which should be VM or NETLB. This is used for deciding which type of endpoint this address can be used after the external IPv6 address reservation.
         */
        ipv6EndpointType?: string | null;
        /**
         * The IP version that will be used by this address. Valid options are IPV4 or IPV6.
         */
        ipVersion?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#address for addresses.
         */
        kind?: string | null;
        /**
         * A fingerprint for the labels being applied to this Address, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve an Address.
         */
        labelFingerprint?: string | null;
        /**
         * Labels for this resource. These can only be added or modified by the setLabels method. Each label key/value pair must comply with RFC1035. Label values may be empty.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?`. The first character must be a lowercase letter, and all following characters (except for the last character) must be a dash, lowercase letter, or digit. The last character must be a lowercase letter or digit.
         */
        name?: string | null;
        /**
         * The URL of the network in which to reserve the address. This field can only be used with INTERNAL type with the VPC_PEERING purpose.
         */
        network?: string | null;
        /**
         * This signifies the networking tier used for configuring this address and can only take the following values: PREMIUM or STANDARD. Internal IP addresses are always Premium Tier; global external IP addresses are always Premium Tier; regional external IP addresses can be either Standard or Premium Tier. If this field is not specified, it is assumed to be PREMIUM.
         */
        networkTier?: string | null;
        /**
         * The prefix length if the resource represents an IP range.
         */
        prefixLength?: number | null;
        /**
         * The purpose of this resource, which can be one of the following values: - GCE_ENDPOINT for addresses that are used by VM instances, alias IP ranges, load balancers, and similar resources. - DNS_RESOLVER for a DNS resolver address in a subnetwork for a Cloud DNS inbound forwarder IP addresses (regional internal IP address in a subnet of a VPC network) - VPC_PEERING for global internal IP addresses used for private services access allocated ranges. - NAT_AUTO for the regional external IP addresses used by Cloud NAT when allocating addresses using automatic NAT IP address allocation. - IPSEC_INTERCONNECT for addresses created from a private IP range that are reserved for a VLAN attachment in an *HA VPN over Cloud Interconnect* configuration. These addresses are regional resources. - `SHARED_LOADBALANCER_VIP` for an internal IP address that is assigned to multiple internal forwarding rules. - `PRIVATE_SERVICE_CONNECT` for a private network address that is used to configure Private Service Connect. Only global internal addresses can use this purpose.
         */
        purpose?: string | null;
        /**
         * [Output Only] The URL of the region where a regional address resides. For regional addresses, you must specify the region as a path parameter in the HTTP request URL. *This field is not applicable to global addresses.*
         */
        region?: string | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * [Output Only] The status of the address, which can be one of RESERVING, RESERVED, or IN_USE. An address that is RESERVING is currently in the process of being reserved. A RESERVED address is currently reserved and available to use. An IN_USE address is currently being used by another resource and is not available.
         */
        status?: string | null;
        /**
         * The URL of the subnetwork in which to reserve the address. If an IP address is specified, it must be within the subnetwork's IP range. This field can only be used with INTERNAL type with a GCE_ENDPOINT or DNS_RESOLVER purpose.
         */
        subnetwork?: string | null;
        /**
         * [Output Only] The URLs of the resources that are using this address.
         */
        users?: string[] | null;
    }
    export interface Schema$AddressAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of AddressesScopedList resources.
         */
        items?: {
            [key: string]: Schema$AddressesScopedList;
        } | null;
        /**
         * [Output Only] Type of resource. Always compute#addressAggregatedList for aggregated lists of addresses.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$AddressesScopedList {
        /**
         * [Output Only] A list of addresses contained in this scope.
         */
        addresses?: Schema$Address[];
        /**
         * [Output Only] Informational warning which replaces the list of addresses when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Contains a list of addresses.
     */
    export interface Schema$AddressList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of Address resources.
         */
        items?: Schema$Address[];
        /**
         * [Output Only] Type of resource. Always compute#addressList for lists of addresses.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Specifies options for controlling advanced machine features. Options that would traditionally be configured in a BIOS belong here. Features that require operating system support may have corresponding entries in the GuestOsFeatures of an Image (e.g., whether or not the OS in the Image supports nested virtualization being enabled or disabled).
     */
    export interface Schema$AdvancedMachineFeatures {
        /**
         * Whether to enable nested virtualization or not (default is false).
         */
        enableNestedVirtualization?: boolean | null;
        /**
         * Whether to enable UEFI networking for instance creation.
         */
        enableUefiNetworking?: boolean | null;
        /**
         * The number of vNUMA nodes.
         */
        numaNodeCount?: number | null;
        /**
         * Type of Performance Monitoring Unit requested on instance.
         */
        performanceMonitoringUnit?: string | null;
        /**
         * The number of threads per physical core. To disable simultaneous multithreading (SMT) set this to 1. If unset, the maximum number of threads supported per core by the underlying processor is assumed.
         */
        threadsPerCore?: number | null;
        /**
         * The number of physical cores to expose to an instance. Multiply by the number of threads per core to compute the total number of virtual CPUs to expose to the instance. If unset, the number of cores is inferred from the instance's nominal CPU count and the underlying platform's SMT width.
         */
        visibleCoreCount?: number | null;
    }
    /**
     * An alias IP range attached to an instance's network interface.
     */
    export interface Schema$AliasIpRange {
        /**
         * The IP alias ranges to allocate for this interface. This IP CIDR range must belong to the specified subnetwork and cannot contain IP addresses reserved by system or used by other network interfaces. This range may be a single IP address (such as 10.2.3.4), a netmask (such as /24) or a CIDR-formatted string (such as 10.1.2.0/24).
         */
        ipCidrRange?: string | null;
        /**
         * The name of a subnetwork secondary IP range from which to allocate an IP alias range. If not specified, the primary range of the subnetwork is used.
         */
        subnetworkRangeName?: string | null;
    }
    /**
     * This reservation type is specified by total resource amounts (e.g. total count of CPUs) and can account for multiple instance SKUs. In other words, one can create instances of varying shapes against this reservation.
     */
    export interface Schema$AllocationAggregateReservation {
        /**
         * [Output only] List of resources currently in use.
         */
        inUseResources?: Schema$AllocationAggregateReservationReservedResourceInfo[];
        /**
         * List of reserved resources (CPUs, memory, accelerators).
         */
        reservedResources?: Schema$AllocationAggregateReservationReservedResourceInfo[];
        /**
         * The VM family that all instances scheduled against this reservation must belong to.
         */
        vmFamily?: string | null;
        /**
         * The workload type of the instances that will target this reservation.
         */
        workloadType?: string | null;
    }
    export interface Schema$AllocationAggregateReservationReservedResourceInfo {
        /**
         * Properties of accelerator resources in this reservation.
         */
        accelerator?: Schema$AllocationAggregateReservationReservedResourceInfoAccelerator;
    }
    export interface Schema$AllocationAggregateReservationReservedResourceInfoAccelerator {
        /**
         * Number of accelerators of specified type.
         */
        acceleratorCount?: number | null;
        /**
         * Full or partial URL to accelerator type. e.g. "projects/{PROJECT\}/zones/{ZONE\}/acceleratorTypes/ct4l"
         */
        acceleratorType?: string | null;
    }
    /**
     * [Output Only] Contains output only fields.
     */
    export interface Schema$AllocationResourceStatus {
        /**
         * Allocation Properties of this reservation.
         */
        specificSkuAllocation?: Schema$AllocationResourceStatusSpecificSKUAllocation;
    }
    /**
     * Contains Properties set for the reservation.
     */
    export interface Schema$AllocationResourceStatusSpecificSKUAllocation {
        /**
         * ID of the instance template used to populate reservation properties.
         */
        sourceInstanceTemplateId?: string | null;
    }
    export interface Schema$AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk {
        /**
         * Specifies the size of the disk in base-2 GB.
         */
        diskSizeGb?: string | null;
        /**
         * Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME. The default is SCSI. For performance characteristics of SCSI over NVMe, see Local SSD performance.
         */
        interface?: string | null;
    }
    /**
     * Properties of the SKU instances being reserved. Next ID: 9
     */
    export interface Schema$AllocationSpecificSKUAllocationReservedInstanceProperties {
        /**
         * Specifies accelerator type and count.
         */
        guestAccelerators?: Schema$AcceleratorConfig[];
        /**
         * Specifies amount of local ssd to reserve with each instance. The type of disk is local-ssd.
         */
        localSsds?: Schema$AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk[];
        /**
         * An opaque location hint used to place the allocation close to other resources. This field is for use by internal tools that use the public API.
         */
        locationHint?: string | null;
        /**
         * Specifies type of machine (name only) which has fixed number of vCPUs and fixed amount of memory. This also includes specifying custom machine type following custom-NUMBER_OF_CPUS-AMOUNT_OF_MEMORY pattern.
         */
        machineType?: string | null;
        /**
         * Specifies the number of hours after reservation creation where instances using the reservation won't be scheduled for maintenance.
         */
        maintenanceFreezeDurationHours?: number | null;
        /**
         * Specifies the frequency of planned maintenance events. The accepted values are: `PERIODIC`.
         */
        maintenanceInterval?: string | null;
        /**
         * Minimum cpu platform the reservation.
         */
        minCpuPlatform?: string | null;
    }
    /**
     * This reservation type allows to pre allocate specific instance configuration. Next ID: 6
     */
    export interface Schema$AllocationSpecificSKUReservation {
        /**
         * [Output Only] Indicates how many instances are actually usable currently.
         */
        assuredCount?: string | null;
        /**
         * Specifies the number of resources that are allocated.
         */
        count?: string | null;
        /**
         * The instance properties for the reservation.
         */
        instanceProperties?: Schema$AllocationSpecificSKUAllocationReservedInstanceProperties;
        /**
         * [Output Only] Indicates how many instances are in use.
         */
        inUseCount?: string | null;
        /**
         * Specifies the instance template to create the reservation. If you use this field, you must exclude the instanceProperties field. This field is optional, and it can be a full or partial URL. For example, the following are all valid URLs to an instance template: - https://www.googleapis.com/compute/v1/projects/project /global/instanceTemplates/instanceTemplate - projects/project/global/instanceTemplates/instanceTemplate - global/instanceTemplates/instanceTemplate
         */
        sourceInstanceTemplate?: string | null;
    }
    /**
     * An instance-attached disk resource.
     */
    export interface Schema$AttachedDisk {
        /**
         * [Output Only] The architecture of the attached disk. Valid values are ARM64 or X86_64.
         */
        architecture?: string | null;
        /**
         * Specifies whether the disk will be auto-deleted when the instance is deleted (but not when the disk is detached from the instance).
         */
        autoDelete?: boolean | null;
        /**
         * Indicates that this is a boot disk. The virtual machine will use the first partition of the disk for its root filesystem.
         */
        boot?: boolean | null;
        /**
         * Specifies a unique device name of your choice that is reflected into the /dev/disk/by-id/google-* tree of a Linux operating system running within the instance. This name can be used to reference the device for mounting, resizing, and so on, from within the instance. If not specified, the server chooses a default device name to apply to this disk, in the form persistent-disk-x, where x is a number assigned by Google Compute Engine. This field is only applicable for persistent disks.
         */
        deviceName?: string | null;
        /**
         * Encrypts or decrypts a disk using a customer-supplied encryption key. If you are creating a new disk, this field encrypts the new disk using an encryption key that you provide. If you are attaching an existing disk that is already encrypted, this field decrypts the disk using the customer-supplied encryption key. If you encrypt a disk using a customer-supplied key, you must provide the same key again when you attempt to use this resource at a later time. For example, you must provide the key when you create a snapshot or an image from the disk or when you attach the disk to a virtual machine instance. If you do not provide an encryption key, then the disk will be encrypted using an automatically generated key and you do not need to provide a key to use the disk later. Instance templates do not store customer-supplied encryption keys, so you cannot use your own keys to encrypt disks in a managed instance group.
         */
        diskEncryptionKey?: Schema$CustomerEncryptionKey;
        /**
         * The size of the disk in GB.
         */
        diskSizeGb?: string | null;
        /**
         * [Input Only] Whether to force attach the regional disk even if it's currently attached to another instance. If you try to force attach a zonal disk to an instance, you will receive an error.
         */
        forceAttach?: boolean | null;
        /**
         * A list of features to enable on the guest operating system. Applicable only for bootable images. Read Enabling guest operating system features to see a list of available options.
         */
        guestOsFeatures?: Schema$GuestOsFeature[];
        /**
         * [Output Only] A zero-based index to this disk, where 0 is reserved for the boot disk. If you have many disks attached to an instance, each disk would have a unique index number.
         */
        index?: number | null;
        /**
         * [Input Only] Specifies the parameters for a new disk that will be created alongside the new instance. Use initialization parameters to create boot disks or local SSDs attached to the new instance. This property is mutually exclusive with the source property; you can only define one or the other, but not both.
         */
        initializeParams?: Schema$AttachedDiskInitializeParams;
        /**
         * Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME. For most machine types, the default is SCSI. Local SSDs can use either NVME or SCSI. In certain configurations, persistent disks can use NVMe. For more information, see About persistent disks.
         */
        interface?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#attachedDisk for attached disks.
         */
        kind?: string | null;
        /**
         * [Output Only] Any valid publicly visible licenses.
         */
        licenses?: string[] | null;
        /**
         * [Output Only] Whether to indicate the attached disk is locked. The locked disk is not allowed to be detached from the instance, or to be used as the source of the snapshot creation, and the image creation. The instance with at least one locked attached disk is not allow to be used as source of machine image creation, instant snapshot creation, and not allowed to be deleted with --keep-disk parameter set to true for locked disks.
         */
        locked?: boolean | null;
        /**
         * The mode in which to attach this disk, either READ_WRITE or READ_ONLY. If not specified, the default is to attach the disk in READ_WRITE mode.
         */
        mode?: string | null;
        /**
         * For LocalSSD disks on VM Instances in STOPPED or SUSPENDED state, this field is set to PRESERVED if the LocalSSD data has been saved to a persistent location by customer request. (see the discard_local_ssd option on Stop/Suspend). Read-only in the api.
         */
        savedState?: string | null;
        /**
         * [Output Only] shielded vm initial state stored on disk
         */
        shieldedInstanceInitialState?: Schema$InitialStateConfig;
        /**
         * Specifies a valid partial or full URL to an existing Persistent Disk resource. When creating a new instance, one of initializeParams.sourceImage or initializeParams.sourceSnapshot or disks.source is required except for local SSD. If desired, you can also attach existing non-root persistent disks using this property. This field is only applicable for persistent disks. Note that for InstanceTemplate, specify the disk name for zonal disk, and the URL for regional disk.
         */
        source?: string | null;
        /**
         * Specifies the type of the disk, either SCRATCH or PERSISTENT. If not specified, the default is PERSISTENT.
         */
        type?: string | null;
        /**
         * [Output Only] A list of user provided licenses. It represents a list of URLs to the license resource. Unlike regular licenses, user provided licenses can be modified after the disk is created.
         */
        userLicenses?: string[] | null;
    }
    /**
     * [Input Only] Specifies the parameters for a new disk that will be created alongside the new instance. Use initialization parameters to create boot disks or local SSDs attached to the new instance. This field is persisted and returned for instanceTemplate and not returned in the context of instance. This property is mutually exclusive with the source property; you can only define one or the other, but not both.
     */
    export interface Schema$AttachedDiskInitializeParams {
        /**
         * The architecture of the attached disk. Valid values are arm64 or x86_64.
         */
        architecture?: string | null;
        /**
         * An optional description. Provide this property when creating the disk.
         */
        description?: string | null;
        /**
         * Specifies the disk name. If not specified, the default is to use the name of the instance. If a disk with the same name already exists in the given region, the existing disk is attached to the new instance and the new disk is not created.
         */
        diskName?: string | null;
        /**
         * Specifies the size of the disk in base-2 GB. The size must be at least 10 GB. If you specify a sourceImage, which is required for boot disks, the default size is the size of the sourceImage. If you do not specify a sourceImage, the default disk size is 500 GB.
         */
        diskSizeGb?: string | null;
        /**
         * Specifies the disk type to use to create the instance. If not specified, the default is pd-standard, specified using the full URL. For example: https://www.googleapis.com/compute/v1/projects/project/zones/zone /diskTypes/pd-standard For a full list of acceptable values, see Persistent disk types. If you specify this field when creating a VM, you can provide either the full or partial URL. For example, the following values are valid: - https://www.googleapis.com/compute/v1/projects/project/zones/zone /diskTypes/diskType - projects/project/zones/zone/diskTypes/diskType - zones/zone/diskTypes/diskType If you specify this field when creating or updating an instance template or all-instances configuration, specify the type of the disk, not the URL. For example: pd-standard.
         */
        diskType?: string | null;
        /**
         * Whether this disk is using confidential compute mode.
         */
        enableConfidentialCompute?: boolean | null;
        /**
         * A list of features to enable on the guest operating system. Applicable only for bootable images. Read Enabling guest operating system features to see a list of available options. Guest OS features are applied by merging initializeParams.guestOsFeatures and disks.guestOsFeatures
         */
        guestOsFeatures?: Schema$GuestOsFeature[];
        /**
         * [Deprecated] Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME. The default is SCSI.
         */
        interface?: string | null;
        /**
         * Labels to apply to this disk. These can be later modified by the disks.setLabels method. This field is only applicable for persistent disks.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * Integer license codes indicating which licenses are attached to this disk.
         */
        licenseCodes?: string[] | null;
        /**
         * A list of publicly visible licenses. Reserved for Google's use.
         */
        licenses?: string[] | null;
        /**
         * Indicates whether or not the disk can be read/write attached to more than one instance.
         */
        multiWriter?: boolean | null;
        /**
         * Specifies which action to take on instance update with this disk. Default is to use the existing disk.
         */
        onUpdateAction?: string | null;
        /**
         * Indicates how many IOPS to provision for the disk. This sets the number of I/O operations per second that the disk can handle. Values must be between 10,000 and 120,000. For more details, see the Extreme persistent disk documentation.
         */
        provisionedIops?: string | null;
        /**
         * Indicates how much throughput to provision for the disk. This sets the number of throughput mb per second that the disk can handle. Values must be between 1 and 7,124.
         */
        provisionedThroughput?: string | null;
        /**
         * Required for each regional disk associated with the instance. Specify the URLs of the zones where the disk should be replicated to. You must provide exactly two replica zones, and one zone must be the same as the instance zone.
         */
        replicaZones?: string[] | null;
        /**
         * Resource manager tags to be bound to the disk. Tag keys and values have the same definition as resource manager tags. Keys must be in the format `tagKeys/{tag_key_id\}`, and values are in the format `tagValues/456`. The field is ignored (both PUT & PATCH) when empty.
         */
        resourceManagerTags?: {
            [key: string]: string;
        } | null;
        /**
         * Resource policies applied to this disk for automatic snapshot creations. Specified using the full or partial URL. For instance template, specify only the resource policy name.
         */
        resourcePolicies?: string[] | null;
        /**
         * The source image to create this disk. When creating a new instance, one of initializeParams.sourceImage or initializeParams.sourceSnapshot or disks.source is required except for local SSD. To create a disk with one of the public operating system images, specify the image by its family name. For example, specify family/debian-9 to use the latest Debian 9 image: projects/debian-cloud/global/images/family/debian-9 Alternatively, use a specific version of a public operating system image: projects/debian-cloud/global/images/debian-9-stretch-vYYYYMMDD To create a disk with a custom image that you created, specify the image name in the following format: global/images/my-custom-image You can also specify a custom image by its image family, which returns the latest version of the image in that family. Replace the image name with family/family-name: global/images/family/my-image-family If the source image is deleted later, this field will not be set.
         */
        sourceImage?: string | null;
        /**
         * The customer-supplied encryption key of the source image. Required if the source image is protected by a customer-supplied encryption key. InstanceTemplate and InstancePropertiesPatch do not store customer-supplied encryption keys, so you cannot create disks for instances in a managed instance group if the source images are encrypted with your own keys.
         */
        sourceImageEncryptionKey?: Schema$CustomerEncryptionKey;
        /**
         * The source instant-snapshot to create this disk. When creating a new instance, one of initializeParams.sourceSnapshot or initializeParams.sourceInstantSnapshot initializeParams.sourceImage or disks.source is required except for local SSD. To create a disk with a snapshot that you created, specify the snapshot name in the following format: us-central1-a/instantSnapshots/my-backup If the source instant-snapshot is deleted later, this field will not be set.
         */
        sourceInstantSnapshot?: string | null;
        /**
         * The source snapshot to create this disk. When creating a new instance, one of initializeParams.sourceSnapshot or initializeParams.sourceImage or disks.source is required except for local SSD. To create a disk with a snapshot that you created, specify the snapshot name in the following format: global/snapshots/my-backup If the source snapshot is deleted later, this field will not be set.
         */
        sourceSnapshot?: string | null;
        /**
         * The customer-supplied encryption key of the source snapshot.
         */
        sourceSnapshotEncryptionKey?: Schema$CustomerEncryptionKey;
        /**
         * The storage pool in which the new disk is created. You can provide this as a partial or full URL to the resource. For example, the following are valid values: - https://www.googleapis.com/compute/v1/projects/project/zones/zone /storagePools/storagePool - projects/project/zones/zone/storagePools/storagePool - zones/zone/storagePools/storagePool
         */
        storagePool?: string | null;
    }
    /**
     * Specifies the audit configuration for a service. The configuration determines which permission types are logged, and what identities, if any, are exempted from logging. An AuditConfig must have one or more AuditLogConfigs. If there are AuditConfigs for both `allServices` and a specific service, the union of the two AuditConfigs is used for that service: the log_types specified in each AuditConfig are enabled, and the exempted_members in each AuditLogConfig are exempted. Example Policy with multiple AuditConfigs: { "audit_configs": [ { "service": "allServices", "audit_log_configs": [ { "log_type": "DATA_READ", "exempted_members": [ "user:jose@example.com" ] \}, { "log_type": "DATA_WRITE" \}, { "log_type": "ADMIN_READ" \} ] \}, { "service": "sampleservice.googleapis.com", "audit_log_configs": [ { "log_type": "DATA_READ" \}, { "log_type": "DATA_WRITE", "exempted_members": [ "user:aliya@example.com" ] \} ] \} ] \} For sampleservice, this policy enables DATA_READ, DATA_WRITE and ADMIN_READ logging. It also exempts jose@example.com from DATA_READ logging, and aliya@example.com from DATA_WRITE logging.
     */
    export interface Schema$AuditConfig {
        /**
         * The configuration for logging of each type of permission.
         */
        auditLogConfigs?: Schema$AuditLogConfig[];
        /**
         * This is deprecated and has no effect. Do not use.
         */
        exemptedMembers?: string[] | null;
        /**
         * Specifies a service that will be enabled for audit logging. For example, `storage.googleapis.com`, `cloudsql.googleapis.com`. `allServices` is a special value that covers all services.
         */
        service?: string | null;
    }
    /**
     * Provides the configuration for logging a type of permissions. Example: { "audit_log_configs": [ { "log_type": "DATA_READ", "exempted_members": [ "user:jose@example.com" ] \}, { "log_type": "DATA_WRITE" \} ] \} This enables 'DATA_READ' and 'DATA_WRITE' logging, while exempting jose@example.com from DATA_READ logging.
     */
    export interface Schema$AuditLogConfig {
        /**
         * Specifies the identities that do not cause logging for this type of permission. Follows the same format of Binding.members.
         */
        exemptedMembers?: string[] | null;
        /**
         * This is deprecated and has no effect. Do not use.
         */
        ignoreChildExemptions?: boolean | null;
        /**
         * The log type that this config enables.
         */
        logType?: string | null;
    }
    /**
     * [Deprecated] The authentication settings for the backend service. The authentication settings for the backend service.
     */
    export interface Schema$AuthenticationPolicy {
        /**
         * List of authentication methods that can be used for origin authentication. Similar to peers, these will be evaluated in order the first valid one will be used to set origin identity. If none of these methods pass, the request will be rejected with authentication failed error (401). Leave the list empty if origin authentication is not required.
         */
        origins?: Schema$OriginAuthenticationMethod[];
        /**
         * List of authentication methods that can be used for peer authentication. They will be evaluated in order the first valid one will be used to set peer identity. If none of these methods pass, the request will be rejected with authentication failed error (401). Leave the list empty if peer authentication is not required.
         */
        peers?: Schema$PeerAuthenticationMethod[];
        /**
         * Define whether peer or origin identity should be used for principal. Default value is USE_PEER. If peer (or origin) identity is not available, either because peer/origin authentication is not defined, or failed, principal will be left unset. In other words, binding rule does not affect the decision to accept or reject request. This field can be set to one of the following: USE_PEER: Principal will be set to the identity from peer authentication. USE_ORIGIN: Principal will be set to the identity from origin authentication.
         */
        principalBinding?: string | null;
        /**
         * Configures the mechanism to obtain server-side security certificates and identity information.
         */
        serverTlsContext?: Schema$TlsContext;
    }
    /**
     * [Deprecated] Authorization configuration provides service-level and method-level access control for a service. control for a service.
     */
    export interface Schema$AuthorizationConfig {
        /**
         * List of RbacPolicies.
         */
        policies?: Schema$RbacPolicy[];
    }
    /**
     * This is deprecated and has no effect. Do not use.
     */
    export interface Schema$AuthorizationLoggingOptions {
        /**
         * This is deprecated and has no effect. Do not use.
         */
        permissionType?: string | null;
    }
    /**
     * Represents an Autoscaler resource. Google Compute Engine has two Autoscaler resources: * [Zonal](/compute/docs/reference/rest/alpha/autoscalers) * [Regional](/compute/docs/reference/rest/alpha/regionAutoscalers) Use autoscalers to automatically add or delete instances from a managed instance group according to your defined autoscaling policy. For more information, read Autoscaling Groups of Instances. For zonal managed instance groups resource, use the autoscaler resource. For regional managed instance groups, use the regionAutoscalers resource.
     */
    export interface Schema$Autoscaler {
        /**
         * The configuration parameters for the autoscaling algorithm. You can define one or more signals for an autoscaler: cpuUtilization, customMetricUtilizations, and loadBalancingUtilization. If none of these are specified, the default will be to autoscale based on cpuUtilization to 0.6 or 60%.
         */
        autoscalingPolicy?: Schema$AutoscalingPolicy;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#autoscaler for autoscalers.
         */
        kind?: string | null;
        /**
         * Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * [Output Only] Target recommended MIG size (number of instances) computed by autoscaler. Autoscaler calculates the recommended MIG size even when the autoscaling policy mode is different from ON. This field is empty when autoscaler is not connected to an existing managed instance group or autoscaler did not generate its prediction.
         */
        recommendedSize?: number | null;
        /**
         * [Output Only] URL of the region where the instance group resides (for autoscalers living in regional scope).
         */
        region?: string | null;
        /**
         * [Output Only] Status information of existing scaling schedules.
         */
        scalingScheduleStatus?: {
            [key: string]: Schema$ScalingScheduleStatus;
        } | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * [Output Only] The status of the autoscaler configuration. Current set of possible values: - PENDING: Autoscaler backend hasn't read new/updated configuration. - DELETING: Configuration is being deleted. - ACTIVE: Configuration is acknowledged to be effective. Some warnings might be present in the statusDetails field. - ERROR: Configuration has errors. Actionable for users. Details are present in the statusDetails field. New values might be added in the future.
         */
        status?: string | null;
        /**
         * [Output Only] Human-readable details about the current state of the autoscaler. Read the documentation for Commonly returned status messages for examples of status messages you might encounter.
         */
        statusDetails?: Schema$AutoscalerStatusDetails[];
        /**
         * URL of the managed instance group that this autoscaler will scale. This field is required when creating an autoscaler.
         */
        target?: string | null;
        /**
         * [Output Only] URL of the zone where the instance group resides (for autoscalers living in zonal scope).
         */
        zone?: string | null;
    }
    export interface Schema$AutoscalerAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of AutoscalersScopedList resources.
         */
        items?: {
            [key: string]: Schema$AutoscalersScopedList;
        } | null;
        /**
         * [Output Only] Type of resource. Always compute#autoscalerAggregatedList for aggregated lists of autoscalers.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Contains a list of Autoscaler resources.
     */
    export interface Schema$AutoscalerList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of Autoscaler resources.
         */
        items?: Schema$Autoscaler[];
        /**
         * [Output Only] Type of resource. Always compute#autoscalerList for lists of autoscalers.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$AutoscalersScopedList {
        /**
         * [Output Only] A list of autoscalers contained in this scope.
         */
        autoscalers?: Schema$Autoscaler[];
        /**
         * [Output Only] Informational warning which replaces the list of autoscalers when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$AutoscalerStatusDetails {
        /**
         * The status message.
         */
        message?: string | null;
        /**
         * The type of error, warning, or notice returned. Current set of possible values: - ALL_INSTANCES_UNHEALTHY (WARNING): All instances in the instance group are unhealthy (not in RUNNING state). - BACKEND_SERVICE_DOES_NOT_EXIST (ERROR): There is no backend service attached to the instance group. - CAPPED_AT_MAX_NUM_REPLICAS (WARNING): Autoscaler recommends a size greater than maxNumReplicas. - CUSTOM_METRIC_DATA_POINTS_TOO_SPARSE (WARNING): The custom metric samples are not exported often enough to be a credible base for autoscaling. - CUSTOM_METRIC_INVALID (ERROR): The custom metric that was specified does not exist or does not have the necessary labels. - MIN_EQUALS_MAX (WARNING): The minNumReplicas is equal to maxNumReplicas. This means the autoscaler cannot add or remove instances from the instance group. - MISSING_CUSTOM_METRIC_DATA_POINTS (WARNING): The autoscaler did not receive any data from the custom metric configured for autoscaling. - MISSING_LOAD_BALANCING_DATA_POINTS (WARNING): The autoscaler is configured to scale based on a load balancing signal but the instance group has not received any requests from the load balancer. - MODE_OFF (WARNING): Autoscaling is turned off. The number of instances in the group won't change automatically. The autoscaling configuration is preserved. - MODE_ONLY_UP (WARNING): Autoscaling is in the "Autoscale only out" mode. The autoscaler can add instances but not remove any. - MORE_THAN_ONE_BACKEND_SERVICE (ERROR): The instance group cannot be autoscaled because it has more than one backend service attached to it. - NOT_ENOUGH_QUOTA_AVAILABLE (ERROR): There is insufficient quota for the necessary resources, such as CPU or number of instances. - REGION_RESOURCE_STOCKOUT (ERROR): Shown only for regional autoscalers: there is a resource stockout in the chosen region. - SCALING_TARGET_DOES_NOT_EXIST (ERROR): The target to be scaled does not exist. - UNSUPPORTED_MAX_RATE_LOAD_BALANCING_CONFIGURATION (ERROR): Autoscaling does not work with an HTTP/S load balancer that has been configured for maxRate. - ZONE_RESOURCE_STOCKOUT (ERROR): For zonal autoscalers: there is a resource stockout in the chosen zone. For regional autoscalers: in at least one of the zones you're using there is a resource stockout. New values might be added in the future. Some of the values might not be available in all API versions.
         */
        type?: string | null;
    }
    /**
     * Cloud Autoscaler policy.
     */
    export interface Schema$AutoscalingPolicy {
        /**
         * The number of seconds that your application takes to initialize on a VM instance. This is referred to as the [initialization period](/compute/docs/autoscaler#cool_down_period). Specifying an accurate initialization period improves autoscaler decisions. For example, when scaling out, the autoscaler ignores data from VMs that are still initializing because those VMs might not yet represent normal usage of your application. The default initialization period is 60 seconds. Initialization periods might vary because of numerous factors. We recommend that you test how long your application takes to initialize. To do this, create a VM and time your application's startup process.
         */
        coolDownPeriodSec?: number | null;
        /**
         * Defines the CPU utilization policy that allows the autoscaler to scale based on the average CPU utilization of a managed instance group.
         */
        cpuUtilization?: Schema$AutoscalingPolicyCpuUtilization;
        /**
         * Configuration parameters of autoscaling based on a custom metric.
         */
        customMetricUtilizations?: Schema$AutoscalingPolicyCustomMetricUtilization[];
        /**
         * Configuration parameters of autoscaling based on load balancer.
         */
        loadBalancingUtilization?: Schema$AutoscalingPolicyLoadBalancingUtilization;
        /**
         * The maximum number of instances that the autoscaler can scale out to. This is required when creating or updating an autoscaler. The maximum number of replicas must not be lower than minimal number of replicas.
         */
        maxNumReplicas?: number | null;
        /**
         * The minimum number of replicas that the autoscaler can scale in to. This cannot be less than 0. If not provided, autoscaler chooses a default value depending on maximum number of instances allowed.
         */
        minNumReplicas?: number | null;
        /**
         * Defines the operating mode for this policy. The following modes are available: - OFF: Disables the autoscaler but maintains its configuration. - ONLY_SCALE_OUT: Restricts the autoscaler to add VM instances only. - ON: Enables all autoscaler activities according to its policy. For more information, see "Turning off or restricting an autoscaler"
         */
        mode?: string | null;
        scaleDownControl?: Schema$AutoscalingPolicyScaleDownControl;
        scaleInControl?: Schema$AutoscalingPolicyScaleInControl;
        /**
         * Scaling schedules defined for an autoscaler. Multiple schedules can be set on an autoscaler, and they can overlap. During overlapping periods the greatest min_required_replicas of all scaling schedules is applied. Up to 128 scaling schedules are allowed.
         */
        scalingSchedules?: {
            [key: string]: Schema$AutoscalingPolicyScalingSchedule;
        } | null;
    }
    /**
     * CPU utilization policy.
     */
    export interface Schema$AutoscalingPolicyCpuUtilization {
        /**
         * Indicates whether predictive autoscaling based on CPU metric is enabled. Valid values are: * NONE (default). No predictive method is used. The autoscaler scales the group to meet current demand based on real-time metrics. * OPTIMIZE_AVAILABILITY. Predictive autoscaling improves availability by monitoring daily and weekly load patterns and scaling out ahead of anticipated demand.
         */
        predictiveMethod?: string | null;
        /**
         * The target CPU utilization that the autoscaler maintains. Must be a float value in the range (0, 1]. If not specified, the default is 0.6. If the CPU level is below the target utilization, the autoscaler scales in the number of instances until it reaches the minimum number of instances you specified or until the average CPU of your instances reaches the target utilization. If the average CPU is above the target utilization, the autoscaler scales out until it reaches the maximum number of instances you specified or until the average utilization reaches the target utilization.
         */
        utilizationTarget?: number | null;
    }
    /**
     * Custom utilization metric policy.
     */
    export interface Schema$AutoscalingPolicyCustomMetricUtilization {
        /**
         * A filter string, compatible with a Stackdriver Monitoring filter string for TimeSeries.list API call. This filter is used to select a specific TimeSeries for the purpose of autoscaling and to determine whether the metric is exporting per-instance or per-group data. For the filter to be valid for autoscaling purposes, the following rules apply: - You can only use the AND operator for joining selectors. - You can only use direct equality comparison operator (=) without any functions for each selector. - You can specify the metric in both the filter string and in the metric field. However, if specified in both places, the metric must be identical. - The monitored resource type determines what kind of values are expected for the metric. If it is a gce_instance, the autoscaler expects the metric to include a separate TimeSeries for each instance in a group. In such a case, you cannot filter on resource labels. If the resource type is any other value, the autoscaler expects this metric to contain values that apply to the entire autoscaled instance group and resource label filtering can be performed to point autoscaler at the correct TimeSeries to scale upon. This is called a *per-group metric* for the purpose of autoscaling. If not specified, the type defaults to gce_instance. Try to provide a filter that is selective enough to pick just one TimeSeries for the autoscaled group or for each of the instances (if you are using gce_instance resource type). If multiple TimeSeries are returned upon the query execution, the autoscaler will sum their respective values to obtain its scaling value.
         */
        filter?: string | null;
        /**
         * The identifier (type) of the Stackdriver Monitoring metric. The metric cannot have negative values. The metric must have a value type of INT64 or DOUBLE.
         */
        metric?: string | null;
        /**
         * If scaling is based on a per-group metric value that represents the total amount of work to be done or resource usage, set this value to an amount assigned for a single instance of the scaled group. Autoscaler keeps the number of instances proportional to the value of this metric. The metric itself does not change value due to group resizing. A good metric to use with the target is for example pubsub.googleapis.com/subscription/num_undelivered_messages or a custom metric exporting the total number of requests coming to your instances. A bad example would be a metric exporting an average or median latency, since this value can't include a chunk assignable to a single instance, it could be better used with utilization_target instead.
         */
        singleInstanceAssignment?: number | null;
        /**
         * The target value of the metric that autoscaler maintains. This must be a positive value. A utilization metric scales number of virtual machines handling requests to increase or decrease proportionally to the metric. For example, a good metric to use as a utilization_target is https://www.googleapis.com/compute/v1/instance/network/received_bytes_count. The autoscaler works to keep this value constant for each of the instances.
         */
        utilizationTarget?: number | null;
        /**
         * Defines how target utilization value is expressed for a Stackdriver Monitoring metric. Either GAUGE, DELTA_PER_SECOND, or DELTA_PER_MINUTE.
         */
        utilizationTargetType?: string | null;
    }
    /**
     * Configuration parameters of autoscaling based on load balancing.
     */
    export interface Schema$AutoscalingPolicyLoadBalancingUtilization {
        /**
         * Fraction of backend capacity utilization (set in HTTP(S) load balancing configuration) that the autoscaler maintains. Must be a positive float value. If not defined, the default is 0.8.
         */
        utilizationTarget?: number | null;
    }
    /**
     * Configuration that allows for slower scale in so that even if Autoscaler recommends an abrupt scale in of a MIG, it will be throttled as specified by the parameters below.
     */
    export interface Schema$AutoscalingPolicyScaleDownControl {
        /**
         * Maximum allowed number (or %) of VMs that can be deducted from the peak recommendation during the window autoscaler looks at when computing recommendations. Possibly all these VMs can be deleted at once so user service needs to be prepared to lose that many VMs in one step.
         */
        maxScaledDownReplicas?: Schema$FixedOrPercent;
        /**
         * How far back autoscaling looks when computing recommendations to include directives regarding slower scale in, as described above.
         */
        timeWindowSec?: number | null;
    }
    /**
     * Configuration that allows for slower scale in so that even if Autoscaler recommends an abrupt scale in of a MIG, it will be throttled as specified by the parameters below.
     */
    export interface Schema$AutoscalingPolicyScaleInControl {
        /**
         * Maximum allowed number (or %) of VMs that can be deducted from the peak recommendation during the window autoscaler looks at when computing recommendations. Possibly all these VMs can be deleted at once so user service needs to be prepared to lose that many VMs in one step.
         */
        maxScaledInReplicas?: Schema$FixedOrPercent;
        /**
         * How far back autoscaling looks when computing recommendations to include directives regarding slower scale in, as described above.
         */
        timeWindowSec?: number | null;
    }
    /**
     * Scaling based on user-defined schedule. The message describes a single scaling schedule. A scaling schedule changes the minimum number of VM instances an autoscaler can recommend, which can trigger scaling out.
     */
    export interface Schema$AutoscalingPolicyScalingSchedule {
        /**
         * A description of a scaling schedule.
         */
        description?: string | null;
        /**
         * A boolean value that specifies whether a scaling schedule can influence autoscaler recommendations. If set to true, then a scaling schedule has no effect. This field is optional, and its value is false by default.
         */
        disabled?: boolean | null;
        /**
         * The duration of time intervals, in seconds, for which this scaling schedule is to run. The minimum allowed value is 300. This field is required.
         */
        durationSec?: number | null;
        /**
         * The minimum number of VM instances that the autoscaler will recommend in time intervals starting according to schedule. This field is required.
         */
        minRequiredReplicas?: number | null;
        /**
         * The start timestamps of time intervals when this scaling schedule is to provide a scaling signal. This field uses the extended cron format (with an optional year field). The expression can describe a single timestamp if the optional year is set, in which case the scaling schedule runs once. The schedule is interpreted with respect to time_zone. This field is required. Note: These timestamps only describe when autoscaler starts providing the scaling signal. The VMs need additional time to become serving.
         */
        schedule?: string | null;
        /**
         * The time zone to use when interpreting the schedule. The value of this field must be a time zone name from the tz database: https://en.wikipedia.org/wiki/Tz_database. This field is assigned a default value of "UTC" if left empty.
         */
        timeZone?: string | null;
    }
    /**
     * Contains the configurations necessary to generate a signature for access to private storage buckets that support Signature Version 4 for authentication. The service name for generating the authentication header will always default to 's3'.
     */
    export interface Schema$AWSV4Signature {
        /**
         * The access key used for s3 bucket authentication. Required for updating or creating a backend that uses AWS v4 signature authentication, but will not be returned as part of the configuration when queried with a REST API GET request. @InputOnly
         */
        accessKey?: string | null;
        /**
         * The identifier of an access key used for s3 bucket authentication.
         */
        accessKeyId?: string | null;
        /**
         * The optional version identifier for the access key. You can use this to keep track of different iterations of your access key.
         */
        accessKeyVersion?: string | null;
        /**
         * The name of the cloud region of your origin. This is a free-form field with the name of the region your cloud uses to host your origin. For example, "us-east-1" for AWS or "us-ashburn-1" for OCI.
         */
        originRegion?: string | null;
    }
    /**
     * Message containing information of one individual backend.
     */
    export interface Schema$Backend {
        /**
         * Specifies how to determine whether the backend of a load balancer can handle additional traffic or is fully loaded. For usage guidelines, see Connection balancing mode. Backends must use compatible balancing modes. For more information, see Supported balancing modes and target capacity settings and Restrictions and guidance for instance groups. Note: Currently, if you use the API to configure incompatible balancing modes, the configuration might be accepted even though it has no impact and is ignored. Specifically, Backend.maxUtilization is ignored when Backend.balancingMode is RATE. In the future, this incompatible combination will be rejected.
         */
        balancingMode?: string | null;
        /**
         * A multiplier applied to the backend's target capacity of its balancing mode. The default value is 1, which means the group serves up to 100% of its configured capacity (depending on balancingMode). A setting of 0 means the group is completely drained, offering 0% of its available capacity. The valid ranges are 0.0 and [0.1,1.0]. You cannot configure a setting larger than 0 and smaller than 0.1. You cannot configure a setting of 0 when there is only one backend attached to the backend service. Not available with backends that don't support using a balancingMode. This includes backends such as global internet NEGs, regional serverless NEGs, and PSC NEGs.
         */
        capacityScaler?: number | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * This field designates whether this is a failover backend. More than one failover backend can be configured for a given BackendService.
         */
        failover?: boolean | null;
        /**
         * The fully-qualified URL of an instance group or network endpoint group (NEG) resource. To determine what types of backends a load balancer supports, see the [Backend services overview](https://cloud.google.com/load-balancing/docs/backend-service#backends). You must use the *fully-qualified* URL (starting with https://www.googleapis.com/) to specify the instance group or NEG. Partial URLs are not supported.
         */
        group?: string | null;
        /**
         * Defines a target maximum number of simultaneous connections. For usage guidelines, see Connection balancing mode and Utilization balancing mode. Not available if the backend's balancingMode is RATE.
         */
        maxConnections?: number | null;
        /**
         * Defines a target maximum number of simultaneous connections. For usage guidelines, see Connection balancing mode and Utilization balancing mode. Not available if the backend's balancingMode is RATE.
         */
        maxConnectionsPerEndpoint?: number | null;
        /**
         * Defines a target maximum number of simultaneous connections. For usage guidelines, see Connection balancing mode and Utilization balancing mode. Not available if the backend's balancingMode is RATE.
         */
        maxConnectionsPerInstance?: number | null;
        /**
         * Defines a maximum number of HTTP requests per second (RPS). For usage guidelines, see Rate balancing mode and Utilization balancing mode. Not available if the backend's balancingMode is CONNECTION.
         */
        maxRate?: number | null;
        /**
         * Defines a maximum target for requests per second (RPS). For usage guidelines, see Rate balancing mode and Utilization balancing mode. Not available if the backend's balancingMode is CONNECTION.
         */
        maxRatePerEndpoint?: number | null;
        /**
         * Defines a maximum target for requests per second (RPS). For usage guidelines, see Rate balancing mode and Utilization balancing mode. Not available if the backend's balancingMode is CONNECTION.
         */
        maxRatePerInstance?: number | null;
        /**
         * Optional parameter to define a target capacity for the UTILIZATION balancing mode. The valid range is [0.0, 1.0]. For usage guidelines, see Utilization balancing mode.
         */
        maxUtilization?: number | null;
        /**
         * This field indicates whether this backend should be fully utilized before sending traffic to backends with default preference. The possible values are: - PREFERRED: Backends with this preference level will be filled up to their capacity limits first, based on RTT. - DEFAULT: If preferred backends don't have enough capacity, backends in this layer would be used and traffic would be assigned based on the load balancing algorithm you use. This is the default
         */
        preference?: string | null;
    }
    /**
     * Represents a Cloud Storage Bucket resource. This Cloud Storage bucket resource is referenced by a URL map of a load balancer. For more information, read Backend Buckets.
     */
    export interface Schema$BackendBucket {
        /**
         * Cloud Storage bucket name.
         */
        bucketName?: string | null;
        /**
         * Cloud CDN configuration for this BackendBucket.
         */
        cdnPolicy?: Schema$BackendBucketCdnPolicy;
        /**
         * Compress text responses using Brotli or gzip compression, based on the client's Accept-Encoding header.
         */
        compressionMode?: string | null;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * Headers that the Application Load Balancer should add to proxied responses.
         */
        customResponseHeaders?: string[] | null;
        /**
         * An optional textual description of the resource; provided by the client when the resource is created.
         */
        description?: string | null;
        /**
         * [Output Only] The resource URL for the edge security policy associated with this backend bucket.
         */
        edgeSecurityPolicy?: string | null;
        /**
         * If true, enable Cloud CDN for this BackendBucket.
         */
        enableCdn?: boolean | null;
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * Type of the resource.
         */
        kind?: string | null;
        /**
         * Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
    }
    /**
     * Message containing Cloud CDN configuration for a backend bucket.
     */
    export interface Schema$BackendBucketCdnPolicy {
        /**
         * Bypass the cache when the specified request headers are matched - e.g. Pragma or Authorization headers. Up to 5 headers can be specified. The cache is bypassed for all cdnPolicy.cacheMode settings.
         */
        bypassCacheOnRequestHeaders?: Schema$BackendBucketCdnPolicyBypassCacheOnRequestHeader[];
        /**
         * The CacheKeyPolicy for this CdnPolicy.
         */
        cacheKeyPolicy?: Schema$BackendBucketCdnPolicyCacheKeyPolicy;
        /**
         * Specifies the cache setting for all responses from this backend. The possible values are: USE_ORIGIN_HEADERS Requires the origin to set valid caching headers to cache content. Responses without these headers will not be cached at Google's edge, and will require a full trip to the origin on every request, potentially impacting performance and increasing load on the origin server. FORCE_CACHE_ALL Cache all content, ignoring any "private", "no-store" or "no-cache" directives in Cache-Control response headers. Warning: this may result in Cloud CDN caching private, per-user (user identifiable) content. CACHE_ALL_STATIC Automatically cache static content, including common image formats, media (video and audio), and web assets (JavaScript and CSS). Requests and responses that are marked as uncacheable, as well as dynamic content (including HTML), will not be cached.
         */
        cacheMode?: string | null;
        /**
         * Specifies a separate client (e.g. browser client) maximum TTL. This is used to clamp the max-age (or Expires) value sent to the client. With FORCE_CACHE_ALL, the lesser of client_ttl and default_ttl is used for the response max-age directive, along with a "public" directive. For cacheable content in CACHE_ALL_STATIC mode, client_ttl clamps the max-age from the origin (if specified), or else sets the response max-age directive to the lesser of the client_ttl and default_ttl, and also ensures a "public" cache-control directive is present. If a client TTL is not specified, a default value (1 hour) will be used. The maximum allowed value is 31,622,400s (1 year).
         */
        clientTtl?: number | null;
        /**
         * Specifies the default TTL for cached content served by this origin for responses that do not have an existing valid TTL (max-age or s-max-age). Setting a TTL of "0" means "always revalidate". The value of defaultTTL cannot be set to a value greater than that of maxTTL, but can be equal. When the cacheMode is set to FORCE_CACHE_ALL, the defaultTTL will overwrite the TTL set in all responses. The maximum allowed value is 31,622,400s (1 year), noting that infrequently accessed objects may be evicted from the cache before the defined TTL.
         */
        defaultTtl?: number | null;
        /**
         * Specifies the maximum allowed TTL for cached content served by this origin. Cache directives that attempt to set a max-age or s-maxage higher than this, or an Expires header more than maxTTL seconds in the future will be capped at the value of maxTTL, as if it were the value of an s-maxage Cache-Control directive. Headers sent to the client will not be modified. Setting a TTL of "0" means "always revalidate". The maximum allowed value is 31,622,400s (1 year), noting that infrequently accessed objects may be evicted from the cache before the defined TTL.
         */
        maxTtl?: number | null;
        /**
         * Negative caching allows per-status code TTLs to be set, in order to apply fine-grained caching for common errors or redirects. This can reduce the load on your origin and improve end-user experience by reducing response latency. When the cache mode is set to CACHE_ALL_STATIC or USE_ORIGIN_HEADERS, negative caching applies to responses with the specified response code that lack any Cache-Control, Expires, or Pragma: no-cache directives. When the cache mode is set to FORCE_CACHE_ALL, negative caching applies to all responses with the specified response code, and override any caching headers. By default, Cloud CDN will apply the following default TTLs to these status codes: HTTP 300 (Multiple Choice), 301, 308 (Permanent Redirects): 10m HTTP 404 (Not Found), 410 (Gone), 451 (Unavailable For Legal Reasons): 120s HTTP 405 (Method Not Found), 421 (Misdirected Request), 501 (Not Implemented): 60s. These defaults can be overridden in negative_caching_policy.
         */
        negativeCaching?: boolean | null;
        /**
         * Sets a cache TTL for the specified HTTP status code. negative_caching must be enabled to configure negative_caching_policy. Omitting the policy and leaving negative_caching enabled will use Cloud CDN's default cache TTLs. Note that when specifying an explicit negative_caching_policy, you should take care to specify a cache TTL for all response codes that you wish to cache. Cloud CDN will not apply any default negative caching when a policy exists.
         */
        negativeCachingPolicy?: Schema$BackendBucketCdnPolicyNegativeCachingPolicy[];
        /**
         * If true then Cloud CDN will combine multiple concurrent cache fill requests into a small number of requests to the origin.
         */
        requestCoalescing?: boolean | null;
        /**
         * Serve existing content from the cache (if available) when revalidating content with the origin, or when an error is encountered when refreshing the cache. This setting defines the default "max-stale" duration for any cached responses that do not specify a max-stale directive. Stale responses that exceed the TTL configured here will not be served. The default limit (max-stale) is 86400s (1 day), which will allow stale content to be served up to this limit beyond the max-age (or s-max-age) of a cached response. The maximum allowed value is 604800 (1 week). Set this to zero (0) to disable serve-while-stale.
         */
        serveWhileStale?: number | null;
        /**
         * Maximum number of seconds the response to a signed URL request will be considered fresh. After this time period, the response will be revalidated before being served. Defaults to 1hr (3600s). When serving responses to signed URL requests, Cloud CDN will internally behave as though all responses from this backend had a "Cache-Control: public, max-age=[TTL]" header, regardless of any existing Cache-Control header. The actual headers served in responses will not be altered.
         */
        signedUrlCacheMaxAgeSec?: string | null;
        /**
         * [Output Only] Names of the keys for signing request URLs.
         */
        signedUrlKeyNames?: string[] | null;
    }
    /**
     * Bypass the cache when the specified request headers are present, e.g. Pragma or Authorization headers. Values are case insensitive. The presence of such a header overrides the cache_mode setting.
     */
    export interface Schema$BackendBucketCdnPolicyBypassCacheOnRequestHeader {
        /**
         * The header field name to match on when bypassing cache. Values are case-insensitive.
         */
        headerName?: string | null;
    }
    /**
     * Message containing what to include in the cache key for a request for Cloud CDN.
     */
    export interface Schema$BackendBucketCdnPolicyCacheKeyPolicy {
        /**
         * Allows HTTP request headers (by name) to be used in the cache key.
         */
        includeHttpHeaders?: string[] | null;
        /**
         * Names of query string parameters to include in cache keys. Default parameters are always included. '&' and '=' will be percent encoded and not treated as delimiters.
         */
        queryStringWhitelist?: string[] | null;
    }
    /**
     * Specify CDN TTLs for response error codes.
     */
    export interface Schema$BackendBucketCdnPolicyNegativeCachingPolicy {
        /**
         * The HTTP status code to define a TTL against. Only HTTP status codes 300, 301, 302, 307, 308, 404, 405, 410, 421, 451 and 501 are can be specified as values, and you cannot specify a status code more than once.
         */
        code?: number | null;
        /**
         * The TTL (in seconds) for which to cache responses with the corresponding status code. The maximum allowed value is 1800s (30 minutes), noting that infrequently accessed objects may be evicted from the cache before the defined TTL.
         */
        ttl?: number | null;
    }
    /**
     * Contains a list of BackendBucket resources.
     */
    export interface Schema$BackendBucketList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of BackendBucket resources.
         */
        items?: Schema$BackendBucket[];
        /**
         * Type of resource.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Represents a Backend Service resource. A backend service defines how Google Cloud load balancers distribute traffic. The backend service configuration contains a set of values, such as the protocol used to connect to backends, various distribution and session settings, health checks, and timeouts. These settings provide fine-grained control over how your load balancer behaves. Most of the settings have default values that allow for easy configuration if you need to get started quickly. Backend services in Google Compute Engine can be either regionally or globally scoped. * [Global](https://cloud.google.com/compute/docs/reference/rest/alpha/backendServices) * [Regional](https://cloud.google.com/compute/docs/reference/rest/alpha/regionBackendServices) For more information, see Backend Services.
     */
    export interface Schema$BackendService {
        /**
         * Lifetime of cookies in seconds. This setting is applicable to external and internal HTTP(S) load balancers and Traffic Director and requires GENERATED_COOKIE or HTTP_COOKIE session affinity. If set to 0, the cookie is non-persistent and lasts only until the end of the browser session (or equivalent). The maximum allowed value is two weeks (1,209,600). Not supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true.
         */
        affinityCookieTtlSec?: number | null;
        /**
         * The list of backends that serve this BackendService.
         */
        backends?: Schema$Backend[];
        /**
         * Cloud CDN configuration for this BackendService. Only available for specified load balancer types.
         */
        cdnPolicy?: Schema$BackendServiceCdnPolicy;
        circuitBreakers?: Schema$CircuitBreakers;
        /**
         * Compress text responses using Brotli or gzip compression, based on the client's Accept-Encoding header.
         */
        compressionMode?: string | null;
        connectionDraining?: Schema$ConnectionDraining;
        /**
         * Connection Tracking configuration for this BackendService. Connection tracking policy settings are only available for Network Load Balancing and Internal TCP/UDP Load Balancing.
         */
        connectionTrackingPolicy?: Schema$BackendServiceConnectionTrackingPolicy;
        /**
         * Consistent Hash-based load balancing can be used to provide soft session affinity based on HTTP headers, cookies or other properties. This load balancing policy is applicable only for HTTP connections. The affinity to a particular destination host will be lost when one or more hosts are added/removed from the destination service. This field specifies parameters that control consistent hashing. This field is only applicable when localityLbPolicy is set to MAGLEV or RING_HASH. This field is applicable to either: - A regional backend service with the service_protocol set to HTTP, HTTPS, or HTTP2, and load_balancing_scheme set to INTERNAL_MANAGED. - A global backend service with the load_balancing_scheme set to INTERNAL_SELF_MANAGED.
         */
        consistentHash?: Schema$ConsistentHashLoadBalancerSettings;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * Headers that the load balancer adds to proxied requests. See [Creating custom headers](https://cloud.google.com/load-balancing/docs/custom-headers).
         */
        customRequestHeaders?: string[] | null;
        /**
         * Headers that the load balancer adds to proxied responses. See [Creating custom headers](https://cloud.google.com/load-balancing/docs/custom-headers).
         */
        customResponseHeaders?: string[] | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * [Output Only] The resource URL for the edge security policy associated with this backend service.
         */
        edgeSecurityPolicy?: string | null;
        /**
         * If true, enables Cloud CDN for the backend service of an external HTTP(S) load balancer.
         */
        enableCDN?: boolean | null;
        /**
         * Requires at least one backend instance group to be defined as a backup (failover) backend. For load balancers that have configurable failover: [Internal TCP/UDP Load Balancing](https://cloud.google.com/load-balancing/docs/internal/failover-overview) and [external TCP/UDP Load Balancing](https://cloud.google.com/load-balancing/docs/network/networklb-failover-overview).
         */
        failoverPolicy?: Schema$BackendServiceFailoverPolicy;
        /**
         * Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a BackendService. An up-to-date fingerprint must be provided in order to update the BackendService, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a BackendService.
         */
        fingerprint?: string | null;
        /**
         * The list of URLs to the healthChecks, httpHealthChecks (legacy), or httpsHealthChecks (legacy) resource for health checking this backend service. Not all backend services support legacy health checks. See Load balancer guide. Currently, at most one health check can be specified for each backend service. Backend services with instance group or zonal NEG backends must have a health check. Backend services with internet or serverless NEG backends must not have a health check.
         */
        healthChecks?: string[] | null;
        /**
         * The configurations for Identity-Aware Proxy on this resource. Not available for Internal TCP/UDP Load Balancing and Network Load Balancing.
         */
        iap?: Schema$BackendServiceIAP;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * Specifies preference of traffic to the backend (from the proxy and from the client for proxyless gRPC). The possible values are: - IPV4_ONLY: Only send IPv4 traffic to the backends of the Backend Service (Instance Group, Managed Instance Group, Network Endpoint Group) regardless of traffic from the client to the proxy. Only IPv4 health-checks are used to check the health of the backends. This is the default setting. - PREFER_IPV6: Prioritize the connection to the endpoints IPv6 address over its IPv4 address (provided there is a healthy IPv6 address). - IPV6_ONLY: Only send IPv6 traffic to the backends of the Backend Service (Instance Group, Managed Instance Group, Network Endpoint Group) regardless of traffic from the client to the proxy. Only IPv6 health-checks are used to check the health of the backends. This field is applicable to either: - Advanced Global External HTTPS Load Balancing (load balancing scheme EXTERNAL_MANAGED), - Regional External HTTPS Load Balancing, - Internal TCP Proxy (load balancing scheme INTERNAL_MANAGED), - Regional Internal HTTPS Load Balancing (load balancing scheme INTERNAL_MANAGED), - Traffic Director with Envoy proxies and proxyless gRPC (load balancing scheme INTERNAL_SELF_MANAGED).
         */
        ipAddressSelectionPolicy?: string | null;
        /**
         * [Output Only] Type of resource. Always compute#backendService for backend services.
         */
        kind?: string | null;
        /**
         * Specifies the load balancer type. A backend service created for one type of load balancer cannot be used with another. For more information, refer to Choosing a load balancer.
         */
        loadBalancingScheme?: string | null;
        /**
         * A list of locality load-balancing policies to be used in order of preference. When you use localityLbPolicies, you must set at least one value for either the localityLbPolicies[].policy or the localityLbPolicies[].customPolicy field. localityLbPolicies overrides any value set in the localityLbPolicy field. For an example of how to use this field, see Define a list of preferred policies. Caution: This field and its children are intended for use in a service mesh that includes gRPC clients only. Envoy proxies can't use backend services that have this configuration.
         */
        localityLbPolicies?: Schema$BackendServiceLocalityLoadBalancingPolicyConfig[];
        /**
         * The load balancing algorithm used within the scope of the locality. The possible values are: - ROUND_ROBIN: This is a simple policy in which each healthy backend is selected in round robin order. This is the default. - LEAST_REQUEST: An O(1) algorithm which selects two random healthy hosts and picks the host which has fewer active requests. - RING_HASH: The ring/modulo hash load balancer implements consistent hashing to backends. The algorithm has the property that the addition/removal of a host from a set of N hosts only affects 1/N of the requests. - RANDOM: The load balancer selects a random healthy host. - ORIGINAL_DESTINATION: Backend host is selected based on the client connection metadata, i.e., connections are opened to the same address as the destination address of the incoming connection before the connection was redirected to the load balancer. - MAGLEV: used as a drop in replacement for the ring hash load balancer. Maglev is not as stable as ring hash but has faster table lookup build times and host selection times. For more information about Maglev, see https://ai.google/research/pubs/pub44824 This field is applicable to either: - A regional backend service with the service_protocol set to HTTP, HTTPS, or HTTP2, and load_balancing_scheme set to INTERNAL_MANAGED. - A global backend service with the load_balancing_scheme set to INTERNAL_SELF_MANAGED, INTERNAL_MANAGED, or EXTERNAL_MANAGED. If sessionAffinity is not NONE, and this field is not set to MAGLEV or RING_HASH, session affinity settings will not take effect. Only ROUND_ROBIN and RING_HASH are supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true.
         */
        localityLbPolicy?: string | null;
        /**
         * This field denotes the logging options for the load balancer traffic served by this backend service. If logging is enabled, logs will be exported to Stackdriver.
         */
        logConfig?: Schema$BackendServiceLogConfig;
        /**
         * Specifies the default maximum duration (timeout) for streams to this service. Duration is computed from the beginning of the stream until the response has been completely processed, including all retries. A stream that does not complete in this duration is closed. If not specified, there will be no timeout limit, i.e. the maximum duration is infinite. This value can be overridden in the PathMatcher configuration of the UrlMap that references this backend service. This field is only allowed when the loadBalancingScheme of the backend service is INTERNAL_SELF_MANAGED.
         */
        maxStreamDuration?: Schema$Duration;
        /**
         * Deployment metadata associated with the resource to be set by a GKE hub controller and read by the backend RCTH
         */
        metadatas?: {
            [key: string]: string;
        } | null;
        /**
         * Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * The URL of the network to which this backend service belongs. This field can only be specified when the load balancing scheme is set to INTERNAL.
         */
        network?: string | null;
        /**
         * Settings controlling the ejection of unhealthy backend endpoints from the load balancing pool of each individual proxy instance that processes the traffic for the given backend service. If not set, this feature is considered disabled. Results of the outlier detection algorithm (ejection of endpoints from the load balancing pool and returning them back to the pool) are executed independently by each proxy instance of the load balancer. In most cases, more than one proxy instance handles the traffic received by a backend service. Thus, it is possible that an unhealthy endpoint is detected and ejected by only some of the proxies, and while this happens, other proxies may continue to send requests to the same unhealthy endpoint until they detect and eject the unhealthy endpoint. Applicable backend endpoints can be: - VM instances in an Instance Group - Endpoints in a Zonal NEG (GCE_VM_IP, GCE_VM_IP_PORT) - Endpoints in a Hybrid Connectivity NEG (NON_GCP_PRIVATE_IP_PORT) - Serverless NEGs, that resolve to Cloud Run, App Engine, or Cloud Functions Services - Private Service Connect NEGs, that resolve to Google-managed regional API endpoints or managed services published using Private Service Connect Applicable backend service types can be: - A global backend service with the loadBalancingScheme set to INTERNAL_SELF_MANAGED or EXTERNAL_MANAGED. - A regional backend service with the serviceProtocol set to HTTP, HTTPS, or HTTP2, and loadBalancingScheme set to INTERNAL_MANAGED or EXTERNAL_MANAGED. Not supported for Serverless NEGs. Not supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true.
         */
        outlierDetection?: Schema$OutlierDetection;
        /**
         * Deprecated in favor of portName. The TCP port to connect on the backend. The default value is 80. For Internal TCP/UDP Load Balancing and Network Load Balancing, omit port.
         */
        port?: number | null;
        /**
         * A named port on a backend instance group representing the port for communication to the backend VMs in that group. The named port must be [defined on each backend instance group](https://cloud.google.com/load-balancing/docs/backend-service#named_ports). This parameter has no meaning if the backends are NEGs. For Internal TCP/UDP Load Balancing and Network Load Balancing, omit port_name.
         */
        portName?: string | null;
        /**
         * The protocol this BackendService uses to communicate with backends. Possible values are HTTP, HTTPS, HTTP2, TCP, SSL, UDP or GRPC. depending on the chosen load balancer or Traffic Director configuration. Refer to the documentation for the load balancers or for Traffic Director for more information. Must be set to GRPC when the backend service is referenced by a URL map that is bound to target gRPC proxy.
         */
        protocol?: string | null;
        /**
         * [Output Only] URL of the region where the regional backend service resides. This field is not applicable to global backend services. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
         */
        region?: string | null;
        /**
         * [Output Only] The resource URL for the security policy associated with this backend service.
         */
        securityPolicy?: string | null;
        /**
         * This field specifies the security settings that apply to this backend service. This field is applicable to a global backend service with the load_balancing_scheme set to INTERNAL_SELF_MANAGED.
         */
        securitySettings?: Schema$SecuritySettings;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * URLs of networkservices.ServiceBinding resources. Can only be set if load balancing scheme is INTERNAL_SELF_MANAGED. If set, lists of backends and health checks must be both empty.
         */
        serviceBindings?: string[] | null;
        /**
         * URL to networkservices.ServiceLbPolicy resource. Can only be set if load balancing scheme is EXTERNAL, EXTERNAL_MANAGED, INTERNAL_MANAGED or INTERNAL_SELF_MANAGED and the scope is global.
         */
        serviceLbPolicy?: string | null;
        /**
         * Type of session affinity to use. The default is NONE. Only NONE and HEADER_FIELD are supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true. For more details, see: [Session Affinity](https://cloud.google.com/load-balancing/docs/backend-service#session_affinity).
         */
        sessionAffinity?: string | null;
        subsetting?: Schema$Subsetting;
        /**
         * The backend service timeout has a different meaning depending on the type of load balancer. For more information see, Backend service settings. The default is 30 seconds. The full range of timeout values allowed goes from 1 through 2,147,483,647 seconds. This value can be overridden in the PathMatcher configuration of the UrlMap that references this backend service. Not supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true. Instead, use maxStreamDuration.
         */
        timeoutSec?: number | null;
        usedBy?: Schema$BackendServiceUsedBy[];
        /**
         * The network scope of the backends that can be added to the backend service. This field can be either GLOBAL_VPC_NETWORK or REGIONAL_VPC_NETWORK. A backend service with the VPC scope set to GLOBAL_VPC_NETWORK is only allowed to have backends in global VPC networks. When the VPC scope is set to REGIONAL_VPC_NETWORK the backend service is only allowed to have backends in regional networks in the same scope as the backend service. Note: if not specified then GLOBAL_VPC_NETWORK will be used.
         */
        vpcNetworkScope?: string | null;
    }
    /**
     * Contains a list of BackendServicesScopedList.
     */
    export interface Schema$BackendServiceAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of BackendServicesScopedList resources.
         */
        items?: {
            [key: string]: Schema$BackendServicesScopedList;
        } | null;
        /**
         * Type of resource.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Message containing Cloud CDN configuration for a backend service.
     */
    export interface Schema$BackendServiceCdnPolicy {
        /**
         * Bypass the cache when the specified request headers are matched - e.g. Pragma or Authorization headers. Up to 5 headers can be specified. The cache is bypassed for all cdnPolicy.cacheMode settings.
         */
        bypassCacheOnRequestHeaders?: Schema$BackendServiceCdnPolicyBypassCacheOnRequestHeader[];
        /**
         * The CacheKeyPolicy for this CdnPolicy.
         */
        cacheKeyPolicy?: Schema$CacheKeyPolicy;
        /**
         * Specifies the cache setting for all responses from this backend. The possible values are: USE_ORIGIN_HEADERS Requires the origin to set valid caching headers to cache content. Responses without these headers will not be cached at Google's edge, and will require a full trip to the origin on every request, potentially impacting performance and increasing load on the origin server. FORCE_CACHE_ALL Cache all content, ignoring any "private", "no-store" or "no-cache" directives in Cache-Control response headers. Warning: this may result in Cloud CDN caching private, per-user (user identifiable) content. CACHE_ALL_STATIC Automatically cache static content, including common image formats, media (video and audio), and web assets (JavaScript and CSS). Requests and responses that are marked as uncacheable, as well as dynamic content (including HTML), will not be cached.
         */
        cacheMode?: string | null;
        /**
         * Specifies a separate client (e.g. browser client) maximum TTL. This is used to clamp the max-age (or Expires) value sent to the client. With FORCE_CACHE_ALL, the lesser of client_ttl and default_ttl is used for the response max-age directive, along with a "public" directive. For cacheable content in CACHE_ALL_STATIC mode, client_ttl clamps the max-age from the origin (if specified), or else sets the response max-age directive to the lesser of the client_ttl and default_ttl, and also ensures a "public" cache-control directive is present. If a client TTL is not specified, a default value (1 hour) will be used. The maximum allowed value is 31,622,400s (1 year).
         */
        clientTtl?: number | null;
        /**
         * Specifies the default TTL for cached content served by this origin for responses that do not have an existing valid TTL (max-age or s-max-age). Setting a TTL of "0" means "always revalidate". The value of defaultTTL cannot be set to a value greater than that of maxTTL, but can be equal. When the cacheMode is set to FORCE_CACHE_ALL, the defaultTTL will overwrite the TTL set in all responses. The maximum allowed value is 31,622,400s (1 year), noting that infrequently accessed objects may be evicted from the cache before the defined TTL.
         */
        defaultTtl?: number | null;
        /**
         * Specifies the maximum allowed TTL for cached content served by this origin. Cache directives that attempt to set a max-age or s-maxage higher than this, or an Expires header more than maxTTL seconds in the future will be capped at the value of maxTTL, as if it were the value of an s-maxage Cache-Control directive. Headers sent to the client will not be modified. Setting a TTL of "0" means "always revalidate". The maximum allowed value is 31,622,400s (1 year), noting that infrequently accessed objects may be evicted from the cache before the defined TTL.
         */
        maxTtl?: number | null;
        /**
         * Negative caching allows per-status code TTLs to be set, in order to apply fine-grained caching for common errors or redirects. This can reduce the load on your origin and improve end-user experience by reducing response latency. When the cache mode is set to CACHE_ALL_STATIC or USE_ORIGIN_HEADERS, negative caching applies to responses with the specified response code that lack any Cache-Control, Expires, or Pragma: no-cache directives. When the cache mode is set to FORCE_CACHE_ALL, negative caching applies to all responses with the specified response code, and override any caching headers. By default, Cloud CDN will apply the following default TTLs to these status codes: HTTP 300 (Multiple Choice), 301, 308 (Permanent Redirects): 10m HTTP 404 (Not Found), 410 (Gone), 451 (Unavailable For Legal Reasons): 120s HTTP 405 (Method Not Found), 421 (Misdirected Request), 501 (Not Implemented): 60s. These defaults can be overridden in negative_caching_policy.
         */
        negativeCaching?: boolean | null;
        /**
         * Sets a cache TTL for the specified HTTP status code. negative_caching must be enabled to configure negative_caching_policy. Omitting the policy and leaving negative_caching enabled will use Cloud CDN's default cache TTLs. Note that when specifying an explicit negative_caching_policy, you should take care to specify a cache TTL for all response codes that you wish to cache. Cloud CDN will not apply any default negative caching when a policy exists.
         */
        negativeCachingPolicy?: Schema$BackendServiceCdnPolicyNegativeCachingPolicy[];
        /**
         * If true then Cloud CDN will combine multiple concurrent cache fill requests into a small number of requests to the origin.
         */
        requestCoalescing?: boolean | null;
        /**
         * Serve existing content from the cache (if available) when revalidating content with the origin, or when an error is encountered when refreshing the cache. This setting defines the default "max-stale" duration for any cached responses that do not specify a max-stale directive. Stale responses that exceed the TTL configured here will not be served. The default limit (max-stale) is 86400s (1 day), which will allow stale content to be served up to this limit beyond the max-age (or s-max-age) of a cached response. The maximum allowed value is 604800 (1 week). Set this to zero (0) to disable serve-while-stale.
         */
        serveWhileStale?: number | null;
        /**
         * Maximum number of seconds the response to a signed URL request will be considered fresh. After this time period, the response will be revalidated before being served. Defaults to 1hr (3600s). When serving responses to signed URL requests, Cloud CDN will internally behave as though all responses from this backend had a "Cache-Control: public, max-age=[TTL]" header, regardless of any existing Cache-Control header. The actual headers served in responses will not be altered.
         */
        signedUrlCacheMaxAgeSec?: string | null;
        /**
         * [Output Only] Names of the keys for signing request URLs.
         */
        signedUrlKeyNames?: string[] | null;
    }
    /**
     * Bypass the cache when the specified request headers are present, e.g. Pragma or Authorization headers. Values are case insensitive. The presence of such a header overrides the cache_mode setting.
     */
    export interface Schema$BackendServiceCdnPolicyBypassCacheOnRequestHeader {
        /**
         * The header field name to match on when bypassing cache. Values are case-insensitive.
         */
        headerName?: string | null;
    }
    /**
     * Specify CDN TTLs for response error codes.
     */
    export interface Schema$BackendServiceCdnPolicyNegativeCachingPolicy {
        /**
         * The HTTP status code to define a TTL against. Only HTTP status codes 300, 301, 302, 307, 308, 404, 405, 410, 421, 451 and 501 are can be specified as values, and you cannot specify a status code more than once.
         */
        code?: number | null;
        /**
         * The TTL (in seconds) for which to cache responses with the corresponding status code. The maximum allowed value is 1800s (30 minutes), noting that infrequently accessed objects may be evicted from the cache before the defined TTL.
         */
        ttl?: number | null;
    }
    /**
     * Connection Tracking configuration for this BackendService.
     */
    export interface Schema$BackendServiceConnectionTrackingPolicy {
        /**
         * Specifies connection persistence when backends are unhealthy. The default value is DEFAULT_FOR_PROTOCOL. If set to DEFAULT_FOR_PROTOCOL, the existing connections persist on unhealthy backends only for connection-oriented protocols (TCP and SCTP) and only if the Tracking Mode is PER_CONNECTION (default tracking mode) or the Session Affinity is configured for 5-tuple. They do not persist for UDP. If set to NEVER_PERSIST, after a backend becomes unhealthy, the existing connections on the unhealthy backend are never persisted on the unhealthy backend. They are always diverted to newly selected healthy backends (unless all backends are unhealthy). If set to ALWAYS_PERSIST, existing connections always persist on unhealthy backends regardless of protocol and session affinity. It is generally not recommended to use this mode overriding the default. For more details, see [Connection Persistence for Network Load Balancing](https://cloud.google.com/load-balancing/docs/network/networklb-backend-service#connection-persistence) and [Connection Persistence for Internal TCP/UDP Load Balancing](https://cloud.google.com/load-balancing/docs/internal#connection-persistence).
         */
        connectionPersistenceOnUnhealthyBackends?: string | null;
        /**
         * Enable Strong Session Affinity for Network Load Balancing. This option is not available publicly.
         */
        enableStrongAffinity?: boolean | null;
        /**
         * Specifies how long to keep a Connection Tracking entry while there is no matching traffic (in seconds). For Internal TCP/UDP Load Balancing: - The minimum (default) is 10 minutes and the maximum is 16 hours. - It can be set only if Connection Tracking is less than 5-tuple (i.e. Session Affinity is CLIENT_IP_NO_DESTINATION, CLIENT_IP or CLIENT_IP_PROTO, and Tracking Mode is PER_SESSION). For Network Load Balancer the default is 60 seconds. This option is not available publicly.
         */
        idleTimeoutSec?: number | null;
        /**
         * Specifies the key used for connection tracking. There are two options: - PER_CONNECTION: This is the default mode. The Connection Tracking is performed as per the Connection Key (default Hash Method) for the specific protocol. - PER_SESSION: The Connection Tracking is performed as per the configured Session Affinity. It matches the configured Session Affinity. For more details, see [Tracking Mode for Network Load Balancing](https://cloud.google.com/load-balancing/docs/network/networklb-backend-service#tracking-mode) and [Tracking Mode for Internal TCP/UDP Load Balancing](https://cloud.google.com/load-balancing/docs/internal#tracking-mode).
         */
        trackingMode?: string | null;
    }
    /**
     * For load balancers that have configurable failover: [Internal TCP/UDP Load Balancing](https://cloud.google.com/load-balancing/docs/internal/failover-overview) and [external TCP/UDP Load Balancing](https://cloud.google.com/load-balancing/docs/network/networklb-failover-overview). On failover or failback, this field indicates whether connection draining will be honored. Google Cloud has a fixed connection draining timeout of 10 minutes. A setting of true terminates existing TCP connections to the active pool during failover and failback, immediately draining traffic. A setting of false allows existing TCP connections to persist, even on VMs no longer in the active pool, for up to the duration of the connection draining timeout (10 minutes).
     */
    export interface Schema$BackendServiceFailoverPolicy {
        /**
         * This can be set to true only if the protocol is TCP. The default is false.
         */
        disableConnectionDrainOnFailover?: boolean | null;
        /**
         * If set to true, connections to the load balancer are dropped when all primary and all backup backend VMs are unhealthy.If set to false, connections are distributed among all primary VMs when all primary and all backup backend VMs are unhealthy. For load balancers that have configurable failover: [Internal TCP/UDP Load Balancing](https://cloud.google.com/load-balancing/docs/internal/failover-overview) and [external TCP/UDP Load Balancing](https://cloud.google.com/load-balancing/docs/network/networklb-failover-overview). The default is false.
         */
        dropTrafficIfUnhealthy?: boolean | null;
        /**
         * The value of the field must be in the range [0, 1]. If the value is 0, the load balancer performs a failover when the number of healthy primary VMs equals zero. For all other values, the load balancer performs a failover when the total number of healthy primary VMs is less than this ratio. For load balancers that have configurable failover: [Internal TCP/UDP Load Balancing](https://cloud.google.com/load-balancing/docs/internal/failover-overview) and [external TCP/UDP Load Balancing](https://cloud.google.com/load-balancing/docs/network/networklb-failover-overview).
         */
        failoverRatio?: number | null;
    }
    export interface Schema$BackendServiceGroupHealth {
        /**
         * Metadata defined as annotations on the network endpoint group.
         */
        annotations?: {
            [key: string]: string;
        } | null;
        /**
         * Health state of the backend instances or endpoints in requested instance or network endpoint group, determined based on configured health checks.
         */
        healthStatus?: Schema$HealthStatus[];
        /**
         * [Output Only] Type of resource. Always compute#backendServiceGroupHealth for the health of backend services.
         */
        kind?: string | null;
    }
    /**
     * Identity-Aware Proxy
     */
    export interface Schema$BackendServiceIAP {
        /**
         * Whether the serving infrastructure will authenticate and authorize all incoming requests.
         */
        enabled?: boolean | null;
        /**
         * OAuth2 client ID to use for the authentication flow.
         */
        oauth2ClientId?: string | null;
        /**
         * [Input Only] OAuth client info required to generate client id to be used for IAP.
         */
        oauth2ClientInfo?: Schema$BackendServiceIAPOAuth2ClientInfo;
        /**
         * OAuth2 client secret to use for the authentication flow. For security reasons, this value cannot be retrieved via the API. Instead, the SHA-256 hash of the value is returned in the oauth2ClientSecretSha256 field. @InputOnly
         */
        oauth2ClientSecret?: string | null;
        /**
         * [Output Only] SHA256 hash value for the field oauth2_client_secret above.
         */
        oauth2ClientSecretSha256?: string | null;
    }
    export interface Schema$BackendServiceIAPOAuth2ClientInfo {
        /**
         * Application name to be used in OAuth consent screen.
         */
        applicationName?: string | null;
        /**
         * Name of the client to be generated. Optional - If not provided, the name will be autogenerated by the backend.
         */
        clientName?: string | null;
        /**
         * Developer's information to be used in OAuth consent screen.
         */
        developerEmailAddress?: string | null;
    }
    /**
     * Contains a list of BackendService resources.
     */
    export interface Schema$BackendServiceList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of BackendService resources.
         */
        items?: Schema$BackendService[];
        /**
         * [Output Only] Type of resource. Always compute#backendServiceList for lists of backend services.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Contains a list of usable BackendService resources.
     */
    export interface Schema$BackendServiceListUsable {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of BackendService resources.
         */
        items?: Schema$BackendService[];
        /**
         * [Output Only] Type of resource. Always compute#usableBackendServiceList for lists of usable backend services.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Container for either a built-in LB policy supported by gRPC or Envoy or a custom one implemented by the end user.
     */
    export interface Schema$BackendServiceLocalityLoadBalancingPolicyConfig {
        customPolicy?: Schema$BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy;
        policy?: Schema$BackendServiceLocalityLoadBalancingPolicyConfigPolicy;
    }
    /**
     * The configuration for a custom policy implemented by the user and deployed with the client.
     */
    export interface Schema$BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy {
        /**
         * An optional, arbitrary JSON object with configuration data, understood by a locally installed custom policy implementation.
         */
        data?: string | null;
        /**
         * Identifies the custom policy. The value should match the name of a custom implementation registered on the gRPC clients. It should follow protocol buffer message naming conventions and include the full path (for example, myorg.CustomLbPolicy). The maximum length is 256 characters. Do not specify the same custom policy more than once for a backend. If you do, the configuration is rejected. For an example of how to use this field, see Use a custom policy.
         */
        name?: string | null;
    }
    /**
     * The configuration for a built-in load balancing policy.
     */
    export interface Schema$BackendServiceLocalityLoadBalancingPolicyConfigPolicy {
        /**
         * The name of a locality load-balancing policy. Valid values include ROUND_ROBIN and, for Java clients, LEAST_REQUEST. For information about these values, see the description of localityLbPolicy. Do not specify the same policy more than once for a backend. If you do, the configuration is rejected.
         */
        name?: string | null;
    }
    /**
     * The available logging options for the load balancer traffic served by this backend service.
     */
    export interface Schema$BackendServiceLogConfig {
        /**
         * Denotes whether to enable logging for the load balancer traffic served by this backend service. The default value is false.
         */
        enable?: boolean | null;
        /**
         * Deprecated in favor of optionalMode. This field can only be specified if logging is enabled for this backend service. Configures whether all, none or a subset of optional fields should be added to the reported logs. One of [INCLUDE_ALL_OPTIONAL, EXCLUDE_ALL_OPTIONAL, CUSTOM]. Default is EXCLUDE_ALL_OPTIONAL.
         */
        optional?: string | null;
        /**
         * This field can only be specified if logging is enabled for this backend service and "logConfig.optionalMode" was set to CUSTOM. Contains a list of optional fields you want to include in the logs. For example: serverInstance, serverGkeDetails.cluster, serverGkeDetails.pod.podNamespace
         */
        optionalFields?: string[] | null;
        /**
         * This field can only be specified if logging is enabled for this backend service. Configures whether all, none or a subset of optional fields should be added to the reported logs. One of [INCLUDE_ALL_OPTIONAL, EXCLUDE_ALL_OPTIONAL, CUSTOM]. Default is EXCLUDE_ALL_OPTIONAL.
         */
        optionalMode?: string | null;
        /**
         * This field can only be specified if logging is enabled for this backend service. The value of the field must be in [0, 1]. This configures the sampling rate of requests to the load balancer where 1.0 means all logged requests are reported and 0.0 means no logged requests are reported. The default value is 1.0.
         */
        sampleRate?: number | null;
    }
    export interface Schema$BackendServiceReference {
        backendService?: string | null;
    }
    export interface Schema$BackendServicesScopedList {
        /**
         * A list of BackendServices contained in this scope.
         */
        backendServices?: Schema$BackendService[];
        /**
         * Informational warning which replaces the list of backend services when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$BackendServiceUsedBy {
        reference?: string | null;
    }
    export interface Schema$BfdPacket {
        /**
         * The Authentication Present bit of the BFD packet. This is specified in section 4.1 of RFC5880
         */
        authenticationPresent?: boolean | null;
        /**
         * The Control Plane Independent bit of the BFD packet. This is specified in section 4.1 of RFC5880
         */
        controlPlaneIndependent?: boolean | null;
        /**
         * The demand bit of the BFD packet. This is specified in section 4.1 of RFC5880
         */
        demand?: boolean | null;
        /**
         * The diagnostic code specifies the local system's reason for the last change in session state. This allows remote systems to determine the reason that the previous session failed, for example. These diagnostic codes are specified in section 4.1 of RFC5880
         */
        diagnostic?: string | null;
        /**
         * The Final bit of the BFD packet. This is specified in section 4.1 of RFC5880
         */
        final?: boolean | null;
        /**
         * The length of the BFD Control packet in bytes. This is specified in section 4.1 of RFC5880
         */
        length?: number | null;
        /**
         * The Required Min Echo RX Interval value in the BFD packet. This is specified in section 4.1 of RFC5880
         */
        minEchoRxIntervalMs?: number | null;
        /**
         * The Required Min RX Interval value in the BFD packet. This is specified in section 4.1 of RFC5880
         */
        minRxIntervalMs?: number | null;
        /**
         * The Desired Min TX Interval value in the BFD packet. This is specified in section 4.1 of RFC5880
         */
        minTxIntervalMs?: number | null;
        /**
         * The detection time multiplier of the BFD packet. This is specified in section 4.1 of RFC5880
         */
        multiplier?: number | null;
        /**
         * The multipoint bit of the BFD packet. This is specified in section 4.1 of RFC5880
         */
        multipoint?: boolean | null;
        /**
         * The My Discriminator value in the BFD packet. This is specified in section 4.1 of RFC5880
         */
        myDiscriminator?: number | null;
        /**
         * The Poll bit of the BFD packet. This is specified in section 4.1 of RFC5880
         */
        poll?: boolean | null;
        /**
         * The current BFD session state as seen by the transmitting system. These states are specified in section 4.1 of RFC5880
         */
        state?: string | null;
        /**
         * The version number of the BFD protocol, as specified in section 4.1 of RFC5880.
         */
        version?: number | null;
        /**
         * The Your Discriminator value in the BFD packet. This is specified in section 4.1 of RFC5880
         */
        yourDiscriminator?: number | null;
    }
    /**
     * Next free: 15
     */
    export interface Schema$BfdStatus {
        /**
         * The BFD session initialization mode for this BGP peer. If set to ACTIVE, the Cloud Router will initiate the BFD session for this BGP peer. If set to PASSIVE, the Cloud Router will wait for the peer router to initiate the BFD session for this BGP peer. If set to DISABLED, BFD is disabled for this BGP peer.
         */
        bfdSessionInitializationMode?: string | null;
        /**
         * Unix timestamp of the most recent config update.
         */
        configUpdateTimestampMicros?: string | null;
        /**
         * Control packet counts for the current BFD session.
         */
        controlPacketCounts?: Schema$BfdStatusPacketCounts;
        /**
         * Inter-packet time interval statistics for control packets.
         */
        controlPacketIntervals?: Schema$PacketIntervals[];
        /**
         * Echo packet counts for the current BFD session.
         */
        echoPacketCounts?: Schema$BfdStatusPacketCounts;
        /**
         * Inter-packet time interval statistics for echo packets.
         */
        echoPacketIntervals?: Schema$PacketIntervals[];
        /**
         * The diagnostic code specifies the local system's reason for the last change in session state. This allows remote systems to determine the reason that the previous session failed, for example. These diagnostic codes are specified in section 4.1 of RFC5880
         */
        localDiagnostic?: string | null;
        /**
         * The current BFD session state as seen by the transmitting system. These states are specified in section 4.1 of RFC5880
         */
        localState?: string | null;
        /**
         * Negotiated transmit interval for control packets.
         */
        negotiatedLocalControlTxIntervalMs?: number | null;
        /**
         * Negotiated transmit interval for echo packets.
         */
        negotiatedLocalEchoTxIntervalMs?: number | null;
        /**
         * The most recent Rx control packet for this BFD session.
         */
        rxPacket?: Schema$BfdPacket;
        /**
         * The most recent Tx control packet for this BFD session.
         */
        txPacket?: Schema$BfdPacket;
        /**
         * Session uptime in milliseconds. Value will be 0 if session is not up.
         */
        uptimeMs?: string | null;
        /**
         * Indicates if echo mode is currently being used.
         */
        usingEchoMode?: boolean | null;
    }
    export interface Schema$BfdStatusPacketCounts {
        /**
         * Number of packets received since the beginning of the current BFD session.
         */
        numRx?: number | null;
        /**
         * Number of packets received that were rejected because of errors since the beginning of the current BFD session.
         */
        numRxRejected?: number | null;
        /**
         * Number of packets received that were successfully processed since the beginning of the current BFD session.
         */
        numRxSuccessful?: number | null;
        /**
         * Number of packets transmitted since the beginning of the current BFD session.
         */
        numTx?: number | null;
    }
    export interface Schema$BgpRoute {
        /**
         * [Output only] AS-PATH for the route
         */
        asPaths?: Schema$BgpRouteAsPath[];
        /**
         * [Output only] BGP communities in human-readable A:B format.
         */
        communities?: string[] | null;
        /**
         * [Output only] Destination IP range for the route, in human-readable CIDR format
         */
        destination?: Schema$BgpRouteNetworkLayerReachabilityInformation;
        /**
         * [Output only] BGP multi-exit discriminator
         */
        med?: number | null;
        /**
         * [Output only] BGP origin (EGP, IGP or INCOMPLETE)
         */
        origin?: string | null;
    }
    export interface Schema$BgpRouteAsPath {
        /**
         * [Output only] ASNs in the path segment. When type is SEQUENCE, these are ordered.
         */
        asns?: number[] | null;
        /**
         * [Output only] Type of AS-PATH segment (SEQUENCE or SET)
         */
        type?: string | null;
    }
    /**
     * Network Layer Reachability Information (NLRI) for a route.
     */
    export interface Schema$BgpRouteNetworkLayerReachabilityInformation {
        /**
         * Human readable CIDR notation for a prefix. E.g. 10.42.0.0/16.
         */
        destination?: string | null;
        /**
         * If the BGP session supports multiple paths (RFC 7911), the path identifier for this route.
         */
        pathId?: number | null;
    }
    /**
     * Associates `members`, or principals, with a `role`.
     */
    export interface Schema$Binding {
        /**
         * This is deprecated and has no effect. Do not use.
         */
        bindingId?: string | null;
        /**
         * The condition that is associated with this binding. If the condition evaluates to `true`, then this binding applies to the current request. If the condition evaluates to `false`, then this binding does not apply to the current request. However, a different role binding might grant the same role to one or more of the principals in this binding. To learn which resources support conditions in their IAM policies, see the [IAM documentation](https://cloud.google.com/iam/help/conditions/resource-policies).
         */
        condition?: Schema$Expr;
        /**
         * Specifies the principals requesting access for a Google Cloud resource. `members` can have the following values: * `allUsers`: A special identifier that represents anyone who is on the internet; with or without a Google account. * `allAuthenticatedUsers`: A special identifier that represents anyone who is authenticated with a Google account or a service account. Does not include identities that come from external identity providers (IdPs) through identity federation. * `user:{emailid\}`: An email address that represents a specific Google account. For example, `alice@example.com` . * `serviceAccount:{emailid\}`: An email address that represents a Google service account. For example, `my-other-app@appspot.gserviceaccount.com`. * `serviceAccount:{projectid\}.svc.id.goog[{namespace\}/{kubernetes-sa\}]`: An identifier for a [Kubernetes service account](https://cloud.google.com/kubernetes-engine/docs/how-to/kubernetes-service-accounts). For example, `my-project.svc.id.goog[my-namespace/my-kubernetes-sa]`. * `group:{emailid\}`: An email address that represents a Google group. For example, `admins@example.com`. * `domain:{domain\}`: The G Suite domain (primary) that represents all the users of that domain. For example, `google.com` or `example.com`. * `deleted:user:{emailid\}?uid={uniqueid\}`: An email address (plus unique identifier) representing a user that has been recently deleted. For example, `alice@example.com?uid=123456789012345678901`. If the user is recovered, this value reverts to `user:{emailid\}` and the recovered user retains the role in the binding. * `deleted:serviceAccount:{emailid\}?uid={uniqueid\}`: An email address (plus unique identifier) representing a service account that has been recently deleted. For example, `my-other-app@appspot.gserviceaccount.com?uid=123456789012345678901`. If the service account is undeleted, this value reverts to `serviceAccount:{emailid\}` and the undeleted service account retains the role in the binding. * `deleted:group:{emailid\}?uid={uniqueid\}`: An email address (plus unique identifier) representing a Google group that has been recently deleted. For example, `admins@example.com?uid=123456789012345678901`. If the group is recovered, this value reverts to `group:{emailid\}` and the recovered group retains the role in the binding.
         */
        members?: string[] | null;
        /**
         * Role that is assigned to the list of `members`, or principals. For example, `roles/viewer`, `roles/editor`, or `roles/owner`.
         */
        role?: string | null;
    }
    /**
     * A transient resource used in compute.disks.bulkInsert and compute.regionDisks.bulkInsert. It is only used to process requests and is not persisted.
     */
    export interface Schema$BulkInsertDiskResource {
        /**
         * The URL of the DiskConsistencyGroupPolicy for the group of disks to clone. This may be a full or partial URL, such as: - https://www.googleapis.com/compute/v1/projects/project/regions/region /resourcePolicies/resourcePolicy - projects/project/regions/region/resourcePolicies/resourcePolicy - regions/region/resourcePolicies/resourcePolicy
         */
        sourceConsistencyGroupPolicy?: string | null;
    }
    /**
     * A transient resource used in compute.instances.bulkInsert and compute.regionInstances.bulkInsert . This resource is not persisted anywhere, it is used only for processing the requests.
     */
    export interface Schema$BulkInsertInstanceResource {
        /**
         * The maximum number of instances to create.
         */
        count?: string | null;
        /**
         * The instance properties defining the VM instances to be created. Required if sourceInstanceTemplate is not provided.
         */
        instanceProperties?: Schema$InstanceProperties;
        /**
         * Policy for chosing target zone. For more information, see Create VMs in bulk .
         */
        locationPolicy?: Schema$LocationPolicy;
        /**
         * The minimum number of instances to create. If no min_count is specified then count is used as the default value. If min_count instances cannot be created, then no instances will be created and instances already created will be deleted.
         */
        minCount?: string | null;
        /**
         * The string pattern used for the names of the VMs. Either name_pattern or per_instance_properties must be set. The pattern must contain one continuous sequence of placeholder hash characters (#) with each character corresponding to one digit of the generated instance name. Example: a name_pattern of inst-#### generates instance names such as inst-0001 and inst-0002. If existing instances in the same project and zone have names that match the name pattern then the generated instance numbers start after the biggest existing number. For example, if there exists an instance with name inst-0050, then instance names generated using the pattern inst-#### begin with inst-0051. The name pattern placeholder #...# can contain up to 18 characters.
         */
        namePattern?: string | null;
        /**
         * Per-instance properties to be set on individual instances. Keys of this map specify requested instance names. Can be empty if name_pattern is used.
         */
        perInstanceProperties?: {
            [key: string]: Schema$BulkInsertInstanceResourcePerInstanceProperties;
        } | null;
        /**
         * Specifies the instance template from which to create instances. You may combine sourceInstanceTemplate with instanceProperties to override specific values from an existing instance template. Bulk API follows the semantics of JSON Merge Patch described by RFC 7396. It can be a full or partial URL. For example, the following are all valid URLs to an instance template: - https://www.googleapis.com/compute/v1/projects/project /global/instanceTemplates/instanceTemplate - projects/project/global/instanceTemplates/instanceTemplate - global/instanceTemplates/instanceTemplate This field is optional.
         */
        sourceInstanceTemplate?: string | null;
    }
    /**
     * Per-instance properties to be set on individual instances. To be extended in the future.
     */
    export interface Schema$BulkInsertInstanceResourcePerInstanceProperties {
        /**
         * Specifies the hostname of the instance. More details in: https://cloud.google.com/compute/docs/instances/custom-hostname-vm#naming_convention
         */
        hostname?: string | null;
        /**
         * This field is only temporary. It will be removed. Do not use it.
         */
        name?: string | null;
    }
    export interface Schema$BulkInsertOperationStatus {
        /**
         * [Output Only] Count of VMs successfully created so far.
         */
        createdVmCount?: number | null;
        /**
         * [Output Only] Count of VMs that got deleted during rollback.
         */
        deletedVmCount?: number | null;
        /**
         * [Output Only] Count of VMs that started creating but encountered an error.
         */
        failedToCreateVmCount?: number | null;
        /**
         * [Output Only] Creation status of BulkInsert operation - information if the flow is rolling forward or rolling back.
         */
        status?: string | null;
        /**
         * [Output Only] Count of VMs originally planned to be created.
         */
        targetVmCount?: number | null;
    }
    export interface Schema$BundledLocalSsds {
        /**
         * The default disk interface if the interface is not specified.
         */
        defaultInterface?: string | null;
        /**
         * The number of partitions.
         */
        partitionCount?: number | null;
    }
    export interface Schema$CacheInvalidationRule {
        /**
         * If set, this invalidation rule will only apply to requests with a Host header matching host.
         */
        host?: string | null;
        path?: string | null;
    }
    /**
     * Message containing what to include in the cache key for a request for Cloud CDN.
     */
    export interface Schema$CacheKeyPolicy {
        /**
         * If true, requests to different hosts will be cached separately.
         */
        includeHost?: boolean | null;
        /**
         * Allows HTTP request headers (by name) to be used in the cache key.
         */
        includeHttpHeaders?: string[] | null;
        /**
         * Allows HTTP cookies (by name) to be used in the cache key. The name=value pair will be used in the cache key Cloud CDN generates.
         */
        includeNamedCookies?: string[] | null;
        /**
         * If true, http and https requests will be cached separately.
         */
        includeProtocol?: boolean | null;
        /**
         * If true, include query string parameters in the cache key according to query_string_whitelist and query_string_blacklist. If neither is set, the entire query string will be included. If false, the query string will be excluded from the cache key entirely.
         */
        includeQueryString?: boolean | null;
        /**
         * Names of query string parameters to exclude in cache keys. All other parameters will be included. Either specify query_string_whitelist or query_string_blacklist, not both. '&' and '=' will be percent encoded and not treated as delimiters.
         */
        queryStringBlacklist?: string[] | null;
        /**
         * Names of query string parameters to include in cache keys. All other parameters will be excluded. Either specify query_string_whitelist or query_string_blacklist, not both. '&' and '=' will be percent encoded and not treated as delimiters.
         */
        queryStringWhitelist?: string[] | null;
    }
    /**
     * [Deprecated] gRPC call credentials to access the SDS server. gRPC call credentials to access the SDS server.
     */
    export interface Schema$CallCredentials {
        /**
         * The type of call credentials to use for GRPC requests to the SDS server. This field can be set to one of the following: - GCE_VM: The local GCE VM service account credentials are used to access the SDS server. - FROM_PLUGIN: Custom authenticator credentials are used to access the SDS server.
         */
        callCredentialType?: string | null;
        /**
         * Custom authenticator credentials. Valid if callCredentialType is FROM_PLUGIN.
         */
        fromPlugin?: Schema$MetadataCredentialsFromPlugin;
    }
    /**
     * [Deprecated] gRPC channel credentials to access the SDS server. gRPC channel credentials to access the SDS server.
     */
    export interface Schema$ChannelCredentials {
        /**
         * The call credentials to access the SDS server.
         */
        certificates?: Schema$TlsCertificatePaths;
        /**
         * The channel credentials to access the SDS server. This field can be set to one of the following: CERTIFICATES: Use TLS certificates to access the SDS server. GCE_VM: Use local GCE VM credentials to access the SDS server.
         */
        channelCredentialType?: string | null;
    }
    /**
     * Settings controlling the volume of requests, connections and retries to this backend service.
     */
    export interface Schema$CircuitBreakers {
        /**
         * The timeout for new network connections to hosts.
         */
        connectTimeout?: Schema$Duration;
        /**
         * The maximum number of connections to the backend service. If not specified, there is no limit. Not supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true.
         */
        maxConnections?: number | null;
        /**
         * The maximum number of pending requests allowed to the backend service. If not specified, there is no limit. Not supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true.
         */
        maxPendingRequests?: number | null;
        /**
         * The maximum number of parallel requests that allowed to the backend service. If not specified, there is no limit.
         */
        maxRequests?: number | null;
        /**
         * Maximum requests for a single connection to the backend service. This parameter is respected by both the HTTP/1.1 and HTTP/2 implementations. If not specified, there is no limit. Setting this parameter to 1 will effectively disable keep alive. Not supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true.
         */
        maxRequestsPerConnection?: number | null;
        /**
         * The maximum number of parallel retries allowed to the backend cluster. If not specified, the default is 1. Not supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true.
         */
        maxRetries?: number | null;
    }
    /**
     * [Deprecated] The client side authentication settings for connection originating from the backend service. the backend service.
     */
    export interface Schema$ClientTlsSettings {
        /**
         * Configures the mechanism to obtain client-side security certificates and identity information. This field is only applicable when mode is set to MUTUAL.
         */
        clientTlsContext?: Schema$TlsContext;
        /**
         * Indicates whether connections to this port should be secured using TLS. The value of this field determines how TLS is enforced. This can be set to one of the following values: DISABLE: Do not setup a TLS connection to the backends. SIMPLE: Originate a TLS connection to the backends. MUTUAL: Secure connections to the backends using mutual TLS by presenting client certificates for authentication.
         */
        mode?: string | null;
        /**
         * SNI string to present to the server during TLS handshake. This field is applicable only when mode is SIMPLE or MUTUAL.
         */
        sni?: string | null;
        /**
         * A list of alternate names to verify the subject identity in the certificate.If specified, the proxy will verify that the server certificate's subject alt name matches one of the specified values. This field is applicable only when mode is SIMPLE or MUTUAL.
         */
        subjectAltNames?: string[] | null;
    }
    /**
     * Represents a regional Commitment resource. Creating a commitment resource means that you are purchasing a committed use contract with an explicit start and end time. You can create commitments based on vCPUs and memory usage and receive discounted rates. For full details, read Signing Up for Committed Use Discounts.
     */
    export interface Schema$Commitment {
        /**
         * Specifies whether to enable automatic renewal for the commitment. The default value is false if not specified. The field can be updated until the day of the commitment expiration at 12:00am PST. If the field is set to true, the commitment will be automatically renewed for either one or three years according to the terms of the existing commitment.
         */
        autoRenew?: boolean | null;
        /**
         * The category of the commitment. Category MACHINE specifies commitments composed of machine resources such as VCPU or MEMORY, listed in resources. Category LICENSE specifies commitments composed of software licenses, listed in licenseResources. Note that only MACHINE commitments should have a Type specified.
         */
        category?: string | null;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * [Output Only] Commitment end time in RFC3339 text format.
         */
        endTimestamp?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#commitment for commitments.
         */
        kind?: string | null;
        /**
         * The license specification required as part of a license commitment.
         */
        licenseResource?: Schema$LicenseResourceCommitment;
        /**
         * List of source commitments to be merged into a new commitment.
         */
        mergeSourceCommitments?: string[] | null;
        /**
         * Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * The plan for this commitment, which determines duration and discount rate. The currently supported plans are TWELVE_MONTH (1 year), and THIRTY_SIX_MONTH (3 years).
         */
        plan?: string | null;
        /**
         * [Output Only] URL of the region where this commitment may be used.
         */
        region?: string | null;
        /**
         * List of create-on-create reseravtions for this commitment.
         */
        reservations?: Schema$Reservation[];
        /**
         * A list of commitment amounts for particular resources. Note that VCPU and MEMORY resource commitments must occur together.
         */
        resources?: Schema$ResourceCommitment[];
        /**
         * [Output Only] Status information for Commitment resource.
         */
        resourceStatus?: Schema$CommitmentResourceStatus;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * Source commitment to be split into a new commitment.
         */
        splitSourceCommitment?: string | null;
        /**
         * [Output Only] Commitment start time in RFC3339 text format.
         */
        startTimestamp?: string | null;
        /**
         * [Output Only] Status of the commitment with regards to eventual expiration (each commitment has an end date defined). One of the following values: NOT_YET_ACTIVE, ACTIVE, EXPIRED.
         */
        status?: string | null;
        /**
         * [Output Only] An optional, human-readable explanation of the status.
         */
        statusMessage?: string | null;
        /**
         * The type of commitment, which affects the discount rate and the eligible resources. Type MEMORY_OPTIMIZED specifies a commitment that will only apply to memory optimized machines. Type ACCELERATOR_OPTIMIZED specifies a commitment that will only apply to accelerator optimized machines.
         */
        type?: string | null;
    }
    export interface Schema$CommitmentAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of CommitmentsScopedList resources.
         */
        items?: {
            [key: string]: Schema$CommitmentsScopedList;
        } | null;
        /**
         * [Output Only] Type of resource. Always compute#commitmentAggregatedList for aggregated lists of commitments.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Contains a list of Commitment resources.
     */
    export interface Schema$CommitmentList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of Commitment resources.
         */
        items?: Schema$Commitment[];
        /**
         * [Output Only] Type of resource. Always compute#commitmentList for lists of commitments.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * [Output Only] Contains output only fields.
     */
    export interface Schema$CommitmentResourceStatus {
        /**
         * [Output Only] An optional, contains all the needed information of cancellation.
         */
        cancellationInformation?: Schema$CommitmentResourceStatusCancellationInformation;
    }
    export interface Schema$CommitmentResourceStatusCancellationInformation {
        /**
         * [Output Only] An optional amount of CUDs canceled so far in the last 365 days.
         */
        canceledCommitment?: Schema$Money;
        /**
         * [Output Only] An optional last update time of canceled_commitment. RFC3339 text format.
         */
        canceledCommitmentLastUpdatedTimestamp?: string | null;
        /**
         * [Output Only] An optional,the cancellation cap for how much commitments can be canceled in a rolling 365 per billing account.
         */
        cancellationCap?: Schema$Money;
        /**
         * [Output Only] An optional, cancellation fee.
         */
        cancellationFee?: Schema$Money;
        /**
         * [Output Only] An optional, cancellation fee expiration time. RFC3339 text format.
         */
        cancellationFeeExpirationTimestamp?: string | null;
    }
    export interface Schema$CommitmentsScopedList {
        /**
         * [Output Only] A list of commitments contained in this scope.
         */
        commitments?: Schema$Commitment[];
        /**
         * [Output Only] Informational warning which replaces the list of commitments when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * This is deprecated and has no effect. Do not use.
     */
    export interface Schema$Condition {
        /**
         * This is deprecated and has no effect. Do not use.
         */
        iam?: string | null;
        /**
         * This is deprecated and has no effect. Do not use.
         */
        op?: string | null;
        /**
         * This is deprecated and has no effect. Do not use.
         */
        svc?: string | null;
        /**
         * This is deprecated and has no effect. Do not use.
         */
        sys?: string | null;
        /**
         * This is deprecated and has no effect. Do not use.
         */
        values?: string[] | null;
    }
    /**
     * A set of Confidential Instance options.
     */
    export interface Schema$ConfidentialInstanceConfig {
        /**
         * Defines the type of technology used by the confidential instance.
         */
        confidentialInstanceType?: string | null;
        /**
         * Defines whether the instance should have confidential compute enabled.
         */
        enableConfidentialCompute?: boolean | null;
    }
    /**
     * Message containing connection draining configuration.
     */
    export interface Schema$ConnectionDraining {
        /**
         * Configures a duration timeout for existing requests on a removed backend instance. For supported load balancers and protocols, as described in Enabling connection draining.
         */
        drainingTimeoutSec?: number | null;
    }
    /**
     * This message defines settings for a consistent hash style load balancer.
     */
    export interface Schema$ConsistentHashLoadBalancerSettings {
        /**
         * Hash is based on HTTP Cookie. This field describes a HTTP cookie that will be used as the hash key for the consistent hash load balancer. If the cookie is not present, it will be generated. This field is applicable if the sessionAffinity is set to HTTP_COOKIE. Not supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true.
         */
        httpCookie?: Schema$ConsistentHashLoadBalancerSettingsHttpCookie;
        /**
         * The hash based on the value of the specified header field. This field is applicable if the sessionAffinity is set to HEADER_FIELD.
         */
        httpHeaderName?: string | null;
        /**
         * The minimum number of virtual nodes to use for the hash ring. Defaults to 1024. Larger ring sizes result in more granular load distributions. If the number of hosts in the load balancing pool is larger than the ring size, each host will be assigned a single virtual node.
         */
        minimumRingSize?: string | null;
    }
    /**
     * The information about the HTTP Cookie on which the hash function is based for load balancing policies that use a consistent hash.
     */
    export interface Schema$ConsistentHashLoadBalancerSettingsHttpCookie {
        /**
         * Name of the cookie.
         */
        name?: string | null;
        /**
         * Path to set for the cookie.
         */
        path?: string | null;
        /**
         * Lifetime of the cookie.
         */
        ttl?: Schema$Duration;
    }
    /**
     * The specification for allowing client-side cross-origin requests. For more information about the W3C recommendation for cross-origin resource sharing (CORS), see Fetch API Living Standard.
     */
    export interface Schema$CorsPolicy {
        /**
         * In response to a preflight request, setting this to true indicates that the actual request can include user credentials. This field translates to the Access-Control-Allow-Credentials header. Default is false.
         */
        allowCredentials?: boolean | null;
        /**
         * Specifies the content for the Access-Control-Allow-Headers header.
         */
        allowHeaders?: string[] | null;
        /**
         * Specifies the content for the Access-Control-Allow-Methods header.
         */
        allowMethods?: string[] | null;
        /**
         * Specifies a regular expression that matches allowed origins. For more information about the regular expression syntax, see Syntax. An origin is allowed if it matches either an item in allowOrigins or an item in allowOriginRegexes. Regular expressions can only be used when the loadBalancingScheme is set to INTERNAL_SELF_MANAGED.
         */
        allowOriginRegexes?: string[] | null;
        /**
         * Specifies the list of origins that is allowed to do CORS requests. An origin is allowed if it matches either an item in allowOrigins or an item in allowOriginRegexes.
         */
        allowOrigins?: string[] | null;
        /**
         * If true, the setting specifies the CORS policy is disabled. The default value of false, which indicates that the CORS policy is in effect.
         */
        disabled?: boolean | null;
        /**
         * Specifies the content for the Access-Control-Expose-Headers header.
         */
        exposeHeaders?: string[] | null;
        /**
         * Specifies how long results of a preflight request can be cached in seconds. This field translates to the Access-Control-Max-Age header.
         */
        maxAge?: number | null;
    }
    export interface Schema$CustomerEncryptionKey {
        /**
         * The name of the encryption key that is stored in Google Cloud KMS. For example: "kmsKeyName": "projects/kms_project_id/locations/region/keyRings/ key_region/cryptoKeys/key The fully-qualifed key name may be returned for resource GET requests. For example: "kmsKeyName": "projects/kms_project_id/locations/region/keyRings/ key_region/cryptoKeys/key /cryptoKeyVersions/1
         */
        kmsKeyName?: string | null;
        /**
         * The service account being used for the encryption request for the given KMS key. If absent, the Compute Engine default service account is used. For example: "kmsKeyServiceAccount": "name@project_id.iam.gserviceaccount.com/
         */
        kmsKeyServiceAccount?: string | null;
        /**
         * Specifies a 256-bit customer-supplied encryption key, encoded in RFC 4648 base64 to either encrypt or decrypt this resource. You can provide either the rawKey or the rsaEncryptedKey. For example: "rawKey": "SGVsbG8gZnJvbSBHb29nbGUgQ2xvdWQgUGxhdGZvcm0="
         */
        rawKey?: string | null;
        /**
         * Specifies an RFC 4648 base64 encoded, RSA-wrapped 2048-bit customer-supplied encryption key to either encrypt or decrypt this resource. You can provide either the rawKey or the rsaEncryptedKey. For example: "rsaEncryptedKey": "ieCx/NcW06PcT7Ep1X6LUTc/hLvUDYyzSZPPVCVPTVEohpeHASqC8uw5TzyO9U+Fka9JFH z0mBibXUInrC/jEk014kCK/NPjYgEMOyssZ4ZINPKxlUh2zn1bV+MCaTICrdmuSBTWlUUiFoD D6PYznLwh8ZNdaheCeZ8ewEXgFQ8V+sDroLaN3Xs3MDTXQEMMoNUXMCZEIpg9Vtp9x2oe==" The key must meet the following requirements before you can provide it to Compute Engine: 1. The key is wrapped using a RSA public key certificate provided by Google. 2. After being wrapped, the key must be encoded in RFC 4648 base64 encoding. Gets the RSA public key certificate provided by Google at: https://cloud-certs.storage.googleapis.com/google-cloud-csek-ingress.pem
         */
        rsaEncryptedKey?: string | null;
        /**
         * [Output only] The RFC 4648 base64 encoded SHA-256 hash of the customer-supplied encryption key that protects this resource.
         */
        sha256?: string | null;
    }
    export interface Schema$CustomerEncryptionKeyProtectedDisk {
        /**
         * Decrypts data associated with the disk with a customer-supplied encryption key.
         */
        diskEncryptionKey?: Schema$CustomerEncryptionKey;
        /**
         * Specifies a valid partial or full URL to an existing Persistent Disk resource. This field is only applicable for persistent disks. For example: "source": "/compute/v1/projects/project_id/zones/zone/disks/ disk_name
         */
        source?: string | null;
    }
    /**
     * Specifies the custom error response policy that must be applied when the backend service or backend bucket responds with an error.
     */
    export interface Schema$CustomErrorResponsePolicy {
        /**
         * Specifies rules for returning error responses. In a given policy, if you specify rules for both a range of error codes as well as rules for specific error codes then rules with specific error codes have a higher priority. For example, assume that you configure a rule for 401 (Un-authorized) code, and another for all 4 series error codes (4XX). If the backend service returns a 401, then the rule for 401 will be applied. However if the backend service returns a 403, the rule for 4xx takes effect.
         */
        errorResponseRules?: Schema$CustomErrorResponsePolicyCustomErrorResponseRule[];
        /**
         * The full or partial URL to the BackendBucket resource that contains the custom error content. Examples are: - https://www.googleapis.com/compute/v1/projects/project/global/backendBuckets/myBackendBucket - compute/v1/projects/project/global/backendBuckets/myBackendBucket - global/backendBuckets/myBackendBucket If errorService is not specified at lower levels like pathMatcher, pathRule and routeRule, an errorService specified at a higher level in the UrlMap will be used. If UrlMap.defaultCustomErrorResponsePolicy contains one or more errorResponseRules[], it must specify errorService. If load balancer cannot reach the backendBucket, a simple Not Found Error will be returned, with the original response code (or overrideResponseCode if configured). errorService is not supported for internal or regional HTTP/HTTPS load balancers.
         */
        errorService?: string | null;
    }
    /**
     * Specifies the mapping between the response code that will be returned along with the custom error content and the response code returned by the backend service.
     */
    export interface Schema$CustomErrorResponsePolicyCustomErrorResponseRule {
        /**
         * Valid values include: - A number between 400 and 599: For example 401 or 503, in which case the load balancer applies the policy if the error code exactly matches this value. - 5xx: Load Balancer will apply the policy if the backend service responds with any response code in the range of 500 to 599. - 4xx: Load Balancer will apply the policy if the backend service responds with any response code in the range of 400 to 499. Values must be unique within matchResponseCodes and across all errorResponseRules of CustomErrorResponsePolicy.
         */
        matchResponseCodes?: string[] | null;
        /**
         * The HTTP status code returned with the response containing the custom error content. If overrideResponseCode is not supplied, the same response code returned by the original backend bucket or backend service is returned to the client.
         */
        overrideResponseCode?: number | null;
        /**
         * The full path to a file within backendBucket . For example: /errors/defaultError.html path must start with a leading slash. path cannot have trailing slashes. If the file is not available in backendBucket or the load balancer cannot reach the BackendBucket, a simple Not Found Error is returned to the client. The value must be from 1 to 1024 characters
         */
        path?: string | null;
    }
    /**
     * Deprecation status for a public resource.
     */
    export interface Schema$DeprecationStatus {
        /**
         * An optional RFC3339 timestamp on or after which the state of this resource is intended to change to DELETED. This is only informational and the status will not change unless the client explicitly changes it.
         */
        deleted?: string | null;
        /**
         * An optional RFC3339 timestamp on or after which the state of this resource is intended to change to DEPRECATED. This is only informational and the status will not change unless the client explicitly changes it.
         */
        deprecated?: string | null;
        /**
         * An optional RFC3339 timestamp on or after which the state of this resource is intended to change to OBSOLETE. This is only informational and the status will not change unless the client explicitly changes it.
         */
        obsolete?: string | null;
        /**
         * The URL of the suggested replacement for a deprecated resource. The suggested replacement resource must be the same kind of resource as the deprecated resource.
         */
        replacement?: string | null;
        /**
         * The deprecation state of this resource. This can be ACTIVE, DEPRECATED, OBSOLETE, or DELETED. Operations which communicate the end of life date for an image, can use ACTIVE. Operations which create a new resource using a DEPRECATED resource will return successfully, but with a warning indicating the deprecated resource and recommending its replacement. Operations which use OBSOLETE or DELETED resources will be rejected and result in an error.
         */
        state?: string | null;
        /**
         * The rollout policy for this deprecation. This policy is only enforced by image family views. The rollout policy restricts the zones where the associated resource is considered in a deprecated state. When the rollout policy does not include the user specified zone, or if the zone is rolled out, the associated resource is considered in a deprecated state. The rollout policy for this deprecation is read-only, except for allowlisted users. This field might not be configured. To view the latest non-deprecated image in a specific zone, use the imageFamilyViews.get method.
         */
        stateOverride?: Schema$RolloutPolicy;
    }
    /**
     * Represents a Persistent Disk resource. Google Compute Engine has two Disk resources: * [Zonal](/compute/docs/reference/rest/alpha/disks) * [Regional](/compute/docs/reference/rest/alpha/regionDisks) Persistent disks are required for running your VM instances. Create both boot and non-boot (data) persistent disks. For more information, read Persistent Disks. For more storage options, read Storage options. The disks resource represents a zonal persistent disk. For more information, read Zonal persistent disks. The regionDisks resource represents a regional persistent disk. For more information, read Regional resources.
     */
    export interface Schema$Disk {
        /**
         * The access mode of the disk. - READ_WRITE_SINGLE: The default AccessMode, means the disk can be attached to single instance in RW mode. - READ_WRITE_MANY: The AccessMode means the disk can be attached to multiple instances in RW mode. - READ_ONLY_MANY: The AccessMode means the disk can be attached to multiple instances in RO mode. The AccessMode is only valid for Hyperdisk disk types.
         */
        accessMode?: string | null;
        /**
         * The architecture of the disk. Valid values are ARM64 or X86_64.
         */
        architecture?: string | null;
        /**
         * Disk asynchronously replicated into this disk.
         */
        asyncPrimaryDisk?: Schema$DiskAsyncReplication;
        /**
         * [Output Only] A list of disks this disk is asynchronously replicated to.
         */
        asyncSecondaryDisks?: {
            [key: string]: Schema$DiskAsyncReplicationList;
        } | null;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * Encrypts the disk using a customer-supplied encryption key or a customer-managed encryption key. Encryption keys do not protect access to metadata of the disk. After you encrypt a disk with a customer-supplied key, you must provide the same key if you use the disk later. For example, to create a disk snapshot, to create a disk image, to create a machine image, or to attach the disk to a virtual machine. After you encrypt a disk with a customer-managed key, the diskEncryptionKey.kmsKeyName is set to a key *version* name once the disk is created. The disk is encrypted with this version of the key. In the response, diskEncryptionKey.kmsKeyName appears in the following format: "diskEncryptionKey.kmsKeyName": "projects/kms_project_id/locations/region/keyRings/ key_region/cryptoKeys/key /cryptoKeysVersions/version If you do not provide an encryption key when creating the disk, then the disk is encrypted using an automatically generated key and you don't need to provide a key to use the disk later.
         */
        diskEncryptionKey?: Schema$CustomerEncryptionKey;
        /**
         * Whether this disk is using confidential compute mode.
         */
        enableConfidentialCompute?: boolean | null;
        /**
         * Specifies whether the disk restored from a source snapshot should erase Windows specific VSS signature.
         */
        eraseWindowsVssSignature?: boolean | null;
        /**
         * A list of features to enable on the guest operating system. Applicable only for bootable images. Read Enabling guest operating system features to see a list of available options.
         */
        guestOsFeatures?: Schema$GuestOsFeature[];
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Deprecated] Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME. The default is SCSI.
         */
        interface?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#disk for disks.
         */
        kind?: string | null;
        /**
         * A fingerprint for the labels being applied to this disk, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a disk.
         */
        labelFingerprint?: string | null;
        /**
         * Labels to apply to this disk. These can be later modified by the setLabels method.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * [Output Only] Last attach timestamp in RFC3339 text format.
         */
        lastAttachTimestamp?: string | null;
        /**
         * [Output Only] Last detach timestamp in RFC3339 text format.
         */
        lastDetachTimestamp?: string | null;
        /**
         * Integer license codes indicating which licenses are attached to this disk.
         */
        licenseCodes?: string[] | null;
        /**
         * A list of publicly visible licenses. Reserved for Google's use.
         */
        licenses?: string[] | null;
        /**
         * An opaque location hint used to place the disk close to other resources. This field is for use by internal tools that use the public API.
         */
        locationHint?: string | null;
        /**
         * [Output Only] The field indicates if the disk is created from a locked source image. Attachment of a disk created from a locked source image will cause the following operations to become irreversibly prohibited: - R/W or R/O disk attachment to any other instance - Disk detachment. And the disk can only be deleted when the instance is deleted - Creation of images or snapshots - Disk cloning Furthermore, the instance with at least one disk with locked flag set to true will be prohibited from performing the operations below: - Further attachment of secondary disks. - Detachment of any disks - Create machine images - Create instance template - Delete the instance with --keep-disk parameter set to true for locked disks - Attach a locked disk with --auto-delete parameter set to false
         */
        locked?: boolean | null;
        /**
         * Indicates whether or not the disk can be read/write attached to more than one instance.
         */
        multiWriter?: boolean | null;
        /**
         * Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * Internal use only.
         */
        options?: string | null;
        /**
         * Input only. [Input Only] Additional params passed with the request, but not persisted as part of resource payload.
         */
        params?: Schema$DiskParams;
        /**
         * Physical block size of the persistent disk, in bytes. If not present in a request, a default value is used. The currently supported size is 4096, other sizes may be added in the future. If an unsupported value is requested, the error message will list the supported values for the caller's project.
         */
        physicalBlockSizeBytes?: string | null;
        /**
         * Indicates how many IOPS to provision for the disk. This sets the number of I/O operations per second that the disk can handle. Values must be between 10,000 and 120,000. For more details, see the Extreme persistent disk documentation.
         */
        provisionedIops?: string | null;
        /**
         * Indicates how much throughput to provision for the disk. This sets the number of throughput mb per second that the disk can handle. Values must be between 1 and 7,124.
         */
        provisionedThroughput?: string | null;
        /**
         * [Output Only] URL of the region where the disk resides. Only applicable for regional resources. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
         */
        region?: string | null;
        /**
         * URLs of the zones where the disk should be replicated to. Only applicable for regional resources.
         */
        replicaZones?: string[] | null;
        /**
         * Resource policies applied to this disk for automatic snapshot creations.
         */
        resourcePolicies?: string[] | null;
        /**
         * [Output Only] Status information for the disk resource.
         */
        resourceStatus?: Schema$DiskResourceStatus;
        /**
         * [Output Only] Reserved for future use.
         */
        satisfiesPzs?: boolean | null;
        /**
         * [Output Only] Server-defined fully-qualified URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource's resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * Size, in GB, of the persistent disk. You can specify this field when creating a persistent disk using the sourceImage, sourceSnapshot, or sourceDisk parameter, or specify it alone to create an empty persistent disk. If you specify this field along with a source, the value of sizeGb must not be less than the size of the source. Acceptable values are greater than 0.
         */
        sizeGb?: string | null;
        /**
         * [Output Only] URL of the DiskConsistencyGroupPolicy for a secondary disk that was created using a consistency group.
         */
        sourceConsistencyGroupPolicy?: string | null;
        /**
         * [Output Only] ID of the DiskConsistencyGroupPolicy for a secondary disk that was created using a consistency group.
         */
        sourceConsistencyGroupPolicyId?: string | null;
        /**
         * The source disk used to create this disk. You can provide this as a partial or full URL to the resource. For example, the following are valid values: - https://www.googleapis.com/compute/v1/projects/project/zones/zone /disks/disk - https://www.googleapis.com/compute/v1/projects/project/regions/region /disks/disk - projects/project/zones/zone/disks/disk - projects/project/regions/region/disks/disk - zones/zone/disks/disk - regions/region/disks/disk
         */
        sourceDisk?: string | null;
        /**
         * [Output Only] The unique ID of the disk used to create this disk. This value identifies the exact disk that was used to create this persistent disk. For example, if you created the persistent disk from a disk that was later deleted and recreated under the same name, the source disk ID would identify the exact version of the disk that was used.
         */
        sourceDiskId?: string | null;
        /**
         * The source image used to create this disk. If the source image is deleted, this field will not be set. To create a disk with one of the public operating system images, specify the image by its family name. For example, specify family/debian-9 to use the latest Debian 9 image: projects/debian-cloud/global/images/family/debian-9 Alternatively, use a specific version of a public operating system image: projects/debian-cloud/global/images/debian-9-stretch-vYYYYMMDD To create a disk with a custom image that you created, specify the image name in the following format: global/images/my-custom-image You can also specify a custom image by its image family, which returns the latest version of the image in that family. Replace the image name with family/family-name: global/images/family/my-image-family
         */
        sourceImage?: string | null;
        /**
         * The customer-supplied encryption key of the source image. Required if the source image is protected by a customer-supplied encryption key.
         */
        sourceImageEncryptionKey?: Schema$CustomerEncryptionKey;
        /**
         * [Output Only] The ID value of the image used to create this disk. This value identifies the exact image that was used to create this persistent disk. For example, if you created the persistent disk from an image that was later deleted and recreated under the same name, the source image ID would identify the exact version of the image that was used.
         */
        sourceImageId?: string | null;
        /**
         * The source instant snapshot used to create this disk. You can provide this as a partial or full URL to the resource. For example, the following are valid values: - https://www.googleapis.com/compute/v1/projects/project/zones/zone /instantSnapshots/instantSnapshot - projects/project/zones/zone/instantSnapshots/instantSnapshot - zones/zone/instantSnapshots/instantSnapshot
         */
        sourceInstantSnapshot?: string | null;
        /**
         * [Output Only] The unique ID of the instant snapshot used to create this disk. This value identifies the exact instant snapshot that was used to create this persistent disk. For example, if you created the persistent disk from an instant snapshot that was later deleted and recreated under the same name, the source instant snapshot ID would identify the exact version of the instant snapshot that was used.
         */
        sourceInstantSnapshotId?: string | null;
        /**
         * The source snapshot used to create this disk. You can provide this as a partial or full URL to the resource. For example, the following are valid values: - https://www.googleapis.com/compute/v1/projects/project /global/snapshots/snapshot - projects/project/global/snapshots/snapshot - global/snapshots/snapshot
         */
        sourceSnapshot?: string | null;
        /**
         * The customer-supplied encryption key of the source snapshot. Required if the source snapshot is protected by a customer-supplied encryption key.
         */
        sourceSnapshotEncryptionKey?: Schema$CustomerEncryptionKey;
        /**
         * [Output Only] The unique ID of the snapshot used to create this disk. This value identifies the exact snapshot that was used to create this persistent disk. For example, if you created the persistent disk from a snapshot that was later deleted and recreated under the same name, the source snapshot ID would identify the exact version of the snapshot that was used.
         */
        sourceSnapshotId?: string | null;
        /**
         * The full Google Cloud Storage URI where the disk image is stored. This file must be a gzip-compressed tarball whose name ends in .tar.gz or virtual machine disk whose name ends in vmdk. Valid URIs may start with gs:// or https://storage.googleapis.com/. This flag is not optimized for creating multiple disks from a source storage object. To create many disks from a source storage object, use gcloud compute images import instead.
         */
        sourceStorageObject?: string | null;
        /**
         * [Output Only] The status of disk creation. - CREATING: Disk is provisioning. - RESTORING: Source data is being copied into the disk. - FAILED: Disk creation failed. - READY: Disk is ready for use. - DELETING: Disk is deleting.
         */
        status?: string | null;
        /**
         * The storage pool in which the new disk is created. You can provide this as a partial or full URL to the resource. For example, the following are valid values: - https://www.googleapis.com/compute/v1/projects/project/zones/zone /storagePools/storagePool - projects/project/zones/zone/storagePools/storagePool - zones/zone/storagePools/storagePool
         */
        storagePool?: string | null;
        /**
         * [Deprecated] Storage type of the persistent disk.
         */
        storageType?: string | null;
        /**
         * URL of the disk type resource describing which disk type to use to create the disk. Provide this when creating the disk. For example: projects/project /zones/zone/diskTypes/pd-ssd . See Persistent disk types.
         */
        type?: string | null;
        /**
         * A list of publicly visible user-licenses. Unlike regular licenses, user provided licenses can be modified after the disk is created. This includes a list of URLs to the license resource. For example, to provide a debian license: https://www.googleapis.com/compute/v1/projects/debian-cloud/global/licenses/debian-9-stretch
         */
        userLicenses?: string[] | null;
        /**
         * [Output Only] Links to the users of the disk (attached instances) in form: projects/project/zones/zone/instances/instance
         */
        users?: string[] | null;
        /**
         * [Output Only] URL of the zone where the disk resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
         */
        zone?: string | null;
    }
    export interface Schema$DiskAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of DisksScopedList resources.
         */
        items?: {
            [key: string]: Schema$DisksScopedList;
        } | null;
        /**
         * [Output Only] Type of resource. Always compute#diskAggregatedList for aggregated lists of persistent disks.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$DiskAsyncReplication {
        /**
         * [Output Only] URL of the DiskConsistencyGroupPolicy if replication was started on the disk as a member of a group.
         */
        consistencyGroupPolicy?: string | null;
        /**
         * [Output Only] ID of the DiskConsistencyGroupPolicy if replication was started on the disk as a member of a group.
         */
        consistencyGroupPolicyId?: string | null;
        /**
         * The other disk asynchronously replicated to or from the current disk. You can provide this as a partial or full URL to the resource. For example, the following are valid values: - https://www.googleapis.com/compute/v1/projects/project/zones/zone /disks/disk - projects/project/zones/zone/disks/disk - zones/zone/disks/disk
         */
        disk?: string | null;
        /**
         * [Output Only] The unique ID of the other disk asynchronously replicated to or from the current disk. This value identifies the exact disk that was used to create this replication. For example, if you started replicating the persistent disk from a disk that was later deleted and recreated under the same name, the disk ID would identify the exact version of the disk that was used.
         */
        diskId?: string | null;
    }
    export interface Schema$DiskAsyncReplicationList {
        asyncReplicationDisk?: Schema$DiskAsyncReplication;
    }
    /**
     * A specification of the desired way to instantiate a disk in the instance template when its created from a source instance.
     */
    export interface Schema$DiskInstantiationConfig {
        /**
         * Specifies whether the disk will be auto-deleted when the instance is deleted (but not when the disk is detached from the instance).
         */
        autoDelete?: boolean | null;
        /**
         * The custom source image to be used to restore this disk when instantiating this instance template.
         */
        customImage?: string | null;
        /**
         * Specifies the device name of the disk to which the configurations apply to.
         */
        deviceName?: string | null;
        /**
         * Specifies whether to include the disk and what image to use. Possible values are: - source-image: to use the same image that was used to create the source instance's corresponding disk. Applicable to the boot disk and additional read-write disks. - source-image-family: to use the same image family that was used to create the source instance's corresponding disk. Applicable to the boot disk and additional read-write disks. - custom-image: to use a user-provided image url for disk creation. Applicable to the boot disk and additional read-write disks. - attach-read-only: to attach a read-only disk. Applicable to read-only disks. - do-not-include: to exclude a disk from the template. Applicable to additional read-write disks, local SSDs, and read-only disks.
         */
        instantiateFrom?: string | null;
    }
    /**
     * A list of Disk resources.
     */
    export interface Schema$DiskList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of Disk resources.
         */
        items?: Schema$Disk[];
        /**
         * [Output Only] Type of resource. Always compute#diskList for lists of disks.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$DiskMoveRequest {
        /**
         * The URL of the destination zone to move the disk. This can be a full or partial URL. For example, the following are all valid URLs to a zone: - https://www.googleapis.com/compute/v1/projects/project/zones/zone - projects/project/zones/zone - zones/zone
         */
        destinationZone?: string | null;
        /**
         * The URL of the target disk to move. This can be a full or partial URL. For example, the following are all valid URLs to a disk: - https://www.googleapis.com/compute/v1/projects/project/zones/zone /disks/disk - projects/project/zones/zone/disks/disk - zones/zone/disks/disk
         */
        targetDisk?: string | null;
    }
    /**
     * Additional disk params.
     */
    export interface Schema$DiskParams {
        /**
         * Resource manager tags to be bound to the disk. Tag keys and values have the same definition as resource manager tags. Keys must be in the format `tagKeys/{tag_key_id\}`, and values are in the format `tagValues/456`. The field is ignored (both PUT & PATCH) when empty.
         */
        resourceManagerTags?: {
            [key: string]: string;
        } | null;
    }
    export interface Schema$DiskResourceStatus {
        asyncPrimaryDisk?: Schema$DiskResourceStatusAsyncReplicationStatus;
        /**
         * Key: disk, value: AsyncReplicationStatus message
         */
        asyncSecondaryDisks?: {
            [key: string]: Schema$DiskResourceStatusAsyncReplicationStatus;
        } | null;
        /**
         * [Output Only] Space used by data stored in the disk (in bytes). Note that this field is set only when the disk is in a storage pool.
         */
        usedBytes?: string | null;
    }
    export interface Schema$DiskResourceStatusAsyncReplicationStatus {
        state?: string | null;
    }
    export interface Schema$DisksAddResourcePoliciesRequest {
        /**
         * Full or relative path to the resource policy to be added to this disk. You can only specify one resource policy.
         */
        resourcePolicies?: string[] | null;
    }
    export interface Schema$DiskSettings {
        /**
         * An optional parameter for storing the default resource policies that will be used for the Disks created in the given scope. The Key is a string type, provided by customers to uniquely identify the default Resource Policy entry. The Value is a Default ResourcePolicyDetails Object used to represent the detailed information of the Resource Policy entry.
         */
        defaultResourcePolicies?: {
            [key: string]: Schema$DiskSettingsResourcePolicyDetails;
        } | null;
    }
    /**
     * This is the object for storing the detail information about the Resource Policy that will be set as default ones for the Disks that is using the DiskSettings. It contains: - one target Resource Policy referenced by its Fully-Qualified URL, - [output only] Disk Types that will be excluded from using this Resource Policy, - Other filtering support (e.g. Label filtering) for Default Resource Policy can be added here as well
     */
    export interface Schema$DiskSettingsResourcePolicyDetails {
        /**
         * [Output Only] A list of Disk Types that will be excluded from applying the Resource Policy referenced here. If absent, Disks created in any DiskType can use the referenced default Resource Policy.
         */
        excludedDiskTypes?: string[] | null;
        /**
         * The target Resource Policies identified by their Fully-Qualified URL.
         */
        resourcePolicy?: string | null;
    }
    export interface Schema$DisksRemoveResourcePoliciesRequest {
        /**
         * Resource policies to be removed from this disk.
         */
        resourcePolicies?: string[] | null;
    }
    export interface Schema$DisksResizeRequest {
        /**
         * The new size of the persistent disk, which is specified in GB.
         */
        sizeGb?: string | null;
    }
    export interface Schema$DisksScopedList {
        /**
         * [Output Only] A list of disks contained in this scope.
         */
        disks?: Schema$Disk[];
        /**
         * [Output Only] Informational warning which replaces the list of disks when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$DisksStartAsyncReplicationRequest {
        /**
         * The secondary disk to start asynchronous replication to. You can provide this as a partial or full URL to the resource. For example, the following are valid values: - https://www.googleapis.com/compute/v1/projects/project/zones/zone /disks/disk - https://www.googleapis.com/compute/v1/projects/project/regions/region /disks/disk - projects/project/zones/zone/disks/disk - projects/project/regions/region/disks/disk - zones/zone/disks/disk - regions/region/disks/disk
         */
        asyncSecondaryDisk?: string | null;
    }
    /**
     * A transient resource used in compute.disks.stopGroupAsyncReplication and compute.regionDisks.stopGroupAsyncReplication. It is only used to process requests and is not persisted.
     */
    export interface Schema$DisksStopGroupAsyncReplicationResource {
        /**
         * The URL of the DiskConsistencyGroupPolicy for the group of disks to stop. This may be a full or partial URL, such as: - https://www.googleapis.com/compute/v1/projects/project/regions/region /resourcePolicies/resourcePolicy - projects/project/regions/region/resourcePolicies/resourcePolicy - regions/region/resourcePolicies/resourcePolicy
         */
        resourcePolicy?: string | null;
    }
    /**
     * Represents a Disk Type resource. Google Compute Engine has two Disk Type resources: * [Regional](/compute/docs/reference/rest/alpha/regionDiskTypes) * [Zonal](/compute/docs/reference/rest/alpha/diskTypes) You can choose from a variety of disk types based on your needs. For more information, read Storage options. The diskTypes resource represents disk types for a zonal persistent disk. For more information, read Zonal persistent disks. The regionDiskTypes resource represents disk types for a regional persistent disk. For more information, read Regional persistent disks.
     */
    export interface Schema$DiskType {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * [Output Only] Server-defined default disk size in GB.
         */
        defaultDiskSizeGb?: string | null;
        /**
         * [Output Only] The deprecation status associated with this disk type.
         */
        deprecated?: Schema$DeprecationStatus;
        /**
         * [Output Only] An optional description of this resource.
         */
        description?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#diskType for disk types.
         */
        kind?: string | null;
        /**
         * [Output Only] Name of the resource.
         */
        name?: string | null;
        /**
         * [Output Only] URL of the region where the disk type resides. Only applicable for regional resources. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
         */
        region?: string | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * [Output Only] An optional textual description of the valid disk size, such as "10GB-10TB".
         */
        validDiskSize?: string | null;
        /**
         * [Output Only] URL of the zone where the disk type resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
         */
        zone?: string | null;
    }
    export interface Schema$DiskTypeAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of DiskTypesScopedList resources.
         */
        items?: {
            [key: string]: Schema$DiskTypesScopedList;
        } | null;
        /**
         * [Output Only] Type of resource. Always compute#diskTypeAggregatedList.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Contains a list of disk types.
     */
    export interface Schema$DiskTypeList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of DiskType resources.
         */
        items?: Schema$DiskType[];
        /**
         * [Output Only] Type of resource. Always compute#diskTypeList for disk types.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$DiskTypesScopedList {
        /**
         * [Output Only] A list of disk types contained in this scope.
         */
        diskTypes?: Schema$DiskType[];
        /**
         * [Output Only] Informational warning which replaces the list of disk types when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * A set of Display Device options
     */
    export interface Schema$DisplayDevice {
        /**
         * Defines whether the instance has Display enabled.
         */
        enableDisplay?: boolean | null;
    }
    export interface Schema$DistributionPolicy {
        /**
         * The distribution shape to which the group converges either proactively or on resize events (depending on the value set in updatePolicy.instanceRedistributionType).
         */
        targetShape?: string | null;
        /**
         * Zones where the regional managed instance group will create and manage its instances.
         */
        zones?: Schema$DistributionPolicyZoneConfiguration[];
    }
    export interface Schema$DistributionPolicyZoneConfiguration {
        /**
         * The URL of the zone. The zone must exist in the region where the managed instance group is located.
         */
        zone?: string | null;
    }
    /**
     * A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years.
     */
    export interface Schema$Duration {
        /**
         * Span of time that's a fraction of a second at nanosecond resolution. Durations less than one second are represented with a 0 `seconds` field and a positive `nanos` field. Must be from 0 to 999,999,999 inclusive.
         */
        nanos?: number | null;
        /**
         * Span of time at a resolution of a second. Must be from 0 to 315,576,000,000 inclusive. Note: these bounds are computed from: 60 sec/min * 60 min/hr * 24 hr/day * 365.25 days/year * 10000 years
         */
        seconds?: string | null;
    }
    /**
     * Describes the cause of the error with structured details. Example of an error when contacting the "pubsub.googleapis.com" API when it is not enabled: { "reason": "API_DISABLED" "domain": "googleapis.com" "metadata": { "resource": "projects/123", "service": "pubsub.googleapis.com" \} \} This response indicates that the pubsub.googleapis.com API is not enabled. Example of an error that is returned when attempting to create a Spanner instance in a region that is out of stock: { "reason": "STOCKOUT" "domain": "spanner.googleapis.com", "metadata": { "availableRegions": "us-central1,us-east2" \} \}
     */
    export interface Schema$ErrorInfo {
        /**
         * The logical grouping to which the "reason" belongs. The error domain is typically the registered service name of the tool or product that generates the error. Example: "pubsub.googleapis.com". If the error is generated by some common infrastructure, the error domain must be a globally unique value that identifies the infrastructure. For Google API infrastructure, the error domain is "googleapis.com".
         */
        domain?: string | null;
        /**
         * Additional structured details about this error. Keys should match /[a-zA-Z0-9-_]/ and be limited to 64 characters in length. When identifying the current value of an exceeded limit, the units should be contained in the key, not the value. For example, rather than {"instanceLimit": "100/request"\}, should be returned as, {"instanceLimitPerRequest": "100"\}, if the client exceeds the number of instances that can be created in a single (batch) request.
         */
        metadatas?: {
            [key: string]: string;
        } | null;
        /**
         * The reason of the error. This is a constant value that identifies the proximate cause of the error. Error reasons are unique within a particular domain of errors. This should be at most 63 characters and match a regular expression of `A-Z+[A-Z0-9]`, which represents UPPER_SNAKE_CASE.
         */
        reason?: string | null;
    }
    export interface Schema$ExchangedPeeringRoute {
        /**
         * The destination range of the route.
         */
        destRange?: string | null;
        /**
         * True if the peering route has been imported from a peer. The actual import happens if the field networkPeering.importCustomRoutes is true for this network, and networkPeering.exportCustomRoutes is true for the peer network, and the import does not result in a route conflict.
         */
        imported?: boolean | null;
        /**
         * The region of peering route next hop, only applies to dynamic routes.
         */
        nextHopRegion?: string | null;
        /**
         * The priority of the peering route.
         */
        priority?: number | null;
        /**
         * The type of the peering route.
         */
        type?: string | null;
    }
    export interface Schema$ExchangedPeeringRoutesList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of ExchangedPeeringRoute resources.
         */
        items?: Schema$ExchangedPeeringRoute[];
        /**
         * [Output Only] Type of resource. Always compute#exchangedPeeringRoutesList for exchanged peering routes lists.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Represents a textual expression in the Common Expression Language (CEL) syntax. CEL is a C-like expression language. The syntax and semantics of CEL are documented at https://github.com/google/cel-spec. Example (Comparison): title: "Summary size limit" description: "Determines if a summary is less than 100 chars" expression: "document.summary.size() < 100" Example (Equality): title: "Requestor is owner" description: "Determines if requestor is the document owner" expression: "document.owner == request.auth.claims.email" Example (Logic): title: "Public documents" description: "Determine whether the document should be publicly visible" expression: "document.type != 'private' && document.type != 'internal'" Example (Data Manipulation): title: "Notification string" description: "Create a notification string with a timestamp." expression: "'New message received at ' + string(document.create_time)" The exact variables and functions that may be referenced within an expression are determined by the service that evaluates it. See the service documentation for additional information.
     */
    export interface Schema$Expr {
        /**
         * Optional. Description of the expression. This is a longer text which describes the expression, e.g. when hovered over it in a UI.
         */
        description?: string | null;
        /**
         * Textual representation of an expression in Common Expression Language syntax.
         */
        expression?: string | null;
        /**
         * Optional. String indicating the location of the expression for error reporting, e.g. a file name and a position in the file.
         */
        location?: string | null;
        /**
         * Optional. Title for the expression, i.e. a short string describing its purpose. This can be used e.g. in UIs which allow to enter the expression.
         */
        title?: string | null;
    }
    /**
     * Represents an external VPN gateway. External VPN gateway is the on-premises VPN gateway(s) or another cloud provider's VPN gateway that connects to your Google Cloud VPN gateway. To create a highly available VPN from Google Cloud Platform to your VPN gateway or another cloud provider's VPN gateway, you must create a external VPN gateway resource with information about the other gateway. For more information about using external VPN gateways, see Creating an HA VPN gateway and tunnel pair to a peer VPN.
     */
    export interface Schema$ExternalVpnGateway {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * A list of interfaces for this external VPN gateway. If your peer-side gateway is an on-premises gateway and non-AWS cloud providers' gateway, at most two interfaces can be provided for an external VPN gateway. If your peer side is an AWS virtual private gateway, four interfaces should be provided for an external VPN gateway.
         */
        interfaces?: Schema$ExternalVpnGatewayInterface[];
        /**
         * [Output Only] Type of the resource. Always compute#externalVpnGateway for externalVpnGateways.
         */
        kind?: string | null;
        /**
         * A fingerprint for the labels being applied to this ExternalVpnGateway, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve an ExternalVpnGateway.
         */
        labelFingerprint?: string | null;
        /**
         * Labels for this resource. These can only be added or modified by the setLabels method. Each label key/value pair must comply with RFC1035. Label values may be empty.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * Indicates the user-supplied redundancy type of this external VPN gateway.
         */
        redundancyType?: string | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
    }
    /**
     * The interface for the external VPN gateway.
     */
    export interface Schema$ExternalVpnGatewayInterface {
        /**
         * The numeric ID of this interface. The allowed input values for this id for different redundancy types of external VPN gateway: - SINGLE_IP_INTERNALLY_REDUNDANT - 0 - TWO_IPS_REDUNDANCY - 0, 1 - FOUR_IPS_REDUNDANCY - 0, 1, 2, 3
         */
        id?: number | null;
        /**
         * IP address of the interface in the external VPN gateway. Only IPv4 is supported. This IP address can be either from your on-premise gateway or another Cloud provider's VPN gateway, it cannot be an IP address from Google Compute Engine.
         */
        ipAddress?: string | null;
        /**
         * IPv6 address of the interface in the external VPN gateway. This IPv6 address can be either from your on-premise gateway or another Cloud provider's VPN gateway, it cannot be an IP address from Google Compute Engine. Must specify an IPv6 address (not IPV4-mapped) using any format described in RFC 4291 (e.g. 2001:db8:0:0:2d9:51:0:0). The output format is RFC 5952 format (e.g. 2001:db8::2d9:51:0:0).
         */
        ipv6Address?: string | null;
    }
    /**
     * Response to the list request, and contains a list of externalVpnGateways.
     */
    export interface Schema$ExternalVpnGatewayList {
        etag?: string | null;
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of ExternalVpnGateway resources.
         */
        items?: Schema$ExternalVpnGateway[];
        /**
         * [Output Only] Type of resource. Always compute#externalVpnGatewayList for lists of externalVpnGateways.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$FileContentBuffer {
        /**
         * The raw content in the secure keys file.
         */
        content?: string | null;
        /**
         * The file type of source file.
         */
        fileType?: string | null;
    }
    /**
     * Represents a Firewall Rule resource. Firewall rules allow or deny ingress traffic to, and egress traffic from your instances. For more information, read Firewall rules.
     */
    export interface Schema$Firewall {
        /**
         * The list of ALLOW rules specified by this firewall. Each rule specifies a protocol and port-range tuple that describes a permitted connection.
         */
        allowed?: Array<{
            IPProtocol?: string;
            ports?: string[];
        }> | null;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * The list of DENY rules specified by this firewall. Each rule specifies a protocol and port-range tuple that describes a denied connection.
         */
        denied?: Array<{
            IPProtocol?: string;
            ports?: string[];
        }> | null;
        /**
         * An optional description of this resource. Provide this field when you create the resource.
         */
        description?: string | null;
        /**
         * If destination ranges are specified, the firewall rule applies only to traffic that has destination IP address in these ranges. These ranges must be expressed in CIDR format. Both IPv4 and IPv6 are supported.
         */
        destinationRanges?: string[] | null;
        /**
         * Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields.
         */
        direction?: string | null;
        /**
         * Denotes whether the firewall rule is disabled. When set to true, the firewall rule is not enforced and the network behaves as if it did not exist. If this is unspecified, the firewall rule will be enabled.
         */
        disabled?: boolean | null;
        /**
         * Deprecated in favor of enable in LogConfig. This field denotes whether to enable logging for a particular firewall rule. If logging is enabled, logs will be exported t Cloud Logging.
         */
        enableLogging?: boolean | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#firewall for firewall rules.
         */
        kind?: string | null;
        /**
         * This field denotes the logging options for a particular firewall rule. If logging is enabled, logs will be exported to Cloud Logging.
         */
        logConfig?: Schema$FirewallLogConfig;
        /**
         * Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?`. The first character must be a lowercase letter, and all following characters (except for the last character) must be a dash, lowercase letter, or digit. The last character must be a lowercase letter or digit.
         */
        name?: string | null;
        /**
         * URL of the network resource for this firewall rule. If not specified when creating a firewall rule, the default network is used: global/networks/default If you choose to specify this field, you can specify the network as a full or partial URL. For example, the following are all valid URLs: - https://www.googleapis.com/compute/v1/projects/myproject/global/networks/my-network - projects/myproject/global/networks/my-network - global/networks/default
         */
        network?: string | null;
        /**
         * Priority for this rule. This is an integer between `0` and `65535`, both inclusive. The default value is `1000`. Relative priorities determine which rule takes effect if multiple rules apply. Lower values indicate higher priority. For example, a rule with priority `0` has higher precedence than a rule with priority `1`. DENY rules take precedence over ALLOW rules if they have equal priority. Note that VPC networks have implied rules with a priority of `65535`. To avoid conflicts with the implied rules, use a priority number less than `65535`.
         */
        priority?: number | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * If source ranges are specified, the firewall rule applies only to traffic that has a source IP address in these ranges. These ranges must be expressed in CIDR format. One or both of sourceRanges and sourceTags may be set. If both fields are set, the rule applies to traffic that has a source IP address within sourceRanges OR a source IP from a resource with a matching tag listed in the sourceTags field. The connection does not need to match both fields for the rule to apply. Both IPv4 and IPv6 are supported.
         */
        sourceRanges?: string[] | null;
        /**
         * If source service accounts are specified, the firewall rules apply only to traffic originating from an instance with a service account in this list. Source service accounts cannot be used to control traffic to an instance's external IP address because service accounts are associated with an instance, not an IP address. sourceRanges can be set at the same time as sourceServiceAccounts. If both are set, the firewall applies to traffic that has a source IP address within the sourceRanges OR a source IP that belongs to an instance with service account listed in sourceServiceAccount. The connection does not need to match both fields for the firewall to apply. sourceServiceAccounts cannot be used at the same time as sourceTags or targetTags.
         */
        sourceServiceAccounts?: string[] | null;
        /**
         * If source tags are specified, the firewall rule applies only to traffic with source IPs that match the primary network interfaces of VM instances that have the tag and are in the same VPC network. Source tags cannot be used to control traffic to an instance's external IP address, it only applies to traffic between instances in the same virtual network. Because tags are associated with instances, not IP addresses. One or both of sourceRanges and sourceTags may be set. If both fields are set, the firewall applies to traffic that has a source IP address within sourceRanges OR a source IP from a resource with a matching tag listed in the sourceTags field. The connection does not need to match both fields for the firewall to apply.
         */
        sourceTags?: string[] | null;
        /**
         * A list of service accounts indicating sets of instances located in the network that may make network connections as specified in allowed[]. targetServiceAccounts cannot be used at the same time as targetTags or sourceTags. If neither targetServiceAccounts nor targetTags are specified, the firewall rule applies to all instances on the specified network.
         */
        targetServiceAccounts?: string[] | null;
        /**
         * A list of tags that controls which instances the firewall rule applies to. If targetTags are specified, then the firewall rule applies only to instances in the VPC network that have one of those tags. If no targetTags are specified, the firewall rule applies to all instances on the specified network.
         */
        targetTags?: string[] | null;
    }
    /**
     * Contains a list of firewalls.
     */
    export interface Schema$FirewallList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of Firewall resources.
         */
        items?: Schema$Firewall[];
        /**
         * [Output Only] Type of resource. Always compute#firewallList for lists of firewalls.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * The available logging options for a firewall rule.
     */
    export interface Schema$FirewallLogConfig {
        /**
         * This field denotes whether to enable logging for a particular firewall rule.
         */
        enable?: boolean | null;
        /**
         * This field can only be specified for a particular firewall rule if logging is enabled for that rule. This field denotes whether to include or exclude metadata for firewall logs.
         */
        metadata?: string | null;
    }
    export interface Schema$FirewallPoliciesListAssociationsResponse {
        /**
         * A list of associations.
         */
        associations?: Schema$FirewallPolicyAssociation[];
        /**
         * [Output Only] Type of firewallPolicy associations. Always compute#FirewallPoliciesListAssociations for lists of firewallPolicy associations.
         */
        kind?: string | null;
    }
    /**
     * Represents a Firewall Policy resource.
     */
    export interface Schema$FirewallPolicy {
        /**
         * A list of associations that belong to this firewall policy.
         */
        associations?: Schema$FirewallPolicyAssociation[];
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * Deprecated, please use short name instead. User-provided name of the Organization firewall policy. The name should be unique in the organization in which the firewall policy is created. This field is not applicable to network firewall policies. This name must be set on creation and cannot be changed. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        displayName?: string | null;
        /**
         * Specifies a fingerprint for this resource, which is essentially a hash of the metadata's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update metadata. You must always provide an up-to-date fingerprint hash in order to update or change metadata, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make get() request to the firewall policy.
         */
        fingerprint?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output only] Type of the resource. Always compute#firewallPolicyfor firewall policies
         */
        kind?: string | null;
        /**
         * Name of the resource. For Organization Firewall Policies it's a [Output Only] numeric ID allocated by Google Cloud which uniquely identifies the Organization Firewall Policy.
         */
        name?: string | null;
        /**
         * [Output Only] The parent of the firewall policy. This field is not applicable to network firewall policies.
         */
        parent?: string | null;
        /**
         * [Output Only] URL of the region where the regional firewall policy resides. This field is not applicable to global firewall policies. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
         */
        region?: string | null;
        /**
         * A list of rules that belong to this policy. There must always be a default rule (rule with priority 2147483647 and match "*"). If no rules are provided when creating a firewall policy, a default rule with action "allow" will be added.
         */
        rules?: Schema$FirewallPolicyRule[];
        /**
         * [Output Only] Total count of all firewall policy rule tuples. A firewall policy can not exceed a set number of tuples.
         */
        ruleTupleCount?: number | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * User-provided name of the Organization firewall policy. The name should be unique in the organization in which the firewall policy is created. This field is not applicable to network firewall policies. This name must be set on creation and cannot be changed. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        shortName?: string | null;
        /**
         * The scope of networks allowed to be associated with the firewall policy. This field can be either GLOBAL_VPC_NETWORK or REGIONAL_VPC_NETWORK. A firewall policy with the VPC scope set to GLOBAL_VPC_NETWORK is allowed to be attached only to global networks. When the VPC scope is set to REGIONAL_VPC_NETWORK the firewall policy is allowed to be attached only to regional networks in the same scope as the firewall policy. Note: if not specified then GLOBAL_VPC_NETWORK will be used.
         */
        vpcNetworkScope?: string | null;
    }
    export interface Schema$FirewallPolicyAssociation {
        /**
         * The target that the firewall policy is attached to.
         */
        attachmentTarget?: string | null;
        /**
         * [Output Only] Deprecated, please use short name instead. The display name of the firewall policy of the association.
         */
        displayName?: string | null;
        /**
         * [Output Only] The firewall policy ID of the association.
         */
        firewallPolicyId?: string | null;
        /**
         * The name for an association.
         */
        name?: string | null;
        /**
         * An integer indicating the priority of an association. The priority must be a positive value between 1 and 2147483647. Firewall Policies are evaluated from highest to lowest priority where 1 is the highest priority and 2147483647 is the lowest priority. The default value is `1000`. If two associations have the same priority then lexicographical order on association names is applied.
         */
        priority?: number | null;
        /**
         * [Output Only] The short name of the firewall policy of the association.
         */
        shortName?: string | null;
    }
    export interface Schema$FirewallPolicyList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of FirewallPolicy resources.
         */
        items?: Schema$FirewallPolicy[];
        /**
         * [Output Only] Type of resource. Always compute#firewallPolicyList for listsof FirewallPolicies
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Represents a rule that describes one or more match conditions along with the action to be taken when traffic matches this condition (allow or deny).
     */
    export interface Schema$FirewallPolicyRule {
        /**
         * The Action to perform when the client connection triggers the rule. Valid actions are "allow", "deny" and "goto_next".
         */
        action?: string | null;
        /**
         * An optional description for this resource.
         */
        description?: string | null;
        /**
         * The direction in which this rule applies.
         */
        direction?: string | null;
        /**
         * Denotes whether the firewall policy rule is disabled. When set to true, the firewall policy rule is not enforced and traffic behaves as if it did not exist. If this is unspecified, the firewall policy rule will be enabled.
         */
        disabled?: boolean | null;
        /**
         * Denotes whether to enable logging for a particular rule. If logging is enabled, logs will be exported to the configured export destination in Stackdriver. Logs may be exported to BigQuery or Pub/Sub. Note: you cannot enable logging on "goto_next" rules.
         */
        enableLogging?: boolean | null;
        /**
         * [Output only] Type of the resource. Always compute#firewallPolicyRule for firewall policy rules
         */
        kind?: string | null;
        /**
         * A match condition that incoming traffic is evaluated against. If it evaluates to true, the corresponding 'action' is enforced.
         */
        match?: Schema$FirewallPolicyRuleMatcher;
        /**
         * An integer indicating the priority of a rule in the list. The priority must be a positive value between 0 and 2147483647. Rules are evaluated from highest to lowest priority where 0 is the highest priority and 2147483647 is the lowest prority.
         */
        priority?: number | null;
        /**
         * An optional name for the rule. This field is not a unique identifier and can be updated.
         */
        ruleName?: string | null;
        /**
         * [Output Only] Calculation of the complexity of a single firewall policy rule.
         */
        ruleTupleCount?: number | null;
        /**
         * A fully-qualified URL of a SecurityProfile resource instance. Example: https://networksecurity.googleapis.com/v1/projects/{project\}/locations/{location\}/securityProfileGroups/my-security-profile-group Must be specified if action = 'apply_security_profile_group' and cannot be specified for other actions.
         */
        securityProfileGroup?: string | null;
        /**
         * A list of network resource URLs to which this rule applies. This field allows you to control which network's VMs get this rule. If this field is left blank, all VMs within the organization will receive the rule.
         */
        targetResources?: string[] | null;
        /**
         * A list of secure tags that controls which instances the firewall rule applies to. If targetSecureTag are specified, then the firewall rule applies only to instances in the VPC network that have one of those EFFECTIVE secure tags, if all the target_secure_tag are in INEFFECTIVE state, then this rule will be ignored. targetSecureTag may not be set at the same time as targetServiceAccounts. If neither targetServiceAccounts nor targetSecureTag are specified, the firewall rule applies to all instances on the specified network. Maximum number of target label tags allowed is 256.
         */
        targetSecureTags?: Schema$FirewallPolicyRuleSecureTag[];
        /**
         * A list of service accounts indicating the sets of instances that are applied with this rule.
         */
        targetServiceAccounts?: string[] | null;
        /**
         * Boolean flag indicating if the traffic should be TLS decrypted. Can be set only if action = 'apply_security_profile_group' and cannot be set for other actions.
         */
        tlsInspect?: boolean | null;
    }
    /**
     * Represents a match condition that incoming traffic is evaluated against. Exactly one field must be specified.
     */
    export interface Schema$FirewallPolicyRuleMatcher {
        /**
         * Address groups which should be matched against the traffic destination. Maximum number of destination address groups is 10.
         */
        destAddressGroups?: string[] | null;
        /**
         * Fully Qualified Domain Name (FQDN) which should be matched against traffic destination. Maximum number of destination fqdn allowed is 100.
         */
        destFqdns?: string[] | null;
        /**
         * CIDR IP address range. Maximum number of destination CIDR IP ranges allowed is 5000.
         */
        destIpRanges?: string[] | null;
        /**
         * Region codes whose IP addresses will be used to match for destination of traffic. Should be specified as 2 letter country code defined as per ISO 3166 alpha-2 country codes. ex."US" Maximum number of dest region codes allowed is 5000.
         */
        destRegionCodes?: string[] | null;
        /**
         * Names of Network Threat Intelligence lists. The IPs in these lists will be matched against traffic destination.
         */
        destThreatIntelligences?: string[] | null;
        /**
         * Pairs of IP protocols and ports that the rule should match.
         */
        layer4Configs?: Schema$FirewallPolicyRuleMatcherLayer4Config[];
        /**
         * Address groups which should be matched against the traffic source. Maximum number of source address groups is 10.
         */
        srcAddressGroups?: string[] | null;
        /**
         * Fully Qualified Domain Name (FQDN) which should be matched against traffic source. Maximum number of source fqdn allowed is 100.
         */
        srcFqdns?: string[] | null;
        /**
         * CIDR IP address range. Maximum number of source CIDR IP ranges allowed is 5000.
         */
        srcIpRanges?: string[] | null;
        /**
         * Region codes whose IP addresses will be used to match for source of traffic. Should be specified as 2 letter country code defined as per ISO 3166 alpha-2 country codes. ex."US" Maximum number of source region codes allowed is 5000.
         */
        srcRegionCodes?: string[] | null;
        /**
         * List of secure tag values, which should be matched at the source of the traffic. For INGRESS rule, if all the srcSecureTag are INEFFECTIVE, and there is no srcIpRange, this rule will be ignored. Maximum number of source tag values allowed is 256.
         */
        srcSecureTags?: Schema$FirewallPolicyRuleSecureTag[];
        /**
         * Names of Network Threat Intelligence lists. The IPs in these lists will be matched against traffic source.
         */
        srcThreatIntelligences?: string[] | null;
    }
    export interface Schema$FirewallPolicyRuleMatcherLayer4Config {
        /**
         * The IP protocol to which this rule applies. The protocol type is required when creating a firewall rule. This value can either be one of the following well known protocol strings (tcp, udp, icmp, esp, ah, ipip, sctp), or the IP protocol number.
         */
        ipProtocol?: string | null;
        /**
         * An optional list of ports to which this rule applies. This field is only applicable for UDP or TCP protocol. Each entry must be either an integer or a range. If not specified, this rule applies to connections through any port. Example inputs include: ["22"], ["80","443"], and ["12345-12349"].
         */
        ports?: string[] | null;
    }
    export interface Schema$FirewallPolicyRuleSecureTag {
        /**
         * Name of the secure tag, created with TagManager's TagValue API.
         */
        name?: string | null;
        /**
         * [Output Only] State of the secure tag, either `EFFECTIVE` or `INEFFECTIVE`. A secure tag is `INEFFECTIVE` when it is deleted or its network is deleted.
         */
        state?: string | null;
    }
    /**
     * Encapsulates numeric value that can be either absolute or relative.
     */
    export interface Schema$FixedOrPercent {
        /**
         * [Output Only] Absolute value of VM instances calculated based on the specific mode. - If the value is fixed, then the calculated value is equal to the fixed value. - If the value is a percent, then the calculated value is percent/100 * targetSize. For example, the calculated value of a 80% of a managed instance group with 150 instances would be (80/100 * 150) = 120 VM instances. If there is a remainder, the number is rounded.
         */
        calculated?: number | null;
        /**
         * Specifies a fixed number of VM instances. This must be a positive integer.
         */
        fixed?: number | null;
        /**
         * Specifies a percentage of instances between 0 to 100%, inclusive. For example, specify 80 for 80%.
         */
        percent?: number | null;
    }
    /**
     * Represents a Forwarding Rule resource. Forwarding rule resources in Google Cloud can be either regional or global in scope: * [Global](https://cloud.google.com/compute/docs/reference/rest/alpha/globalForwardingRules) * [Regional](https://cloud.google.com/compute/docs/reference/rest/alpha/forwardingRules) A forwarding rule and its corresponding IP address represent the frontend configuration of a Google Cloud Platform load balancer. Forwarding rules can also reference target instances and Cloud VPN Classic gateways (targetVpnGateway). For more information, read Forwarding rule concepts and Using protocol forwarding.
     */
    export interface Schema$ForwardingRule {
        /**
         * This field is used along with the backend_service field for internal load balancing or with the target field for internal TargetInstance. If set to true, clients can access the Internal TCP/UDP Load Balancer, Internal HTTP(S) and TCP Proxy Load Balancer from all regions. If false, only allows access from the local region the load balancer is located at. Note that for INTERNAL_MANAGED forwarding rules, this field cannot be changed after the forwarding rule is created.
         */
        allowGlobalAccess?: boolean | null;
        /**
         * This is used in PSC consumer ForwardingRule to control whether the PSC endpoint can be accessed from another region.
         */
        allowPscGlobalAccess?: boolean | null;
        /**
         * This is used in PSC consumer ForwardingRule to control whether the producer is allowed to inject packets into the consumer's network. If set to true, the target service attachment must have tunneling enabled and TunnelingConfig.RoutingMode set to PACKET_INJECTION Non-PSC forwarding rules should not use this field.
         */
        allowPscPacketInjection?: boolean | null;
        /**
         * This field can only be used: - If IPProtocol is one of TCP, UDP, or SCTP. - By internal TCP/UDP load balancers, backend service-based network load balancers, and internal and external protocol forwarding. Set this field to true to allow packets addressed to any port or packets lacking destination port information (for example, UDP fragments after the first fragment) to be forwarded to the backends configured with this forwarding rule. The ports, port_range, and allPorts fields are mutually exclusive.
         */
        allPorts?: boolean | null;
        /**
         * Identifies the backend service to which the forwarding rule sends traffic. Required for Internal TCP/UDP Load Balancing and Network Load Balancing; must be omitted for all other load balancer types.
         */
        backendService?: string | null;
        /**
         * [Output Only] The URL for the corresponding base Forwarding Rule. By base Forwarding Rule, we mean the Forwarding Rule that has the same IP address, protocol, and port settings with the current Forwarding Rule, but without sourceIPRanges specified. Always empty if the current Forwarding Rule does not have sourceIPRanges specified.
         */
        baseForwardingRule?: string | null;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a ForwardingRule. Include the fingerprint in patch request to ensure that you do not overwrite changes that were applied from another concurrent request. To see the latest fingerprint, make a get() request to retrieve a ForwardingRule.
         */
        fingerprint?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * IP address for which this forwarding rule accepts traffic. When a client sends traffic to this IP address, the forwarding rule directs the traffic to the referenced target or backendService. While creating a forwarding rule, specifying an IPAddress is required under the following circumstances: - When the target is set to targetGrpcProxy and validateForProxyless is set to true, the IPAddress should be set to 0.0.0.0. - When the target is a Private Service Connect Google APIs bundle, you must specify an IPAddress. Otherwise, you can optionally specify an IP address that references an existing static (reserved) IP address resource. When omitted, Google Cloud assigns an ephemeral IP address. Use one of the following formats to specify an IP address while creating a forwarding rule: * IP address number, as in `100.1.2.3` * IPv6 address range, as in `2600:1234::/96` * Full resource URL, as in https://www.googleapis.com/compute/v1/projects/ project_id/regions/region/addresses/address-name * Partial URL or by name, as in: - projects/project_id/regions/region/addresses/address-name - regions/region/addresses/address-name - global/addresses/address-name - address-name The forwarding rule's target or backendService, and in most cases, also the loadBalancingScheme, determine the type of IP address that you can use. For detailed information, see [IP address specifications](https://cloud.google.com/load-balancing/docs/forwarding-rule-concepts#ip_address_specifications). When reading an IPAddress, the API always returns the IP address number.
         */
        IPAddress?: string | null;
        /**
         * Resource reference of a PublicDelegatedPrefix. The PDP must be a sub-PDP in EXTERNAL_IPV6_FORWARDING_RULE_CREATION mode. Use one of the following formats to specify a sub-PDP when creating an IPv6 NetLB forwarding rule using BYOIP: Full resource URL, as in https://www.googleapis.com/compute/v1/projects/project_id/regions/region /publicDelegatedPrefixes/sub-pdp-name Partial URL, as in: - projects/project_id/regions/region/publicDelegatedPrefixes/sub-pdp-name - regions/region/publicDelegatedPrefixes/sub-pdp-name
         */
        ipCollection?: string | null;
        /**
         * The IP protocol to which this rule applies. For protocol forwarding, valid options are TCP, UDP, ESP, AH, SCTP, ICMP and L3_DEFAULT. The valid IP protocols are different for different load balancing products as described in [Load balancing features](https://cloud.google.com/load-balancing/docs/features#protocols_from_the_load_balancer_to_the_backends).
         */
        IPProtocol?: string | null;
        /**
         * The IP Version that will be used by this forwarding rule. Valid options are IPV4 or IPV6.
         */
        ipVersion?: string | null;
        /**
         * Indicates whether or not this load balancer can be used as a collector for packet mirroring. To prevent mirroring loops, instances behind this load balancer will not have their traffic mirrored even if a PacketMirroring rule applies to them. This can only be set to true for load balancers that have their loadBalancingScheme set to INTERNAL.
         */
        isMirroringCollector?: boolean | null;
        /**
         * [Output Only] Type of the resource. Always compute#forwardingRule for Forwarding Rule resources.
         */
        kind?: string | null;
        /**
         * A fingerprint for the labels being applied to this resource, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a ForwardingRule.
         */
        labelFingerprint?: string | null;
        /**
         * Labels for this resource. These can only be added or modified by the setLabels method. Each label key/value pair must comply with RFC1035. Label values may be empty.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * Specifies the forwarding rule type. For more information about forwarding rules, refer to Forwarding rule concepts.
         */
        loadBalancingScheme?: string | null;
        /**
         * Opaque filter criteria used by load balancer to restrict routing configuration to a limited set of xDS compliant clients. In their xDS requests to load balancer, xDS clients present node metadata. When there is a match, the relevant configuration is made available to those proxies. Otherwise, all the resources (e.g. TargetHttpProxy, UrlMap) referenced by the ForwardingRule are not visible to those proxies. For each metadataFilter in this list, if its filterMatchCriteria is set to MATCH_ANY, at least one of the filterLabels must match the corresponding label provided in the metadata. If its filterMatchCriteria is set to MATCH_ALL, then all of its filterLabels must match with corresponding labels provided in the metadata. If multiple metadataFilters are specified, all of them need to be satisfied in order to be considered a match. metadataFilters specified here will be applifed before those specified in the UrlMap that this ForwardingRule references. metadataFilters only applies to Loadbalancers that have their loadBalancingScheme set to INTERNAL_SELF_MANAGED.
         */
        metadataFilters?: Schema$MetadataFilter[];
        /**
         * Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. For Private Service Connect forwarding rules that forward traffic to Google APIs, the forwarding rule name must be a 1-20 characters string with lowercase letters and numbers and must start with a letter.
         */
        name?: string | null;
        /**
         * This field is not used for global external load balancing. For Internal TCP/UDP Load Balancing, this field identifies the network that the load balanced IP should belong to for this Forwarding Rule. If the subnetwork is specified, the network of the subnetwork will be used. If neither subnetwork nor this field is specified, the default network will be used. For Private Service Connect forwarding rules that forward traffic to Google APIs, a network must be provided.
         */
        network?: string | null;
        /**
         * This signifies the networking tier used for configuring this load balancer and can only take the following values: PREMIUM, STANDARD. For regional ForwardingRule, the valid values are PREMIUM and STANDARD. For GlobalForwardingRule, the valid value is PREMIUM. If this field is not specified, it is assumed to be PREMIUM. If IPAddress is specified, this value must be equal to the networkTier of the Address.
         */
        networkTier?: string | null;
        /**
         * This is used in PSC consumer ForwardingRule to control whether it should try to auto-generate a DNS zone or not. Non-PSC forwarding rules do not use this field. Once set, this field is not mutable.
         */
        noAutomateDnsZone?: boolean | null;
        /**
         * This field can only be used: - If IPProtocol is one of TCP, UDP, or SCTP. - By backend service-based network load balancers, target pool-based network load balancers, internal proxy load balancers, external proxy load balancers, Traffic Director, external protocol forwarding, and Classic VPN. Some products have restrictions on what ports can be used. See port specifications for details. Only packets addressed to ports in the specified range will be forwarded to the backends configured with this forwarding rule. The ports, port_range, and allPorts fields are mutually exclusive. For external forwarding rules, two or more forwarding rules cannot use the same [IPAddress, IPProtocol] pair, and cannot have overlapping portRanges. For internal forwarding rules within the same VPC network, two or more forwarding rules cannot use the same [IPAddress, IPProtocol] pair, and cannot have overlapping portRanges. @pattern: \\d+(?:-\\d+)?
         */
        portRange?: string | null;
        /**
         * This field can only be used: - If IPProtocol is one of TCP, UDP, or SCTP. - By internal TCP/UDP load balancers, backend service-based network load balancers, and internal protocol forwarding. You can specify a list of up to five ports by number, separated by commas. The ports can be contiguous or discontiguous. Only packets addressed to these ports will be forwarded to the backends configured with this forwarding rule. For external forwarding rules, two or more forwarding rules cannot use the same [IPAddress, IPProtocol] pair, and cannot share any values defined in ports. For internal forwarding rules within the same VPC network, two or more forwarding rules cannot use the same [IPAddress, IPProtocol] pair, and cannot share any values defined in ports. The ports, port_range, and allPorts fields are mutually exclusive. @pattern: \\d+(?:-\\d+)?
         */
        ports?: string[] | null;
        /**
         * [Output Only] The PSC connection id of the PSC Forwarding Rule.
         */
        pscConnectionId?: string | null;
        pscConnectionStatus?: string | null;
        /**
         * [Output Only] URL of the region where the regional forwarding rule resides. This field is not applicable to global forwarding rules. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
         */
        region?: string | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * Service Directory resources to register this forwarding rule with. Currently, only supports a single Service Directory resource.
         */
        serviceDirectoryRegistrations?: Schema$ForwardingRuleServiceDirectoryRegistration[];
        /**
         * An optional prefix to the service name for this Forwarding Rule. If specified, the prefix is the first label of the fully qualified service name. The label must be 1-63 characters long, and comply with RFC1035. Specifically, the label must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. This field is only used for internal load balancing.
         */
        serviceLabel?: string | null;
        /**
         * [Output Only] The internal fully qualified service name for this Forwarding Rule. This field is only used for internal load balancing.
         */
        serviceName?: string | null;
        /**
         * If not empty, this Forwarding Rule will only forward the traffic when the source IP address matches one of the IP addresses or CIDR ranges set here. Note that a Forwarding Rule can only have up to 64 source IP ranges, and this field can only be used with a regional Forwarding Rule whose scheme is EXTERNAL. Each source_ip_range entry should be either an IP address (for example, 1.2.3.4) or a CIDR range (for example, 1.2.3.0/24).
         */
        sourceIpRanges?: string[] | null;
        /**
         * This field identifies the subnetwork that the load balanced IP should belong to for this Forwarding Rule, used in internal load balancing and network load balancing with IPv6. If the network specified is in auto subnet mode, this field is optional. However, a subnetwork must be specified if the network is in custom subnet mode or when creating external forwarding rule with IPv6.
         */
        subnetwork?: string | null;
        /**
         * The URL of the target resource to receive the matched traffic. For regional forwarding rules, this target must be in the same region as the forwarding rule. For global forwarding rules, this target must be a global load balancing resource. The forwarded traffic must be of a type appropriate to the target object. - For load balancers, see the "Target" column in [Port specifications](https://cloud.google.com/load-balancing/docs/forwarding-rule-concepts#ip_address_specifications). - For Private Service Connect forwarding rules that forward traffic to Google APIs, provide the name of a supported Google API bundle: - vpc-sc - APIs that support VPC Service Controls. - all-apis - All supported Google APIs. - For Private Service Connect forwarding rules that forward traffic to managed services, the target must be a service attachment. The target is not mutable once set as a service attachment.
         */
        target?: string | null;
    }
    export interface Schema$ForwardingRuleAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of ForwardingRulesScopedList resources.
         */
        items?: {
            [key: string]: Schema$ForwardingRulesScopedList;
        } | null;
        /**
         * [Output Only] Type of resource. Always compute#forwardingRuleAggregatedList for lists of forwarding rules.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Contains a list of ForwardingRule resources.
     */
    export interface Schema$ForwardingRuleList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of ForwardingRule resources.
         */
        items?: Schema$ForwardingRule[];
        /**
         * Type of resource.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$ForwardingRuleReference {
        forwardingRule?: string | null;
    }
    /**
     * Describes the auto-registration of the Forwarding Rule to Service Directory. The region and project of the Service Directory resource generated from this registration will be the same as this Forwarding Rule.
     */
    export interface Schema$ForwardingRuleServiceDirectoryRegistration {
        /**
         * Service Directory namespace to register the forwarding rule under.
         */
        namespace?: string | null;
        /**
         * Service Directory service to register the forwarding rule under.
         */
        service?: string | null;
        /**
         * [Optional] Service Directory region to register this global forwarding rule under. Default to "us-central1". Only used for PSC for Google APIs. All PSC for Google APIs Forwarding Rules on the same network should use the same Service Directory region.
         */
        serviceDirectoryRegion?: string | null;
    }
    export interface Schema$ForwardingRulesScopedList {
        /**
         * A list of forwarding rules contained in this scope.
         */
        forwardingRules?: Schema$ForwardingRule[];
        /**
         * Informational warning which replaces the list of forwarding rules when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$FutureReservation {
        /**
         * Future timestamp when the FR auto-created reservations will be deleted by GCE. Format of this field must be a valid href="https://www.ietf.org/rfc/rfc3339.txt"\>RFC3339 value.
         */
        autoCreatedReservationsDeleteTime?: string | null;
        /**
         * Specifies the duration of auto-created reservations. It represents relative time to future reservation start_time when auto-created reservations will be automatically deleted by GCE. Duration time unit is represented as a count of seconds and fractions of seconds at nanosecond resolution.
         */
        autoCreatedReservationsDuration?: Schema$Duration;
        /**
         * Setting for enabling or disabling automatic deletion for auto-created reservation. If set to true, auto-created reservations will be deleted at Future Reservation's end time (default) or at user's defined timestamp if any of the [auto_created_reservations_delete_time, auto_created_reservations_duration] values is specified. For keeping auto-created reservation indefinitely, this value should be set to false.
         */
        autoDeleteAutoCreatedReservations?: boolean | null;
        /**
         * [Output Only] The creation timestamp for this future reservation in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the future reservation.
         */
        description?: string | null;
        /**
         * [Output Only] A unique identifier for this future reservation. The server defines this identifier.
         */
        id?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#futureReservation for future reservations.
         */
        kind?: string | null;
        /**
         * The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * Name prefix for the reservations to be created at the time of delivery. The name prefix must comply with RFC1035. Maximum allowed length for name prefix is 20. Automatically created reservations name format will be -date-####.
         */
        namePrefix?: string | null;
        /**
         * Planning state before being submitted for evaluation
         */
        planningStatus?: string | null;
        /**
         * [Output Only] Server-defined fully-qualified URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * List of Projects/Folders to share with.
         */
        shareSettings?: Schema$ShareSettings;
        /**
         * Future Reservation configuration to indicate instance properties and total count.
         */
        specificSkuProperties?: Schema$FutureReservationSpecificSKUProperties;
        /**
         * [Output only] Status of the Future Reservation
         */
        status?: Schema$FutureReservationStatus;
        /**
         * Time window for this Future Reservation.
         */
        timeWindow?: Schema$FutureReservationTimeWindow;
        /**
         * [Output Only] URL of the Zone where this future reservation resides.
         */
        zone?: string | null;
    }
    /**
     * Contains a list of future reservations.
     */
    export interface Schema$FutureReservationsAggregatedListResponse {
        etag?: string | null;
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of Future reservation resources.
         */
        items?: {
            [key: string]: Schema$FutureReservationsScopedList;
        } | null;
        /**
         * [Output Only] Type of resource. Always compute#futureReservationsAggregatedListResponse for future resevation aggregated list response.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$FutureReservationsListResponse {
        etag?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] A list of future reservation resources.
         */
        items?: Schema$FutureReservation[];
        /**
         * [Output Only] Type of resource.Always compute#FutureReservationsListResponse for lists of reservations
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$FutureReservationSpecificSKUProperties {
        /**
         * Properties of the SKU instances being reserved.
         */
        instanceProperties?: Schema$AllocationSpecificSKUAllocationReservedInstanceProperties;
        /**
         * The instance template that will be used to populate the ReservedInstanceProperties of the future reservation
         */
        sourceInstanceTemplate?: string | null;
        /**
         * Total number of instances for which capacity assurance is requested at a future time period.
         */
        totalCount?: string | null;
    }
    export interface Schema$FutureReservationsScopedList {
        /**
         * A list of future reservations contained in this scope.
         */
        futureReservations?: Schema$FutureReservation[];
        /**
         * Informational warning which replaces the list of future reservations when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * [Output only] Represents status related to the future reservation.
     */
    export interface Schema$FutureReservationStatus {
        /**
         * [Output Only] The current status of the requested amendment.
         */
        amendmentStatus?: string | null;
        /**
         * Fully qualified urls of the automatically created reservations at start_time.
         */
        autoCreatedReservations?: string[] | null;
        /**
         * This count indicates the fulfilled capacity so far. This is set during "PROVISIONING" state. This count also includes capacity delivered as part of existing matching reservations.
         */
        fulfilledCount?: string | null;
        /**
         * [Output Only] This field represents the future reservation before an amendment was requested. If the amendment is declined, the Future Reservation will be reverted to the last known good state. The last known good state is not set when updating a future reservation whose Procurement Status is DRAFTING.
         */
        lastKnownGoodState?: Schema$FutureReservationStatusLastKnownGoodState;
        /**
         * Time when Future Reservation would become LOCKED, after which no modifications to Future Reservation will be allowed. Applicable only after the Future Reservation is in the APPROVED state. The lock_time is an RFC3339 string. The procurement_status will transition to PROCURING state at this time.
         */
        lockTime?: string | null;
        /**
         * Current state of this Future Reservation
         */
        procurementStatus?: string | null;
        specificSkuProperties?: Schema$FutureReservationStatusSpecificSKUProperties;
    }
    /**
     * The state that the future reservation will be reverted to should the amendment be declined.
     */
    export interface Schema$FutureReservationStatusLastKnownGoodState {
        /**
         * [Output Only] The description of the FutureReservation before an amendment was requested.
         */
        description?: string | null;
        futureReservationSpecs?: Schema$FutureReservationStatusLastKnownGoodStateFutureReservationSpecs;
        /**
         * [Output Only] The lock time of the FutureReservation before an amendment was requested.
         */
        lockTime?: string | null;
        /**
         * [Output Only] The name prefix of the Future Reservation before an amendment was requested.
         */
        namePrefix?: string | null;
        /**
         * [Output Only] The status of the last known good state for the Future Reservation.
         */
        procurementStatus?: string | null;
    }
    /**
     * The properties of the last known good state for the Future Reservation.
     */
    export interface Schema$FutureReservationStatusLastKnownGoodStateFutureReservationSpecs {
        /**
         * [Output Only] The previous share settings of the Future Reservation.
         */
        shareSettings?: Schema$ShareSettings;
        /**
         * [Output Only] The previous instance related properties of the Future Reservation.
         */
        specificSkuProperties?: Schema$FutureReservationSpecificSKUProperties;
        /**
         * [Output Only] The previous time window of the Future Reservation.
         */
        timeWindow?: Schema$FutureReservationTimeWindow;
    }
    /**
     * Properties to be set for the Future Reservation.
     */
    export interface Schema$FutureReservationStatusSpecificSKUProperties {
        /**
         * ID of the instance template used to populate the Future Reservation properties.
         */
        sourceInstanceTemplateId?: string | null;
    }
    export interface Schema$FutureReservationTimeWindow {
        duration?: Schema$Duration;
        endTime?: string | null;
        /**
         * Start time of the Future Reservation. The start_time is an RFC3339 string.
         */
        startTime?: string | null;
    }
    export interface Schema$GetOwnerInstanceResponse {
        /**
         * Full instance resource URL.
         */
        instance?: string | null;
    }
    export interface Schema$GlobalAddressesMoveRequest {
        /**
         * An optional destination address description if intended to be different from the source.
         */
        description?: string | null;
        /**
         * The URL of the destination address to move to. This can be a full or partial URL. For example, the following are all valid URLs to a address: - https://www.googleapis.com/compute/v1/projects/project /global/addresses/address - projects/project/global/addresses/address Note that destination project must be different from the source project. So /global/addresses/address is not valid partial url.
         */
        destinationAddress?: string | null;
    }
    export interface Schema$GlobalNetworkEndpointGroupsAttachEndpointsRequest {
        /**
         * The list of network endpoints to be attached.
         */
        networkEndpoints?: Schema$NetworkEndpoint[];
    }
    export interface Schema$GlobalNetworkEndpointGroupsDetachEndpointsRequest {
        /**
         * The list of network endpoints to be detached.
         */
        networkEndpoints?: Schema$NetworkEndpoint[];
    }
    export interface Schema$GlobalOrganizationSetPolicyRequest {
        /**
         * Flatten Policy to create a backward compatible wire-format. Deprecated. Use 'policy' to specify bindings.
         */
        bindings?: Schema$Binding[];
        /**
         * Flatten Policy to create a backward compatible wire-format. Deprecated. Use 'policy' to specify the etag.
         */
        etag?: string | null;
        /**
         * REQUIRED: The complete policy to be applied to the 'resource'. The size of the policy is limited to a few 10s of KB. An empty policy is in general a valid policy but certain services (like Projects) might reject them.
         */
        policy?: Schema$Policy;
    }
    export interface Schema$GlobalSetLabelsRequest {
        /**
         * The fingerprint of the previous set of labels for this resource, used to detect conflicts. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash when updating or changing labels, otherwise the request will fail with error 412 conditionNotMet. Make a get() request to the resource to get the latest fingerprint.
         */
        labelFingerprint?: string | null;
        /**
         * A list of labels to apply for this resource. Each label must comply with the requirements for labels. For example, "webserver-frontend": "images". A label value can also be empty (e.g. "my-label": "").
         */
        labels?: {
            [key: string]: string;
        } | null;
    }
    export interface Schema$GlobalSetPolicyRequest {
        /**
         * Flatten Policy to create a backward compatible wire-format. Deprecated. Use 'policy' to specify bindings.
         */
        bindings?: Schema$Binding[];
        /**
         * Flatten Policy to create a backward compatible wire-format. Deprecated. Use 'policy' to specify the etag.
         */
        etag?: string | null;
        /**
         * REQUIRED: The complete policy to be applied to the 'resource'. The size of the policy is limited to a few 10s of KB. An empty policy is in general a valid policy but certain services (like Projects) might reject them.
         */
        policy?: Schema$Policy;
    }
    export interface Schema$GRPCHealthCheck {
        /**
         * The gRPC service name for the health check. This field is optional. The value of grpc_service_name has the following meanings by convention: - Empty service_name means the overall status of all services at the backend. - Non-empty service_name means the health of that gRPC service, as defined by the owner of the service. The grpc_service_name can only be ASCII.
         */
        grpcServiceName?: string | null;
        /**
         * The TCP port number to which the health check prober sends packets. Valid values are 1 through 65535.
         */
        port?: number | null;
        /**
         * Not supported.
         */
        portName?: string | null;
        /**
         * Specifies how a port is selected for health checking. Can be one of the following values: USE_FIXED_PORT: Specifies a port number explicitly using the port field in the health check. Supported by backend services for pass-through load balancers and backend services for proxy load balancers. Not supported by target pools. The health check supports all backends supported by the backend service provided the backend can be health checked. For example, GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network endpoint groups, and instance group backends. USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an indirect method of specifying the health check port by referring to the backend service. Only supported by backend services for proxy load balancers. Not supported by target pools. Not supported by backend services for pass-through load balancers. Supports all backends that can be health checked; for example, GCE_VM_IP_PORT network endpoint groups and instance group backends. For GCE_VM_IP_PORT network endpoint group backends, the health check uses the port number specified for each endpoint in the network endpoint group. For instance group backends, the health check uses the port number determined by looking up the backend service's named port in the instance group's list of named ports.
         */
        portSpecification?: string | null;
    }
    /**
     * [Deprecated] gRPC config to access the SDS server. gRPC config to access the SDS server.
     */
    export interface Schema$GrpcServiceConfig {
        /**
         * The call credentials to access the SDS server.
         */
        callCredentials?: Schema$CallCredentials;
        /**
         * The channel credentials to access the SDS server.
         */
        channelCredentials?: Schema$ChannelCredentials;
        /**
         * The target URI of the SDS server.
         */
        targetUri?: string | null;
    }
    /**
     * A guest attributes entry.
     */
    export interface Schema$GuestAttributes {
        /**
         * [Output Only] Type of the resource. Always compute#guestAttributes for guest attributes entry.
         */
        kind?: string | null;
        /**
         * The path to be queried. This can be the default namespace ('') or a nested namespace ('\/') or a specified key ('\/\').
         */
        queryPath?: string | null;
        /**
         * [Output Only] The value of the requested queried path.
         */
        queryValue?: Schema$GuestAttributesValue;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * The key to search for.
         */
        variableKey?: string | null;
        /**
         * [Output Only] The value found for the requested key.
         */
        variableValue?: string | null;
    }
    /**
     * A guest attributes namespace/key/value entry.
     */
    export interface Schema$GuestAttributesEntry {
        /**
         * Key for the guest attribute entry.
         */
        key?: string | null;
        /**
         * Namespace for the guest attribute entry.
         */
        namespace?: string | null;
        /**
         * Value for the guest attribute entry.
         */
        value?: string | null;
    }
    /**
     * Array of guest attribute namespace/key/value tuples.
     */
    export interface Schema$GuestAttributesValue {
        items?: Schema$GuestAttributesEntry[];
    }
    /**
     * Guest OS features.
     */
    export interface Schema$GuestOsFeature {
        /**
         * The ID of a supported feature. To add multiple values, use commas to separate values. Set to one or more of the following values: - VIRTIO_SCSI_MULTIQUEUE - WINDOWS - MULTI_IP_SUBNET - UEFI_COMPATIBLE - GVNIC - SEV_CAPABLE - SUSPEND_RESUME_COMPATIBLE - SEV_LIVE_MIGRATABLE - SEV_SNP_CAPABLE For more information, see Enabling guest operating system features.
         */
        type?: string | null;
    }
    /**
     * Represents a health check resource. Google Compute Engine has two health check resources: * [Regional](/compute/docs/reference/rest/alpha/regionHealthChecks) * [Global](/compute/docs/reference/rest/alpha/healthChecks) These health check resources can be used for load balancing and for autohealing VMs in a managed instance group (MIG). **Load balancing** The following load balancer can use either regional or global health check: * Internal TCP/UDP load balancer The following load balancers require regional health check: * Internal HTTP(S) load balancer * Backend service-based network load balancer Traffic Director and the following load balancers require global health check: * External HTTP(S) load balancer * TCP proxy load balancer * SSL proxy load balancer The following load balancer require [legacy HTTP health checks](/compute/docs/reference/rest/v1/httpHealthChecks): * Target pool-based network load balancer **Autohealing in MIGs** The health checks that you use for autohealing VMs in a MIG can be either regional or global. For more information, see Set up an application health check and autohealing. For more information, see Health checks overview.
     */
    export interface Schema$HealthCheck {
        /**
         * How often (in seconds) to send a health check. The default value is 5 seconds.
         */
        checkIntervalSec?: number | null;
        /**
         * [Output Only] Creation timestamp in 3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        grpcHealthCheck?: Schema$GRPCHealthCheck;
        /**
         * A so-far unhealthy instance will be marked healthy after this many consecutive successes. The default value is 2.
         */
        healthyThreshold?: number | null;
        http2HealthCheck?: Schema$HTTP2HealthCheck;
        httpHealthCheck?: Schema$HTTPHealthCheck;
        httpsHealthCheck?: Schema$HTTPSHealthCheck;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * Type of the resource.
         */
        kind?: string | null;
        /**
         * Configure logging on this health check.
         */
        logConfig?: Schema$HealthCheckLogConfig;
        /**
         * Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. For example, a name that is 1-63 characters long, matches the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?`, and otherwise complies with RFC1035. This regular expression describes a name where the first character is a lowercase letter, and all following characters are a dash, lowercase letter, or digit, except the last character, which isn't a dash.
         */
        name?: string | null;
        /**
         * [Output Only] Region where the health check resides. Not applicable to global health checks.
         */
        region?: string | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * The list of cloud regions from which health checks are performed. If any regions are specified, then exactly 3 regions should be specified. The region names must be valid names of GCP regions. This can only be set for global health check. If this list is non-empty, then there are restrictions on what other health check fields are supported and what other resources can use this health check: - SSL, HTTP2, and GRPC protocols are not supported. - The TCP request field is not supported. - The proxyHeader field for HTTP, HTTPS, and TCP is not supported. - The checkIntervalSec field must be at least 30. - The health check cannot be used with BackendService nor with managed instance group auto-healing.
         */
        sourceRegions?: string[] | null;
        sslHealthCheck?: Schema$SSLHealthCheck;
        tcpHealthCheck?: Schema$TCPHealthCheck;
        /**
         * How long (in seconds) to wait before claiming failure. The default value is 5 seconds. It is invalid for timeoutSec to have greater value than checkIntervalSec.
         */
        timeoutSec?: number | null;
        /**
         * Specifies the type of the healthCheck, either TCP, SSL, HTTP, HTTPS, HTTP2 or GRPC. Exactly one of the protocol-specific health check fields must be specified, which must match type field.
         */
        type?: string | null;
        udpHealthCheck?: Schema$UDPHealthCheck;
        /**
         * A so-far healthy instance will be marked unhealthy after this many consecutive failures. The default value is 2.
         */
        unhealthyThreshold?: number | null;
    }
    /**
     * Contains a list of HealthCheck resources.
     */
    export interface Schema$HealthCheckList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of HealthCheck resources.
         */
        items?: Schema$HealthCheck[];
        /**
         * Type of resource.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Configuration of logging on a health check. If logging is enabled, logs will be exported to Stackdriver.
     */
    export interface Schema$HealthCheckLogConfig {
        /**
         * Indicates whether or not to export logs. This is false by default, which means no health check logging will be done.
         */
        enable?: boolean | null;
    }
    /**
     * A full or valid partial URL to a health check. For example, the following are valid URLs: - https://www.googleapis.com/compute/beta/projects/project-id/global/httpHealthChecks/health-check - projects/project-id/global/httpHealthChecks/health-check - global/httpHealthChecks/health-check
     */
    export interface Schema$HealthCheckReference {
        healthCheck?: string | null;
    }
    export interface Schema$HealthChecksAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of HealthChecksScopedList resources.
         */
        items?: {
            [key: string]: Schema$HealthChecksScopedList;
        } | null;
        /**
         * Type of resource.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Represents a Health-Check as a Service resource.
     */
    export interface Schema$HealthCheckService {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a HealthCheckService. An up-to-date fingerprint must be provided in order to patch/update the HealthCheckService; Otherwise, the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the HealthCheckService.
         */
        fingerprint?: string | null;
        /**
         * A list of URLs to the HealthCheck resources. Must have at least one HealthCheck, and not more than 10 for regional HealthCheckService, and not more than 1 for global HealthCheckService. HealthCheck resources must have portSpecification=USE_SERVING_PORT or portSpecification=USE_FIXED_PORT. For regional HealthCheckService, the HealthCheck must be regional and in the same region. For global HealthCheckService, HealthCheck must be global. Mix of regional and global HealthChecks is not supported. Multiple regional HealthChecks must belong to the same region. Regional HealthChecks must belong to the same region as zones of NetworkEndpointGroups. For global HealthCheckService using global INTERNET_IP_PORT NetworkEndpointGroups, the global HealthChecks must specify sourceRegions, and HealthChecks that specify sourceRegions can only be used with global INTERNET_IP_PORT NetworkEndpointGroups.
         */
        healthChecks?: string[] | null;
        /**
         * Optional. Policy for how the results from multiple health checks for the same endpoint are aggregated. Defaults to NO_AGGREGATION if unspecified. - NO_AGGREGATION. An EndpointHealth message is returned for each pair in the health check service. - AND. If any health check of an endpoint reports UNHEALTHY, then UNHEALTHY is the HealthState of the endpoint. If all health checks report HEALTHY, the HealthState of the endpoint is HEALTHY. . This is only allowed with regional HealthCheckService.
         */
        healthStatusAggregationPolicy?: string | null;
        /**
         * This field is deprecated. Use health_status_aggregation_policy instead. Policy for how the results from multiple health checks for the same endpoint are aggregated. - NO_AGGREGATION. An EndpointHealth message is returned for each backend in the health check service. - AND. If any backend's health check reports UNHEALTHY, then UNHEALTHY is the HealthState of the entire health check service. If all backend's are healthy, the HealthState of the health check service is HEALTHY. .
         */
        healthStatusAggregationStrategy?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output only] Type of the resource. Always compute#healthCheckServicefor health check services.
         */
        kind?: string | null;
        /**
         * Name of the resource. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * A list of URLs to the NetworkEndpointGroup resources. Must not have more than 100. For regional HealthCheckService, NEGs must be in zones in the region of the HealthCheckService. For global HealthCheckServices, the NetworkEndpointGroups must be global INTERNET_IP_PORT.
         */
        networkEndpointGroups?: string[] | null;
        /**
         * A list of URLs to the NotificationEndpoint resources. Must not have more than 10. A list of endpoints for receiving notifications of change in health status. For regional HealthCheckService, NotificationEndpoint must be regional and in the same region. For global HealthCheckService, NotificationEndpoint must be global.
         */
        notificationEndpoints?: string[] | null;
        /**
         * [Output Only] URL of the region where the health check service resides. This field is not applicable to global health check services. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
         */
        region?: string | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL with id for the resource.
         */
        selfLinkWithId?: string | null;
    }
    /**
     * Contains a list of HealthCheckServicesScopedList.
     */
    export interface Schema$HealthCheckServiceAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of HealthCheckServicesScopedList resources.
         */
        items?: {
            [key: string]: Schema$HealthCheckServicesScopedList;
        } | null;
        /**
         * Type of resource.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * A full or valid partial URL to a health check service. For example, the following are valid URLs: - https://www.googleapis.com/compute/beta/projects/project-id/regions/us-west1/healthCheckServices/health-check-service - projects/project-id/regions/us-west1/healthCheckServices/health-check-service - regions/us-west1/healthCheckServices/health-check-service
     */
    export interface Schema$HealthCheckServiceReference {
        healthCheckService?: string | null;
    }
    export interface Schema$HealthCheckServicesList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of HealthCheckService resources.
         */
        items?: Schema$HealthCheckService[];
        /**
         * [Output Only] Type of the resource. Always compute#healthCheckServicesList for lists of HealthCheckServices.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$HealthCheckServicesScopedList {
        /**
         * A list of HealthCheckServices contained in this scope.
         */
        resources?: Schema$HealthCheckService[];
        /**
         * Informational warning which replaces the list of backend services when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$HealthChecksScopedList {
        /**
         * A list of HealthChecks contained in this scope.
         */
        healthChecks?: Schema$HealthCheck[];
        /**
         * Informational warning which replaces the list of backend services when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$HealthStatus {
        /**
         * Metadata defined as annotations for network endpoint.
         */
        annotations?: {
            [key: string]: string;
        } | null;
        /**
         * URL of the forwarding rule associated with the health status of the instance.
         */
        forwardingRule?: string | null;
        /**
         * A forwarding rule IP address assigned to this instance.
         */
        forwardingRuleIp?: string | null;
        /**
         * Health state of the IPv4 address of the instance.
         */
        healthState?: string | null;
        /**
         * URL of the instance resource.
         */
        instance?: string | null;
        /**
         * For target pool based Network Load Balancing, it indicates the forwarding rule's IP address assigned to this instance. For other types of load balancing, the field indicates VM internal ip.
         */
        ipAddress?: string | null;
        /**
         * The named port of the instance group, not necessarily the port that is health-checked.
         */
        port?: number | null;
        weight?: string | null;
        weightError?: string | null;
    }
    export interface Schema$HealthStatusForNetworkEndpoint {
        /**
         * URL of the backend service associated with the health state of the network endpoint.
         */
        backendService?: Schema$BackendServiceReference;
        /**
         * URL of the forwarding rule associated with the health state of the network endpoint.
         */
        forwardingRule?: Schema$ForwardingRuleReference;
        /**
         * URL of the health check associated with the health state of the network endpoint.
         */
        healthCheck?: Schema$HealthCheckReference;
        /**
         * URL of the health check service associated with the health state of the network endpoint.
         */
        healthCheckService?: Schema$HealthCheckServiceReference;
        /**
         * Health state of the network endpoint determined based on the health checks configured.
         */
        healthState?: string | null;
        /**
         * Health state of the ipv6 network endpoint determined based on the health checks configured.
         */
        ipv6HealthState?: string | null;
    }
    /**
     * Provides links to documentation or for performing an out of band action. For example, if a quota check failed with an error indicating the calling project hasn't enabled the accessed service, this can contain a URL pointing directly to the right place in the developer console to flip the bit.
     */
    export interface Schema$Help {
        /**
         * URL(s) pointing to additional information on handling the current error.
         */
        links?: Schema$HelpLink[];
    }
    /**
     * Describes a URL link.
     */
    export interface Schema$HelpLink {
        /**
         * Describes what the link offers.
         */
        description?: string | null;
        /**
         * The URL of the link.
         */
        url?: string | null;
    }
    /**
     * UrlMaps A host-matching rule for a URL. If matched, will use the named PathMatcher to select the BackendService.
     */
    export interface Schema$HostRule {
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * The list of host patterns to match. They must be valid hostnames with optional port numbers in the format host:port. * matches any string of ([a-z0-9-.]*). In that case, * must be the first character, and if followed by anything, the immediate following character must be either - or .. * based matching is not supported when the URL map is bound to a target gRPC proxy that has the validateForProxyless field set to true.
         */
        hosts?: string[] | null;
        /**
         * The name of the PathMatcher to use to match the path portion of the URL if the hostRule matches the URL's host portion.
         */
        pathMatcher?: string | null;
    }
    export interface Schema$HTTP2HealthCheck {
        /**
         * The value of the host header in the HTTP/2 health check request. If left empty (default value), the host header is set to the destination IP address to which health check packets are sent. The destination IP address depends on the type of load balancer. For details, see: https://cloud.google.com/load-balancing/docs/health-check-concepts#hc-packet-dest
         */
        host?: string | null;
        /**
         * The TCP port number to which the health check prober sends packets. The default value is 443. Valid values are 1 through 65535.
         */
        port?: number | null;
        /**
         * Not supported.
         */
        portName?: string | null;
        /**
         * Specifies how a port is selected for health checking. Can be one of the following values: USE_FIXED_PORT: Specifies a port number explicitly using the port field in the health check. Supported by backend services for pass-through load balancers and backend services for proxy load balancers. Not supported by target pools. The health check supports all backends supported by the backend service provided the backend can be health checked. For example, GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network endpoint groups, and instance group backends. USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an indirect method of specifying the health check port by referring to the backend service. Only supported by backend services for proxy load balancers. Not supported by target pools. Not supported by backend services for pass-through load balancers. Supports all backends that can be health checked; for example, GCE_VM_IP_PORT network endpoint groups and instance group backends. For GCE_VM_IP_PORT network endpoint group backends, the health check uses the port number specified for each endpoint in the network endpoint group. For instance group backends, the health check uses the port number determined by looking up the backend service's named port in the instance group's list of named ports.
         */
        portSpecification?: string | null;
        /**
         * Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE.
         */
        proxyHeader?: string | null;
        /**
         * The request path of the HTTP/2 health check request. The default value is /.
         */
        requestPath?: string | null;
        /**
         * Creates a content-based HTTP/2 health check. In addition to the required HTTP 200 (OK) status code, you can configure the health check to pass only when the backend sends this specific ASCII response string within the first 1024 bytes of the HTTP response body. For details, see: https://cloud.google.com/load-balancing/docs/health-check-concepts#criteria-protocol-http
         */
        response?: string | null;
        /**
         * Weight report mode. used for weighted Load Balancing.
         */
        weightReportMode?: string | null;
    }
    /**
     * Specification for how requests are aborted as part of fault injection.
     */
    export interface Schema$HttpFaultAbort {
        /**
         * The HTTP status code used to abort the request. The value must be from 200 to 599 inclusive. For gRPC protocol, the gRPC status code is mapped to HTTP status code according to this mapping table. HTTP status 200 is mapped to gRPC status UNKNOWN. Injecting an OK status is currently not supported by Traffic Director.
         */
        httpStatus?: number | null;
        /**
         * The percentage of traffic for connections, operations, or requests that is aborted as part of fault injection. The value must be from 0.0 to 100.0 inclusive.
         */
        percentage?: number | null;
    }
    /**
     * Specifies the delay introduced by the load balancer before forwarding the request to the backend service as part of fault injection.
     */
    export interface Schema$HttpFaultDelay {
        /**
         * Specifies the value of the fixed delay interval.
         */
        fixedDelay?: Schema$Duration;
        /**
         * The percentage of traffic for connections, operations, or requests for which a delay is introduced as part of fault injection. The value must be from 0.0 to 100.0 inclusive.
         */
        percentage?: number | null;
    }
    /**
     * The specification for fault injection introduced into traffic to test the resiliency of clients to backend service failure. As part of fault injection, when clients send requests to a backend service, delays can be introduced by the load balancer on a percentage of requests before sending those request to the backend service. Similarly requests from clients can be aborted by the load balancer for a percentage of requests.
     */
    export interface Schema$HttpFaultInjection {
        /**
         * The specification for how client requests are aborted as part of fault injection.
         */
        abort?: Schema$HttpFaultAbort;
        /**
         * The specification for how client requests are delayed as part of fault injection, before being sent to a backend service.
         */
        delay?: Schema$HttpFaultDelay;
    }
    /**
     * HttpFilterConfiguration supplies additional contextual settings for networkservices.HttpFilter resources enabled by Traffic Director.
     */
    export interface Schema$HttpFilterConfig {
        /**
         * The configuration needed to enable the networkservices.HttpFilter resource. The configuration must be YAML formatted and only contain fields defined in the protobuf identified in configTypeUrl
         */
        config?: string | null;
        /**
         * The fully qualified versioned proto3 type url of the protobuf that the filter expects for its contextual settings, for example: type.googleapis.com/google.protobuf.Struct
         */
        configTypeUrl?: string | null;
        /**
         * Name of the networkservices.HttpFilter resource this configuration belongs to. This name must be known to the xDS client. Example: envoy.wasm
         */
        filterName?: string | null;
    }
    /**
     * The request and response header transformations that take effect before the request is passed along to the selected backendService.
     */
    export interface Schema$HttpHeaderAction {
        /**
         * Headers to add to a matching request before forwarding the request to the backendService.
         */
        requestHeadersToAdd?: Schema$HttpHeaderOption[];
        /**
         * A list of header names for headers that need to be removed from the request before forwarding the request to the backendService.
         */
        requestHeadersToRemove?: string[] | null;
        /**
         * Headers to add the response before sending the response back to the client.
         */
        responseHeadersToAdd?: Schema$HttpHeaderOption[];
        /**
         * A list of header names for headers that need to be removed from the response before sending the response back to the client.
         */
        responseHeadersToRemove?: string[] | null;
    }
    /**
     * matchRule criteria for request header matches.
     */
    export interface Schema$HttpHeaderMatch {
        /**
         * The value should exactly match contents of exactMatch. Only one of exactMatch, prefixMatch, suffixMatch, regexMatch, presentMatch or rangeMatch must be set.
         */
        exactMatch?: string | null;
        /**
         * The name of the HTTP header to match. For matching against the HTTP request's authority, use a headerMatch with the header name ":authority". For matching a request's method, use the headerName ":method". When the URL map is bound to a target gRPC proxy that has the validateForProxyless field set to true, only non-binary user-specified custom metadata and the `content-type` header are supported. The following transport-level headers cannot be used in header matching rules: `:authority`, `:method`, `:path`, `:scheme`, `user-agent`, `accept-encoding`, `content-encoding`, `grpc-accept-encoding`, `grpc-encoding`, `grpc-previous-rpc-attempts`, `grpc-tags-bin`, `grpc-timeout` and `grpc-trace-bin`.
         */
        headerName?: string | null;
        /**
         * If set to false, the headerMatch is considered a match if the preceding match criteria are met. If set to true, the headerMatch is considered a match if the preceding match criteria are NOT met. The default setting is false.
         */
        invertMatch?: boolean | null;
        /**
         * The value of the header must start with the contents of prefixMatch. Only one of exactMatch, prefixMatch, suffixMatch, regexMatch, presentMatch or rangeMatch must be set.
         */
        prefixMatch?: string | null;
        /**
         * A header with the contents of headerName must exist. The match takes place whether or not the request's header has a value. Only one of exactMatch, prefixMatch, suffixMatch, regexMatch, presentMatch or rangeMatch must be set.
         */
        presentMatch?: boolean | null;
        /**
         * The header value must be an integer and its value must be in the range specified in rangeMatch. If the header does not contain an integer, number or is empty, the match fails. For example for a range [-5, 0] - -3 will match. - 0 will not match. - 0.25 will not match. - -3someString will not match. Only one of exactMatch, prefixMatch, suffixMatch, regexMatch, presentMatch or rangeMatch must be set. rangeMatch is not supported for load balancers that have loadBalancingScheme set to EXTERNAL.
         */
        rangeMatch?: Schema$Int64RangeMatch;
        /**
         * The value of the header must match the regular expression specified in regexMatch. For more information about regular expression syntax, see Syntax. For matching against a port specified in the HTTP request, use a headerMatch with headerName set to PORT and a regular expression that satisfies the RFC2616 Host header's port specifier. Only one of exactMatch, prefixMatch, suffixMatch, regexMatch, presentMatch or rangeMatch must be set. Regular expressions can only be used when the loadBalancingScheme is set to INTERNAL_SELF_MANAGED.
         */
        regexMatch?: string | null;
        /**
         * The value of the header must end with the contents of suffixMatch. Only one of exactMatch, prefixMatch, suffixMatch, regexMatch, presentMatch or rangeMatch must be set.
         */
        suffixMatch?: string | null;
    }
    /**
     * Specification determining how headers are added to requests or responses.
     */
    export interface Schema$HttpHeaderOption {
        /**
         * The name of the header.
         */
        headerName?: string | null;
        /**
         * The value of the header to add.
         */
        headerValue?: string | null;
        /**
         * If false, headerValue is appended to any values that already exist for the header. If true, headerValue is set for the header, discarding any values that were set for that header. The default value is false.
         */
        replace?: boolean | null;
    }
    export interface Schema$HTTPHealthCheck {
        /**
         * The value of the host header in the HTTP health check request. If left empty (default value), the host header is set to the destination IP address to which health check packets are sent. The destination IP address depends on the type of load balancer. For details, see: https://cloud.google.com/load-balancing/docs/health-check-concepts#hc-packet-dest
         */
        host?: string | null;
        /**
         * The TCP port number to which the health check prober sends packets. The default value is 80. Valid values are 1 through 65535.
         */
        port?: number | null;
        /**
         * Not supported.
         */
        portName?: string | null;
        /**
         * Specifies how a port is selected for health checking. Can be one of the following values: USE_FIXED_PORT: Specifies a port number explicitly using the port field in the health check. Supported by backend services for pass-through load balancers and backend services for proxy load balancers. Also supported in legacy HTTP health checks for target pools. The health check supports all backends supported by the backend service provided the backend can be health checked. For example, GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network endpoint groups, and instance group backends. USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an indirect method of specifying the health check port by referring to the backend service. Only supported by backend services for proxy load balancers. Not supported by target pools. Not supported by backend services for pass-through load balancers. Supports all backends that can be health checked; for example, GCE_VM_IP_PORT network endpoint groups and instance group backends. For GCE_VM_IP_PORT network endpoint group backends, the health check uses the port number specified for each endpoint in the network endpoint group. For instance group backends, the health check uses the port number determined by looking up the backend service's named port in the instance group's list of named ports.
         */
        portSpecification?: string | null;
        /**
         * Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE.
         */
        proxyHeader?: string | null;
        /**
         * The request path of the HTTP health check request. The default value is /.
         */
        requestPath?: string | null;
        /**
         * Creates a content-based HTTP health check. In addition to the required HTTP 200 (OK) status code, you can configure the health check to pass only when the backend sends this specific ASCII response string within the first 1024 bytes of the HTTP response body. For details, see: https://cloud.google.com/load-balancing/docs/health-check-concepts#criteria-protocol-http
         */
        response?: string | null;
        /**
         * Weight report mode. used for weighted Load Balancing.
         */
        weightReportMode?: string | null;
    }
    /**
     * Represents a legacy HTTP Health Check resource. Legacy HTTP health checks are now only required by target pool-based network load balancers. For all other load balancers, including backend service-based network load balancers, and for managed instance group auto-healing, you must use modern (non-legacy) health checks. For more information, see Health checks overview .
     */
    export interface Schema$HttpHealthCheck {
        /**
         * How often (in seconds) to send a health check. The default value is 5 seconds.
         */
        checkIntervalSec?: number | null;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * A so-far unhealthy instance will be marked healthy after this many consecutive successes. The default value is 2.
         */
        healthyThreshold?: number | null;
        /**
         * The value of the host header in the HTTP health check request. If left empty (default value), the public IP on behalf of which this health check is performed will be used.
         */
        host?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#httpHealthCheck for HTTP health checks.
         */
        kind?: string | null;
        /**
         * Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * The TCP port number for the HTTP health check request. The default value is 80.
         */
        port?: number | null;
        /**
         * The request path of the HTTP health check request. The default value is /. This field does not support query parameters. Must comply with RFC3986.
         */
        requestPath?: string | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * How long (in seconds) to wait before claiming failure. The default value is 5 seconds. It is invalid for timeoutSec to have greater value than checkIntervalSec.
         */
        timeoutSec?: number | null;
        /**
         * A so-far healthy instance will be marked unhealthy after this many consecutive failures. The default value is 2.
         */
        unhealthyThreshold?: number | null;
    }
    /**
     * Contains a list of HttpHealthCheck resources.
     */
    export interface Schema$HttpHealthCheckList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of HttpHealthCheck resources.
         */
        items?: Schema$HttpHealthCheck[];
        /**
         * Type of resource.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * HttpRouteRuleMatch criteria for a request's query parameter.
     */
    export interface Schema$HttpQueryParameterMatch {
        /**
         * The queryParameterMatch matches if the value of the parameter exactly matches the contents of exactMatch. Only one of presentMatch, exactMatch, or regexMatch must be set.
         */
        exactMatch?: string | null;
        /**
         * The name of the query parameter to match. The query parameter must exist in the request, in the absence of which the request match fails.
         */
        name?: string | null;
        /**
         * Specifies that the queryParameterMatch matches if the request contains the query parameter, irrespective of whether the parameter has a value or not. Only one of presentMatch, exactMatch, or regexMatch must be set.
         */
        presentMatch?: boolean | null;
        /**
         * The queryParameterMatch matches if the value of the parameter matches the regular expression specified by regexMatch. For more information about regular expression syntax, see Syntax. Only one of presentMatch, exactMatch, or regexMatch must be set. Regular expressions can only be used when the loadBalancingScheme is set to INTERNAL_SELF_MANAGED.
         */
        regexMatch?: string | null;
    }
    /**
     * Specifies settings for an HTTP redirect.
     */
    export interface Schema$HttpRedirectAction {
        /**
         * The host that is used in the redirect response instead of the one that was supplied in the request. The value must be from 1 to 255 characters.
         */
        hostRedirect?: string | null;
        /**
         * If set to true, the URL scheme in the redirected request is set to HTTPS. If set to false, the URL scheme of the redirected request remains the same as that of the request. This must only be set for URL maps used in TargetHttpProxys. Setting this true for TargetHttpsProxy is not permitted. The default is set to false.
         */
        httpsRedirect?: boolean | null;
        /**
         * The path that is used in the redirect response instead of the one that was supplied in the request. pathRedirect cannot be supplied together with prefixRedirect. Supply one alone or neither. If neither is supplied, the path of the original request is used for the redirect. The value must be from 1 to 1024 characters.
         */
        pathRedirect?: string | null;
        /**
         * The prefix that replaces the prefixMatch specified in the HttpRouteRuleMatch, retaining the remaining portion of the URL before redirecting the request. prefixRedirect cannot be supplied together with pathRedirect. Supply one alone or neither. If neither is supplied, the path of the original request is used for the redirect. The value must be from 1 to 1024 characters.
         */
        prefixRedirect?: string | null;
        /**
         * The HTTP Status code to use for this RedirectAction. Supported values are: - MOVED_PERMANENTLY_DEFAULT, which is the default value and corresponds to 301. - FOUND, which corresponds to 302. - SEE_OTHER which corresponds to 303. - TEMPORARY_REDIRECT, which corresponds to 307. In this case, the request method is retained. - PERMANENT_REDIRECT, which corresponds to 308. In this case, the request method is retained.
         */
        redirectResponseCode?: string | null;
        /**
         * If set to true, any accompanying query portion of the original URL is removed before redirecting the request. If set to false, the query portion of the original URL is retained. The default is set to false.
         */
        stripQuery?: boolean | null;
    }
    /**
     * The retry policy associates with HttpRouteRule
     */
    export interface Schema$HttpRetryPolicy {
        /**
         * Specifies the allowed number retries. This number must be \> 0. If not specified, defaults to 1.
         */
        numRetries?: number | null;
        /**
         * Specifies a non-zero timeout per retry attempt. If not specified, will use the timeout set in the HttpRouteAction field. If timeout in the HttpRouteAction field is not set, this field uses the largest timeout among all backend services associated with the route. Not supported when the URL map is bound to a target gRPC proxy that has the validateForProxyless field set to true.
         */
        perTryTimeout?: Schema$Duration;
        /**
         * Specifies one or more conditions when this retry policy applies. Valid values are: - 5xx: retry is attempted if the instance or endpoint responds with any 5xx response code, or if the instance or endpoint does not respond at all. For example, disconnects, reset, read timeout, connection failure, and refused streams. - gateway-error: Similar to 5xx, but only applies to response codes 502, 503 or 504. - connect-failure: a retry is attempted on failures connecting to the instance or endpoint. For example, connection timeouts. - retriable-4xx: a retry is attempted if the instance or endpoint responds with a 4xx response code. The only error that you can retry is error code 409. - refused-stream: a retry is attempted if the instance or endpoint resets the stream with a REFUSED_STREAM error code. This reset type indicates that it is safe to retry. - cancelled: a retry is attempted if the gRPC status code in the response header is set to cancelled. - deadline-exceeded: a retry is attempted if the gRPC status code in the response header is set to deadline-exceeded. - internal: a retry is attempted if the gRPC status code in the response header is set to internal. - resource-exhausted: a retry is attempted if the gRPC status code in the response header is set to resource-exhausted. - unavailable: a retry is attempted if the gRPC status code in the response header is set to unavailable. Only the following codes are supported when the URL map is bound to target gRPC proxy that has validateForProxyless field set to true. - cancelled - deadline-exceeded - internal - resource-exhausted - unavailable
         */
        retryConditions?: string[] | null;
    }
    export interface Schema$HttpRouteAction {
        /**
         * The specification for allowing client-side cross-origin requests. For more information about the W3C recommendation for cross-origin resource sharing (CORS), see Fetch API Living Standard. Not supported when the URL map is bound to a target gRPC proxy.
         */
        corsPolicy?: Schema$CorsPolicy;
        /**
         * The specification for fault injection introduced into traffic to test the resiliency of clients to backend service failure. As part of fault injection, when clients send requests to a backend service, delays can be introduced by a load balancer on a percentage of requests before sending those requests to the backend service. Similarly requests from clients can be aborted by the load balancer for a percentage of requests. timeout and retry_policy is ignored by clients that are configured with a fault_injection_policy if: 1. The traffic is generated by fault injection AND 2. The fault injection is not a delay fault injection. Fault injection is not supported with the classic Application Load Balancer . To see which load balancers support fault injection, see Load balancing: Routing and traffic management features.
         */
        faultInjectionPolicy?: Schema$HttpFaultInjection;
        /**
         * Specifies the maximum duration (timeout) for streams on the selected route. Unlike the timeout field where the timeout duration starts from the time the request has been fully processed (known as *end-of-stream*), the duration in this field is computed from the beginning of the stream until the response has been processed, including all retries. A stream that does not complete in this duration is closed. If not specified, this field uses the maximum maxStreamDuration value among all backend services associated with the route. This field is only allowed if the Url map is used with backend services with loadBalancingScheme set to INTERNAL_SELF_MANAGED.
         */
        maxStreamDuration?: Schema$Duration;
        /**
         * Specifies the policy on how requests intended for the route's backends are shadowed to a separate mirrored backend service. The load balancer does not wait for responses from the shadow service. Before sending traffic to the shadow service, the host / authority header is suffixed with -shadow. Not supported when the URL map is bound to a target gRPC proxy that has the validateForProxyless field set to true.
         */
        requestMirrorPolicy?: Schema$RequestMirrorPolicy;
        /**
         * Specifies the retry policy associated with this route.
         */
        retryPolicy?: Schema$HttpRetryPolicy;
        /**
         * Specifies the timeout for the selected route. Timeout is computed from the time the request has been fully processed (known as *end-of-stream*) up until the response has been processed. Timeout includes all retries. If not specified, this field uses the largest timeout among all backend services associated with the route. Not supported when the URL map is bound to a target gRPC proxy that has validateForProxyless field set to true.
         */
        timeout?: Schema$Duration;
        /**
         * The spec to modify the URL of the request, before forwarding the request to the matched service. urlRewrite is the only action supported in UrlMaps for classic Application Load Balancers. Not supported when the URL map is bound to a target gRPC proxy that has the validateForProxyless field set to true.
         */
        urlRewrite?: Schema$UrlRewrite;
        /**
         * A list of weighted backend services to send traffic to when a route match occurs. The weights determine the fraction of traffic that flows to their corresponding backend service. If all traffic needs to go to a single backend service, there must be one weightedBackendService with weight set to a non-zero number. After a backend service is identified and before forwarding the request to the backend service, advanced routing actions such as URL rewrites and header transformations are applied depending on additional settings specified in this HttpRouteAction.
         */
        weightedBackendServices?: Schema$WeightedBackendService[];
    }
    /**
     * The HttpRouteRule setting specifies how to match an HTTP request and the corresponding routing action that load balancing proxies perform.
     */
    export interface Schema$HttpRouteRule {
        /**
         * customErrorResponsePolicy specifies how the Load Balancer returns error responses when BackendServiceor BackendBucket responds with an error. If a policy for an error code is not configured for the RouteRule, a policy for the error code configured in pathMatcher.defaultCustomErrorResponsePolicy is applied. If one is not specified in pathMatcher.defaultCustomErrorResponsePolicy, the policy configured in UrlMap.defaultCustomErrorResponsePolicy takes effect. For example, consider a UrlMap with the following configuration: - UrlMap.defaultCustomErrorResponsePolicy are configured with policies for 5xx and 4xx errors - A RouteRule for /coming_soon/ is configured for the error code 404. If the request is for www.myotherdomain.com and a 404 is encountered, the policy under UrlMap.defaultCustomErrorResponsePolicy takes effect. If a 404 response is encountered for the request www.example.com/current_events/, the pathMatcher's policy takes effect. If however, the request for www.example.com/coming_soon/ encounters a 404, the policy in RouteRule.customErrorResponsePolicy takes effect. If any of the requests in this example encounter a 500 error code, the policy at UrlMap.defaultCustomErrorResponsePolicy takes effect. When used in conjunction with routeRules.routeAction.retryPolicy, retries take precedence. Only once all retries are exhausted, the customErrorResponsePolicy is applied. While attempting a retry, if load balancer is successful in reaching the service, the customErrorResponsePolicy is ignored and the response from the service is returned to the client. customErrorResponsePolicy is supported only for global external Application Load Balancers.
         */
        customErrorResponsePolicy?: Schema$CustomErrorResponsePolicy;
        /**
         * The short description conveying the intent of this routeRule. The description can have a maximum length of 1024 characters.
         */
        description?: string | null;
        /**
         * Specifies changes to request and response headers that need to take effect for the selected backendService. The headerAction value specified here is applied before the matching pathMatchers[].headerAction and after pathMatchers[].routeRules[].routeAction.weightedBackendService.backendServiceWeightAction[].headerAction HeaderAction is not supported for load balancers that have their loadBalancingScheme set to EXTERNAL. Not supported when the URL map is bound to a target gRPC proxy that has validateForProxyless field set to true.
         */
        headerAction?: Schema$HttpHeaderAction;
        /**
         * Outbound route specific configuration for networkservices.HttpFilter resources enabled by Traffic Director. httpFilterConfigs only applies for load balancers with loadBalancingScheme set to INTERNAL_SELF_MANAGED. See ForwardingRule for more details. Not supported when the URL map is bound to a target gRPC proxy that has validateForProxyless field set to true.
         */
        httpFilterConfigs?: Schema$HttpFilterConfig[];
        /**
         * Outbound route specific metadata supplied to networkservices.HttpFilter resources enabled by Traffic Director. httpFilterMetadata only applies for load balancers with loadBalancingScheme set to INTERNAL_SELF_MANAGED. See ForwardingRule for more details. The only configTypeUrl supported is type.googleapis.com/google.protobuf.Struct Not supported when the URL map is bound to a target gRPC proxy that has validateForProxyless field set to true.
         */
        httpFilterMetadata?: Schema$HttpFilterConfig[];
        /**
         * The list of criteria for matching attributes of a request to this routeRule. This list has OR semantics: the request matches this routeRule when any of the matchRules are satisfied. However predicates within a given matchRule have AND semantics. All predicates within a matchRule must match for the request to match the rule.
         */
        matchRules?: Schema$HttpRouteRuleMatch[];
        /**
         * For routeRules within a given pathMatcher, priority determines the order in which a load balancer interprets routeRules. RouteRules are evaluated in order of priority, from the lowest to highest number. The priority of a rule decreases as its number increases (1, 2, 3, N+1). The first rule that matches the request is applied. You cannot configure two or more routeRules with the same priority. Priority for each rule must be set to a number from 0 to 2147483647 inclusive. Priority numbers can have gaps, which enable you to add or remove rules in the future without affecting the rest of the rules. For example, 1, 2, 3, 4, 5, 9, 12, 16 is a valid series of priority numbers to which you could add rules numbered from 6 to 8, 10 to 11, and 13 to 15 in the future without any impact on existing rules.
         */
        priority?: number | null;
        /**
         * In response to a matching matchRule, the load balancer performs advanced routing actions, such as URL rewrites and header transformations, before forwarding the request to the selected backend. If routeAction specifies any weightedBackendServices, service must not be set. Conversely if service is set, routeAction cannot contain any weightedBackendServices. Only one of urlRedirect, service or routeAction.weightedBackendService must be set. URL maps for classic Application Load Balancers only support the urlRewrite action within a route rule's routeAction.
         */
        routeAction?: Schema$HttpRouteAction;
        /**
         * The full or partial URL of the backend service resource to which traffic is directed if this rule is matched. If routeAction is also specified, advanced routing actions, such as URL rewrites, take effect before sending the request to the backend. However, if service is specified, routeAction cannot contain any weightedBackendServices. Conversely, if routeAction specifies any weightedBackendServices, service must not be specified. Only one of urlRedirect, service or routeAction.weightedBackendService must be set.
         */
        service?: string | null;
        /**
         * When this rule is matched, the request is redirected to a URL specified by urlRedirect. If urlRedirect is specified, service or routeAction must not be set. Not supported when the URL map is bound to a target gRPC proxy.
         */
        urlRedirect?: Schema$HttpRedirectAction;
    }
    /**
     * HttpRouteRuleMatch specifies a set of criteria for matching requests to an HttpRouteRule. All specified criteria must be satisfied for a match to occur.
     */
    export interface Schema$HttpRouteRuleMatch {
        /**
         * For satisfying the matchRule condition, the path of the request must exactly match the value specified in fullPathMatch after removing any query parameters and anchor that may be part of the original URL. fullPathMatch must be from 1 to 1024 characters. Only one of prefixMatch, fullPathMatch or regexMatch must be specified.
         */
        fullPathMatch?: string | null;
        /**
         * Specifies a list of header match criteria, all of which must match corresponding headers in the request.
         */
        headerMatches?: Schema$HttpHeaderMatch[];
        /**
         * Specifies that prefixMatch and fullPathMatch matches are case sensitive. The default value is false. ignoreCase must not be used with regexMatch. Not supported when the URL map is bound to a target gRPC proxy.
         */
        ignoreCase?: boolean | null;
        /**
         * Opaque filter criteria used by the load balancer to restrict routing configuration to a limited set of xDS compliant clients. In their xDS requests to the load balancer, xDS clients present node metadata. When there is a match, the relevant routing configuration is made available to those proxies. For each metadataFilter in this list, if its filterMatchCriteria is set to MATCH_ANY, at least one of the filterLabels must match the corresponding label provided in the metadata. If its filterMatchCriteria is set to MATCH_ALL, then all of its filterLabels must match with corresponding labels provided in the metadata. If multiple metadata filters are specified, all of them need to be satisfied in order to be considered a match. metadataFilters specified here is applied after those specified in ForwardingRule that refers to the UrlMap this HttpRouteRuleMatch belongs to. metadataFilters only applies to load balancers that have loadBalancingScheme set to INTERNAL_SELF_MANAGED. Not supported when the URL map is bound to a target gRPC proxy that has validateForProxyless field set to true.
         */
        metadataFilters?: Schema$MetadataFilter[];
        /**
         * If specified, the route is a pattern match expression that must match the :path header once the query string is removed. A pattern match allows you to match - The value must be between 1 and 1024 characters - The pattern must start with a leading slash ("/") - There may be no more than 5 operators in pattern Precisely one of prefix_match, full_path_match, regex_match or path_template_match must be set.
         */
        pathTemplateMatch?: string | null;
        /**
         * For satisfying the matchRule condition, the request's path must begin with the specified prefixMatch. prefixMatch must begin with a /. The value must be from 1 to 1024 characters. Only one of prefixMatch, fullPathMatch or regexMatch must be specified.
         */
        prefixMatch?: string | null;
        /**
         * Specifies a list of query parameter match criteria, all of which must match corresponding query parameters in the request. Not supported when the URL map is bound to a target gRPC proxy.
         */
        queryParameterMatches?: Schema$HttpQueryParameterMatch[];
        /**
         * For satisfying the matchRule condition, the path of the request must satisfy the regular expression specified in regexMatch after removing any query parameters and anchor supplied with the original URL. For more information about regular expression syntax, see Syntax. Only one of prefixMatch, fullPathMatch or regexMatch must be specified. Regular expressions can only be used when the loadBalancingScheme is set to INTERNAL_SELF_MANAGED.
         */
        regexMatch?: string | null;
    }
    export interface Schema$HTTPSHealthCheck {
        /**
         * The value of the host header in the HTTPS health check request. If left empty (default value), the host header is set to the destination IP address to which health check packets are sent. The destination IP address depends on the type of load balancer. For details, see: https://cloud.google.com/load-balancing/docs/health-check-concepts#hc-packet-dest
         */
        host?: string | null;
        /**
         * The TCP port number to which the health check prober sends packets. The default value is 443. Valid values are 1 through 65535.
         */
        port?: number | null;
        /**
         * Not supported.
         */
        portName?: string | null;
        /**
         * Specifies how a port is selected for health checking. Can be one of the following values: USE_FIXED_PORT: Specifies a port number explicitly using the port field in the health check. Supported by backend services for pass-through load balancers and backend services for proxy load balancers. Not supported by target pools. The health check supports all backends supported by the backend service provided the backend can be health checked. For example, GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network endpoint groups, and instance group backends. USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an indirect method of specifying the health check port by referring to the backend service. Only supported by backend services for proxy load balancers. Not supported by target pools. Not supported by backend services for pass-through load balancers. Supports all backends that can be health checked; for example, GCE_VM_IP_PORT network endpoint groups and instance group backends. For GCE_VM_IP_PORT network endpoint group backends, the health check uses the port number specified for each endpoint in the network endpoint group. For instance group backends, the health check uses the port number determined by looking up the backend service's named port in the instance group's list of named ports.
         */
        portSpecification?: string | null;
        /**
         * Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE.
         */
        proxyHeader?: string | null;
        /**
         * The request path of the HTTPS health check request. The default value is /.
         */
        requestPath?: string | null;
        /**
         * Creates a content-based HTTPS health check. In addition to the required HTTP 200 (OK) status code, you can configure the health check to pass only when the backend sends this specific ASCII response string within the first 1024 bytes of the HTTP response body. For details, see: https://cloud.google.com/load-balancing/docs/health-check-concepts#criteria-protocol-http
         */
        response?: string | null;
        /**
         * Weight report mode. used for weighted Load Balancing.
         */
        weightReportMode?: string | null;
    }
    /**
     * Represents a legacy HTTPS Health Check resource. Legacy HTTPS health checks have been deprecated. If you are using a target pool-based network load balancer, you must use a legacy HTTP (not HTTPS) health check. For all other load balancers, including backend service-based network load balancers, and for managed instance group auto-healing, you must use modern (non-legacy) health checks. For more information, see Health checks overview .
     */
    export interface Schema$HttpsHealthCheck {
        /**
         * How often (in seconds) to send a health check. The default value is 5 seconds.
         */
        checkIntervalSec?: number | null;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * A so-far unhealthy instance will be marked healthy after this many consecutive successes. The default value is 2.
         */
        healthyThreshold?: number | null;
        /**
         * The value of the host header in the HTTPS health check request. If left empty (default value), the public IP on behalf of which this health check is performed will be used.
         */
        host?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * Type of the resource.
         */
        kind?: string | null;
        /**
         * Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * The TCP port number for the HTTPS health check request. The default value is 443.
         */
        port?: number | null;
        /**
         * The request path of the HTTPS health check request. The default value is "/". Must comply with RFC3986.
         */
        requestPath?: string | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * How long (in seconds) to wait before claiming failure. The default value is 5 seconds. It is invalid for timeoutSec to have a greater value than checkIntervalSec.
         */
        timeoutSec?: number | null;
        /**
         * A so-far healthy instance will be marked unhealthy after this many consecutive failures. The default value is 2.
         */
        unhealthyThreshold?: number | null;
    }
    /**
     * Contains a list of HttpsHealthCheck resources.
     */
    export interface Schema$HttpsHealthCheckList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of HttpsHealthCheck resources.
         */
        items?: Schema$HttpsHealthCheck[];
        /**
         * Type of resource.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Represents an Image resource. You can use images to create boot disks for your VM instances. For more information, read Images.
     */
    export interface Schema$Image {
        /**
         * The architecture of the image. Valid values are ARM64 or X86_64.
         */
        architecture?: string | null;
        /**
         * Size of the image tar.gz archive stored in Google Cloud Storage (in bytes).
         */
        archiveSizeBytes?: string | null;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * The deprecation status associated with this image.
         */
        deprecated?: Schema$DeprecationStatus;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * Size of the image when restored onto a persistent disk (in GB).
         */
        diskSizeGb?: string | null;
        /**
         * Whether this image is created from a confidential compute mode disk. [Output Only]: This field is not set by user, but from source disk.
         */
        enableConfidentialCompute?: boolean | null;
        /**
         * The name of the image family to which this image belongs. The image family name can be from a publicly managed image family provided by Compute Engine, or from a custom image family you create. For example, centos-stream-9 is a publicly available image family. For more information, see Image family best practices. When creating disks, you can specify an image family instead of a specific image name. The image family always returns its latest image that is not deprecated. The name of the image family must comply with RFC1035.
         */
        family?: string | null;
        /**
         * A list of features to enable on the guest operating system. Applicable only for bootable images. To see a list of available options, see the guestOSfeatures[].type parameter.
         */
        guestOsFeatures?: Schema$GuestOsFeature[];
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * Encrypts the image using a customer-supplied encryption key. After you encrypt an image with a customer-supplied key, you must provide the same key if you use the image later (e.g. to create a disk from the image). Customer-supplied encryption keys do not protect access to metadata of the disk. If you do not provide an encryption key when creating the image, then the disk will be encrypted using an automatically generated key and you do not need to provide a key to use the image later.
         */
        imageEncryptionKey?: Schema$CustomerEncryptionKey;
        /**
         * [Output Only] Type of the resource. Always compute#image for images.
         */
        kind?: string | null;
        /**
         * A fingerprint for the labels being applied to this image, which is essentially a hash of the labels used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve an image.
         */
        labelFingerprint?: string | null;
        /**
         * Labels to apply to this image. These can be later modified by the setLabels method.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * Integer license codes indicating which licenses are attached to this image.
         */
        licenseCodes?: string[] | null;
        /**
         * Any applicable license URI.
         */
        licenses?: string[] | null;
        /**
         * A flag for marketplace VM disk created from the image, which is designed for marketplace VM disk to prevent the proprietary data on the disk from being accessed unwantedly. The flag will be inherited by the disk created from the image. The disk with locked flag set to true will be prohibited from performing the operations below: - R/W or R/O disk attach - Disk detach, if disk is created via create-on-create - Create images - Create snapshots - Create disk clone (create disk from the current disk) The image with the locked field set to true will be prohibited from performing the operations below: - Create images from the current image - Update the locked field for the current image The instance with at least one disk with locked flag set to true will be prohibited from performing the operations below: - Secondary disk attach - Create instant snapshot - Create machine images - Create instance template - Delete the instance with --keep-disk parameter set to true
         */
        locked?: boolean | null;
        /**
         * Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * The parameters of the raw disk image.
         */
        rawDisk?: {
            containerType?: string;
            sha1Checksum?: string;
            source?: string;
        } | null;
        /**
         * A rollout policy to apply to this image. When specified, the rollout policy overrides per-zone references to the image via the associated image family. The rollout policy restricts the zones where this image is accessible when using a zonal image family reference. When the rollout policy does not include the user specified zone, or if the zone is rolled out, this image is accessible. The rollout policy for this image is read-only, except for allowlisted users. This field might not be configured. To view the latest non-deprecated image in a specific zone, use the imageFamilyViews.get method.
         */
        rolloutOverride?: Schema$RolloutPolicy;
        /**
         * [Output Only] Reserved for future use.
         */
        satisfiesPzs?: boolean | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource's resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * Set the secure boot keys of shielded instance.
         */
        shieldedInstanceInitialState?: Schema$InitialStateConfig;
        /**
         * URL of the source disk used to create this image. For example, the following are valid values: - https://www.googleapis.com/compute/v1/projects/project/zones/zone /disks/disk - projects/project/zones/zone/disks/disk - zones/zone/disks/disk In order to create an image, you must provide the full or partial URL of one of the following: - The rawDisk.source URL - The sourceDisk URL - The sourceImage URL - The sourceSnapshot URL
         */
        sourceDisk?: string | null;
        /**
         * The customer-supplied encryption key of the source disk. Required if the source disk is protected by a customer-supplied encryption key.
         */
        sourceDiskEncryptionKey?: Schema$CustomerEncryptionKey;
        /**
         * [Output Only] The ID value of the disk used to create this image. This value may be used to determine whether the image was taken from the current or a previous instance of a given disk name.
         */
        sourceDiskId?: string | null;
        /**
         * URL of the source image used to create this image. The following are valid formats for the URL: - https://www.googleapis.com/compute/v1/projects/project_id/global/ images/image_name - projects/project_id/global/images/image_name In order to create an image, you must provide the full or partial URL of one of the following: - The rawDisk.source URL - The sourceDisk URL - The sourceImage URL - The sourceSnapshot URL
         */
        sourceImage?: string | null;
        /**
         * The customer-supplied encryption key of the source image. Required if the source image is protected by a customer-supplied encryption key.
         */
        sourceImageEncryptionKey?: Schema$CustomerEncryptionKey;
        /**
         * [Output Only] The ID value of the image used to create this image. This value may be used to determine whether the image was taken from the current or a previous instance of a given image name.
         */
        sourceImageId?: string | null;
        /**
         * URL of the source snapshot used to create this image. The following are valid formats for the URL: - https://www.googleapis.com/compute/v1/projects/project_id/global/ snapshots/snapshot_name - projects/project_id/global/snapshots/snapshot_name In order to create an image, you must provide the full or partial URL of one of the following: - The rawDisk.source URL - The sourceDisk URL - The sourceImage URL - The sourceSnapshot URL
         */
        sourceSnapshot?: string | null;
        /**
         * The customer-supplied encryption key of the source snapshot. Required if the source snapshot is protected by a customer-supplied encryption key.
         */
        sourceSnapshotEncryptionKey?: Schema$CustomerEncryptionKey;
        /**
         * [Output Only] The ID value of the snapshot used to create this image. This value may be used to determine whether the snapshot was taken from the current or a previous instance of a given snapshot name.
         */
        sourceSnapshotId?: string | null;
        /**
         * The type of the image used to create this disk. The default and only valid value is RAW.
         */
        sourceType?: string | null;
        /**
         * [Output Only] The status of the image. An image can be used to create other resources, such as instances, only after the image has been successfully created and the status is set to READY. Possible values are FAILED, PENDING, or READY.
         */
        status?: string | null;
        /**
         * Cloud Storage bucket storage location of the image (regional or multi-regional).
         */
        storageLocations?: string[] | null;
        /**
         * A list of publicly visible user-licenses. Unlike regular licenses, user provided licenses can be modified after the disk is created. This includes a list of URLs to the license resource. For example, to provide a debian license: https://www.googleapis.com/compute/v1/projects/debian-cloud/global/licenses/debian-9-stretch
         */
        userLicenses?: string[] | null;
    }
    export interface Schema$ImageFamilyView {
        /**
         * The latest image that is part of the specified image family in the requested location, and that is not deprecated.
         */
        image?: Schema$Image;
    }
    /**
     * Contains a list of images.
     */
    export interface Schema$ImageList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of Image resources.
         */
        items?: Schema$Image[];
        /**
         * Type of resource.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Initial State for shielded instance, these are public keys which are safe to store in public
     */
    export interface Schema$InitialStateConfig {
        /**
         * The Key Database (db).
         */
        dbs?: Schema$FileContentBuffer[];
        /**
         * The forbidden key database (dbx).
         */
        dbxs?: Schema$FileContentBuffer[];
        /**
         * The Key Exchange Key (KEK).
         */
        keks?: Schema$FileContentBuffer[];
        /**
         * The Platform Key (PK).
         */
        pk?: Schema$FileContentBuffer;
    }
    /**
     * Represents an Instance resource. An instance is a virtual machine that is hosted on Google Cloud Platform. For more information, read Virtual Machine Instances.
     */
    export interface Schema$Instance {
        /**
         * Controls for advanced machine-related behavior features.
         */
        advancedMachineFeatures?: Schema$AdvancedMachineFeatures;
        /**
         * Allows this instance to send and receive packets with non-matching destination or source IPs. This is required if you plan to use this instance to forward routes. For more information, see Enabling IP Forwarding .
         */
        canIpForward?: boolean | null;
        confidentialInstanceConfig?: Schema$ConfidentialInstanceConfig;
        /**
         * [Output Only] The CPU platform used by this instance.
         */
        cpuPlatform?: string | null;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * Whether the resource should be protected against deletion.
         */
        deletionProtection?: boolean | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * Array of disks associated with this instance. Persistent disks must be created before you can assign them.
         */
        disks?: Schema$AttachedDisk[];
        /**
         * Enables display device for the instance.
         */
        displayDevice?: Schema$DisplayDevice;
        /**
         * Specifies whether the disks restored from source snapshots or source machine image should erase Windows specific VSS signature.
         */
        eraseWindowsVssSignature?: boolean | null;
        /**
         * Specifies a fingerprint for this resource, which is essentially a hash of the instance's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update the instance. You must always provide an up-to-date fingerprint hash in order to update the instance. To see the latest fingerprint, make get() request to the instance.
         */
        fingerprint?: string | null;
        /**
         * A list of the type and count of accelerator cards attached to the instance.
         */
        guestAccelerators?: Schema$AcceleratorConfig[];
        /**
         * Specifies the hostname of the instance. The specified hostname must be RFC1035 compliant. If hostname is not specified, the default hostname is [INSTANCE_NAME].c.[PROJECT_ID].internal when using the global DNS, and [INSTANCE_NAME].[ZONE].c.[PROJECT_ID].internal when using zonal DNS.
         */
        hostname?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * Encrypts suspended data for an instance with a customer-managed encryption key. If you are creating a new instance, this field will encrypt the local SSD and in-memory contents of the instance during the suspend operation. If you do not provide an encryption key when creating the instance, then the local SSD and in-memory contents will be encrypted using an automatically generated key during the suspend operation.
         */
        instanceEncryptionKey?: Schema$CustomerEncryptionKey;
        /**
         * KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified.
         */
        keyRevocationActionType?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#instance for instances.
         */
        kind?: string | null;
        /**
         * A fingerprint for this request, which is essentially a hash of the label's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels. To see the latest fingerprint, make get() request to the instance.
         */
        labelFingerprint?: string | null;
        /**
         * Labels to apply to this instance. These can be later modified by the setLabels method.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * [Output Only] Last start timestamp in RFC3339 text format.
         */
        lastStartTimestamp?: string | null;
        /**
         * [Output Only] Last stop timestamp in RFC3339 text format.
         */
        lastStopTimestamp?: string | null;
        /**
         * [Output Only] Last suspended timestamp in RFC3339 text format.
         */
        lastSuspendedTimestamp?: string | null;
        /**
         * Full or partial URL of the machine type resource to use for this instance, in the format: zones/zone/machineTypes/machine-type. This is provided by the client when the instance is created. For example, the following is a valid partial url to a predefined machine type: zones/us-central1-f/machineTypes/n1-standard-1 To create a custom machine type, provide a URL to a machine type in the following format, where CPUS is 1 or an even number up to 32 (2, 4, 6, ... 24, etc), and MEMORY is the total memory for this instance. Memory must be a multiple of 256 MB and must be supplied in MB (e.g. 5 GB of memory is 5120 MB): zones/zone/machineTypes/custom-CPUS-MEMORY For example: zones/us-central1-f/machineTypes/custom-4-5120 For a full list of restrictions, read the Specifications for custom machine types.
         */
        machineType?: string | null;
        /**
         * The metadata key/value pairs assigned to this instance. This includes custom metadata and predefined keys.
         */
        metadata?: Schema$Metadata;
        /**
         * Specifies a minimum CPU platform for the VM instance. Applicable values are the friendly names of CPU platforms, such as minCpuPlatform: "Intel Haswell" or minCpuPlatform: "Intel Sandy Bridge".
         */
        minCpuPlatform?: string | null;
        /**
         * The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * An array of network configurations for this instance. These specify how interfaces are configured to interact with other network services, such as connecting to the internet. Multiple interfaces are supported per instance.
         */
        networkInterfaces?: Schema$NetworkInterface[];
        networkPerformanceConfig?: Schema$NetworkPerformanceConfig;
        /**
         * Input only. [Input Only] Additional params passed with the request, but not persisted as part of resource payload.
         */
        params?: Schema$InstanceParams;
        /**
         * Partner Metadata assigned to the instance. A map from a subdomain (namespace) to entries map.
         */
        partnerMetadata?: {
            [key: string]: Schema$StructuredEntries;
        } | null;
        /**
         * PostKeyRevocationActionType of the instance.
         */
        postKeyRevocationActionType?: string | null;
        /**
         * Total amount of preserved state for SUSPENDED instances. Read-only in the api.
         */
        preservedStateSizeGb?: string | null;
        /**
         * The private IPv6 google access type for the VM. If not specified, use INHERIT_FROM_SUBNETWORK as default.
         */
        privateIpv6GoogleAccess?: string | null;
        /**
         * Specifies the reservations that this instance can consume from.
         */
        reservationAffinity?: Schema$ReservationAffinity;
        /**
         * Resource policies applied to this instance.
         */
        resourcePolicies?: string[] | null;
        /**
         * [Output Only] Specifies values set for instance attributes as compared to the values requested by user in the corresponding input only field.
         */
        resourceStatus?: Schema$ResourceStatus;
        /**
         * [Output Only] Reserved for future use.
         */
        satisfiesPzs?: boolean | null;
        /**
         * Sets the scheduling options for this instance.
         */
        scheduling?: Schema$Scheduling;
        /**
         * [Input Only] Secure tags to apply to this instance. These can be later modified by the update method. Maximum number of secure tags allowed is 50.
         */
        secureTags?: string[] | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * A list of service accounts, with their specified scopes, authorized for this instance. Only one service account per VM instance is supported. Service accounts generate access tokens that can be accessed through the metadata server and used to authenticate applications on the instance. See Service Accounts for more information.
         */
        serviceAccounts?: Schema$ServiceAccount[];
        /**
         * Mapping of user-defined keys to specifications for service integrations. Currently only a single key-value pair is supported.
         */
        serviceIntegrationSpecs?: {
            [key: string]: Schema$ServiceIntegrationSpec;
        } | null;
        shieldedInstanceConfig?: Schema$ShieldedInstanceConfig;
        shieldedInstanceIntegrityPolicy?: Schema$ShieldedInstanceIntegrityPolicy;
        /**
         * Deprecating, please use shielded_instance_config.
         */
        shieldedVmConfig?: Schema$ShieldedVmConfig;
        /**
         * Deprecating, please use shielded_instance_integrity_policy.
         */
        shieldedVmIntegrityPolicy?: Schema$ShieldedVmIntegrityPolicy;
        /**
         * Source machine image
         */
        sourceMachineImage?: string | null;
        /**
         * Source machine image encryption key when creating an instance from a machine image.
         */
        sourceMachineImageEncryptionKey?: Schema$CustomerEncryptionKey;
        /**
         * [Output Only] Whether a VM has been restricted for start because Compute Engine has detected suspicious activity.
         */
        startRestricted?: boolean | null;
        /**
         * [Output Only] The status of the instance. One of the following values: PROVISIONING, STAGING, RUNNING, STOPPING, SUSPENDING, SUSPENDED, REPAIRING, and TERMINATED. For more information about the status of the instance, see Instance life cycle.
         */
        status?: string | null;
        /**
         * [Output Only] An optional, human-readable explanation of the status.
         */
        statusMessage?: string | null;
        /**
         * Tags to apply to this instance. Tags are used to identify valid sources or targets for network firewalls and are specified by the client during instance creation. The tags can be later modified by the setTags method. Each tag within the list must comply with RFC1035. Multiple tags can be specified via the 'tags.items' field.
         */
        tags?: Schema$Tags;
        /**
         * [Output Only] Specifies upcoming maintenance for the instance.
         */
        upcomingMaintenance?: Schema$UpcomingMaintenance;
        /**
         * [Output Only] URL of the zone where the instance resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
         */
        zone?: string | null;
    }
    export interface Schema$InstanceAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * An object that contains a list of instances scoped by zone.
         */
        items?: {
            [key: string]: Schema$InstancesScopedList;
        } | null;
        /**
         * [Output Only] Type of resource. Always compute#instanceAggregatedList for aggregated lists of Instance resources.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$InstanceConsumptionData {
        /**
         * Resources consumed by the instance.
         */
        consumptionInfo?: Schema$InstanceConsumptionInfo;
        /**
         * Server-defined URL for the instance.
         */
        instance?: string | null;
    }
    export interface Schema$InstanceConsumptionInfo {
        /**
         * The number of virtual CPUs that are available to the instance.
         */
        guestCpus?: number | null;
        /**
         * The amount of local SSD storage available to the instance, defined in GiB.
         */
        localSsdGb?: number | null;
        /**
         * The amount of physical memory available to the instance, defined in MiB.
         */
        memoryMb?: number | null;
        /**
         * The minimal guaranteed number of virtual CPUs that are reserved.
         */
        minNodeCpus?: number | null;
    }
    /**
     * Represents an Instance Group resource. Instance Groups can be used to configure a target for load balancing. Instance groups can either be managed or unmanaged. To create managed instance groups, use the instanceGroupManager or regionInstanceGroupManager resource instead. Use zonal unmanaged instance groups if you need to apply load balancing to groups of heterogeneous instances or if you need to manage the instances yourself. You cannot create regional unmanaged instance groups. For more information, read Instance groups.
     */
    export interface Schema$InstanceGroup {
        /**
         * [Output Only] The creation timestamp for this instance group in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * [Output Only] The fingerprint of the named ports. The system uses this fingerprint to detect conflicts when multiple users change the named ports concurrently.
         */
        fingerprint?: string | null;
        /**
         * [Output Only] A unique identifier for this instance group, generated by the server.
         */
        id?: string | null;
        /**
         * [Output Only] The resource type, which is always compute#instanceGroup for instance groups.
         */
        kind?: string | null;
        /**
         * The name of the instance group. The name must be 1-63 characters long, and comply with RFC1035.
         */
        name?: string | null;
        /**
         *  Assigns a name to a port number. For example: {name: "http", port: 80\} This allows the system to reference ports by the assigned name instead of a port number. Named ports can also contain multiple ports. For example: [{name: "app1", port: 8080\}, {name: "app1", port: 8081\}, {name: "app2", port: 8082\}] Named ports apply to all instances in this instance group.
         */
        namedPorts?: Schema$NamedPort[];
        /**
         * [Output Only] The URL of the network to which all instances in the instance group belong. If your instance has multiple network interfaces, then the network and subnetwork fields only refer to the network and subnet used by your primary interface (nic0).
         */
        network?: string | null;
        /**
         * [Output Only] The URL of the region where the instance group is located (for regional resources).
         */
        region?: string | null;
        /**
         * [Output Only] The URL for this instance group. The server generates this URL.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * [Output Only] The total number of instances in the instance group.
         */
        size?: number | null;
        /**
         * [Output Only] The URL of the subnetwork to which all instances in the instance group belong. If your instance has multiple network interfaces, then the network and subnetwork fields only refer to the network and subnet used by your primary interface (nic0).
         */
        subnetwork?: string | null;
        /**
         * [Output Only] The URL of the zone where the instance group is located (for zonal resources).
         */
        zone?: string | null;
    }
    export interface Schema$InstanceGroupAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of InstanceGroupsScopedList resources.
         */
        items?: {
            [key: string]: Schema$InstanceGroupsScopedList;
        } | null;
        /**
         * [Output Only] The resource type, which is always compute#instanceGroupAggregatedList for aggregated lists of instance groups.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * A list of InstanceGroup resources.
     */
    export interface Schema$InstanceGroupList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of InstanceGroup resources.
         */
        items?: Schema$InstanceGroup[];
        /**
         * [Output Only] The resource type, which is always compute#instanceGroupList for instance group lists.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Represents a Managed Instance Group resource. An instance group is a collection of VM instances that you can manage as a single entity. For more information, read Instance groups. For zonal Managed Instance Group, use the instanceGroupManagers resource. For regional Managed Instance Group, use the regionInstanceGroupManagers resource.
     */
    export interface Schema$InstanceGroupManager {
        /**
         * Specifies configuration that overrides the instance template configuration for the group.
         */
        allInstancesConfig?: Schema$InstanceGroupManagerAllInstancesConfig;
        /**
         * The autohealing policy for this managed instance group. You can specify only one value.
         */
        autoHealingPolicies?: Schema$InstanceGroupManagerAutoHealingPolicy[];
        /**
         * The base instance name to use for instances in this group. The value must be 1-58 characters long. Instances are named by appending a hyphen and a random four-character string to the base instance name. The base instance name must comply with RFC1035.
         */
        baseInstanceName?: string | null;
        /**
         * [Output Only] The creation timestamp for this managed instance group in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * [Output Only] The list of instance actions and the number of instances in this managed instance group that are scheduled for each of those actions.
         */
        currentActions?: Schema$InstanceGroupManagerActionsSummary;
        /**
         * An optional description of this resource.
         */
        description?: string | null;
        /**
         * Policy specifying the intended distribution of managed instances across zones in a regional managed instance group.
         */
        distributionPolicy?: Schema$DistributionPolicy;
        /**
         * The action to perform in case of zone failure. Only one value is supported, NO_FAILOVER. The default is NO_FAILOVER.
         */
        failoverAction?: string | null;
        /**
         * Fingerprint of this resource. This field may be used in optimistic locking. It will be ignored when inserting an InstanceGroupManager. An up-to-date fingerprint must be provided in order to update the InstanceGroupManager, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve an InstanceGroupManager.
         */
        fingerprint?: string | null;
        /**
         * [Output Only] A unique identifier for this resource type. The server generates this identifier.
         */
        id?: string | null;
        /**
         * Instance flexibility allowing MIG to create VMs from multiple types of machines. Instance flexibility configuration on MIG overrides instance template configuration.
         */
        instanceFlexibilityPolicy?: Schema$InstanceGroupManagerInstanceFlexibilityPolicy;
        /**
         * [Output Only] The URL of the Instance Group resource.
         */
        instanceGroup?: string | null;
        /**
         * The repair policy for this managed instance group.
         */
        instanceLifecyclePolicy?: Schema$InstanceGroupManagerInstanceLifecyclePolicy;
        /**
         * The URL of the instance template that is specified for this managed instance group. The group uses this template to create all new instances in the managed instance group. The templates for existing instances in the group do not change unless you run recreateInstances, run applyUpdatesToInstances, or set the group's updatePolicy.type to PROACTIVE.
         */
        instanceTemplate?: string | null;
        /**
         * [Output Only] The resource type, which is always compute#instanceGroupManager for managed instance groups.
         */
        kind?: string | null;
        /**
         * Pagination behavior of the listManagedInstances API method for this managed instance group.
         */
        listManagedInstancesResults?: string | null;
        /**
         * The name of the managed instance group. The name must be 1-63 characters long, and comply with RFC1035.
         */
        name?: string | null;
        /**
         * Named ports configured for the Instance Groups complementary to this Instance Group Manager.
         */
        namedPorts?: Schema$NamedPort[];
        /**
         * [Output Only] The URL of the region where the managed instance group resides (for regional resources).
         */
        region?: string | null;
        /**
         * [Output Only] The URL for this managed instance group. The server defines this URL.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * The service account to be used as credentials for all operations performed by the managed instance group on instances. The service accounts needs all permissions required to create and delete instances. By default, the service account {projectNumber\}@cloudservices.gserviceaccount.com is used.
         */
        serviceAccount?: string | null;
        /**
         * Standby policy for stopped and suspended instances.
         */
        standbyPolicy?: Schema$InstanceGroupManagerStandbyPolicy;
        /**
         * Stateful configuration for this Instanced Group Manager
         */
        statefulPolicy?: Schema$StatefulPolicy;
        /**
         * [Output Only] The status of this managed instance group.
         */
        status?: Schema$InstanceGroupManagerStatus;
        /**
         * The URLs for all TargetPool resources to which instances in the instanceGroup field are added. The target pools automatically apply to all of the instances in the managed instance group.
         */
        targetPools?: string[] | null;
        /**
         * The target number of running instances for this managed instance group. You can reduce this number by using the instanceGroupManager deleteInstances or abandonInstances methods. Resizing the group also changes this number.
         */
        targetSize?: number | null;
        /**
         * The unit of measure for the target size.
         */
        targetSizeUnit?: string | null;
        /**
         * The target number of stopped instances for this managed instance group. This number changes when you: - Stop instance using the stopInstances method or start instances using the startInstances method. - Manually change the targetStoppedSize using the update method.
         */
        targetStoppedSize?: number | null;
        /**
         * The target number of suspended instances for this managed instance group. This number changes when you: - Suspend instance using the suspendInstances method or resume instances using the resumeInstances method. - Manually change the targetSuspendedSize using the update method.
         */
        targetSuspendedSize?: number | null;
        /**
         * The update policy for this managed instance group.
         */
        updatePolicy?: Schema$InstanceGroupManagerUpdatePolicy;
        /**
         * Specifies the instance templates used by this managed instance group to create instances. Each version is defined by an instanceTemplate and a name. Every version can appear at most once per instance group. This field overrides the top-level instanceTemplate field. Read more about the relationships between these fields. Exactly one version must leave the targetSize field unset. That version will be applied to all remaining instances. For more information, read about canary updates.
         */
        versions?: Schema$InstanceGroupManagerVersion[];
        /**
         * [Output Only] The URL of a zone where the managed instance group is located (for zonal resources).
         */
        zone?: string | null;
    }
    export interface Schema$InstanceGroupManagerActionsSummary {
        /**
         * [Output Only] The total number of instances in the managed instance group that are scheduled to be abandoned. Abandoning an instance removes it from the managed instance group without deleting it.
         */
        abandoning?: number | null;
        /**
         * [Output Only] The number of instances in the managed instance group that are scheduled to be created or are currently being created. If the group fails to create any of these instances, it tries again until it creates the instance successfully. If you have disabled creation retries, this field will not be populated; instead, the creatingWithoutRetries field will be populated.
         */
        creating?: number | null;
        /**
         * [Output Only] The number of instances that the managed instance group will attempt to create atomically, in a batch mode. If the desired count of instances can not be created, entire batch will be deleted and the group will decrease its targetSize value accordingly.
         */
        creatingAtomically?: number | null;
        /**
         * [Output Only] The number of instances that the managed instance group will attempt to create. The group attempts to create each instance only once. If the group fails to create any of these instances, it decreases the group's targetSize value accordingly.
         */
        creatingWithoutRetries?: number | null;
        /**
         * [Output Only] The number of instances in the managed instance group that are scheduled to be deleted or are currently being deleted.
         */
        deleting?: number | null;
        /**
         * [Output Only] The number of instances in the managed instance group that are running and have no scheduled actions.
         */
        none?: number | null;
        /**
         * [Output Only] The number of instances that the managed instance group is currently queuing.
         */
        queuing?: number | null;
        /**
         * [Output Only] The number of instances in the managed instance group that are scheduled to be recreated or are currently being being recreated. Recreating an instance deletes the existing root persistent disk and creates a new disk from the image that is defined in the instance template.
         */
        recreating?: number | null;
        /**
         * [Output Only] The number of instances in the managed instance group that are being reconfigured with properties that do not require a restart or a recreate action. For example, setting or removing target pools for the instance.
         */
        refreshing?: number | null;
        /**
         * [Output Only] The number of instances in the managed instance group that are scheduled to be restarted or are currently being restarted.
         */
        restarting?: number | null;
        /**
         * [Output Only] The number of instances in the managed instance group that are scheduled to be resumed or are currently being resumed.
         */
        resuming?: number | null;
        /**
         * [Output Only] The number of instances in the managed instance group that are scheduled to be started or are currently being started.
         */
        starting?: number | null;
        /**
         * [Output Only] The number of instances in the managed instance group that are scheduled to be stopped or are currently being stopped.
         */
        stopping?: number | null;
        /**
         * [Output Only] The number of instances in the managed instance group that are scheduled to be suspended or are currently being suspended.
         */
        suspending?: number | null;
        /**
         * [Output Only] The number of instances in the managed instance group that are being verified. See the managedInstances[].currentAction property in the listManagedInstances method documentation.
         */
        verifying?: number | null;
    }
    export interface Schema$InstanceGroupManagerAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of InstanceGroupManagersScopedList resources.
         */
        items?: {
            [key: string]: Schema$InstanceGroupManagersScopedList;
        } | null;
        /**
         * [Output Only] The resource type, which is always compute#instanceGroupManagerAggregatedList for an aggregated list of managed instance groups.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$InstanceGroupManagerAllInstancesConfig {
        /**
         * Properties to set on all instances in the group. You can add or modify properties using the instanceGroupManagers.patch or regionInstanceGroupManagers.patch. After setting allInstancesConfig on the group, you must update the group's instances to apply the configuration. To apply the configuration, set the group's updatePolicy.type field to use proactive updates or use the applyUpdatesToInstances method.
         */
        properties?: Schema$InstancePropertiesPatch;
    }
    export interface Schema$InstanceGroupManagerAutoHealingPolicy {
        /**
         * Restricts what triggers autohealing.
         */
        autoHealingTriggers?: Schema$InstanceGroupManagerAutoHealingPolicyAutoHealingTriggers;
        /**
         * The URL for the health check that signals autohealing.
         */
        healthCheck?: string | null;
        /**
         * The initial delay is the number of seconds that a new VM takes to initialize and run its startup script. During a VM's initial delay period, the MIG ignores unsuccessful health checks because the VM might be in the startup process. This prevents the MIG from prematurely recreating a VM. If the health check receives a healthy response during the initial delay, it indicates that the startup process is complete and the VM is ready. The value of initial delay must be between 0 and 3600 seconds. The default value is 0.
         */
        initialDelaySec?: number | null;
        /**
         * Maximum number of instances that can be unavailable when autohealing. When 'percent' is used, the value is rounded if necessary. The instance is considered available if all of the following conditions are satisfied: 1. Instance's status is RUNNING. 2. Instance's currentAction is NONE (in particular its liveness health check result was observed to be HEALTHY at least once as it passed VERIFYING). 3. There is no outgoing action on an instance triggered by IGM. By default, number of concurrently autohealed instances is smaller than the managed instance group target size. However, if a zonal managed instance group has only one instance, or a regional managed instance group has only one instance per zone, autohealing will recreate these instances when they become unhealthy.
         */
        maxUnavailable?: Schema$FixedOrPercent;
    }
    export interface Schema$InstanceGroupManagerAutoHealingPolicyAutoHealingTriggers {
        /**
         * If you have configured an application-based health check for the group, this field controls whether to trigger VM autohealing based on a failed health check. Valid values are: - ON (default): The group recreates running VMs that fail the application-based health check. - OFF: When set to OFF, you can still observe instance health state, but the group does not recreate VMs that fail the application-based health check. This is useful for troubleshooting and setting up your health check configuration.
         */
        onHealthCheck?: string | null;
    }
    export interface Schema$InstanceGroupManagerInstanceFlexibilityPolicy {
        /**
         * Named instance selections configuring properties that the group will use when creating new VMs.
         */
        instanceSelectionLists?: {
            [key: string]: Schema$InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection;
        } | null;
    }
    export interface Schema$InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection {
        /**
         * Full machine-type names, e.g. "n1-standard-16".
         */
        machineTypes?: string[] | null;
        /**
         * Preference of this instance selection. Lower number means higher preference. MIG will first try to create a VM based on the machine-type with lowest rank and fallback to next rank based on availability. Machine types and instance selections with the same rank have the same preference.
         */
        rank?: number | null;
    }
    export interface Schema$InstanceGroupManagerInstanceLifecyclePolicy {
        /**
         * The action that a MIG performs on a failed or an unhealthy VM. A VM is marked as unhealthy when the application running on that VM fails a health check. Valid values are - REPAIR (default): MIG automatically repairs a failed or an unhealthy VM by recreating it. For more information, see About repairing VMs in a MIG. - DO_NOTHING: MIG does not repair a failed or an unhealthy VM.
         */
        defaultActionOnFailure?: string | null;
        /**
         * A bit indicating whether to forcefully apply the group's latest configuration when repairing a VM. Valid options are: - NO (default): If configuration updates are available, they are not forcefully applied during repair. Instead, configuration updates are applied according to the group's update policy. - YES: If configuration updates are available, they are applied during repair.
         */
        forceUpdateOnRepair?: string | null;
        /**
         * The configuration for metadata based readiness signal sent by the instance during initialization when stopping / suspending an instance. The Instance Group Manager will wait for a signal that indicates successful initialization before stopping / suspending an instance. If a successful readiness signal is not sent before timeout, the corresponding instance will not be stopped / suspended. Instead, an error will be visible in the lastAttempt.errors field of the managed instance in the listmanagedinstances method. If metadataBasedReadinessSignal.timeoutSec is unset, the Instance Group Manager will directly proceed to suspend / stop instances, skipping initialization on them.
         */
        metadataBasedReadinessSignal?: Schema$InstanceGroupManagerInstanceLifecyclePolicyMetadataBasedReadinessSignal;
    }
    export interface Schema$InstanceGroupManagerInstanceLifecyclePolicyMetadataBasedReadinessSignal {
        /**
         * The number of seconds to wait for a readiness signal during initialization before timing out.
         */
        timeoutSec?: number | null;
    }
    /**
     * [Output Only] A list of managed instance groups.
     */
    export interface Schema$InstanceGroupManagerList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of InstanceGroupManager resources.
         */
        items?: Schema$InstanceGroupManager[];
        /**
         * [Output Only] The resource type, which is always compute#instanceGroupManagerList for a list of managed instance groups.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * InstanceGroupManagerResizeRequest represents a request to create a number of VMs: either immediately or by queuing the request for the specified time. This resize request is nested under InstanceGroupManager and the VMs created by this request are added to the owning InstanceGroupManager.
     */
    export interface Schema$InstanceGroupManagerResizeRequest {
        /**
         * The count of instances to create as part of this resize request.
         */
        count?: number | null;
        /**
         * [Output Only] The creation timestamp for this resize request in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource.
         */
        description?: string | null;
        /**
         * [Output Only] A unique identifier for this resource type. The server generates this identifier.
         */
        id?: string | null;
        /**
         * [Output Only] The resource type, which is always compute#instanceGroupManagerResizeRequest for resize requests.
         */
        kind?: string | null;
        /**
         * The name of this resize request. The name must be 1-63 characters long, and comply with RFC1035.
         */
        name?: string | null;
        /**
         * When set, defines queing parameters for the requested deferred capacity. When unset, the request starts provisioning immediately, or fails if immediate provisioning is not possible.
         */
        queuingPolicy?: Schema$QueuingPolicy;
        /**
         * The number of instances to be created by this resize request. The group's target size will be increased by this number.
         */
        resizeBy?: number | null;
        /**
         * [Output Only] The URL for this resize request. The server defines this URL.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * [Output only] Current state of the request.
         */
        state?: string | null;
        /**
         * [Output only] Status of the request.
         */
        status?: Schema$InstanceGroupManagerResizeRequestStatus;
        /**
         * [Output Only] The URL of a zone where the resize request is located. Populated only for zonal resize requests.
         */
        zone?: string | null;
    }
    /**
     * [Output Only] A list of resize requests.
     */
    export interface Schema$InstanceGroupManagerResizeRequestsListResponse {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of resize request resources.
         */
        items?: Schema$InstanceGroupManagerResizeRequest[];
        /**
         * [Output Only] Type of the resource. Always compute#instanceGroupManagerResizeRequestList for a list of resize requests.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$InstanceGroupManagerResizeRequestStatus {
        /**
         * Errors encountered during the queueing or provisioning phases of the ResizeRequest.
         */
        error?: {
            errors?: Array<{
                code?: string;
                errorDetails?: Array<{
                    errorInfo?: Schema$ErrorInfo;
                    help?: Schema$Help;
                    localizedMessage?: Schema$LocalizedMessage;
                    quotaInfo?: Schema$QuotaExceededInfo;
                }>;
                location?: string;
                message?: string;
            }>;
        } | null;
        /**
         * Constraints for the time when the instances start provisioning. Always exposed as absolute time.
         */
        queuingPolicy?: Schema$QueuingPolicy;
    }
    export interface Schema$InstanceGroupManagersAbandonInstancesRequest {
        /**
         * The URLs of one or more instances to abandon. This can be a full URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].
         */
        instances?: string[] | null;
    }
    /**
     * InstanceGroupManagers.applyUpdatesToInstances
     */
    export interface Schema$InstanceGroupManagersApplyUpdatesRequest {
        /**
         * Flag to update all instances instead of specified list of “instances”. If the flag is set to true then the instances may not be specified in the request.
         */
        allInstances?: boolean | null;
        /**
         * The list of URLs of one or more instances for which you want to apply updates. Each URL can be a full URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].
         */
        instances?: string[] | null;
        /**
         * The maximal action that should be performed on the instances. By default REPLACE. This field is deprecated, please use most_disruptive_allowed_action.
         */
        maximalAction?: string | null;
        /**
         * The minimal action that you want to perform on each instance during the update: - REPLACE: At minimum, delete the instance and create it again. - RESTART: Stop the instance and start it again. - REFRESH: Do not stop the instance and limit disruption as much as possible. - NONE: Do not disrupt the instance at all. By default, the minimum action is NONE. If your update requires a more disruptive action than you set with this flag, the necessary action is performed to execute the update.
         */
        minimalAction?: string | null;
        /**
         * The most disruptive action that you want to perform on each instance during the update: - REPLACE: Delete the instance and create it again. - RESTART: Stop the instance and start it again. - REFRESH: Do not stop the instance and limit disruption as much as possible. - NONE: Do not disrupt the instance at all. By default, the most disruptive allowed action is REPLACE. If your update requires a more disruptive action than you set with this flag, the update request will fail.
         */
        mostDisruptiveAllowedAction?: string | null;
    }
    /**
     * InstanceGroupManagers.createInstances
     */
    export interface Schema$InstanceGroupManagersCreateInstancesRequest {
        /**
         * [Required] List of specifications of per-instance configs.
         */
        instances?: Schema$PerInstanceConfig[];
    }
    export interface Schema$InstanceGroupManagersDeleteInstancesRequest {
        /**
         * The list of instance names to delete. Queued instances do not have URL and can be deleted only by name. You cannot specify both URLs and names in a single request.
         */
        instanceNames?: string[] | null;
        /**
         * The URLs of one or more instances to delete. This can be a full URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME]. Queued instances do not have URL and can be deleted only by name. One cannot specify both URLs and names in a single request.
         */
        instances?: string[] | null;
        /**
         * Specifies whether the request should proceed despite the inclusion of instances that are not members of the group or that are already in the process of being deleted or abandoned. If this field is set to `false` and such an instance is specified in the request, the operation fails. The operation always fails if the request contains a malformed instance URL or a reference to an instance that exists in a zone or region other than the group's zone or region.
         */
        skipInstancesOnValidationError?: boolean | null;
    }
    /**
     * InstanceGroupManagers.deletePerInstanceConfigs
     */
    export interface Schema$InstanceGroupManagersDeletePerInstanceConfigsReq {
        /**
         * The list of instance names for which we want to delete per-instance configs on this managed instance group.
         */
        names?: string[] | null;
    }
    export interface Schema$InstanceGroupManagersListErrorsResponse {
        /**
         * [Output Only] The list of errors of the managed instance group.
         */
        items?: Schema$InstanceManagedByIgmError[];
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
    }
    export interface Schema$InstanceGroupManagersListManagedInstancesResponse {
        /**
         * [Output Only] The list of instances in the managed instance group.
         */
        managedInstances?: Schema$ManagedInstance[];
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
    }
    export interface Schema$InstanceGroupManagersListPerInstanceConfigsResp {
        /**
         * [Output Only] The list of PerInstanceConfig.
         */
        items?: Schema$PerInstanceConfig[];
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * InstanceGroupManagers.patchPerInstanceConfigs
     */
    export interface Schema$InstanceGroupManagersPatchPerInstanceConfigsReq {
        /**
         * The list of per-instance configurations to insert or patch on this managed instance group.
         */
        perInstanceConfigs?: Schema$PerInstanceConfig[];
    }
    export interface Schema$InstanceGroupManagersRecreateInstancesRequest {
        /**
         * The URLs of one or more instances to recreate. This can be a full URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].
         */
        instances?: string[] | null;
    }
    export interface Schema$InstanceGroupManagersResizeAdvancedRequest {
        /**
         * If this flag is true, the managed instance group attempts to create all instances initiated by this resize request only once. If there is an error during creation, the managed instance group does not retry create this instance, and we will decrease the targetSize of the request instead. If the flag is false, the group attempts to recreate each instance continuously until it succeeds. This flag matters only in the first attempt of creation of an instance. After an instance is successfully created while this flag is enabled, the instance behaves the same way as all the other instances created with a regular resize request. In particular, if a running instance dies unexpectedly at a later time and needs to be recreated, this mode does not affect the recreation behavior in that scenario. This flag is applicable only to the current resize request. It does not influence other resize requests in any way. You can see which instances is being creating in which mode by calling the get or listManagedInstances API.
         */
        noCreationRetries?: boolean | null;
        /**
         * The number of running instances that the managed instance group should maintain at any given time. The group automatically adds or removes instances to maintain the number of instances specified by this parameter.
         */
        targetSize?: number | null;
    }
    export interface Schema$InstanceGroupManagersResumeInstancesRequest {
        /**
         * The URLs of one or more instances to resume. This can be a full URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].
         */
        instances?: string[] | null;
    }
    export interface Schema$InstanceGroupManagersScopedList {
        /**
         * [Output Only] The list of managed instance groups that are contained in the specified project and zone.
         */
        instanceGroupManagers?: Schema$InstanceGroupManager[];
        /**
         * [Output Only] The warning that replaces the list of managed instance groups when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$InstanceGroupManagersSetAutoHealingRequest {
        autoHealingPolicies?: Schema$InstanceGroupManagerAutoHealingPolicy[];
    }
    export interface Schema$InstanceGroupManagersSetInstanceTemplateRequest {
        /**
         * The URL of the instance template that is specified for this managed instance group. The group uses this template to create all new instances in the managed instance group. The templates for existing instances in the group do not change unless you run recreateInstances, run applyUpdatesToInstances, or set the group's updatePolicy.type to PROACTIVE.
         */
        instanceTemplate?: string | null;
    }
    export interface Schema$InstanceGroupManagersSetTargetPoolsRequest {
        /**
         * The fingerprint of the target pools information. Use this optional property to prevent conflicts when multiple users change the target pools settings concurrently. Obtain the fingerprint with the instanceGroupManagers.get method. Then, include the fingerprint in your request to ensure that you do not overwrite changes that were applied from another concurrent request.
         */
        fingerprint?: string | null;
        /**
         * The list of target pool URLs that instances in this managed instance group belong to. The managed instance group applies these target pools to all of the instances in the group. Existing instances and new instances in the group all receive these target pool settings.
         */
        targetPools?: string[] | null;
    }
    export interface Schema$InstanceGroupManagersStartInstancesRequest {
        /**
         * The URLs of one or more instances to start. This can be a full URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].
         */
        instances?: string[] | null;
    }
    export interface Schema$InstanceGroupManagersStopInstancesRequest {
        /**
         * If this flag is set to true, the Instance Group Manager will proceed to stop the instances, skipping initialization on them.
         */
        forceStop?: boolean | null;
        /**
         * The URLs of one or more instances to stop. This can be a full URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].
         */
        instances?: string[] | null;
    }
    export interface Schema$InstanceGroupManagersSuspendInstancesRequest {
        /**
         * If this flag is set to true, the Instance Group Manager will proceed to suspend the instances, skipping initialization on them.
         */
        forceSuspend?: boolean | null;
        /**
         * The URLs of one or more instances to suspend. This can be a full URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].
         */
        instances?: string[] | null;
    }
    export interface Schema$InstanceGroupManagerStandbyPolicy {
        initialDelaySec?: number | null;
        /**
         * Defines behaviour of using instances from standby pool to resize MIG.
         */
        mode?: string | null;
    }
    export interface Schema$InstanceGroupManagerStatus {
        /**
         * [Output only] Status of all-instances configuration on the group.
         */
        allInstancesConfig?: Schema$InstanceGroupManagerStatusAllInstancesConfig;
        /**
         * [Output Only] The URL of the Autoscaler that targets this instance group manager.
         */
        autoscaler?: string | null;
        /**
         * [Output Only] A bit indicating whether the managed instance group is in a stable state. A stable state means that: none of the instances in the managed instance group is currently undergoing any type of change (for example, creation, restart, or deletion); no future changes are scheduled for instances in the managed instance group; and the managed instance group itself is not being modified.
         */
        isStable?: boolean | null;
        /**
         * [Output Only] Stateful status of the given Instance Group Manager.
         */
        stateful?: Schema$InstanceGroupManagerStatusStateful;
        /**
         * [Output Only] A status of consistency of Instances' versions with their target version specified by version field on Instance Group Manager.
         */
        versionTarget?: Schema$InstanceGroupManagerStatusVersionTarget;
    }
    export interface Schema$InstanceGroupManagerStatusAllInstancesConfig {
        /**
         * [Output Only] Current all-instances configuration revision. This value is in RFC3339 text format.
         */
        currentRevision?: string | null;
        /**
         * [Output Only] A bit indicating whether this configuration has been applied to all managed instances in the group.
         */
        effective?: boolean | null;
    }
    export interface Schema$InstanceGroupManagerStatusStateful {
        /**
         * [Output Only] A bit indicating whether the managed instance group has stateful configuration, that is, if you have configured any items in a stateful policy or in per-instance configs. The group might report that it has no stateful configuration even when there is still some preserved state on a managed instance, for example, if you have deleted all PICs but not yet applied those deletions.
         */
        hasStatefulConfig?: boolean | null;
        /**
         * [Output Only] A bit indicating whether the managed instance group has stateful configuration, that is, if you have configured any items in a stateful policy or in per-instance configs. The group might report that it has no stateful configuration even when there is still some preserved state on a managed instance, for example, if you have deleted all PICs but not yet applied those deletions. This field is deprecated in favor of has_stateful_config.
         */
        isStateful?: boolean | null;
        /**
         * [Output Only] Status of per-instance configurations on the instance.
         */
        perInstanceConfigs?: Schema$InstanceGroupManagerStatusStatefulPerInstanceConfigs;
    }
    export interface Schema$InstanceGroupManagerStatusStatefulPerInstanceConfigs {
        /**
         * A bit indicating if all of the group's per-instance configurations (listed in the output of a listPerInstanceConfigs API call) have status EFFECTIVE or there are no per-instance-configs.
         */
        allEffective?: boolean | null;
    }
    export interface Schema$InstanceGroupManagerStatusVersionTarget {
        /**
         * [Output Only] A bit indicating whether version target has been reached in this managed instance group, i.e. all instances are in their target version. Instances' target version are specified by version field on Instance Group Manager.
         */
        isReached?: boolean | null;
    }
    /**
     * InstanceGroupManagers.updatePerInstanceConfigs
     */
    export interface Schema$InstanceGroupManagersUpdatePerInstanceConfigsReq {
        /**
         * The list of per-instance configurations to insert or patch on this managed instance group.
         */
        perInstanceConfigs?: Schema$PerInstanceConfig[];
    }
    export interface Schema$InstanceGroupManagerUpdatePolicy {
        /**
         * The instance redistribution policy for regional managed instance groups. Valid values are: - PROACTIVE (default): The group attempts to maintain an even distribution of VM instances across zones in the region. - NONE: For non-autoscaled groups, proactive redistribution is disabled.
         */
        instanceRedistributionType?: string | null;
        /**
         * The maximum number of instances that can be created above the specified targetSize during the update process. This value can be either a fixed number or, if the group has 10 or more instances, a percentage. If you set a percentage, the number of instances is rounded if necessary. The default value for maxSurge is a fixed value equal to the number of zones in which the managed instance group operates. At least one of either maxSurge or maxUnavailable must be greater than 0. Learn more about maxSurge.
         */
        maxSurge?: Schema$FixedOrPercent;
        /**
         * The maximum number of instances that can be unavailable during the update process. An instance is considered available if all of the following conditions are satisfied: - The instance's status is RUNNING. - If there is a health check on the instance group, the instance's health check status must be HEALTHY at least once. If there is no health check on the group, then the instance only needs to have a status of RUNNING to be considered available. This value can be either a fixed number or, if the group has 10 or more instances, a percentage. If you set a percentage, the number of instances is rounded if necessary. The default value for maxUnavailable is a fixed value equal to the number of zones in which the managed instance group operates. At least one of either maxSurge or maxUnavailable must be greater than 0. Learn more about maxUnavailable.
         */
        maxUnavailable?: Schema$FixedOrPercent;
        /**
         * Minimal action to be taken on an instance. Use this option to minimize disruption as much as possible or to apply a more disruptive action than is necessary. - To limit disruption as much as possible, set the minimal action to REFRESH. If your update requires a more disruptive action, Compute Engine performs the necessary action to execute the update. - To apply a more disruptive action than is strictly necessary, set the minimal action to RESTART or REPLACE. For example, Compute Engine does not need to restart a VM to change its metadata. But if your application reads instance metadata only when a VM is restarted, you can set the minimal action to RESTART in order to pick up metadata changes.
         */
        minimalAction?: string | null;
        /**
         * Minimum number of seconds to wait for after a newly created instance becomes available. This value must be from range [0, 3600].
         */
        minReadySec?: number | null;
        /**
         * Most disruptive action that is allowed to be taken on an instance. You can specify either NONE to forbid any actions, REFRESH to avoid restarting the VM and to limit disruption as much as possible. RESTART to allow actions that can be applied without instance replacing or REPLACE to allow all possible actions. If the Updater determines that the minimal update action needed is more disruptive than most disruptive allowed action you specify it will not perform the update at all.
         */
        mostDisruptiveAllowedAction?: string | null;
        /**
         * What action should be used to replace instances. See minimal_action.REPLACE
         */
        replacementMethod?: string | null;
        /**
         * The type of update process. You can specify either PROACTIVE so that the MIG automatically updates VMs to the latest configurations or OPPORTUNISTIC so that you can select the VMs that you want to update.
         */
        type?: string | null;
    }
    export interface Schema$InstanceGroupManagerVersion {
        /**
         * The URL of the instance template that is specified for this managed instance group. The group uses this template to create new instances in the managed instance group until the `targetSize` for this version is reached. The templates for existing instances in the group do not change unless you run recreateInstances, run applyUpdatesToInstances, or set the group's updatePolicy.type to PROACTIVE; in those cases, existing instances are updated until the `targetSize` for this version is reached.
         */
        instanceTemplate?: string | null;
        /**
         * Name of the version. Unique among all versions in the scope of this managed instance group.
         */
        name?: string | null;
        /**
         * Tag describing the version. Used to trigger rollout of a target version even if instance_template remains unchanged. Deprecated in favor of 'name'.
         */
        tag?: string | null;
        /**
         * Specifies the intended number of instances to be created from the instanceTemplate. The final number of instances created from the template will be equal to: - If expressed as a fixed number, the minimum of either targetSize.fixed or instanceGroupManager.targetSize is used. - if expressed as a percent, the targetSize would be (targetSize.percent/100 * InstanceGroupManager.targetSize) If there is a remainder, the number is rounded. If unset, this version will update any remaining instances not updated by another version. Read Starting a canary update for more information.
         */
        targetSize?: Schema$FixedOrPercent;
    }
    export interface Schema$InstanceGroupsAddInstancesRequest {
        /**
         * The list of instances to add to the instance group.
         */
        instances?: Schema$InstanceReference[];
    }
    export interface Schema$InstanceGroupsListInstances {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of InstanceWithNamedPorts resources.
         */
        items?: Schema$InstanceWithNamedPorts[];
        /**
         * [Output Only] The resource type, which is always compute#instanceGroupsListInstances for the list of instances in the specified instance group.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$InstanceGroupsListInstancesRequest {
        /**
         * A filter for the state of the instances in the instance group. Valid options are ALL or RUNNING. If you do not specify this parameter the list includes all instances regardless of their state.
         */
        instanceState?: string | null;
    }
    export interface Schema$InstanceGroupsRemoveInstancesRequest {
        /**
         * The list of instances to remove from the instance group.
         */
        instances?: Schema$InstanceReference[];
    }
    export interface Schema$InstanceGroupsScopedList {
        /**
         * [Output Only] The list of instance groups that are contained in this scope.
         */
        instanceGroups?: Schema$InstanceGroup[];
        /**
         * [Output Only] An informational warning that replaces the list of instance groups when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$InstanceGroupsSetNamedPortsRequest {
        /**
         * The fingerprint of the named ports information for this instance group. Use this optional property to prevent conflicts when multiple users change the named ports settings concurrently. Obtain the fingerprint with the instanceGroups.get method. Then, include the fingerprint in your request to ensure that you do not overwrite changes that were applied from another concurrent request. A request with an incorrect fingerprint will fail with error 412 conditionNotMet.
         */
        fingerprint?: string | null;
        /**
         * The list of named ports to set for this instance group.
         */
        namedPorts?: Schema$NamedPort[];
    }
    /**
     * Contains a list of instances.
     */
    export interface Schema$InstanceList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of Instance resources.
         */
        items?: Schema$Instance[];
        /**
         * [Output Only] Type of resource. Always compute#instanceList for lists of Instance resources.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Contains a list of instance referrers.
     */
    export interface Schema$InstanceListReferrers {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of Reference resources.
         */
        items?: Schema$Reference[];
        /**
         * [Output Only] Type of resource. Always compute#instanceListReferrers for lists of Instance referrers.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$InstanceManagedByIgmError {
        /**
         * [Output Only] Contents of the error.
         */
        error?: Schema$InstanceManagedByIgmErrorManagedInstanceError;
        /**
         * [Output Only] Details of the instance action that triggered this error. May be null, if the error was not caused by an action on an instance. This field is optional.
         */
        instanceActionDetails?: Schema$InstanceManagedByIgmErrorInstanceActionDetails;
        /**
         * [Output Only] The time that this error occurred. This value is in RFC3339 text format.
         */
        timestamp?: string | null;
    }
    export interface Schema$InstanceManagedByIgmErrorInstanceActionDetails {
        /**
         * [Output Only] Action that managed instance group was executing on the instance when the error occurred. Possible values:
         */
        action?: string | null;
        /**
         * [Output Only] The URL of the instance. The URL can be set even if the instance has not yet been created.
         */
        instance?: string | null;
        /**
         * [Output Only] Version this instance was created from, or was being created from, but the creation failed. Corresponds to one of the versions that were set on the Instance Group Manager resource at the time this instance was being created.
         */
        version?: Schema$ManagedInstanceVersion;
    }
    export interface Schema$InstanceManagedByIgmErrorManagedInstanceError {
        /**
         * [Output Only] Error code.
         */
        code?: string | null;
        /**
         * [Output Only] Error message.
         */
        message?: string | null;
    }
    export interface Schema$InstanceMoveRequest {
        /**
         * The URL of the destination zone to move the instance. This can be a full or partial URL. For example, the following are all valid URLs to a zone: - https://www.googleapis.com/compute/v1/projects/project/zones/zone - projects/project/zones/zone - zones/zone
         */
        destinationZone?: string | null;
        /**
         * The URL of the target instance to move. This can be a full or partial URL. For example, the following are all valid URLs to an instance: - https://www.googleapis.com/compute/v1/projects/project/zones/zone /instances/instance - projects/project/zones/zone/instances/instance - zones/zone/instances/instance
         */
        targetInstance?: string | null;
    }
    /**
     * Additional instance params.
     */
    export interface Schema$InstanceParams {
        /**
         * Resource manager tags to be bound to the instance. Tag keys and values have the same definition as resource manager tags. Keys must be in the format `tagKeys/{tag_key_id\}`, and values are in the format `tagValues/456`. The field is ignored (both PUT & PATCH) when empty.
         */
        resourceManagerTags?: {
            [key: string]: string;
        } | null;
    }
    export interface Schema$InstanceProperties {
        /**
         * Controls for advanced machine-related behavior features. Note that for MachineImage, this is not supported yet.
         */
        advancedMachineFeatures?: Schema$AdvancedMachineFeatures;
        /**
         * Enables instances created based on these properties to send packets with source IP addresses other than their own and receive packets with destination IP addresses other than their own. If these instances will be used as an IP gateway or it will be set as the next-hop in a Route resource, specify true. If unsure, leave this set to false. See the Enable IP forwarding documentation for more information.
         */
        canIpForward?: boolean | null;
        /**
         * Specifies the Confidential Instance options. Note that for MachineImage, this is not supported yet.
         */
        confidentialInstanceConfig?: Schema$ConfidentialInstanceConfig;
        /**
         * An optional text description for the instances that are created from these properties.
         */
        description?: string | null;
        /**
         * An array of disks that are associated with the instances that are created from these properties.
         */
        disks?: Schema$AttachedDisk[];
        /**
         * Display Device properties to enable support for remote display products like: Teradici, VNC and TeamViewer Note that for MachineImage, this is not supported yet.
         */
        displayDevice?: Schema$DisplayDevice;
        /**
         * A list of guest accelerator cards' type and count to use for instances created from these properties.
         */
        guestAccelerators?: Schema$AcceleratorConfig[];
        /**
         * KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified.
         */
        keyRevocationActionType?: string | null;
        /**
         * Labels to apply to instances that are created from these properties.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * The machine type to use for instances that are created from these properties.
         */
        machineType?: string | null;
        /**
         * The metadata key/value pairs to assign to instances that are created from these properties. These pairs can consist of custom metadata or predefined keys. See Project and instance metadata for more information.
         */
        metadata?: Schema$Metadata;
        /**
         * Minimum cpu/platform to be used by instances. The instance may be scheduled on the specified or newer cpu/platform. Applicable values are the friendly names of CPU platforms, such as minCpuPlatform: "Intel Haswell" or minCpuPlatform: "Intel Sandy Bridge". For more information, read Specifying a Minimum CPU Platform.
         */
        minCpuPlatform?: string | null;
        /**
         * An array of network access configurations for this interface.
         */
        networkInterfaces?: Schema$NetworkInterface[];
        /**
         * Note that for MachineImage, this is not supported yet.
         */
        networkPerformanceConfig?: Schema$NetworkPerformanceConfig;
        /**
         * Partner Metadata assigned to the instance properties. A map from a subdomain (namespace) to entries map.
         */
        partnerMetadata?: {
            [key: string]: Schema$StructuredEntries;
        } | null;
        /**
         * PostKeyRevocationActionType of the instance.
         */
        postKeyRevocationActionType?: string | null;
        /**
         * The private IPv6 google access type for VMs. If not specified, use INHERIT_FROM_SUBNETWORK as default. Note that for MachineImage, this is not supported yet.
         */
        privateIpv6GoogleAccess?: string | null;
        /**
         * Specifies the reservations that instances can consume from. Note that for MachineImage, this is not supported yet.
         */
        reservationAffinity?: Schema$ReservationAffinity;
        /**
         * Resource manager tags to be bound to the instance. Tag keys and values have the same definition as resource manager tags. Keys must be in the format `tagKeys/{tag_key_id\}`, and values are in the format `tagValues/456`. The field is ignored (both PUT & PATCH) when empty.
         */
        resourceManagerTags?: {
            [key: string]: string;
        } | null;
        /**
         * Resource policies (names, not URLs) applied to instances created from these properties. Note that for MachineImage, this is not supported yet.
         */
        resourcePolicies?: string[] | null;
        /**
         * Specifies the scheduling options for the instances that are created from these properties.
         */
        scheduling?: Schema$Scheduling;
        /**
         * [Input Only] Secure tags to apply to this instance. Maximum number of secure tags allowed is 50. Note that for MachineImage, this is not supported yet.
         */
        secureTags?: string[] | null;
        /**
         * A list of service accounts with specified scopes. Access tokens for these service accounts are available to the instances that are created from these properties. Use metadata queries to obtain the access tokens for these instances.
         */
        serviceAccounts?: Schema$ServiceAccount[];
        /**
         * Mapping of user defined keys to ServiceIntegrationSpec.
         */
        serviceIntegrationSpecs?: {
            [key: string]: Schema$ServiceIntegrationSpec;
        } | null;
        /**
         * Note that for MachineImage, this is not supported yet.
         */
        shieldedInstanceConfig?: Schema$ShieldedInstanceConfig;
        /**
         * Specifies the Shielded VM options for the instances that are created from these properties.
         */
        shieldedVmConfig?: Schema$ShieldedVmConfig;
        /**
         * A list of tags to apply to the instances that are created from these properties. The tags identify valid sources or targets for network firewalls. The setTags method can modify this list of tags. Each tag within the list must comply with RFC1035.
         */
        tags?: Schema$Tags;
    }
    /**
     * Represents the change that you want to make to the instance properties.
     */
    export interface Schema$InstancePropertiesPatch {
        /**
         * The label key-value pairs that you want to patch onto the instance.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * The metadata key-value pairs that you want to patch onto the instance. For more information, see Project and instance metadata.
         */
        metadata?: {
            [key: string]: string;
        } | null;
    }
    export interface Schema$InstanceReference {
        /**
         * The URL for a specific instance. @required compute.instancegroups.addInstances/removeInstances
         */
        instance?: string | null;
    }
    export interface Schema$InstancesAddResourcePoliciesRequest {
        /**
         * Resource policies to be added to this instance.
         */
        resourcePolicies?: string[] | null;
    }
    export interface Schema$InstancesBulkInsertOperationMetadata {
        /**
         * Status information per location (location name is key). Example key: zones/us-central1-a
         */
        perLocationStatus?: {
            [key: string]: Schema$BulkInsertOperationStatus;
        } | null;
    }
    /**
     * Represents a Instance Settings resource. You can use instance settings to configure default settings for Compute Engine VM instances. For example, you can use it to configure default machine type of Compute Engine VM instances.
     */
    export interface Schema$InstanceSettings {
        /**
         * Email address of the service account.
         */
        email?: string | null;
        /**
         * Specifies a fingerprint for instance settings, which is essentially a hash of the instance settings resource's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update the instance settings resource. You must always provide an up-to-date fingerprint hash in order to update or change the resource, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the resource.
         */
        fingerprint?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#instance_settings for instance settings.
         */
        kind?: string | null;
        /**
         * The metadata key/value pairs assigned to all the instances in the corresponding scope.
         */
        metadata?: Schema$InstanceSettingsMetadata;
        /**
         * [Output Only] URL of the zone where the resource resides You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
         */
        zone?: string | null;
    }
    export interface Schema$InstanceSettingsMetadata {
        /**
         * A metadata key/value items map. The total size of all keys and values must be less than 512KB.
         */
        items?: {
            [key: string]: string;
        } | null;
        /**
         * [Output Only] Type of the resource. Always compute#metadata for metadata.
         */
        kind?: string | null;
    }
    export interface Schema$InstancesGetEffectiveFirewallsResponse {
        /**
         * Effective firewalls from firewall policies.
         */
        firewallPolicys?: Schema$InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy[];
        /**
         * Effective firewalls on the instance.
         */
        firewalls?: Schema$Firewall[];
        /**
         * Effective firewalls from organization policies.
         */
        organizationFirewalls?: Schema$InstancesGetEffectiveFirewallsResponseOrganizationFirewallPolicy[];
    }
    export interface Schema$InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy {
        /**
         * [Output Only] Deprecated, please use short name instead. The display name of the firewall policy.
         */
        displayName?: string | null;
        /**
         * [Output Only] The name of the firewall policy.
         */
        name?: string | null;
        /**
         * The rules that apply to the network.
         */
        rules?: Schema$FirewallPolicyRule[];
        /**
         * [Output Only] The short name of the firewall policy.
         */
        shortName?: string | null;
        /**
         * [Output Only] The type of the firewall policy. Can be one of HIERARCHY, NETWORK, NETWORK_REGIONAL.
         */
        type?: string | null;
    }
    /**
     * A pruned SecurityPolicy containing ID and any applicable firewall rules.
     */
    export interface Schema$InstancesGetEffectiveFirewallsResponseOrganizationFirewallPolicy {
        /**
         * The unique identifier for the security policy. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * The rules that apply to the network.
         */
        rules?: Schema$SecurityPolicyRule[];
    }
    export interface Schema$InstancesRemoveResourcePoliciesRequest {
        /**
         * Resource policies to be removed from this instance.
         */
        resourcePolicies?: string[] | null;
    }
    export interface Schema$InstancesResumeRequest {
        /**
         * Array of disks associated with this instance that are protected with a customer-supplied encryption key. In order to resume the instance, the disk url and its corresponding key must be provided. If the disk is not protected with a customer-supplied encryption key it should not be specified.
         */
        disks?: Schema$CustomerEncryptionKeyProtectedDisk[];
        /**
         * Decrypts data associated with an instance that is protected with a customer-supplied encryption key. If the instance you are starting is protected with a customer-supplied encryption key, the correct key must be provided otherwise the instance resume will not succeed.
         */
        instanceEncryptionKey?: Schema$CustomerEncryptionKey;
    }
    export interface Schema$InstancesScopedList {
        /**
         * [Output Only] A list of instances contained in this scope.
         */
        instances?: Schema$Instance[];
        /**
         * [Output Only] Informational warning which replaces the list of instances when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$InstancesSetLabelsRequest {
        /**
         * Fingerprint of the previous set of labels for this resource, used to prevent conflicts. Provide the latest fingerprint value when making a request to add or change labels.
         */
        labelFingerprint?: string | null;
        labels?: {
            [key: string]: string;
        } | null;
    }
    export interface Schema$InstancesSetMachineResourcesRequest {
        /**
         * A list of the type and count of accelerator cards attached to the instance.
         */
        guestAccelerators?: Schema$AcceleratorConfig[];
    }
    export interface Schema$InstancesSetMachineTypeRequest {
        /**
         * Full or partial URL of the machine type resource. See Machine Types for a full list of machine types. For example: zones/us-central1-f/machineTypes/n1-standard-1
         */
        machineType?: string | null;
    }
    export interface Schema$InstancesSetMinCpuPlatformRequest {
        /**
         * Minimum cpu/platform this instance should be started at.
         */
        minCpuPlatform?: string | null;
    }
    export interface Schema$InstancesSetNameRequest {
        /**
         * The current name of this resource, used to prevent conflicts. Provide the latest name when making a request to change name.
         */
        currentName?: string | null;
        /**
         * The name to be applied to the instance. Needs to be RFC 1035 compliant.
         */
        name?: string | null;
    }
    export interface Schema$InstancesSetSecurityPolicyRequest {
        /**
         * The network interfaces that the security policy will be applied to. Network interfaces use the nicN naming format. You can only set a security policy for network interfaces with an access config.
         */
        networkInterfaces?: string[] | null;
        /**
         * A full or partial URL to a security policy to add to this instance. If this field is set to an empty string it will remove the associated security policy.
         */
        securityPolicy?: string | null;
    }
    export interface Schema$InstancesSetServiceAccountRequest {
        /**
         * Email address of the service account.
         */
        email?: string | null;
        /**
         * The list of scopes to be made available for this service account.
         */
        scopes?: string[] | null;
    }
    export interface Schema$InstancesStartWithEncryptionKeyRequest {
        /**
         * Array of disks associated with this instance that are protected with a customer-supplied encryption key. In order to start the instance, the disk url and its corresponding key must be provided. If the disk is not protected with a customer-supplied encryption key it should not be specified.
         */
        disks?: Schema$CustomerEncryptionKeyProtectedDisk[];
        /**
         * Decrypts data associated with an instance that is protected with a customer-supplied encryption key. If the instance you are starting is protected with a customer-supplied encryption key, the correct key must be provided otherwise the instance start will not succeed.
         */
        instanceEncryptionKey?: Schema$CustomerEncryptionKey;
    }
    /**
     * Represents an Instance Template resource. Google Compute Engine has two Instance Template resources: * [Global](/compute/docs/reference/rest/alpha/instanceTemplates) * [Regional](/compute/docs/reference/rest/alpha/regionInstanceTemplates) You can reuse a global instance template in different regions whereas you can use a regional instance template in a specified region only. If you want to reduce cross-region dependency or achieve data residency, use a regional instance template. To create VMs, managed instance groups, and reservations, you can use either global or regional instance templates. For more information, read Instance Templates.
     */
    export interface Schema$InstanceTemplate {
        /**
         * [Output Only] The creation timestamp for this instance template in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * [Output Only] A unique identifier for this instance template. The server defines this identifier.
         */
        id?: string | null;
        /**
         * [Output Only] The resource type, which is always compute#instanceTemplate for instance templates.
         */
        kind?: string | null;
        /**
         * Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * The instance properties for this instance template.
         */
        properties?: Schema$InstanceProperties;
        /**
         * [Output Only] URL of the region where the instance template resides. Only applicable for regional resources.
         */
        region?: string | null;
        /**
         * [Output Only] The URL for this instance template. The server defines this URL.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * The source instance used to create the template. You can provide this as a partial or full URL to the resource. For example, the following are valid values: - https://www.googleapis.com/compute/v1/projects/project/zones/zone /instances/instance - projects/project/zones/zone/instances/instance
         */
        sourceInstance?: string | null;
        /**
         * The source instance params to use to create this instance template.
         */
        sourceInstanceParams?: Schema$SourceInstanceParams;
    }
    /**
     * Contains a list of InstanceTemplatesScopedList.
     */
    export interface Schema$InstanceTemplateAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of InstanceTemplatesScopedList resources.
         */
        items?: {
            [key: string]: Schema$InstanceTemplatesScopedList;
        } | null;
        /**
         * Type of resource.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * A list of instance templates.
     */
    export interface Schema$InstanceTemplateList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of InstanceTemplate resources.
         */
        items?: Schema$InstanceTemplate[];
        /**
         * [Output Only] The resource type, which is always compute#instanceTemplatesListResponse for instance template lists.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$InstanceTemplatesScopedList {
        /**
         * [Output Only] A list of instance templates that are contained within the specified project and zone.
         */
        instanceTemplates?: Schema$InstanceTemplate[];
        /**
         * [Output Only] An informational warning that replaces the list of instance templates when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$InstanceWithNamedPorts {
        /**
         * [Output Only] The URL of the instance.
         */
        instance?: string | null;
        /**
         * [Output Only] The named ports that belong to this instance group.
         */
        namedPorts?: Schema$NamedPort[];
        /**
         * [Output Only] The status of the instance.
         */
        status?: string | null;
    }
    /**
     * Represents a InstantSnapshot resource. You can use instant snapshots to create disk rollback points quickly..
     */
    export interface Schema$InstantSnapshot {
        /**
         * [Output Only] The architecture of the instant snapshot. Valid values are ARM64 or X86_64.
         */
        architecture?: string | null;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * [Output Only] Size of the source disk, specified in GB.
         */
        diskSizeGb?: string | null;
        /**
         * Whether to attempt an application consistent instant snapshot by informing the OS to prepare for the snapshot process.
         */
        guestFlush?: boolean | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#instantSnapshot for InstantSnapshot resources.
         */
        kind?: string | null;
        /**
         * A fingerprint for the labels being applied to this InstantSnapshot, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a InstantSnapshot.
         */
        labelFingerprint?: string | null;
        /**
         * Labels to apply to this InstantSnapshot. These can be later modified by the setLabels method. Label values may be empty.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * [Output Only] URL of the region where the instant snapshot resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
         */
        region?: string | null;
        /**
         * [Output Only] Status information for the instant snapshot resource.
         */
        resourceStatus?: Schema$InstantSnapshotResourceStatus;
        /**
         * [Output Only] Reserved for future use.
         */
        satisfiesPzs?: boolean | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource's resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * URL of the source disk used to create this instant snapshot. Note that the source disk must be in the same zone/region as the instant snapshot to be created. This can be a full or valid partial URL. For example, the following are valid values: - https://www.googleapis.com/compute/v1/projects/project/zones/zone /disks/disk - https://www.googleapis.com/compute/v1/projects/project/regions/region /disks/disk - projects/project/zones/zone/disks/disk - projects/project/regions/region/disks/disk - zones/zone/disks/disk - regions/region/disks/disk
         */
        sourceDisk?: string | null;
        /**
         * [Output Only] The ID value of the disk used to create this InstantSnapshot. This value may be used to determine whether the InstantSnapshot was taken from the current or a previous instance of a given disk name.
         */
        sourceDiskId?: string | null;
        /**
         * [Output Only] The status of the instantSnapshot. This can be CREATING, DELETING, FAILED, or READY.
         */
        status?: string | null;
        /**
         * [Output Only] URL of the zone where the instant snapshot resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
         */
        zone?: string | null;
    }
    export interface Schema$InstantSnapshotAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of InstantSnapshotsScopedList resources.
         */
        items?: {
            [key: string]: Schema$InstantSnapshotsScopedList;
        } | null;
        /**
         * [Output Only] Type of resource. Always compute#instantSnapshotAggregatedList for aggregated lists of instantSnapshots.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$InstantSnapshotExportParams {
        /**
         * An optional base instant snapshot that this resource is compared against. If not specified, all blocks of this resource are exported. The base instant snapshot and this resource must be created from the same disk. The base instant snapshot must be created earlier in time than this resource.
         */
        baseInstantSnapshot?: string | null;
        /**
         * The name of an existing bucket in Cloud Storage where the changed blocks will be stored. The Google Service Account must have read and write access to this bucket. The bucket has to be in the same region as this resource.
         */
        bucketName?: string | null;
        /**
         * Encryption key used to encrypt the instant snapshot.
         */
        encryptionKey?: Schema$CustomerEncryptionKey;
        /**
         * Name of the output Bigstore object storing the changed blocks. Object name must be less than 1024 bytes in length.
         */
        objectName?: string | null;
        /**
         * The format of the output file.
         */
        outputType?: string | null;
    }
    /**
     * Contains a list of InstantSnapshot resources.
     */
    export interface Schema$InstantSnapshotList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of InstantSnapshot resources.
         */
        items?: Schema$InstantSnapshot[];
        /**
         * Type of resource.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$InstantSnapshotResourceStatus {
        /**
         * [Output Only] The storage size of this instant snapshot.
         */
        storageSizeBytes?: string | null;
    }
    export interface Schema$InstantSnapshotsExportRequest {
        /**
         * Parameters to export the changed blocks.
         */
        exportParams?: Schema$InstantSnapshotExportParams;
    }
    export interface Schema$InstantSnapshotsScopedList {
        /**
         * [Output Only] A list of instantSnapshots contained in this scope.
         */
        instantSnapshots?: Schema$InstantSnapshot[];
        /**
         * [Output Only] Informational warning which replaces the list of instantSnapshots when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * HttpRouteRuleMatch criteria for field values that must stay within the specified integer range.
     */
    export interface Schema$Int64RangeMatch {
        /**
         * The end of the range (exclusive) in signed long integer format.
         */
        rangeEnd?: string | null;
        /**
         * The start of the range (inclusive) in signed long integer format.
         */
        rangeStart?: string | null;
    }
    /**
     * Represents an Interconnect resource. An Interconnect resource is a dedicated connection between the Google Cloud network and your on-premises network. For more information, read the Dedicated Interconnect Overview.
     */
    export interface Schema$Interconnect {
        /**
         * Administrative status of the interconnect. When this is set to true, the Interconnect is functional and can carry traffic. When set to false, no packets can be carried over the interconnect and no BGP routes are exchanged over it. By default, the status is set to true.
         */
        adminEnabled?: boolean | null;
        /**
         * [Output only] List of features available for this Interconnect connection, which can take one of the following values: - MACSEC If present then the Interconnect connection is provisioned on MACsec capable hardware ports. If not present then the Interconnect connection is provisioned on non-MACsec capable ports and MACsec isn't supported and enabling MACsec fails.
         */
        availableFeatures?: string[] | null;
        /**
         * [Output Only] A list of CircuitInfo objects, that describe the individual circuits in this LAG.
         */
        circuitInfos?: Schema$InterconnectCircuitInfo[];
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * Customer name, to put in the Letter of Authorization as the party authorized to request a crossconnect.
         */
        customerName?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * [Output Only] A list of outages expected for this Interconnect.
         */
        expectedOutages?: Schema$InterconnectOutageNotification[];
        /**
         * [Output Only] IP address configured on the Google side of the Interconnect link. This can be used only for ping tests.
         */
        googleIpAddress?: string | null;
        /**
         * [Output Only] Google reference ID to be used when raising support tickets with Google or otherwise to debug backend connectivity issues.
         */
        googleReferenceId?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] A list of the URLs of all InterconnectAttachments configured to use this Interconnect.
         */
        interconnectAttachments?: string[] | null;
        /**
         * Type of interconnect, which can take one of the following values: - PARTNER: A partner-managed interconnection shared between customers though a partner. - DEDICATED: A dedicated physical interconnection with the customer. Note that a value IT_PRIVATE has been deprecated in favor of DEDICATED.
         */
        interconnectType?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#interconnect for interconnects.
         */
        kind?: string | null;
        /**
         * A fingerprint for the labels being applied to this Interconnect, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve an Interconnect.
         */
        labelFingerprint?: string | null;
        /**
         * Labels for this resource. These can only be added or modified by the setLabels method. Each label key/value pair must comply with RFC1035. Label values may be empty.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * Type of link requested, which can take one of the following values: - LINK_TYPE_ETHERNET_10G_LR: A 10G Ethernet with LR optics - LINK_TYPE_ETHERNET_100G_LR: A 100G Ethernet with LR optics. Note that this field indicates the speed of each of the links in the bundle, not the speed of the entire bundle.
         */
        linkType?: string | null;
        /**
         * URL of the InterconnectLocation object that represents where this connection is to be provisioned.
         */
        location?: string | null;
        /**
         * Configuration that enables Media Access Control security (MACsec) on the Cloud Interconnect connection between Google and your on-premises router.
         */
        macsec?: Schema$InterconnectMacsec;
        /**
         * Enable or disable MACsec on this Interconnect connection. MACsec enablement fails if the MACsec object is not specified.
         */
        macsecEnabled?: boolean | null;
        /**
         * Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * Email address to contact the customer NOC for operations and maintenance notifications regarding this Interconnect. If specified, this will be used for notifications in addition to all other forms described, such as Cloud Monitoring logs alerting and Cloud Notifications. This field is required for users who sign up for Cloud Interconnect using workforce identity federation.
         */
        nocContactEmail?: string | null;
        /**
         * [Output Only] The current status of this Interconnect's functionality, which can take one of the following values: - OS_ACTIVE: A valid Interconnect, which is turned up and is ready to use. Attachments may be provisioned on this Interconnect. - OS_UNPROVISIONED: An Interconnect that has not completed turnup. No attachments may be provisioned on this Interconnect. - OS_UNDER_MAINTENANCE: An Interconnect that is undergoing internal maintenance. No attachments may be provisioned or updated on this Interconnect.
         */
        operationalStatus?: string | null;
        /**
         * [Output Only] IP address configured on the customer side of the Interconnect link. The customer should configure this IP address during turnup when prompted by Google NOC. This can be used only for ping tests.
         */
        peerIpAddress?: string | null;
        /**
         * [Output Only] Number of links actually provisioned in this interconnect.
         */
        provisionedLinkCount?: number | null;
        /**
         * Indicates that this is a Cross-Cloud Interconnect. This field specifies the location outside of Google's network that the interconnect is connected to.
         */
        remoteLocation?: string | null;
        /**
         * Optional. List of features requested for this Interconnect connection, which can take one of the following values: - MACSEC If specified then the connection is created on MACsec capable hardware ports. If not specified, the default value is false, which allocates non-MACsec capable ports first if available. This parameter can be provided only with Interconnect INSERT. It isn't valid for Interconnect PATCH.
         */
        requestedFeatures?: string[] | null;
        /**
         * Target number of physical links in the link bundle, as requested by the customer.
         */
        requestedLinkCount?: number | null;
        /**
         * [Output Only] Reserved for future use.
         */
        satisfiesPzs?: boolean | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * [Output Only] The current state of Interconnect functionality, which can take one of the following values: - ACTIVE: The Interconnect is valid, turned up and ready to use. Attachments may be provisioned on this Interconnect. - UNPROVISIONED: The Interconnect has not completed turnup. No attachments may be provisioned on this Interconnect. - UNDER_MAINTENANCE: The Interconnect is undergoing internal maintenance. No attachments may be provisioned or updated on this Interconnect.
         */
        state?: string | null;
    }
    /**
     * Represents an Interconnect Attachment (VLAN) resource. You can use Interconnect attachments (VLANS) to connect your Virtual Private Cloud networks to your on-premises networks through an Interconnect. For more information, read Creating VLAN Attachments.
     */
    export interface Schema$InterconnectAttachment {
        /**
         * Determines whether this Attachment will carry packets. Not present for PARTNER_PROVIDER.
         */
        adminEnabled?: boolean | null;
        /**
         * Provisioned bandwidth capacity for the interconnect attachment. For attachments of type DEDICATED, the user can set the bandwidth. For attachments of type PARTNER, the Google Partner that is operating the interconnect must set the bandwidth. Output only for PARTNER type, mutable for PARTNER_PROVIDER and DEDICATED, and can take one of the following values: - BPS_50M: 50 Mbit/s - BPS_100M: 100 Mbit/s - BPS_200M: 200 Mbit/s - BPS_300M: 300 Mbit/s - BPS_400M: 400 Mbit/s - BPS_500M: 500 Mbit/s - BPS_1G: 1 Gbit/s - BPS_2G: 2 Gbit/s - BPS_5G: 5 Gbit/s - BPS_10G: 10 Gbit/s - BPS_20G: 20 Gbit/s - BPS_50G: 50 Gbit/s
         */
        bandwidth?: string | null;
        /**
         * This field is not available.
         */
        candidateIpv6Subnets?: string[] | null;
        /**
         * Up to 16 candidate prefixes that can be used to restrict the allocation of cloudRouterIpAddress and customerRouterIpAddress for this attachment. All prefixes must be within link-local address space (169.254.0.0/16) and must be /29 or shorter (/28, /27, etc). Google will attempt to select an unused /29 from the supplied candidate prefix(es). The request will fail if all possible /29s are in use on Google's edge. If not supplied, Google will randomly select an unused /29 from all of link-local space.
         */
        candidateSubnets?: string[] | null;
        /**
         * [Output Only] IPv4 address + prefix length to be configured on Cloud Router Interface for this interconnect attachment.
         */
        cloudRouterIpAddress?: string | null;
        /**
         * [Output Only] IPv6 address + prefix length to be configured on Cloud Router Interface for this interconnect attachment.
         */
        cloudRouterIpv6Address?: string | null;
        /**
         * This field is not available.
         */
        cloudRouterIpv6InterfaceId?: string | null;
        /**
         * [Output Only] Constraints for this attachment, if any. The attachment does not work if these constraints are not met.
         */
        configurationConstraints?: Schema$InterconnectAttachmentConfigurationConstraints;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * [Output Only] IPv4 address + prefix length to be configured on the customer router subinterface for this interconnect attachment.
         */
        customerRouterIpAddress?: string | null;
        /**
         * [Output Only] IPv6 address + prefix length to be configured on the customer router subinterface for this interconnect attachment.
         */
        customerRouterIpv6Address?: string | null;
        /**
         * This field is not available.
         */
        customerRouterIpv6InterfaceId?: string | null;
        /**
         * [Output Only] Dataplane version for this InterconnectAttachment. This field is only present for Dataplane version 2 and higher. Absence of this field in the API output indicates that the Dataplane is version 1.
         */
        dataplaneVersion?: number | null;
        /**
         * An optional description of this resource.
         */
        description?: string | null;
        /**
         * Desired availability domain for the attachment. Only available for type PARTNER, at creation time, and can take one of the following values: - AVAILABILITY_DOMAIN_ANY - AVAILABILITY_DOMAIN_1 - AVAILABILITY_DOMAIN_2 For improved reliability, customers should configure a pair of attachments, one per availability domain. The selected availability domain will be provided to the Partner via the pairing key, so that the provisioned circuit will lie in the specified domain. If not specified, the value will default to AVAILABILITY_DOMAIN_ANY.
         */
        edgeAvailabilityDomain?: string | null;
        /**
         * Indicates the user-supplied encryption option of this VLAN attachment (interconnectAttachment). Can only be specified at attachment creation for PARTNER or DEDICATED attachments. Possible values are: - NONE - This is the default value, which means that the VLAN attachment carries unencrypted traffic. VMs are able to send traffic to, or receive traffic from, such a VLAN attachment. - IPSEC - The VLAN attachment carries only encrypted traffic that is encrypted by an IPsec device, such as an HA VPN gateway or third-party IPsec VPN. VMs cannot directly send traffic to, or receive traffic from, such a VLAN attachment. To use *HA VPN over Cloud Interconnect*, the VLAN attachment must be created with this option.
         */
        encryption?: string | null;
        /**
         * [Output Only] Google reference ID, to be used when raising support tickets with Google or otherwise to debug backend connectivity issues. [Deprecated] This field is not used.
         */
        googleReferenceId?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * URL of the underlying Interconnect object that this attachment's traffic will traverse through.
         */
        interconnect?: string | null;
        /**
         * A list of URLs of addresses that have been reserved for the VLAN attachment. Used only for the VLAN attachment that has the encryption option as IPSEC. The addresses must be regional internal IP address ranges. When creating an HA VPN gateway over the VLAN attachment, if the attachment is configured to use a regional internal IP address, then the VPN gateway's IP address is allocated from the IP address range specified here. For example, if the HA VPN gateway's interface 0 is paired to this VLAN attachment, then a regional internal IP address for the VPN gateway interface 0 will be allocated from the IP address specified for this VLAN attachment. If this field is not specified when creating the VLAN attachment, then later on when creating an HA VPN gateway on this VLAN attachment, the HA VPN gateway's IP address is allocated from the regional external IP address pool.
         */
        ipsecInternalAddresses?: string[] | null;
        /**
         * [Output Only] Type of the resource. Always compute#interconnectAttachment for interconnect attachments.
         */
        kind?: string | null;
        /**
         * A fingerprint for the labels being applied to this InterconnectAttachment, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve an InterconnectAttachment.
         */
        labelFingerprint?: string | null;
        /**
         * Labels for this resource. These can only be added or modified by the setLabels method. Each label key/value pair must comply with RFC1035. Label values may be empty.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * Maximum Transmission Unit (MTU), in bytes, of packets passing through this interconnect attachment. Only 1440 and 1500 are allowed. If not specified, the value will default to 1440.
         */
        mtu?: number | null;
        /**
         * Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * [Output Only] The current status of whether or not this interconnect attachment is functional, which can take one of the following values: - OS_ACTIVE: The attachment has been turned up and is ready to use. - OS_UNPROVISIONED: The attachment is not ready to use yet, because turnup is not complete.
         */
        operationalStatus?: string | null;
        /**
         * [Output only for type PARTNER. Input only for PARTNER_PROVIDER. Not present for DEDICATED]. The opaque identifier of a PARTNER attachment used to initiate provisioning with a selected partner. Of the form "XXXXX/region/domain"
         */
        pairingKey?: string | null;
        /**
         * Optional BGP ASN for the router supplied by a Layer 3 Partner if they configured BGP on behalf of the customer. Output only for PARTNER type, input only for PARTNER_PROVIDER, not available for DEDICATED.
         */
        partnerAsn?: string | null;
        /**
         * Informational metadata about Partner attachments from Partners to display to customers. Output only for PARTNER type, mutable for PARTNER_PROVIDER, not available for DEDICATED.
         */
        partnerMetadata?: Schema$InterconnectAttachmentPartnerMetadata;
        /**
         * [Output Only] Information specific to an InterconnectAttachment. This property is populated if the interconnect that this is attached to is of type DEDICATED.
         */
        privateInterconnectInfo?: Schema$InterconnectAttachmentPrivateInfo;
        /**
         * [Output Only] URL of the region where the regional interconnect attachment resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
         */
        region?: string | null;
        /**
         * [Output Only] If the attachment is on a Cross-Cloud Interconnect connection, this field contains the interconnect's remote location service provider. Example values: "Amazon Web Services" "Microsoft Azure". The field is set only for attachments on Cross-Cloud Interconnect connections. Its value is copied from the InterconnectRemoteLocation remoteService field.
         */
        remoteService?: string | null;
        /**
         * URL of the Cloud Router to be used for dynamic routing. This router must be in the same region as this InterconnectAttachment. The InterconnectAttachment will automatically connect the Interconnect to the network & region within which the Cloud Router is configured.
         */
        router?: string | null;
        /**
         * [Output Only] Reserved for future use.
         */
        satisfiesPzs?: boolean | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * The stack type for this interconnect attachment to identify whether the IPv6 feature is enabled or not. If not specified, IPV4_ONLY will be used. This field can be both set at interconnect attachments creation and update interconnect attachment operations.
         */
        stackType?: string | null;
        /**
         * [Output Only] The current state of this attachment's functionality. Enum values ACTIVE and UNPROVISIONED are shared by DEDICATED/PRIVATE, PARTNER, and PARTNER_PROVIDER interconnect attachments, while enum values PENDING_PARTNER, PARTNER_REQUEST_RECEIVED, and PENDING_CUSTOMER are used for only PARTNER and PARTNER_PROVIDER interconnect attachments. This state can take one of the following values: - ACTIVE: The attachment has been turned up and is ready to use. - UNPROVISIONED: The attachment is not ready to use yet, because turnup is not complete. - PENDING_PARTNER: A newly-created PARTNER attachment that has not yet been configured on the Partner side. - PARTNER_REQUEST_RECEIVED: A PARTNER attachment is in the process of provisioning after a PARTNER_PROVIDER attachment was created that references it. - PENDING_CUSTOMER: A PARTNER or PARTNER_PROVIDER attachment that is waiting for a customer to activate it. - DEFUNCT: The attachment was deleted externally and is no longer functional. This could be because the associated Interconnect was removed, or because the other side of a Partner attachment was deleted.
         */
        state?: string | null;
        /**
         * Length of the IPv4 subnet mask. Allowed values: - 29 (default) - 30 The default value is 29, except for Cross-Cloud Interconnect connections that use an InterconnectRemoteLocation with a constraints.subnetLengthRange.min equal to 30. For example, connections that use an Azure remote location fall into this category. In these cases, the default value is 30, and requesting 29 returns an error. Where both 29 and 30 are allowed, 29 is preferred, because it gives Google Cloud Support more debugging visibility.
         */
        subnetLength?: number | null;
        /**
         * The type of interconnect attachment this is, which can take one of the following values: - DEDICATED: an attachment to a Dedicated Interconnect. - PARTNER: an attachment to a Partner Interconnect, created by the customer. - PARTNER_PROVIDER: an attachment to a Partner Interconnect, created by the partner.
         */
        type?: string | null;
        /**
         * The IEEE 802.1Q VLAN tag for this attachment, in the range 2-4093. Only specified at creation time.
         */
        vlanTag8021q?: number | null;
    }
    export interface Schema$InterconnectAttachmentAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of InterconnectAttachmentsScopedList resources.
         */
        items?: {
            [key: string]: Schema$InterconnectAttachmentsScopedList;
        } | null;
        /**
         * [Output Only] Type of resource. Always compute#interconnectAttachmentAggregatedList for aggregated lists of interconnect attachments.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$InterconnectAttachmentConfigurationConstraints {
        /**
         * [Output Only] Whether the attachment's BGP session requires/allows/disallows BGP MD5 authentication. This can take one of the following values: MD5_OPTIONAL, MD5_REQUIRED, MD5_UNSUPPORTED. For example, a Cross-Cloud Interconnect connection to a remote cloud provider that requires BGP MD5 authentication has the interconnectRemoteLocation attachment_configuration_constraints.bgp_md5 field set to MD5_REQUIRED, and that property is propagated to the attachment. Similarly, if BGP MD5 is MD5_UNSUPPORTED, an error is returned if MD5 is requested.
         */
        bgpMd5?: string | null;
        /**
         * [Output Only] List of ASN ranges that the remote location is known to support. Formatted as an array of inclusive ranges {min: min-value, max: max-value\}. For example, [{min: 123, max: 123\}, {min: 64512, max: 65534\}] allows the peer ASN to be 123 or anything in the range 64512-65534. This field is only advisory. Although the API accepts other ranges, these are the ranges that we recommend.
         */
        bgpPeerAsnRanges?: Schema$InterconnectAttachmentConfigurationConstraintsBgpPeerASNRange[];
    }
    export interface Schema$InterconnectAttachmentConfigurationConstraintsBgpPeerASNRange {
        max?: number | null;
        min?: number | null;
    }
    /**
     * Response to the list request, and contains a list of interconnect attachments.
     */
    export interface Schema$InterconnectAttachmentList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of InterconnectAttachment resources.
         */
        items?: Schema$InterconnectAttachment[];
        /**
         * [Output Only] Type of resource. Always compute#interconnectAttachmentList for lists of interconnect attachments.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Informational metadata about Partner attachments from Partners to display to customers. These fields are propagated from PARTNER_PROVIDER attachments to their corresponding PARTNER attachments.
     */
    export interface Schema$InterconnectAttachmentPartnerMetadata {
        /**
         * Plain text name of the Interconnect this attachment is connected to, as displayed in the Partner's portal. For instance "Chicago 1". This value may be validated to match approved Partner values.
         */
        interconnectName?: string | null;
        /**
         * Plain text name of the Partner providing this attachment. This value may be validated to match approved Partner values.
         */
        partnerName?: string | null;
        /**
         * URL of the Partner's portal for this Attachment. Partners may customise this to be a deep link to the specific resource on the Partner portal. This value may be validated to match approved Partner values.
         */
        portalUrl?: string | null;
    }
    /**
     * Information for an interconnect attachment when this belongs to an interconnect of type DEDICATED.
     */
    export interface Schema$InterconnectAttachmentPrivateInfo {
        /**
         * [Output Only] 802.1q encapsulation tag to be used for traffic between Google and the customer, going to and from this network and region.
         */
        tag8021q?: number | null;
    }
    export interface Schema$InterconnectAttachmentsScopedList {
        /**
         * A list of interconnect attachments contained in this scope.
         */
        interconnectAttachments?: Schema$InterconnectAttachment[];
        /**
         * Informational warning which replaces the list of addresses when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Describes a single physical circuit between the Customer and Google. CircuitInfo objects are created by Google, so all fields are output only.
     */
    export interface Schema$InterconnectCircuitInfo {
        /**
         * Customer-side demarc ID for this circuit.
         */
        customerDemarcId?: string | null;
        /**
         * Google-assigned unique ID for this circuit. Assigned at circuit turn-up.
         */
        googleCircuitId?: string | null;
        /**
         * Google-side demarc ID for this circuit. Assigned at circuit turn-up and provided by Google to the customer in the LOA.
         */
        googleDemarcId?: string | null;
    }
    /**
     * Diagnostics information about the Interconnect connection, which contains detailed and current technical information about Google's side of the connection.
     */
    export interface Schema$InterconnectDiagnostics {
        /**
         * A list of InterconnectDiagnostics.ARPEntry objects, describing individual neighbors currently seen by the Google router in the ARP cache for the Interconnect. This will be empty when the Interconnect is not bundled.
         */
        arpCaches?: Schema$InterconnectDiagnosticsARPEntry[];
        /**
         * The aggregation type of the bundle interface.
         */
        bundleAggregationType?: string | null;
        /**
         * The operational status of the bundle interface.
         */
        bundleOperationalStatus?: string | null;
        /**
         * A list of InterconnectDiagnostics.LinkStatus objects, describing the status for each link on the Interconnect.
         */
        links?: Schema$InterconnectDiagnosticsLinkStatus[];
        /**
         * The MAC address of the Interconnect's bundle interface.
         */
        macAddress?: string | null;
    }
    /**
     * Describing the ARP neighbor entries seen on this link
     */
    export interface Schema$InterconnectDiagnosticsARPEntry {
        /**
         * The IP address of this ARP neighbor.
         */
        ipAddress?: string | null;
        /**
         * The MAC address of this ARP neighbor.
         */
        macAddress?: string | null;
    }
    export interface Schema$InterconnectDiagnosticsLinkLACPStatus {
        /**
         * System ID of the port on Google's side of the LACP exchange.
         */
        googleSystemId?: string | null;
        /**
         * System ID of the port on the neighbor's side of the LACP exchange.
         */
        neighborSystemId?: string | null;
        /**
         * The state of a LACP link, which can take one of the following values: - ACTIVE: The link is configured and active within the bundle. - DETACHED: The link is not configured within the bundle. This means that the rest of the object should be empty.
         */
        state?: string | null;
    }
    export interface Schema$InterconnectDiagnosticsLinkOpticalPower {
        /**
         * The status of the current value when compared to the warning and alarm levels for the receiving or transmitting transceiver. Possible states include: - OK: The value has not crossed a warning threshold. - LOW_WARNING: The value has crossed below the low warning threshold. - HIGH_WARNING: The value has crossed above the high warning threshold. - LOW_ALARM: The value has crossed below the low alarm threshold. - HIGH_ALARM: The value has crossed above the high alarm threshold.
         */
        state?: string | null;
        /**
         * Value of the current receiving or transmitting optical power, read in dBm. Take a known good optical value, give it a 10% margin and trigger warnings relative to that value. In general, a -7dBm warning and a -11dBm alarm are good optical value estimates for most links.
         */
        value?: number | null;
    }
    export interface Schema$InterconnectDiagnosticsLinkStatus {
        /**
         * A list of InterconnectDiagnostics.ARPEntry objects, describing the ARP neighbor entries seen on this link. This will be empty if the link is bundled
         */
        arpCaches?: Schema$InterconnectDiagnosticsARPEntry[];
        /**
         * The unique ID for this link assigned during turn up by Google.
         */
        circuitId?: string | null;
        /**
         * The Demarc address assigned by Google and provided in the LoA.
         */
        googleDemarc?: string | null;
        lacpStatus?: Schema$InterconnectDiagnosticsLinkLACPStatus;
        /**
         * Describes the status of MACsec encryption on this link.
         */
        macsec?: Schema$InterconnectDiagnosticsMacsecStatus;
        /**
         * The operational status of the link.
         */
        operationalStatus?: string | null;
        /**
         * An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the received light level.
         */
        receivingOpticalPower?: Schema$InterconnectDiagnosticsLinkOpticalPower;
        /**
         * An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the transmitted light level.
         */
        transmittingOpticalPower?: Schema$InterconnectDiagnosticsLinkOpticalPower;
    }
    /**
     * Describes the status of MACsec encryption on the link.
     */
    export interface Schema$InterconnectDiagnosticsMacsecStatus {
        /**
         * Indicates the Connectivity Association Key Name (CKN) currently being used if MACsec is operational.
         */
        ckn?: string | null;
        /**
         * Indicates whether or not MACsec is operational on this link.
         */
        operational?: boolean | null;
    }
    /**
     * Response to the list request, and contains a list of interconnects.
     */
    export interface Schema$InterconnectList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of Interconnect resources.
         */
        items?: Schema$Interconnect[];
        /**
         * [Output Only] Type of resource. Always compute#interconnectList for lists of interconnects.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Represents an Interconnect Attachment (VLAN) Location resource. You can use this resource to find location details about an Interconnect attachment (VLAN). For more information about interconnect attachments, read Creating VLAN Attachments.
     */
    export interface Schema$InterconnectLocation {
        /**
         * [Output Only] The postal address of the Point of Presence, each line in the address is separated by a newline character.
         */
        address?: string | null;
        /**
         * [Output Only] Availability zone for this InterconnectLocation. Within a metropolitan area (metro), maintenance will not be simultaneously scheduled in more than one availability zone. Example: "zone1" or "zone2".
         */
        availabilityZone?: string | null;
        /**
         * [Output only] List of features available at this InterconnectLocation, which can take one of the following values: - MACSEC
         */
        availableFeatures?: string[] | null;
        /**
         * [Output only] List of link types available at this InterconnectLocation, which can take one of the following values: - LINK_TYPE_ETHERNET_10G_LR - LINK_TYPE_ETHERNET_100G_LR
         */
        availableLinkTypes?: string[] | null;
        /**
         * [Output Only] Metropolitan area designator that indicates which city an interconnect is located. For example: "Chicago, IL", "Amsterdam, Netherlands".
         */
        city?: string | null;
        /**
         * [Output Only] Continent for this location, which can take one of the following values: - AFRICA - ASIA_PAC - EUROPE - NORTH_AMERICA - SOUTH_AMERICA
         */
        continent?: string | null;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * [Output Only] An optional description of the resource.
         */
        description?: string | null;
        /**
         * [Output Only] The name of the provider for this facility (e.g., EQUINIX).
         */
        facilityProvider?: string | null;
        /**
         * [Output Only] A provider-assigned Identifier for this facility (e.g., Ashburn-DC1).
         */
        facilityProviderFacilityId?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#interconnectLocation for interconnect locations.
         */
        kind?: string | null;
        /**
         * [Output Only] Name of the resource.
         */
        name?: string | null;
        /**
         * [Output Only] The peeringdb identifier for this facility (corresponding with a netfac type in peeringdb).
         */
        peeringdbFacilityId?: string | null;
        /**
         * [Output Only] A list of InterconnectLocation.RegionInfo objects, that describe parameters pertaining to the relation between this InterconnectLocation and various Google Cloud regions.
         */
        regionInfos?: Schema$InterconnectLocationRegionInfo[];
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * [Output Only] The status of this InterconnectLocation, which can take one of the following values: - CLOSED: The InterconnectLocation is closed and is unavailable for provisioning new Interconnects. - AVAILABLE: The InterconnectLocation is available for provisioning new Interconnects.
         */
        status?: string | null;
        /**
         * [Output Only] Reserved for future use.
         */
        supportsPzs?: boolean | null;
    }
    /**
     * Response to the list request, and contains a list of interconnect locations.
     */
    export interface Schema$InterconnectLocationList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of InterconnectLocation resources.
         */
        items?: Schema$InterconnectLocation[];
        /**
         * [Output Only] Type of resource. Always compute#interconnectLocationList for lists of interconnect locations.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Information about any potential InterconnectAttachments between an Interconnect at a specific InterconnectLocation, and a specific Cloud Region.
     */
    export interface Schema$InterconnectLocationRegionInfo {
        /**
         * Expected round-trip time in milliseconds, from this InterconnectLocation to a VM in this region.
         */
        expectedRttMs?: string | null;
        /**
         * Identifies the network presence of this location.
         */
        locationPresence?: string | null;
        /**
         * URL for the region of this location.
         */
        region?: string | null;
    }
    /**
     * Configuration information for enabling Media Access Control security (MACsec) on this Cloud Interconnect connection between Google and your on-premises router.
     */
    export interface Schema$InterconnectMacsec {
        /**
         * If set to true, the Interconnect connection is configured with a should-secure MACsec security policy, that allows the Google router to fallback to cleartext traffic if the MKA session cannot be established. By default, the Interconnect connection is configured with a must-secure security policy that drops all traffic if the MKA session cannot be established with your router.
         */
        failOpen?: boolean | null;
        /**
         * Required. A keychain placeholder describing a set of named key objects along with their start times. A MACsec CKN/CAK is generated for each key in the key chain. Google router automatically picks the key with the most recent startTime when establishing or re-establishing a MACsec secure link.
         */
        preSharedKeys?: Schema$InterconnectMacsecPreSharedKey[];
    }
    /**
     * MACsec configuration information for the Interconnect connection. Contains the generated Connectivity Association Key Name (CKN) and the key (CAK) for this Interconnect connection.
     */
    export interface Schema$InterconnectMacsecConfig {
        /**
         * A keychain placeholder describing a set of named key objects along with their start times. A MACsec CKN/CAK is generated for each key in the key chain. Google router automatically picks the key with the most recent startTime when establishing or re-establishing a MACsec secure link.
         */
        preSharedKeys?: Schema$InterconnectMacsecConfigPreSharedKey[];
    }
    /**
     * Describes a pre-shared key used to setup MACsec in static connectivity association key (CAK) mode.
     */
    export interface Schema$InterconnectMacsecConfigPreSharedKey {
        /**
         * An auto-generated Connectivity Association Key (CAK) for this key.
         */
        cak?: string | null;
        /**
         * An auto-generated Connectivity Association Key Name (CKN) for this key.
         */
        ckn?: string | null;
        /**
         * User provided name for this pre-shared key.
         */
        name?: string | null;
        /**
         * User provided timestamp on or after which this key is valid.
         */
        startTime?: string | null;
    }
    /**
     * Describes a pre-shared key used to setup MACsec in static connectivity association key (CAK) mode.
     */
    export interface Schema$InterconnectMacsecPreSharedKey {
        /**
         * Required. A name for this pre-shared key. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * A RFC3339 timestamp on or after which the key is valid. startTime can be in the future. If the keychain has a single key, startTime can be omitted. If the keychain has multiple keys, startTime is mandatory for each key. The start times of keys must be in increasing order. The start times of two consecutive keys must be at least 6 hours apart.
         */
        startTime?: string | null;
    }
    /**
     * Description of a planned outage on this Interconnect.
     */
    export interface Schema$InterconnectOutageNotification {
        /**
         * If issue_type is IT_PARTIAL_OUTAGE, a list of the Google-side circuit IDs that will be affected.
         */
        affectedCircuits?: string[] | null;
        /**
         * A description about the purpose of the outage.
         */
        description?: string | null;
        /**
         * Scheduled end time for the outage (milliseconds since Unix epoch).
         */
        endTime?: string | null;
        /**
         * Form this outage is expected to take, which can take one of the following values: - OUTAGE: The Interconnect may be completely out of service for some or all of the specified window. - PARTIAL_OUTAGE: Some circuits comprising the Interconnect as a whole should remain up, but with reduced bandwidth. Note that the versions of this enum prefixed with "IT_" have been deprecated in favor of the unprefixed values.
         */
        issueType?: string | null;
        /**
         * Unique identifier for this outage notification.
         */
        name?: string | null;
        /**
         * The party that generated this notification, which can take the following value: - GOOGLE: this notification as generated by Google. Note that the value of NSRC_GOOGLE has been deprecated in favor of GOOGLE.
         */
        source?: string | null;
        /**
         * Scheduled start time for the outage (milliseconds since Unix epoch).
         */
        startTime?: string | null;
        /**
         * State of this notification, which can take one of the following values: - ACTIVE: This outage notification is active. The event could be in the past, present, or future. See start_time and end_time for scheduling. - CANCELLED: The outage associated with this notification was cancelled before the outage was due to start. - COMPLETED: The outage associated with this notification is complete. Note that the versions of this enum prefixed with "NS_" have been deprecated in favor of the unprefixed values.
         */
        state?: string | null;
    }
    /**
     * Represents a Cross-Cloud Interconnect Remote Location resource. You can use this resource to find remote location details about an Interconnect attachment (VLAN).
     */
    export interface Schema$InterconnectRemoteLocation {
        /**
         * [Output Only] The postal address of the Point of Presence, each line in the address is separated by a newline character.
         */
        address?: string | null;
        /**
         * [Output Only] Subset of fields from InterconnectAttachment's |configurationConstraints| field that apply to all attachments for this remote location.
         */
        attachmentConfigurationConstraints?: Schema$InterconnectAttachmentConfigurationConstraints;
        /**
         * [Output Only] Metropolitan area designator that indicates which city an interconnect is located. For example: "Chicago, IL", "Amsterdam, Netherlands".
         */
        city?: string | null;
        /**
         * [Output Only] Constraints on the parameters for creating Cross-Cloud Interconnect and associated InterconnectAttachments.
         */
        constraints?: Schema$InterconnectRemoteLocationConstraints;
        /**
         * [Output Only] Continent for this location, which can take one of the following values: - AFRICA - ASIA_PAC - EUROPE - NORTH_AMERICA - SOUTH_AMERICA
         */
        continent?: string | null;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * [Output Only] An optional description of the resource.
         */
        description?: string | null;
        /**
         * [Output Only] The name of the provider for this facility (e.g., EQUINIX).
         */
        facilityProvider?: string | null;
        /**
         * [Output Only] A provider-assigned Identifier for this facility (e.g., Ashburn-DC1).
         */
        facilityProviderFacilityId?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#interconnectRemoteLocation for interconnect remote locations.
         */
        kind?: string | null;
        /**
         * [Output Only] Link Aggregation Control Protocol (LACP) constraints, which can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED
         */
        lacp?: string | null;
        /**
         * [Output Only] The maximum number of 100 Gbps ports supported in a link aggregation group (LAG). When linkType is 100 Gbps, requestedLinkCount cannot exceed max_lag_size_100_gbps.
         */
        maxLagSize100Gbps?: number | null;
        /**
         * [Output Only] The maximum number of 10 Gbps ports supported in a link aggregation group (LAG). When linkType is 10 Gbps, requestedLinkCount cannot exceed max_lag_size_10_gbps.
         */
        maxLagSize10Gbps?: number | null;
        /**
         * [Output Only] Name of the resource.
         */
        name?: string | null;
        /**
         * [Output Only] The peeringdb identifier for this facility (corresponding with a netfac type in peeringdb).
         */
        peeringdbFacilityId?: string | null;
        /**
         * [Output Only] Permitted connections.
         */
        permittedConnections?: Schema$InterconnectRemoteLocationPermittedConnections[];
        /**
         * [Output Only] Indicates the service provider present at the remote location. Example values: "Amazon Web Services", "Microsoft Azure".
         */
        remoteService?: string | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * [Output Only] The status of this InterconnectRemoteLocation, which can take one of the following values: - CLOSED: The InterconnectRemoteLocation is closed and is unavailable for provisioning new Cross-Cloud Interconnects. - AVAILABLE: The InterconnectRemoteLocation is available for provisioning new Cross-Cloud Interconnects.
         */
        status?: string | null;
    }
    export interface Schema$InterconnectRemoteLocationConstraints {
        /**
         * [Output Only] Port pair remote location constraints, which can take one of the following values: PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION, PORT_PAIR_MATCHING_REMOTE_LOCATION. GCP's API refers only to individual ports, but the UI uses this field when ordering a pair of ports, to prevent users from accidentally ordering something that is incompatible with their cloud provider. Specifically, when ordering a redundant pair of Cross-Cloud Interconnect ports, and one of them uses a remote location with portPairMatchingRemoteLocation set to matching, the UI requires that both ports use the same remote location.
         */
        portPairRemoteLocation?: string | null;
        /**
         * [Output Only] Port pair VLAN constraints, which can take one of the following values: PORT_PAIR_UNCONSTRAINED_VLAN, PORT_PAIR_MATCHING_VLAN
         */
        portPairVlan?: string | null;
        /**
         * [Output Only] [min-length, max-length] The minimum and maximum value (inclusive) for the IPv4 subnet length. For example, an interconnectRemoteLocation for Azure has {min: 30, max: 30\} because Azure requires /30 subnets. This range specifies the values supported by both cloud providers. Interconnect currently supports /29 and /30 IPv4 subnet lengths. If a remote cloud has no constraint on IPv4 subnet length, the range would thus be {min: 29, max: 30\}.
         */
        subnetLengthRange?: Schema$InterconnectRemoteLocationConstraintsSubnetLengthRange;
    }
    export interface Schema$InterconnectRemoteLocationConstraintsSubnetLengthRange {
        max?: number | null;
        min?: number | null;
    }
    /**
     * Response to the list request, and contains a list of interconnect remote locations.
     */
    export interface Schema$InterconnectRemoteLocationList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of InterconnectRemoteLocation resources.
         */
        items?: Schema$InterconnectRemoteLocation[];
        /**
         * [Output Only] Type of resource. Always compute#interconnectRemoteLocationList for lists of interconnect remote locations.
         */
        kind?: string | null;
        /**
         * [Output Only] This token lets you get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$InterconnectRemoteLocationPermittedConnections {
        /**
         * [Output Only] URL of an Interconnect location that is permitted to connect to this Interconnect remote location.
         */
        interconnectLocation?: string | null;
    }
    /**
     * Response for the InterconnectsGetDiagnosticsRequest.
     */
    export interface Schema$InterconnectsGetDiagnosticsResponse {
        result?: Schema$InterconnectDiagnostics;
    }
    /**
     * Response for the InterconnectsGetMacsecConfigRequest.
     */
    export interface Schema$InterconnectsGetMacsecConfigResponse {
        /**
         * end_interface: MixerGetResponseWithEtagBuilder
         */
        etag?: string | null;
        result?: Schema$InterconnectMacsecConfig;
    }
    export interface Schema$InternalIpAddress {
        /**
         * IP CIDR address or range.
         */
        cidr?: string | null;
        /**
         * The owner of the internal IP address.
         */
        owner?: string | null;
        /**
         * The purpose of the internal IP address if applicable.
         */
        purpose?: string | null;
        /**
         * The region of the internal IP address if applicable.
         */
        region?: string | null;
        /**
         * The type of the internal IP address.
         */
        type?: string | null;
    }
    export interface Schema$InternalIpOwner {
        /**
         * IP CIDR range being owned.
         */
        ipCidrRange?: string | null;
        /**
         * URLs of the IP owners of the IP CIDR range.
         */
        owners?: string[] | null;
        /**
         * Whether this IP CIDR range is reserved for system use.
         */
        systemOwned?: boolean | null;
    }
    export interface Schema$IpAddressesList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of InternalIpAddress resources.
         */
        items?: Schema$InternalIpAddress[];
        /**
         * [Output Only] Type of resource. Always compute#ipAddressesList for IP addresses lists.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Contains a list of IP owners.
     */
    export interface Schema$IpOwnerList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of InternalIpOwner resources.
         */
        items?: Schema$InternalIpOwner[];
        /**
         * [Output Only] Type of resource. Always compute#ipOwnerList for lists of IP owners.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * [Deprecated] JWT configuration for origin authentication. JWT configuration for origin authentication.
     */
    export interface Schema$Jwt {
        /**
         * A JWT containing any of these audiences will be accepted. The service name will be accepted if audiences is empty. Examples: bookstore_android.apps.googleusercontent.com, bookstore_web.apps.googleusercontent.com
         */
        audiences?: string[] | null;
        /**
         * Identifies the issuer that issued the JWT, which is usually a URL or an email address. Examples: https://securetoken.google.com, 1234567-compute@developer.gserviceaccount.com
         */
        issuer?: string | null;
        /**
         * The provider's public key set to validate the signature of the JWT.
         */
        jwksPublicKeys?: string | null;
        /**
         * jwt_headers and jwt_params define where to extract the JWT from an HTTP request. If no explicit location is specified, the following default locations are tried in order: 1. The Authorization header using the Bearer schema. See `here `_. Example: Authorization: Bearer . 2. `access_token` query parameter. See `this `_ Multiple JWTs can be verified for a request. Each JWT has to be extracted from the locations its issuer specified or from the default locations. This field is set if JWT is sent in a request header. This field specifies the header name. For example, if `header=x-goog-iap-jwt-assertion`, the header format will be x-goog-iap-jwt-assertion: .
         */
        jwtHeaders?: Schema$JwtHeader[];
        /**
         * This field is set if JWT is sent in a query parameter. This field specifies the query parameter name. For example, if jwt_params[0] is jwt_token, the JWT format in the query parameter is /path?jwt_token=.
         */
        jwtParams?: string[] | null;
    }
    /**
     * [Deprecated] This message specifies a header location to extract JWT token. This message specifies a header location to extract JWT token.
     */
    export interface Schema$JwtHeader {
        /**
         * The HTTP header name.
         */
        name?: string | null;
        /**
         * The value prefix. The value format is "value_prefix" For example, for "Authorization: Bearer ", value_prefix="Bearer " with a space at the end.
         */
        valuePrefix?: string | null;
    }
    /**
     * Represents a License resource. A License represents billing and aggregate usage data for public and marketplace images. *Caution* This resource is intended for use only by third-party partners who are creating Cloud Marketplace images.
     */
    export interface Schema$License {
        /**
         * [Output Only] Deprecated. This field no longer reflects whether a license charges a usage fee.
         */
        chargesUseFee?: boolean | null;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional textual description of the resource; provided by the client when the resource is created.
         */
        description?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] Type of resource. Always compute#license for licenses.
         */
        kind?: string | null;
        /**
         * [Output Only] The unique code used to attach this license to images, snapshots, and disks.
         */
        licenseCode?: string | null;
        /**
         * Name of the resource. The name must be 1-63 characters long and comply with RFC1035.
         */
        name?: string | null;
        resourceRequirements?: Schema$LicenseResourceRequirements;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * If false, licenses will not be copied from the source resource when creating an image from a disk, disk from snapshot, or snapshot from disk.
         */
        transferable?: boolean | null;
    }
    /**
     * Represents a License Code resource. A License Code is a unique identifier used to represent a license resource. *Caution* This resource is intended for use only by third-party partners who are creating Cloud Marketplace images.
     */
    export interface Schema$LicenseCode {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * [Output Only] Description of this License Code.
         */
        description?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] Type of resource. Always compute#licenseCode for licenses.
         */
        kind?: string | null;
        /**
         * [Output Only] URL and description aliases of Licenses with the same License Code.
         */
        licenseAlias?: Schema$LicenseCodeLicenseAlias[];
        /**
         * [Output Only] Name of the resource. The name is 1-20 characters long and must be a valid 64 bit integer.
         */
        name?: string | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Current state of this License Code.
         */
        state?: string | null;
        /**
         * [Output Only] If true, the license will remain attached when creating images or snapshots from disks. Otherwise, the license is not transferred.
         */
        transferable?: boolean | null;
    }
    export interface Schema$LicenseCodeLicenseAlias {
        /**
         * [Output Only] Description of this License Code.
         */
        description?: string | null;
        /**
         * [Output Only] URL of license corresponding to this License Code.
         */
        selfLink?: string | null;
    }
    /**
     * Commitment for a particular license resource.
     */
    export interface Schema$LicenseResourceCommitment {
        /**
         * The number of licenses purchased.
         */
        amount?: string | null;
        /**
         * Specifies the core range of the instance for which this license applies.
         */
        coresPerLicense?: string | null;
        /**
         * Any applicable license URI.
         */
        license?: string | null;
    }
    export interface Schema$LicenseResourceRequirements {
        /**
         * Minimum number of guest cpus required to use the Instance. Enforced at Instance creation and Instance start.
         */
        minGuestCpuCount?: number | null;
        /**
         * Minimum memory required to use the Instance. Enforced at Instance creation and Instance start.
         */
        minMemoryMb?: number | null;
    }
    export interface Schema$LicensesListResponse {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of License resources.
         */
        items?: Schema$License[];
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$LocalDisk {
        /**
         * Specifies the number of such disks.
         */
        diskCount?: number | null;
        /**
         * Specifies the size of the disk in base-2 GB.
         */
        diskSizeGb?: number | null;
        /**
         * Specifies the desired disk type on the node. This disk type must be a local storage type (e.g.: local-ssd). Note that for nodeTemplates, this should be the name of the disk type and not its URL.
         */
        diskType?: string | null;
    }
    /**
     * Provides a localized error message that is safe to return to the user which can be attached to an RPC error.
     */
    export interface Schema$LocalizedMessage {
        /**
         * The locale used following the specification defined at https://www.rfc-editor.org/rfc/bcp/bcp47.txt. Examples are: "en-US", "fr-CH", "es-MX"
         */
        locale?: string | null;
        /**
         * The localized error message in the above locale.
         */
        message?: string | null;
    }
    /**
     * Configuration for location policy among multiple possible locations (e.g. preferences for zone selection among zones in a single region).
     */
    export interface Schema$LocationPolicy {
        /**
         * Location configurations mapped by location name. Currently only zone names are supported and must be represented as valid internal URLs, such as zones/us-central1-a.
         */
        locations?: {
            [key: string]: Schema$LocationPolicyLocation;
        } | null;
        /**
         * Strategy for distributing VMs across zones in a region.
         */
        targetShape?: string | null;
    }
    export interface Schema$LocationPolicyLocation {
        /**
         * Constraints that the caller requires on the result distribution in this zone.
         */
        constraints?: Schema$LocationPolicyLocationConstraints;
        /**
         * Names of resources to be put in the location. Must contain unique, correct resource names. If used, targetShape must be left unset.
         */
        names?: string[] | null;
        /**
         * Preference for a given location. Set to either ALLOW or DENY.
         */
        preference?: string | null;
    }
    /**
     * Per-zone constraints on location policy for this zone.
     */
    export interface Schema$LocationPolicyLocationConstraints {
        /**
         * Maximum number of items that are allowed to be placed in this zone. The value must be non-negative.
         */
        maxCount?: number | null;
    }
    /**
     * This is deprecated and has no effect. Do not use.
     */
    export interface Schema$LogConfig {
        /**
         * This is deprecated and has no effect. Do not use.
         */
        cloudAudit?: Schema$LogConfigCloudAuditOptions;
        /**
         * This is deprecated and has no effect. Do not use.
         */
        counter?: Schema$LogConfigCounterOptions;
        /**
         * This is deprecated and has no effect. Do not use.
         */
        dataAccess?: Schema$LogConfigDataAccessOptions;
    }
    /**
     * This is deprecated and has no effect. Do not use.
     */
    export interface Schema$LogConfigCloudAuditOptions {
        /**
         * This is deprecated and has no effect. Do not use.
         */
        authorizationLoggingOptions?: Schema$AuthorizationLoggingOptions;
        /**
         * This is deprecated and has no effect. Do not use.
         */
        logName?: string | null;
    }
    /**
     * This is deprecated and has no effect. Do not use.
     */
    export interface Schema$LogConfigCounterOptions {
        /**
         * This is deprecated and has no effect. Do not use.
         */
        customFields?: Schema$LogConfigCounterOptionsCustomField[];
        /**
         * This is deprecated and has no effect. Do not use.
         */
        field?: string | null;
        /**
         * This is deprecated and has no effect. Do not use.
         */
        metric?: string | null;
    }
    /**
     * This is deprecated and has no effect. Do not use.
     */
    export interface Schema$LogConfigCounterOptionsCustomField {
        /**
         * This is deprecated and has no effect. Do not use.
         */
        name?: string | null;
        /**
         * This is deprecated and has no effect. Do not use.
         */
        value?: string | null;
    }
    /**
     * This is deprecated and has no effect. Do not use.
     */
    export interface Schema$LogConfigDataAccessOptions {
        /**
         * This is deprecated and has no effect. Do not use.
         */
        logMode?: string | null;
    }
    /**
     * Represents a machine image resource. A machine image is a Compute Engine resource that stores all the configuration, metadata, permissions, and data from one or more disks required to create a Virtual machine (VM) instance. For more information, see Machine images.
     */
    export interface Schema$MachineImage {
        /**
         * [Output Only] The creation timestamp for this machine image in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * [Input Only] Whether to attempt an application consistent machine image by informing the OS to prepare for the snapshot process.
         */
        guestFlush?: boolean | null;
        /**
         * [Output Only] A unique identifier for this machine image. The server defines this identifier.
         */
        id?: string | null;
        /**
         * [Output Only] Properties of source instance
         */
        instanceProperties?: Schema$InstanceProperties;
        /**
         * [Output Only] The resource type, which is always compute#machineImage for machine image.
         */
        kind?: string | null;
        /**
         * Encrypts the machine image using a customer-supplied encryption key. After you encrypt a machine image using a customer-supplied key, you must provide the same key if you use the machine image later. For example, you must provide the encryption key when you create an instance from the encrypted machine image in a future request. Customer-supplied encryption keys do not protect access to metadata of the machine image. If you do not provide an encryption key when creating the machine image, then the machine image will be encrypted using an automatically generated key and you do not need to provide a key to use the machine image later.
         */
        machineImageEncryptionKey?: Schema$CustomerEncryptionKey;
        /**
         * Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * [Output Only] Reserved for future use.
         */
        satisfiesPzs?: boolean | null;
        /**
         * An array of Machine Image specific properties for disks attached to the source instance
         */
        savedDisks?: Schema$SavedDisk[];
        /**
         * [Output Only] The URL for this machine image. The server defines this URL.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * [Input Only] The customer-supplied encryption key of the disks attached to the source instance. Required if the source disk is protected by a customer-supplied encryption key.
         */
        sourceDiskEncryptionKeys?: Schema$SourceDiskEncryptionKey[];
        /**
         * The source instance used to create the machine image. You can provide this as a partial or full URL to the resource. For example, the following are valid values: - https://www.googleapis.com/compute/v1/projects/project/zones/zone /instances/instance - projects/project/zones/zone/instances/instance
         */
        sourceInstance?: string | null;
        /**
         * [Output Only] DEPRECATED: Please use instance_properties instead for source instance related properties. New properties will not be added to this field.
         */
        sourceInstanceProperties?: Schema$SourceInstanceProperties;
        /**
         * [Output Only] The status of the machine image. One of the following values: INVALID, CREATING, READY, DELETING, and UPLOADING.
         */
        status?: string | null;
        /**
         * The regional or multi-regional Cloud Storage bucket location where the machine image is stored.
         */
        storageLocations?: string[] | null;
        /**
         * [Output Only] Total size of the storage used by the machine image.
         */
        totalStorageBytes?: string | null;
    }
    /**
     * A list of machine images.
     */
    export interface Schema$MachineImageList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of MachineImage resources.
         */
        items?: Schema$MachineImage[];
        /**
         * [Output Only] The resource type, which is always compute#machineImagesListResponse for machine image lists.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Represents a Machine Type resource. You can use specific machine types for your VM instances based on performance and pricing requirements. For more information, read Machine Types.
     */
    export interface Schema$MachineType {
        /**
         * [Output Only] A list of accelerator configurations assigned to this machine type.
         */
        accelerators?: Array<{
            guestAcceleratorCount?: number;
            guestAcceleratorType?: string;
        }> | null;
        /**
         * [Output Only] The architecture of the machine type.
         */
        architecture?: string | null;
        /**
         * [Output Only] The configuration of bundled local SSD for the machine type.
         */
        bundledLocalSsds?: Schema$BundledLocalSsds;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * [Output Only] The deprecation status associated with this machine type. Only applicable if the machine type is unavailable.
         */
        deprecated?: Schema$DeprecationStatus;
        /**
         * [Output Only] An optional textual description of the resource.
         */
        description?: string | null;
        /**
         * [Output Only] The number of virtual CPUs that are available to the instance.
         */
        guestCpus?: number | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] Whether this machine type has a shared CPU. See Shared-core machine types for more information.
         */
        isSharedCpu?: boolean | null;
        /**
         * [Output Only] The type of the resource. Always compute#machineType for machine types.
         */
        kind?: string | null;
        /**
         * [Output Only] Maximum persistent disks allowed.
         */
        maximumPersistentDisks?: number | null;
        /**
         * [Output Only] Maximum total persistent disks size (GB) allowed.
         */
        maximumPersistentDisksSizeGb?: string | null;
        /**
         * [Output Only] The amount of physical memory available to the instance, defined in MB.
         */
        memoryMb?: number | null;
        /**
         * [Output Only] Name of the resource.
         */
        name?: string | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * [Output Only] The name of the zone where the machine type resides, such as us-central1-a.
         */
        zone?: string | null;
    }
    export interface Schema$MachineTypeAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of MachineTypesScopedList resources.
         */
        items?: {
            [key: string]: Schema$MachineTypesScopedList;
        } | null;
        /**
         * [Output Only] Type of resource. Always compute#machineTypeAggregatedList for aggregated lists of machine types.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Contains a list of machine types.
     */
    export interface Schema$MachineTypeList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of MachineType resources.
         */
        items?: Schema$MachineType[];
        /**
         * [Output Only] Type of resource. Always compute#machineTypeList for lists of machine types.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$MachineTypesScopedList {
        /**
         * [Output Only] A list of machine types contained in this scope.
         */
        machineTypes?: Schema$MachineType[];
        /**
         * [Output Only] An informational warning that appears when the machine types list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * A Managed Instance resource.
     */
    export interface Schema$ManagedInstance {
        /**
         * [Output Only] Current all-instances configuration revision applied to this instance.
         */
        allInstancesConfig?: Schema$ManagedInstanceAllInstancesConfig;
        /**
         * [Output Only] The current action that the managed instance group has scheduled for the instance. Possible values: - NONE The instance is running, and the managed instance group does not have any scheduled actions for this instance. - CREATING The managed instance group is creating this instance. If the group fails to create this instance, it will try again until it is successful. - CREATING_WITHOUT_RETRIES The managed instance group is attempting to create this instance only once. If the group fails to create this instance, it does not try again and the group's targetSize value is decreased instead. - RECREATING The managed instance group is recreating this instance. - DELETING The managed instance group is permanently deleting this instance. - ABANDONING The managed instance group is abandoning this instance. The instance will be removed from the instance group and from any target pools that are associated with this group. - RESTARTING The managed instance group is restarting the instance. - REFRESHING The managed instance group is applying configuration changes to the instance without stopping it. For example, the group can update the target pool list for an instance without stopping that instance. - VERIFYING The managed instance group has created the instance and it is in the process of being verified.
         */
        currentAction?: string | null;
        /**
         * [Output only] The unique identifier for this resource. This field is empty when instance does not exist.
         */
        id?: string | null;
        /**
         * [Output Only] The URL of the instance. The URL can exist even if the instance has not yet been created.
         */
        instance?: string | null;
        /**
         * [Output Only] The overrides to instance properties resulting from InstanceFlexibilityPolicy.
         */
        instanceFlexibilityOverride?: Schema$ManagedInstanceInstanceFlexibilityOverride;
        /**
         * [Output Only] Health state of the instance per health-check.
         */
        instanceHealth?: Schema$ManagedInstanceInstanceHealth[];
        /**
         * [Output Only] The status of the instance. This field is empty when the instance does not exist.
         */
        instanceStatus?: string | null;
        /**
         * [Output Only] The intended template of the instance. This field is empty when current_action is one of { DELETING, ABANDONING \}.
         */
        instanceTemplate?: string | null;
        /**
         * [Output Only] Information about the last attempt to create or delete the instance.
         */
        lastAttempt?: Schema$ManagedInstanceLastAttempt;
        /**
         * [Output Only] The name of the instance. The name will always exist even if the instance has not yet been created.
         */
        name?: string | null;
        /**
         * [Output Only] Preserved state applied from per-instance config for this instance.
         */
        preservedStateFromConfig?: Schema$PreservedState;
        /**
         * [Output Only] Preserved state generated based on stateful policy for this instance.
         */
        preservedStateFromPolicy?: Schema$PreservedState;
        /**
         * [Output Only] Instance properties selected for this instance resulting from InstanceFlexibilityPolicy.
         */
        propertiesFromFlexibilityPolicy?: Schema$ManagedInstancePropertiesFromFlexibilityPolicy;
        /**
         * [Output Only] Tag describing the version.
         */
        tag?: string | null;
        /**
         * [Output Only] The eventual status of the instance. The instance group manager will not be identified as stable till each managed instance reaches its targetStatus.
         */
        targetStatus?: string | null;
        /**
         * [Output Only] Intended version of this instance.
         */
        version?: Schema$ManagedInstanceVersion;
    }
    export interface Schema$ManagedInstanceAllInstancesConfig {
        /**
         * [Output Only] Current all-instances configuration revision. This value is in RFC3339 text format.
         */
        revision?: string | null;
    }
    export interface Schema$ManagedInstanceInstanceFlexibilityOverride {
        /**
         * The machine type to be used for this instance.
         */
        machineType?: string | null;
        /**
         * The provisioning model to be used for this instance.
         */
        provisioningModel?: string | null;
    }
    export interface Schema$ManagedInstanceInstanceHealth {
        /**
         * [Output Only] The current detailed instance health state.
         */
        detailedHealthState?: string | null;
        /**
         * [Output Only] The URL for the health check that verifies whether the instance is healthy.
         */
        healthCheck?: string | null;
        /**
         * [Output Only] The current instance health state. This field will not get promoted to beta/GA and might be removed from alpha APIs after 01/12/2019. Please use detailed_health_state field instead.
         */
        healthState?: string | null;
    }
    export interface Schema$ManagedInstanceLastAttempt {
        /**
         * [Output Only] Encountered errors during the last attempt to create or delete the instance.
         */
        errors?: {
            errors?: Array<{
                code?: string;
                errorDetails?: Array<{
                    errorInfo?: Schema$ErrorInfo;
                    help?: Schema$Help;
                    localizedMessage?: Schema$LocalizedMessage;
                    quotaInfo?: Schema$QuotaExceededInfo;
                }>;
                location?: string;
                message?: string;
            }>;
        } | null;
    }
    export interface Schema$ManagedInstancePropertiesFromFlexibilityPolicy {
        /**
         * The machine type to be used for this instance.
         */
        machineType?: string | null;
    }
    export interface Schema$ManagedInstanceVersion {
        /**
         * [Output Only] The intended template of the instance. This field is empty when current_action is one of { DELETING, ABANDONING \}.
         */
        instanceTemplate?: string | null;
        /**
         * [Output Only] Name of the version.
         */
        name?: string | null;
    }
    /**
     * A metadata key/value entry.
     */
    export interface Schema$Metadata {
        /**
         * Specifies a fingerprint for this request, which is essentially a hash of the metadata's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update metadata. You must always provide an up-to-date fingerprint hash in order to update or change metadata, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the resource.
         */
        fingerprint?: string | null;
        /**
         * Array of key/value pairs. The total size of all keys and values must be less than 512 KB.
         */
        items?: Array<{
            key?: string;
            value?: string;
        }> | null;
        /**
         * [Output Only] Type of the resource. Always compute#metadata for metadata.
         */
        kind?: string | null;
    }
    /**
     * [Deprecated] Custom authenticator credentials. Custom authenticator credentials.
     */
    export interface Schema$MetadataCredentialsFromPlugin {
        /**
         * Plugin name.
         */
        name?: string | null;
        /**
         * A text proto that conforms to a Struct type definition interpreted by the plugin.
         */
        structConfig?: string | null;
    }
    /**
     * Opaque filter criteria used by load balancers to restrict routing configuration to a limited set of load balancing proxies. Proxies and sidecars involved in load balancing would typically present metadata to the load balancers that need to match criteria specified here. If a match takes place, the relevant configuration is made available to those proxies. For each metadataFilter in this list, if its filterMatchCriteria is set to MATCH_ANY, at least one of the filterLabels must match the corresponding label provided in the metadata. If its filterMatchCriteria is set to MATCH_ALL, then all of its filterLabels must match with corresponding labels provided in the metadata. An example for using metadataFilters would be: if load balancing involves Envoys, they receive routing configuration when values in metadataFilters match values supplied in of their XDS requests to loadbalancers.
     */
    export interface Schema$MetadataFilter {
        /**
         * The list of label value pairs that must match labels in the provided metadata based on filterMatchCriteria This list must not be empty and can have at the most 64 entries.
         */
        filterLabels?: Schema$MetadataFilterLabelMatch[];
        /**
         * Specifies how individual filter label matches within the list of filterLabels and contributes toward the overall metadataFilter match. Supported values are: - MATCH_ANY: at least one of the filterLabels must have a matching label in the provided metadata. - MATCH_ALL: all filterLabels must have matching labels in the provided metadata.
         */
        filterMatchCriteria?: string | null;
    }
    /**
     * MetadataFilter label name value pairs that are expected to match corresponding labels presented as metadata to the load balancer.
     */
    export interface Schema$MetadataFilterLabelMatch {
        /**
         * Name of metadata label. The name can have a maximum length of 1024 characters and must be at least 1 character long.
         */
        name?: string | null;
        /**
         * The value of the label must match the specified value. value can have a maximum length of 1024 characters.
         */
        value?: string | null;
    }
    /**
     * Represents an amount of money with its currency type.
     */
    export interface Schema$Money {
        /**
         * The three-letter currency code defined in ISO 4217.
         */
        currencyCode?: string | null;
        /**
         * Number of nano (10^-9) units of the amount. The value must be between -999,999,999 and +999,999,999 inclusive. If `units` is positive, `nanos` must be positive or zero. If `units` is zero, `nanos` can be positive, zero, or negative. If `units` is negative, `nanos` must be negative or zero. For example $-1.75 is represented as `units`=-1 and `nanos`=-750,000,000.
         */
        nanos?: number | null;
        /**
         * The whole units of the amount. For example if `currencyCode` is `"USD"`, then 1 unit is one US dollar.
         */
        units?: string | null;
    }
    /**
     * [Deprecated] Configuration for the mutual Tls mode for peer authentication. Configuration for the mutual Tls mode for peer authentication.
     */
    export interface Schema$MutualTls {
        /**
         * Specifies if the server TLS is configured to be strict or permissive. This field can be set to one of the following: STRICT: Client certificate must be presented, connection is in TLS. PERMISSIVE: Client certificate can be omitted, connection can be either plaintext or TLS.
         */
        mode?: string | null;
    }
    /**
     * The named port. For example: <"http", 80\>.
     */
    export interface Schema$NamedPort {
        /**
         * The name for this named port. The name must be 1-63 characters long, and comply with RFC1035.
         */
        name?: string | null;
        /**
         * The port number, which can be a value between 1 and 65535.
         */
        port?: number | null;
    }
    /**
     * Contains NAT IP information of a NAT config (i.e. usage status, mode).
     */
    export interface Schema$NatIpInfo {
        /**
         * A list of all NAT IPs assigned to this NAT config.
         */
        natIpInfoMappings?: Schema$NatIpInfoNatIpInfoMapping[];
        /**
         * Name of the NAT config which the NAT IP belongs to.
         */
        natName?: string | null;
    }
    /**
     * Contains information of a NAT IP.
     */
    export interface Schema$NatIpInfoNatIpInfoMapping {
        /**
         * Specifies whether NAT IP is auto or manual.
         */
        mode?: string | null;
        /**
         * NAT IP address. For example: 203.0.113.11.
         */
        natIp?: string | null;
        /**
         * Specifies whether NAT IP is currently serving at least one endpoint or not.
         */
        usage?: string | null;
    }
    export interface Schema$NatIpInfoResponse {
        /**
         * [Output Only] A list of NAT IP information.
         */
        result?: Schema$NatIpInfo[];
    }
    /**
     * Represents a VPC Network resource. Networks connect resources to each other and to the internet. For more information, read Virtual Private Cloud (VPC) Network.
     */
    export interface Schema$Network {
        /**
         * Must be set to create a VPC network. If not set, a legacy network is created. When set to true, the VPC network is created in auto mode. When set to false, the VPC network is created in custom mode. An auto mode VPC network starts with one subnet per region. Each subnet has a predetermined range as described in Auto mode VPC network IP ranges. For custom mode VPC networks, you can add subnets using the subnetworks insert method.
         */
        autoCreateSubnetworks?: boolean | null;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this field when you create the resource.
         */
        description?: string | null;
        /**
         * Enable ULA internal ipv6 on this network. Enabling this feature will assign a /48 from google defined ULA prefix fd20::/20. .
         */
        enableUlaInternalIpv6?: boolean | null;
        /**
         * [Output Only] URL of the firewall policy the network is associated with.
         */
        firewallPolicy?: string | null;
        /**
         * [Output Only] The gateway address for default routing out of the network, selected by Google Cloud.
         */
        gatewayIPv4?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * When enabling ula internal ipv6, caller optionally can specify the /48 range they want from the google defined ULA prefix fd20::/20. The input must be a valid /48 ULA IPv6 address and must be within the fd20::/20. Operation will fail if the speficied /48 is already in used by another resource. If the field is not speficied, then a /48 range will be randomly allocated from fd20::/20 and returned via this field. .
         */
        internalIpv6Range?: string | null;
        /**
         * Deprecated in favor of subnet mode networks. The range of internal addresses that are legal on this network. This range is a CIDR specification, for example: 192.168.0.0/16. Provided by the client when the network is created.
         */
        IPv4Range?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#network for networks.
         */
        kind?: string | null;
        /**
         * Maximum Transmission Unit in bytes. The minimum value for this field is 1300 and the maximum value is 8896. The suggested value is 1500, which is the default MTU used on the Internet, or 8896 if you want to use Jumbo frames. If unspecified, the value defaults to 1460.
         */
        mtu?: number | null;
        /**
         * Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?`. The first character must be a lowercase letter, and all following characters (except for the last character) must be a dash, lowercase letter, or digit. The last character must be a lowercase letter or digit.
         */
        name?: string | null;
        /**
         * The network firewall policy enforcement order. Can be either AFTER_CLASSIC_FIREWALL or BEFORE_CLASSIC_FIREWALL. Defaults to AFTER_CLASSIC_FIREWALL if the field is not specified.
         */
        networkFirewallPolicyEnforcementOrder?: string | null;
        /**
         * [Output Only] A list of network peerings for the resource.
         */
        peerings?: Schema$NetworkPeering[];
        /**
         * [Output Only] URL of the region where the regional network resides. This field is not applicable to global network. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
         */
        region?: string | null;
        /**
         * The network-level routing configuration for this network. Used by Cloud Router to determine what type of network-wide routing behavior to enforce.
         */
        routingConfig?: Schema$NetworkRoutingConfig;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * [Output Only] Server-defined fully-qualified URLs for all subnetworks in this VPC network.
         */
        subnetworks?: string[] | null;
    }
    /**
     * NetworkAttachments A network attachment resource ...
     */
    export interface Schema$NetworkAttachment {
        /**
         * [Output Only] An array of connections for all the producers connected to this network attachment.
         */
        connectionEndpoints?: Schema$NetworkAttachmentConnectedEndpoint[];
        connectionPreference?: string | null;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. An up-to-date fingerprint must be provided in order to patch.
         */
        fingerprint?: string | null;
        /**
         * [Output Only] The unique identifier for the resource type. The server generates this identifier.
         */
        id?: string | null;
        /**
         * [Output Only] Type of the resource.
         */
        kind?: string | null;
        /**
         * Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * [Output Only] The URL of the network which the Network Attachment belongs to. Practically it is inferred by fetching the network of the first subnetwork associated. Because it is required that all the subnetworks must be from the same network, it is assured that the Network Attachment belongs to the same network as all the subnetworks.
         */
        network?: string | null;
        /**
         * Projects that are allowed to connect to this network attachment. The project can be specified using its id or number.
         */
        producerAcceptLists?: string[] | null;
        /**
         * Projects that are not allowed to connect to this network attachment. The project can be specified using its id or number.
         */
        producerRejectLists?: string[] | null;
        /**
         * [Output Only] URL of the region where the network attachment resides. This field applies only to the region resource. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
         */
        region?: string | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource's resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * An array of URLs where each entry is the URL of a subnet provided by the service consumer to use for endpoints in the producers that connect to this network attachment.
         */
        subnetworks?: string[] | null;
    }
    /**
     * Contains a list of NetworkAttachmentsScopedList.
     */
    export interface Schema$NetworkAttachmentAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of NetworkAttachmentsScopedList resources.
         */
        items?: {
            [key: string]: Schema$NetworkAttachmentsScopedList;
        } | null;
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * [Output Only] A connection connected to this network attachment.
     */
    export interface Schema$NetworkAttachmentConnectedEndpoint {
        /**
         * The IPv4 address assigned to the producer instance network interface. This value will be a range in case of Serverless.
         */
        ipAddress?: string | null;
        /**
         * The IPv6 address assigned to the producer instance network interface. This is only assigned when the stack types of both the instance network interface and the consumer subnet are IPv4_IPv6.
         */
        ipv6Address?: string | null;
        /**
         * The project id or number of the interface to which the IP was assigned.
         */
        projectIdOrNum?: string | null;
        /**
         * Alias IP ranges from the same subnetwork.
         */
        secondaryIpCidrRanges?: string[] | null;
        /**
         * The status of a connected endpoint to this network attachment.
         */
        status?: string | null;
        /**
         * The subnetwork used to assign the IP to the producer instance network interface.
         */
        subnetwork?: string | null;
    }
    export interface Schema$NetworkAttachmentList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of NetworkAttachment resources.
         */
        items?: Schema$NetworkAttachment[];
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$NetworkAttachmentsScopedList {
        /**
         * A list of NetworkAttachments contained in this scope.
         */
        networkAttachments?: Schema$NetworkAttachment[];
        /**
         * Informational warning which replaces the list of network attachments when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Represents a Google Cloud Armor network edge security service resource.
     */
    export interface Schema$NetworkEdgeSecurityService {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a NetworkEdgeSecurityService. An up-to-date fingerprint must be provided in order to update the NetworkEdgeSecurityService, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a NetworkEdgeSecurityService.
         */
        fingerprint?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output only] Type of the resource. Always compute#networkEdgeSecurityService for NetworkEdgeSecurityServices
         */
        kind?: string | null;
        /**
         * Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * [Output Only] URL of the region where the resource resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
         */
        region?: string | null;
        /**
         * The resource URL for the network edge security service associated with this network edge security service.
         */
        securityPolicy?: string | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
    }
    export interface Schema$NetworkEdgeSecurityServiceAggregatedList {
        etag?: string | null;
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of NetworkEdgeSecurityServicesScopedList resources.
         */
        items?: {
            [key: string]: Schema$NetworkEdgeSecurityServicesScopedList;
        } | null;
        /**
         * [Output Only] Type of resource. Always compute#networkEdgeSecurityServiceAggregatedList for lists of Network Edge Security Services.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$NetworkEdgeSecurityServicesScopedList {
        /**
         * A list of NetworkEdgeSecurityServices contained in this scope.
         */
        networkEdgeSecurityServices?: Schema$NetworkEdgeSecurityService[];
        /**
         * Informational warning which replaces the list of security policies when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * The network endpoint.
     */
    export interface Schema$NetworkEndpoint {
        /**
         * Metadata defined as annotations on the network endpoint.
         */
        annotations?: {
            [key: string]: string;
        } | null;
        /**
         * Only valid for network endpoint groups created with client_port_mapping supported. Represents the port number to which original packet is sent.
         */
        clientPort?: number | null;
        /**
         * Optional fully qualified domain name of network endpoint. This can only be specified when NetworkEndpointGroup.network_endpoint_type is NON_GCP_FQDN_PORT.
         */
        fqdn?: string | null;
        /**
         * The name for a specific VM instance that the IP address belongs to. This is required for network endpoints of type GCE_VM_IP_PORT. The instance must be in the same zone of network endpoint group. The name must be 1-63 characters long, and comply with RFC1035.
         */
        instance?: string | null;
        /**
         * Optional IPv4 address of network endpoint. The IP address must belong to a VM in Compute Engine (either the primary IP or as part of an aliased IP range). If the IP address is not specified, then the primary IP address for the VM instance in the network that the network endpoint group belongs to will be used.
         */
        ipAddress?: string | null;
        /**
         * Optional IPv6 address of network endpoint.
         */
        ipv6Address?: string | null;
        /**
         * Optional port number of network endpoint. If not specified, the defaultPort for the network endpoint group will be used.
         */
        port?: number | null;
        /**
         * The name of the zone where the instance hosting the network endpoint is located (valid only for regional GCE_VM_IP_PORT NEGs). It should comply with RFC1035. The zone must belong to the region of the Network Endpoint Group.
         */
        zone?: string | null;
    }
    /**
     * Represents a collection of network endpoints. A network endpoint group (NEG) defines how a set of endpoints should be reached, whether they are reachable, and where they are located. For more information about using NEGs for different use cases, see Network endpoint groups overview.
     */
    export interface Schema$NetworkEndpointGroup {
        /**
         * Metadata defined as annotations on the network endpoint group.
         */
        annotations?: {
            [key: string]: string;
        } | null;
        /**
         * Only valid when networkEndpointType is "SERVERLESS". Only one of cloudRun, appEngine or cloudFunction may be set.
         */
        appEngine?: Schema$NetworkEndpointGroupAppEngine;
        /**
         * Only valid when networkEndpointType is "GCE_VM_IP_PORT" and the NEG is regional.
         */
        clientPortMappingMode?: string | null;
        /**
         * Only valid when networkEndpointType is "SERVERLESS". Only one of cloudRun, appEngine or cloudFunction may be set.
         */
        cloudFunction?: Schema$NetworkEndpointGroupCloudFunction;
        /**
         * Only valid when networkEndpointType is "SERVERLESS". Only one of cloudRun, appEngine or cloudFunction may be set.
         */
        cloudRun?: Schema$NetworkEndpointGroupCloudRun;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * The default port used if the port number is not specified in the network endpoint.
         */
        defaultPort?: number | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#networkEndpointGroup for network endpoint group.
         */
        kind?: string | null;
        /**
         * This field is only valid when the network endpoint group is used for load balancing. [Deprecated] This field is deprecated.
         */
        loadBalancer?: Schema$NetworkEndpointGroupLbNetworkEndpointGroup;
        /**
         * Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * The URL of the network to which all network endpoints in the NEG belong. Uses "default" project network if unspecified.
         */
        network?: string | null;
        /**
         * Type of network endpoints in this network endpoint group. Can be one of GCE_VM_IP, GCE_VM_IP_PORT, NON_GCP_PRIVATE_IP_PORT, INTERNET_FQDN_PORT, INTERNET_IP_PORT, SERVERLESS, PRIVATE_SERVICE_CONNECT.
         */
        networkEndpointType?: string | null;
        pscData?: Schema$NetworkEndpointGroupPscData;
        /**
         * The target service url used to set up private service connection to a Google API or a PSC Producer Service Attachment. An example value is: "asia-northeast3-cloudkms.googleapis.com"
         */
        pscTargetService?: string | null;
        /**
         * [Output Only] The URL of the region where the network endpoint group is located.
         */
        region?: string | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * Only valid when networkEndpointType is "SERVERLESS". Only one of cloudRun, appEngine, cloudFunction or serverlessDeployment may be set.
         */
        serverlessDeployment?: Schema$NetworkEndpointGroupServerlessDeployment;
        /**
         * [Output only] Number of network endpoints in the network endpoint group.
         */
        size?: number | null;
        /**
         * Optional URL of the subnetwork to which all network endpoints in the NEG belong.
         */
        subnetwork?: string | null;
        /**
         * Specify the type of this network endpoint group. Only LOAD_BALANCING is valid for now.
         */
        type?: string | null;
        /**
         * [Output Only] The URL of the zone where the network endpoint group is located.
         */
        zone?: string | null;
    }
    export interface Schema$NetworkEndpointGroupAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of NetworkEndpointGroupsScopedList resources.
         */
        items?: {
            [key: string]: Schema$NetworkEndpointGroupsScopedList;
        } | null;
        /**
         * [Output Only] The resource type, which is always compute#networkEndpointGroupAggregatedList for aggregated lists of network endpoint groups.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Configuration for an App Engine network endpoint group (NEG). The service is optional, may be provided explicitly or in the URL mask. The version is optional and can only be provided explicitly or in the URL mask when service is present. Note: App Engine service must be in the same project and located in the same region as the Serverless NEG.
     */
    export interface Schema$NetworkEndpointGroupAppEngine {
        /**
         * Optional serving service. The service name is case-sensitive and must be 1-63 characters long. Example value: "default", "my-service".
         */
        service?: string | null;
        /**
         * A template to parse service and version fields from a request URL. URL mask allows for routing to multiple App Engine services without having to create multiple Network Endpoint Groups and backend services. For example, the request URLs "foo1-dot-appname.appspot.com/v1" and "foo1-dot-appname.appspot.com/v2" can be backed by the same Serverless NEG with URL mask "<service\>-dot-appname.appspot.com/<version\>". The URL mask will parse them to { service = "foo1", version = "v1" \} and { service = "foo1", version = "v2" \} respectively.
         */
        urlMask?: string | null;
        /**
         * Optional serving version. The version name is case-sensitive and must be 1-100 characters long. Example value: "v1", "v2".
         */
        version?: string | null;
    }
    /**
     * Configuration for a Cloud Function network endpoint group (NEG). The function must be provided explicitly or in the URL mask. Note: Cloud Function must be in the same project and located in the same region as the Serverless NEG.
     */
    export interface Schema$NetworkEndpointGroupCloudFunction {
        /**
         * A user-defined name of the Cloud Function. The function name is case-sensitive and must be 1-63 characters long. Example value: "func1".
         */
        function?: string | null;
        /**
         * A template to parse function field from a request URL. URL mask allows for routing to multiple Cloud Functions without having to create multiple Network Endpoint Groups and backend services. For example, request URLs " mydomain.com/function1" and "mydomain.com/function2" can be backed by the same Serverless NEG with URL mask "/<function\>". The URL mask will parse them to { function = "function1" \} and { function = "function2" \} respectively.
         */
        urlMask?: string | null;
    }
    /**
     * Configuration for a Cloud Run network endpoint group (NEG). The service must be provided explicitly or in the URL mask. The tag is optional, may be provided explicitly or in the URL mask. Note: Cloud Run service must be in the same project and located in the same region as the Serverless NEG.
     */
    export interface Schema$NetworkEndpointGroupCloudRun {
        /**
         * Cloud Run service is the main resource of Cloud Run. The service must be 1-63 characters long, and comply with RFC1035. Example value: "run-service".
         */
        service?: string | null;
        /**
         * Optional Cloud Run tag represents the "named-revision" to provide additional fine-grained traffic routing information. The tag must be 1-63 characters long, and comply with RFC1035. Example value: "revision-0010".
         */
        tag?: string | null;
        /**
         * A template to parse <service\> and <tag\> fields from a request URL. URL mask allows for routing to multiple Run services without having to create multiple network endpoint groups and backend services. For example, request URLs "foo1.domain.com/bar1" and "foo1.domain.com/bar2" can be backed by the same Serverless Network Endpoint Group (NEG) with URL mask "<tag\>.domain.com/<service\>". The URL mask will parse them to { service="bar1", tag="foo1" \} and { service="bar2", tag="foo2" \} respectively.
         */
        urlMask?: string | null;
    }
    /**
     * Load balancing specific fields for network endpoint group.
     */
    export interface Schema$NetworkEndpointGroupLbNetworkEndpointGroup {
        /**
         * The default port used if the port number is not specified in the network endpoint. [Deprecated] This field is deprecated.
         */
        defaultPort?: number | null;
        /**
         * The URL of the network to which all network endpoints in the NEG belong. Uses "default" project network if unspecified. [Deprecated] This field is deprecated.
         */
        network?: string | null;
        /**
         * Optional URL of the subnetwork to which all network endpoints in the NEG belong. [Deprecated] This field is deprecated.
         */
        subnetwork?: string | null;
        /**
         * [Output Only] The URL of the zone where the network endpoint group is located. [Deprecated] This field is deprecated.
         */
        zone?: string | null;
    }
    export interface Schema$NetworkEndpointGroupList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of NetworkEndpointGroup resources.
         */
        items?: Schema$NetworkEndpointGroup[];
        /**
         * [Output Only] The resource type, which is always compute#networkEndpointGroupList for network endpoint group lists.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * All data that is specifically relevant to only network endpoint groups of type PRIVATE_SERVICE_CONNECT.
     */
    export interface Schema$NetworkEndpointGroupPscData {
        /**
         * [Output Only] Address allocated from given subnetwork for PSC. This IP address acts as a VIP for a PSC NEG, allowing it to act as an endpoint in L7 PSC-XLB.
         */
        consumerPscAddress?: string | null;
        /**
         * [Output Only] The PSC connection id of the PSC Network Endpoint Group Consumer.
         */
        pscConnectionId?: string | null;
        /**
         * [Output Only] The connection status of the PSC Forwarding Rule.
         */
        pscConnectionStatus?: string | null;
    }
    export interface Schema$NetworkEndpointGroupsAttachEndpointsRequest {
        /**
         * The list of network endpoints to be attached.
         */
        networkEndpoints?: Schema$NetworkEndpoint[];
    }
    export interface Schema$NetworkEndpointGroupsDetachEndpointsRequest {
        /**
         * The list of network endpoints to be detached.
         */
        networkEndpoints?: Schema$NetworkEndpoint[];
    }
    /**
     * Configuration for a serverless network endpoint group (NEG). The platform must be provided. Note: The target backend service must be in the same project and located in the same region as the Serverless NEG.
     */
    export interface Schema$NetworkEndpointGroupServerlessDeployment {
        /**
         * The platform of the backend target(s) of this NEG. The only supported value is API Gateway: apigateway.googleapis.com.
         */
        platform?: string | null;
        /**
         * The user-defined name of the workload/instance. This value must be provided explicitly or in the urlMask. The resource identified by this value is platform-specific and is as follows: 1. API Gateway: The gateway ID 2. App Engine: The service name 3. Cloud Functions: The function name 4. Cloud Run: The service name
         */
        resource?: string | null;
        /**
         * A template to parse platform-specific fields from a request URL. URL mask allows for routing to multiple resources on the same serverless platform without having to create multiple Network Endpoint Groups and backend resources. The fields parsed by this template are platform-specific and are as follows: 1. API Gateway: The gateway ID 2. App Engine: The service and version 3. Cloud Functions: The function name 4. Cloud Run: The service and tag
         */
        urlMask?: string | null;
        /**
         * The optional resource version. The version identified by this value is platform-specific and is follows: 1. API Gateway: Unused 2. App Engine: The service version 3. Cloud Functions: Unused 4. Cloud Run: The service tag
         */
        version?: string | null;
    }
    export interface Schema$NetworkEndpointGroupsListEndpointsRequest {
        /**
         * Optional list of endpoints to query. This is a more efficient but also limited version of filter parameter. Endpoints in the filter must have ip_address and port fields populated, other fields are not supported.
         */
        endpointFilters?: Schema$NetworkEndpointGroupsListEndpointsRequestNetworkEndpointFilter[];
        /**
         * Optional query parameter for showing the health status of each network endpoint. Valid options are SKIP or SHOW. If you don't specify this parameter, the health status of network endpoints will not be provided.
         */
        healthStatus?: string | null;
    }
    export interface Schema$NetworkEndpointGroupsListEndpointsRequestNetworkEndpointFilter {
        networkEndpoint?: Schema$NetworkEndpoint;
    }
    export interface Schema$NetworkEndpointGroupsListNetworkEndpoints {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of NetworkEndpointWithHealthStatus resources.
         */
        items?: Schema$NetworkEndpointWithHealthStatus[];
        /**
         * [Output Only] The resource type, which is always compute#networkEndpointGroupsListNetworkEndpoints for the list of network endpoints in the specified network endpoint group.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$NetworkEndpointGroupsScopedList {
        /**
         * [Output Only] The list of network endpoint groups that are contained in this scope.
         */
        networkEndpointGroups?: Schema$NetworkEndpointGroup[];
        /**
         * [Output Only] An informational warning that replaces the list of network endpoint groups when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$NetworkEndpointWithHealthStatus {
        /**
         * [Output only] The health status of network endpoint;
         */
        healths?: Schema$HealthStatusForNetworkEndpoint[];
        /**
         * [Output only] The network endpoint;
         */
        networkEndpoint?: Schema$NetworkEndpoint;
    }
    /**
     * A network interface resource attached to an instance.
     */
    export interface Schema$NetworkInterface {
        /**
         * An array of configurations for this interface. Currently, only one access config, ONE_TO_ONE_NAT, is supported. If there are no accessConfigs specified, then this instance will have no external internet access.
         */
        accessConfigs?: Schema$AccessConfig[];
        /**
         * An array of alias IP ranges for this network interface. You can only specify this field for network interfaces in VPC networks.
         */
        aliasIpRanges?: Schema$AliasIpRange[];
        /**
         * Fingerprint hash of contents stored in this network interface. This field will be ignored when inserting an Instance or adding a NetworkInterface. An up-to-date fingerprint must be provided in order to update the NetworkInterface. The request will fail with error 400 Bad Request if the fingerprint is not provided, or 412 Precondition Failed if the fingerprint is out of date.
         */
        fingerprint?: string | null;
        /**
         * The prefix length of the primary internal IPv6 range.
         */
        internalIpv6PrefixLength?: number | null;
        /**
         * An array of IPv6 access configurations for this interface. Currently, only one IPv6 access config, DIRECT_IPV6, is supported. If there is no ipv6AccessConfig specified, then this instance will have no external IPv6 Internet access.
         */
        ipv6AccessConfigs?: Schema$AccessConfig[];
        /**
         * [Output Only] One of EXTERNAL, INTERNAL to indicate whether the IP can be accessed from the Internet. This field is always inherited from its subnetwork. Valid only if stackType is IPV4_IPV6.
         */
        ipv6AccessType?: string | null;
        /**
         * An IPv6 internal network address for this network interface. To use a static internal IP address, it must be unused and in the same region as the instance's zone. If not specified, Google Cloud will automatically assign an internal IPv6 address from the instance's subnetwork.
         */
        ipv6Address?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#networkInterface for network interfaces.
         */
        kind?: string | null;
        /**
         * [Output Only] The name of the network interface, which is generated by the server. For a VM, the network interface uses the nicN naming format. Where N is a value between 0 and 7. The default interface value is nic0.
         */
        name?: string | null;
        /**
         * URL of the VPC network resource for this instance. When creating an instance, if neither the network nor the subnetwork is specified, the default network global/networks/default is used. If the selected project doesn't have the default network, you must specify a network or subnet. If the network is not specified but the subnetwork is specified, the network is inferred. If you specify this property, you can specify the network as a full or partial URL. For example, the following are all valid URLs: - https://www.googleapis.com/compute/v1/projects/project/global/networks/ network - projects/project/global/networks/network - global/networks/default
         */
        network?: string | null;
        /**
         * The URL of the network attachment that this interface should connect to in the following format: projects/{project_number\}/regions/{region_name\}/networkAttachments/{network_attachment_name\}.
         */
        networkAttachment?: string | null;
        /**
         * An IPv4 internal IP address to assign to the instance for this network interface. If not specified by the user, an unused internal IP is assigned by the system.
         */
        networkIP?: string | null;
        /**
         * The type of vNIC to be used on this interface. This may be gVNIC or VirtioNet.
         */
        nicType?: string | null;
        /**
         * Name of the parent network interface of a VLAN based nic. If this field is specified, vlan must be set.
         */
        parentNicName?: string | null;
        /**
         * The networking queue count that's specified by users for the network interface. Both Rx and Tx queues will be set to this number. It'll be empty if not specified by the users.
         */
        queueCount?: number | null;
        /**
         * The stack type for this network interface. To assign only IPv4 addresses, use IPV4_ONLY. To assign both IPv4 and IPv6 addresses, use IPV4_IPV6. If not specified, IPV4_ONLY is used. This field can be both set at instance creation and update network interface operations.
         */
        stackType?: string | null;
        /**
         * SubInterfaces help enable L2 communication for the instance over subnetworks that support L2. Every network interface will get a default untagged (vlan not specified) subinterface. Users can specify additional tagged subinterfaces which are sub-fields to the Network Interface.
         */
        subinterfaces?: Schema$NetworkInterfaceSubInterface[];
        /**
         * The URL of the Subnetwork resource for this instance. If the network resource is in legacy mode, do not specify this field. If the network is in auto subnet mode, specifying the subnetwork is optional. If the network is in custom subnet mode, specifying the subnetwork is required. If you specify this field, you can specify the subnetwork as a full or partial URL. For example, the following are all valid URLs: - https://www.googleapis.com/compute/v1/projects/project/regions/region /subnetworks/subnetwork - regions/region/subnetworks/subnetwork
         */
        subnetwork?: string | null;
        /**
         * VLAN tag of a VLAN based network interface, must be in range from 2 to 4094 inclusively. This field is mandatory if the parent network interface name is set.
         */
        vlan?: number | null;
    }
    export interface Schema$NetworkInterfaceSubInterface {
        /**
         * An IPv4 internal IP address to assign to the instance for this subinterface. If specified, ip_allocation_mode should be set to ALLOCATE_IP.
         */
        ipAddress?: string | null;
        ipAllocationMode?: string | null;
        /**
         * If specified, this subnetwork must belong to the same network as that of the network interface. If not specified the subnet of network interface will be used. If you specify this property, you can specify the subnetwork as a full or partial URL. For example, the following are all valid URLs: - https://www.googleapis.com/compute/v1/projects/project/regions/region /subnetworks/subnetwork - regions/region/subnetworks/subnetwork
         */
        subnetwork?: string | null;
        /**
         * VLAN tag. Should match the VLAN(s) supported by the subnetwork to which this subinterface is connecting.
         */
        vlan?: number | null;
    }
    /**
     * Contains a list of networks.
     */
    export interface Schema$NetworkList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of Network resources.
         */
        items?: Schema$Network[];
        /**
         * [Output Only] Type of resource. Always compute#networkList for lists of networks.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * A network peering attached to a network resource. The message includes the peering name, peer network, peering state, and a flag indicating whether Google Compute Engine should automatically create routes for the peering.
     */
    export interface Schema$NetworkPeering {
        /**
         * Whether Cloud Routers in this network can automatically advertise subnets from the peer network.
         */
        advertisePeerSubnetsViaRouters?: boolean | null;
        /**
         * This field will be deprecated soon. Use the exchange_subnet_routes field instead. Indicates whether full mesh connectivity is created and managed automatically between peered networks. Currently this field should always be true since Google Compute Engine will automatically create and manage subnetwork routes between two networks when peering state is ACTIVE.
         */
        autoCreateRoutes?: boolean | null;
        /**
         * Indicates whether full mesh connectivity is created and managed automatically between peered networks. Currently this field should always be true since Google Compute Engine will automatically create and manage subnetwork routes between two networks when peering state is ACTIVE.
         */
        exchangeSubnetRoutes?: boolean | null;
        /**
         * Whether to export the custom routes to peer network. The default value is false.
         */
        exportCustomRoutes?: boolean | null;
        /**
         * Whether subnet routes with public IP range are exported. The default value is true, all subnet routes are exported. IPv4 special-use ranges are always exported to peers and are not controlled by this field.
         */
        exportSubnetRoutesWithPublicIp?: boolean | null;
        /**
         * Whether to import the custom routes from peer network. The default value is false.
         */
        importCustomRoutes?: boolean | null;
        /**
         * Whether subnet routes with public IP range are imported. The default value is false. IPv4 special-use ranges are always imported from peers and are not controlled by this field.
         */
        importSubnetRoutesWithPublicIp?: boolean | null;
        /**
         * Name of this peering. Provided by the client when the peering is created. The name must comply with RFC1035. Specifically, the name must be 1-63 characters long and match regular expression `[a-z]([-a-z0-9]*[a-z0-9])?`. The first character must be a lowercase letter, and all the following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * The URL of the peer network. It can be either full URL or partial URL. The peer network may belong to a different project. If the partial URL does not contain project, it is assumed that the peer network is in the same project as the current network.
         */
        network?: string | null;
        /**
         * Maximum Transmission Unit in bytes.
         */
        peerMtu?: number | null;
        /**
         * Which IP version(s) of traffic and routes are allowed to be imported or exported between peer networks. The default value is IPV4_ONLY.
         */
        stackType?: string | null;
        /**
         * [Output Only] State for the peering, either `ACTIVE` or `INACTIVE`. The peering is `ACTIVE` when there's a matching configuration in the peer network.
         */
        state?: string | null;
        /**
         * [Output Only] Details about the current state of the peering.
         */
        stateDetails?: string | null;
    }
    export interface Schema$NetworkPerformanceConfig {
        externalIpEgressBandwidthTier?: string | null;
        totalEgressBandwidthTier?: string | null;
    }
    /**
     * A routing configuration attached to a network resource. The message includes the list of routers associated with the network, and a flag indicating the type of routing behavior to enforce network-wide.
     */
    export interface Schema$NetworkRoutingConfig {
        /**
         * Enable comparison of Multi-Exit Discriminators (MED) across routes with different neighbor ASNs when using the STANDARD BGP best path selection algorithm.
         */
        bgpAlwaysCompareMed?: boolean | null;
        /**
         * The BGP best path selection algorithm to be employed within this network for dynamic routes learned by Cloud Routers. Can be LEGACY (default) or STANDARD.
         */
        bgpBestPathSelectionMode?: string | null;
        /**
         * Allows to define a preferred approach for handling inter-region cost in the selection process when using the STANDARD BGP best path selection algorithm. Can be DEFAULT or ADD_COST_TO_MED.
         */
        bgpInterRegionCost?: string | null;
        /**
         * The network-wide routing mode to use. If set to REGIONAL, this network's Cloud Routers will only advertise routes with subnets of this network in the same region as the router. If set to GLOBAL, this network's Cloud Routers will advertise routes with all subnets of this network, across regions.
         */
        routingMode?: string | null;
    }
    export interface Schema$NetworksAddPeeringRequest {
        /**
         * This field will be deprecated soon. Use exchange_subnet_routes in network_peering instead. Indicates whether full mesh connectivity is created and managed automatically between peered networks. Currently this field should always be true since Google Compute Engine will automatically create and manage subnetwork routes between two networks when peering state is ACTIVE.
         */
        autoCreateRoutes?: boolean | null;
        /**
         * This field will be deprecated soon. Use export_custom_routes in network_peering instead. Whether to export the custom routes to peer network.
         */
        exportCustomRoutes?: boolean | null;
        /**
         * This field will be deprecated soon. Use import_custom_routes in network_peering instead. Whether to import the custom routes from peer network.
         */
        importCustomRoutes?: boolean | null;
        /**
         * Name of the peering, which should conform to RFC1035.
         */
        name?: string | null;
        /**
         * Network peering parameters. In order to specify route policies for peering using import and export custom routes, you must specify all peering related parameters (name, peer network, exchange_subnet_routes) in the network_peering field. The corresponding fields in NetworksAddPeeringRequest will be deprecated soon.
         */
        networkPeering?: Schema$NetworkPeering;
        /**
         * URL of the peer network. It can be either full URL or partial URL. The peer network may belong to a different project. If the partial URL does not contain project, it is assumed that the peer network is in the same project as the current network.
         */
        peerNetwork?: string | null;
    }
    export interface Schema$NetworksGetEffectiveFirewallsResponse {
        /**
         * Effective firewalls from firewall policy.
         */
        firewallPolicys?: Schema$NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy[];
        /**
         * Effective firewalls on the network.
         */
        firewalls?: Schema$Firewall[];
        /**
         * Effective firewalls from organization policies.
         */
        organizationFirewalls?: Schema$NetworksGetEffectiveFirewallsResponseOrganizationFirewallPolicy[];
    }
    export interface Schema$NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy {
        /**
         * [Output Only] Deprecated, please use short name instead. The display name of the firewall policy.
         */
        displayName?: string | null;
        /**
         * [Output Only] The name of the firewall policy.
         */
        name?: string | null;
        /**
         * The rules that apply to the network.
         */
        rules?: Schema$FirewallPolicyRule[];
        /**
         * [Output Only] The short name of the firewall policy.
         */
        shortName?: string | null;
        /**
         * [Output Only] The type of the firewall policy.
         */
        type?: string | null;
    }
    /**
     * A pruned SecurityPolicy containing ID and any applicable firewall rules.
     */
    export interface Schema$NetworksGetEffectiveFirewallsResponseOrganizationFirewallPolicy {
        /**
         * [Output Only] The unique identifier for the security policy. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * The rules that apply to the network.
         */
        rules?: Schema$SecurityPolicyRule[];
    }
    export interface Schema$NetworksRemovePeeringRequest {
        /**
         * Name of the peering, which should conform to RFC1035.
         */
        name?: string | null;
    }
    export interface Schema$NetworksUpdatePeeringRequest {
        networkPeering?: Schema$NetworkPeering;
    }
    /**
     * Represents a sole-tenant Node Group resource. A sole-tenant node is a physical server that is dedicated to hosting VM instances only for your specific project. Use sole-tenant nodes to keep your instances physically separated from instances in other projects, or to group your instances together on the same host hardware. For more information, read Sole-tenant nodes.
     */
    export interface Schema$NodeGroup {
        /**
         * Specifies how autoscaling should behave.
         */
        autoscalingPolicy?: Schema$NodeGroupAutoscalingPolicy;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        fingerprint?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] The type of the resource. Always compute#nodeGroup for node group.
         */
        kind?: string | null;
        /**
         * An opaque location hint used to place the Node close to other resources. This field is for use by internal tools that use the public API. The location hint here on the NodeGroup overrides any location_hint present in the NodeTemplate.
         */
        locationHint?: string | null;
        /**
         * Specifies the frequency of planned maintenance events. The accepted values are: `AS_NEEDED` and `RECURRENT`.
         */
        maintenanceInterval?: string | null;
        /**
         * Specifies how to handle instances when a node in the group undergoes maintenance. Set to one of: DEFAULT, RESTART_IN_PLACE, or MIGRATE_WITHIN_NODE_GROUP. The default value is DEFAULT. For more information, see Maintenance policies.
         */
        maintenancePolicy?: string | null;
        maintenanceWindow?: Schema$NodeGroupMaintenanceWindow;
        /**
         * The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * URL of the node template to create the node group from.
         */
        nodeTemplate?: string | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * Share-settings for the node group
         */
        shareSettings?: Schema$ShareSettings;
        /**
         * [Output Only] The total number of nodes in the node group.
         */
        size?: number | null;
        status?: string | null;
        /**
         * [Output Only] The name of the zone where the node group resides, such as us-central1-a.
         */
        zone?: string | null;
    }
    export interface Schema$NodeGroupAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of NodeGroupsScopedList resources.
         */
        items?: {
            [key: string]: Schema$NodeGroupsScopedList;
        } | null;
        /**
         * [Output Only] Type of resource.Always compute#nodeGroupAggregatedList for aggregated lists of node groups.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$NodeGroupAutoscalingPolicy {
        /**
         * The maximum number of nodes that the group should have. Must be set if autoscaling is enabled. Maximum value allowed is 100.
         */
        maxNodes?: number | null;
        /**
         * The minimum number of nodes that the group should have.
         */
        minNodes?: number | null;
        /**
         * The autoscaling mode. Set to one of: ON, OFF, or ONLY_SCALE_OUT. For more information, see Autoscaler modes.
         */
        mode?: string | null;
    }
    /**
     * Contains a list of nodeGroups.
     */
    export interface Schema$NodeGroupList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of NodeGroup resources.
         */
        items?: Schema$NodeGroup[];
        /**
         * [Output Only] Type of resource.Always compute#nodeGroupList for lists of node groups.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Time window specified for daily maintenance operations. GCE's internal maintenance will be performed within this window.
     */
    export interface Schema$NodeGroupMaintenanceWindow {
        /**
         * [Output only] A predetermined duration for the window, automatically chosen to be the smallest possible in the given scenario.
         */
        duration?: string | null;
        /**
         * [Output only] A predetermined duration for the window, automatically chosen to be the smallest possible in the given scenario.
         */
        maintenanceDuration?: Schema$Duration;
        /**
         * Start time of the window. This must be in UTC format that resolves to one of 00:00, 04:00, 08:00, 12:00, 16:00, or 20:00. For example, both 13:00-5 and 08:00 are valid.
         */
        startTime?: string | null;
    }
    export interface Schema$NodeGroupNode {
        /**
         * Accelerators for this node.
         */
        accelerators?: Schema$AcceleratorConfig[];
        /**
         * Node resources that are reserved by all instances.
         */
        consumedResources?: Schema$InstanceConsumptionInfo;
        /**
         * CPU overcommit.
         */
        cpuOvercommitType?: string | null;
        /**
         * Local disk configurations.
         */
        disks?: Schema$LocalDisk[];
        /**
         * Instance data that shows consumed resources on the node.
         */
        instanceConsumptionData?: Schema$InstanceConsumptionData[];
        /**
         * Instances scheduled on this node.
         */
        instances?: string[] | null;
        /**
         * The name of the node.
         */
        name?: string | null;
        /**
         * The type of this node.
         */
        nodeType?: string | null;
        /**
         * [Output Only] Reserved for future use.
         */
        satisfiesPzs?: boolean | null;
        /**
         * Binding properties for the physical server.
         */
        serverBinding?: Schema$ServerBinding;
        /**
         * Server ID associated with this node.
         */
        serverId?: string | null;
        status?: string | null;
        /**
         * Total amount of available resources on the node.
         */
        totalResources?: Schema$InstanceConsumptionInfo;
        /**
         * [Output Only] The information about an upcoming maintenance event.
         */
        upcomingMaintenance?: Schema$UpcomingMaintenance;
    }
    export interface Schema$NodeGroupsAddNodesRequest {
        /**
         * Count of additional nodes to be added to the node group.
         */
        additionalNodeCount?: number | null;
    }
    export interface Schema$NodeGroupsDeleteNodesRequest {
        /**
         * Names of the nodes to delete.
         */
        nodes?: string[] | null;
    }
    export interface Schema$NodeGroupsListNodes {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of Node resources.
         */
        items?: Schema$NodeGroupNode[];
        /**
         * [Output Only] The resource type, which is always compute.nodeGroupsListNodes for the list of nodes in the specified node group.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$NodeGroupsPerformMaintenanceRequest {
        /**
         * [Required] List of nodes affected by the call.
         */
        nodes?: string[] | null;
        /**
         * The start time of the schedule. The timestamp is an RFC3339 string.
         */
        startTime?: string | null;
    }
    export interface Schema$NodeGroupsScopedList {
        /**
         * [Output Only] A list of node groups contained in this scope.
         */
        nodeGroups?: Schema$NodeGroup[];
        /**
         * [Output Only] An informational warning that appears when the nodeGroup list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$NodeGroupsSetNodeTemplateRequest {
        /**
         * Full or partial URL of the node template resource to be updated for this node group.
         */
        nodeTemplate?: string | null;
    }
    export interface Schema$NodeGroupsSimulateMaintenanceEventRequest {
        /**
         * Names of the nodes to go under maintenance simulation.
         */
        nodes?: string[] | null;
    }
    /**
     * Represent a sole-tenant Node Template resource. You can use a template to define properties for nodes in a node group. For more information, read Creating node groups and instances.
     */
    export interface Schema$NodeTemplate {
        accelerators?: Schema$AcceleratorConfig[];
        /**
         * CPU overcommit.
         */
        cpuOvercommitType?: string | null;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        disks?: Schema$LocalDisk[];
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] The type of the resource. Always compute#nodeTemplate for node templates.
         */
        kind?: string | null;
        /**
         * The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * Labels to use for node affinity, which will be used in instance scheduling.
         */
        nodeAffinityLabels?: {
            [key: string]: string;
        } | null;
        /**
         * The node type to use for nodes group that are created from this template.
         */
        nodeType?: string | null;
        /**
         * Do not use. Instead, use the node_type property.
         */
        nodeTypeFlexibility?: Schema$NodeTemplateNodeTypeFlexibility;
        /**
         * [Output Only] The name of the region where the node template resides, such as us-central1.
         */
        region?: string | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * Sets the binding properties for the physical server. Valid values include: - *[Default]* RESTART_NODE_ON_ANY_SERVER: Restarts VMs on any available physical server - RESTART_NODE_ON_MINIMAL_SERVER: Restarts VMs on the same physical server whenever possible See Sole-tenant node options for more information.
         */
        serverBinding?: Schema$ServerBinding;
        /**
         * [Output Only] The status of the node template. One of the following values: CREATING, READY, and DELETING.
         */
        status?: string | null;
        /**
         * [Output Only] An optional, human-readable explanation of the status.
         */
        statusMessage?: string | null;
    }
    export interface Schema$NodeTemplateAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of NodeTemplatesScopedList resources.
         */
        items?: {
            [key: string]: Schema$NodeTemplatesScopedList;
        } | null;
        /**
         * [Output Only] Type of resource.Always compute#nodeTemplateAggregatedList for aggregated lists of node templates.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Contains a list of node templates.
     */
    export interface Schema$NodeTemplateList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of NodeTemplate resources.
         */
        items?: Schema$NodeTemplate[];
        /**
         * [Output Only] Type of resource.Always compute#nodeTemplateList for lists of node templates.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$NodeTemplateNodeTypeFlexibility {
        cpus?: string | null;
        localSsd?: string | null;
        memory?: string | null;
    }
    export interface Schema$NodeTemplatesScopedList {
        /**
         * [Output Only] A list of node templates contained in this scope.
         */
        nodeTemplates?: Schema$NodeTemplate[];
        /**
         * [Output Only] An informational warning that appears when the node templates list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Represent a sole-tenant Node Type resource. Each node within a node group must have a node type. A node type specifies the total amount of cores and memory for that node. Currently, the only available node type is n1-node-96-624 node type that has 96 vCPUs and 624 GB of memory, available in multiple zones. For more information read Node types.
     */
    export interface Schema$NodeType {
        /**
         * [Output Only] The CPU platform used by this node type.
         */
        cpuPlatform?: string | null;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * [Output Only] The deprecation status associated with this node type.
         */
        deprecated?: Schema$DeprecationStatus;
        /**
         * [Output Only] An optional textual description of the resource.
         */
        description?: string | null;
        /**
         * [Output Only] The number of virtual CPUs that are available to the node type.
         */
        guestCpus?: number | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] The type of the resource. Always compute#nodeType for node types.
         */
        kind?: string | null;
        /**
         * [Output Only] Local SSD available to the node type, defined in GB.
         */
        localSsdGb?: number | null;
        /**
         * [Output Only] The amount of physical memory available to the node type, defined in MB.
         */
        memoryMb?: number | null;
        /**
         * [Output Only] Name of the resource.
         */
        name?: string | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * [Output Only] The name of the zone where the node type resides, such as us-central1-a.
         */
        zone?: string | null;
    }
    export interface Schema$NodeTypeAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of NodeTypesScopedList resources.
         */
        items?: {
            [key: string]: Schema$NodeTypesScopedList;
        } | null;
        /**
         * [Output Only] Type of resource.Always compute#nodeTypeAggregatedList for aggregated lists of node types.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Contains a list of node types.
     */
    export interface Schema$NodeTypeList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of NodeType resources.
         */
        items?: Schema$NodeType[];
        /**
         * [Output Only] Type of resource.Always compute#nodeTypeList for lists of node types.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$NodeTypesScopedList {
        /**
         * [Output Only] A list of node types contained in this scope.
         */
        nodeTypes?: Schema$NodeType[];
        /**
         * [Output Only] An informational warning that appears when the node types list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Represents a notification endpoint. A notification endpoint resource defines an endpoint to receive notifications when there are status changes detected by the associated health check service. For more information, see Health checks overview.
     */
    export interface Schema$NotificationEndpoint {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * Settings of the gRPC notification endpoint including the endpoint URL and the retry duration.
         */
        grpcSettings?: Schema$NotificationEndpointGrpcSettings;
        /**
         * [Output Only] A unique identifier for this resource type. The server generates this identifier.
         */
        id?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#notificationEndpoint for notification endpoints.
         */
        kind?: string | null;
        /**
         * Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * [Output Only] URL of the region where the notification endpoint resides. This field applies only to the regional resource. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
         */
        region?: string | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
    }
    /**
     * Contains a list of NotificationEndpointsScopedList.
     */
    export interface Schema$NotificationEndpointAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of NotificationEndpointsScopedList resources.
         */
        items?: {
            [key: string]: Schema$NotificationEndpointsScopedList;
        } | null;
        /**
         * Type of resource.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Represents a gRPC setting that describes one gRPC notification endpoint and the retry duration attempting to send notification to this endpoint.
     */
    export interface Schema$NotificationEndpointGrpcSettings {
        /**
         * Optional. If specified, this field is used to set the authority header by the sender of notifications. See https://tools.ietf.org/html/rfc7540#section-8.1.2.3
         */
        authority?: string | null;
        /**
         * Endpoint to which gRPC notifications are sent. This must be a valid gRPCLB DNS name.
         */
        endpoint?: string | null;
        /**
         * Optional. If specified, this field is used to populate the "name" field in gRPC requests.
         */
        payloadName?: string | null;
        /**
         * Optional. This field is used to configure how often to send a full update of all non-healthy backends. If unspecified, full updates are not sent. If specified, must be in the range between 600 seconds to 3600 seconds. Nanos are disallowed. Can only be set for regional notification endpoints.
         */
        resendInterval?: Schema$Duration;
        /**
         * How much time (in seconds) is spent attempting notification retries until a successful response is received. Default is 30s. Limit is 20m (1200s). Must be a positive number.
         */
        retryDurationSec?: number | null;
    }
    export interface Schema$NotificationEndpointList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of NotificationEndpoint resources.
         */
        items?: Schema$NotificationEndpoint[];
        /**
         * [Output Only] Type of the resource. Always compute#notificationEndpoint for notification endpoints.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$NotificationEndpointsScopedList {
        /**
         * A list of NotificationEndpoints contained in this scope.
         */
        resources?: Schema$NotificationEndpoint[];
        /**
         * Informational warning which replaces the list of notification endpoints when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Represents an Operation resource. Google Compute Engine has three Operation resources: * [Global](/compute/docs/reference/rest/alpha/globalOperations) * [Regional](/compute/docs/reference/rest/alpha/regionOperations) * [Zonal](/compute/docs/reference/rest/alpha/zoneOperations) You can use an operation resource to manage asynchronous API requests. For more information, read Handling API responses. Operations can be global, regional or zonal. - For global operations, use the `globalOperations` resource. - For regional operations, use the `regionOperations` resource. - For zonal operations, use the `zoneOperations` resource. For more information, read Global, Regional, and Zonal Resources.
     */
    export interface Schema$Operation {
        /**
         * [Output Only] The value of `requestId` if you provided it in the request. Not present otherwise.
         */
        clientOperationId?: string | null;
        /**
         * [Deprecated] This field is deprecated.
         */
        creationTimestamp?: string | null;
        /**
         * [Output Only] A textual description of the operation, which is set when the operation is created.
         */
        description?: string | null;
        /**
         * [Output Only] The time that this operation was completed. This value is in RFC3339 text format.
         */
        endTime?: string | null;
        /**
         * [Output Only] If errors are generated during processing of the operation, this field will be populated.
         */
        error?: {
            errors?: Array<{
                code?: string;
                errorDetails?: Array<{
                    errorInfo?: Schema$ErrorInfo;
                    help?: Schema$Help;
                    localizedMessage?: Schema$LocalizedMessage;
                    quotaInfo?: Schema$QuotaExceededInfo;
                }>;
                location?: string;
                message?: string;
            }>;
        } | null;
        /**
         * [Output Only] If the operation fails, this field contains the HTTP error message that was returned, such as `NOT FOUND`.
         */
        httpErrorMessage?: string | null;
        /**
         * [Output Only] If the operation fails, this field contains the HTTP error status code that was returned. For example, a `404` means the resource was not found.
         */
        httpErrorStatusCode?: number | null;
        /**
         * [Output Only] The unique identifier for the operation. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] The time that this operation was requested. This value is in RFC3339 text format.
         */
        insertTime?: string | null;
        instancesBulkInsertOperationMetadata?: Schema$InstancesBulkInsertOperationMetadata;
        /**
         * [Output Only] Type of the resource. Always `compute#operation` for Operation resources.
         */
        kind?: string | null;
        /**
         * [Output Only] Name of the operation.
         */
        name?: string | null;
        /**
         * [Output Only] An ID that represents a group of operations, such as when a group of operations results from a `bulkInsert` API request.
         */
        operationGroupId?: string | null;
        /**
         * [Output Only] The type of operation, such as `insert`, `update`, or `delete`, and so on.
         */
        operationType?: string | null;
        /**
         * [Output Only] An optional progress indicator that ranges from 0 to 100. There is no requirement that this be linear or support any granularity of operations. This should not be used to guess when the operation will be complete. This number should monotonically increase as the operation progresses.
         */
        progress?: number | null;
        /**
         * [Output Only] The URL of the region where the operation resides. Only applicable when performing regional operations.
         */
        region?: string | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * [Output Only] If the operation is for projects.setCommonInstanceMetadata, this field will contain information on all underlying zonal actions and their state.
         */
        setCommonInstanceMetadataOperationMetadata?: Schema$SetCommonInstanceMetadataOperationMetadata;
        /**
         * [Output Only] The time that this operation was started by the server. This value is in RFC3339 text format.
         */
        startTime?: string | null;
        /**
         * [Output Only] The status of the operation, which can be one of the following: `PENDING`, `RUNNING`, or `DONE`.
         */
        status?: string | null;
        /**
         * [Output Only] An optional textual description of the current status of the operation.
         */
        statusMessage?: string | null;
        /**
         * [Output Only] The unique target ID, which identifies a specific incarnation of the target resource.
         */
        targetId?: string | null;
        /**
         * [Output Only] The URL of the resource that the operation modifies. For operations related to creating a snapshot, this points to the persistent disk that the snapshot was created from.
         */
        targetLink?: string | null;
        /**
         * [Output Only] User who requested the operation, for example: `user@example.com` or `alice_smith_identifier (global/workforcePools/example-com-us-employees)`.
         */
        user?: string | null;
        /**
         * [Output Only] If warning messages are generated during processing of the operation, this field will be populated.
         */
        warnings?: Array<{
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        }> | null;
        /**
         * [Output Only] The URL of the zone where the operation resides. Only applicable when performing per-zone operations.
         */
        zone?: string | null;
    }
    export interface Schema$OperationAggregatedList {
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] A map of scoped operation lists.
         */
        items?: {
            [key: string]: Schema$OperationsScopedList;
        } | null;
        /**
         * [Output Only] Type of resource. Always `compute#operationAggregatedList` for aggregated lists of operations.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than `maxResults`, use the `nextPageToken` as a value for the query parameter `pageToken` in the next list request. Subsequent list requests will have their own `nextPageToken` to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Contains a list of Operation resources.
     */
    export interface Schema$OperationList {
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] A list of Operation resources.
         */
        items?: Schema$Operation[];
        /**
         * [Output Only] Type of resource. Always `compute#operations` for Operations resource.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than `maxResults`, use the `nextPageToken` as a value for the query parameter `pageToken` in the next list request. Subsequent list requests will have their own `nextPageToken` to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$OperationsScopedList {
        /**
         * [Output Only] A list of operations contained in this scope.
         */
        operations?: Schema$Operation[];
        /**
         * [Output Only] Informational warning which replaces the list of operations when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$OrganizationSecurityPoliciesListAssociationsResponse {
        /**
         * A list of associations.
         */
        associations?: Schema$SecurityPolicyAssociation[];
        /**
         * [Output Only] Type of securityPolicy associations. Always compute#organizationSecurityPoliciesListAssociations for lists of securityPolicy associations.
         */
        kind?: string | null;
    }
    /**
     * [Deprecated] Configuration for the origin authentication method. Configuration for the origin authentication method.
     */
    export interface Schema$OriginAuthenticationMethod {
        jwt?: Schema$Jwt;
    }
    /**
     * Settings controlling the eviction of unhealthy hosts from the load balancing pool for the backend service.
     */
    export interface Schema$OutlierDetection {
        /**
         * The base time that a backend endpoint is ejected for. Defaults to 30000ms or 30s. After a backend endpoint is returned back to the load balancing pool, it can be ejected again in another ejection analysis. Thus, the total ejection time is equal to the base ejection time multiplied by the number of times the backend endpoint has been ejected. Defaults to 30000ms or 30s.
         */
        baseEjectionTime?: Schema$Duration;
        /**
         * Number of consecutive errors before a backend endpoint is ejected from the load balancing pool. When the backend endpoint is accessed over HTTP, a 5xx return code qualifies as an error. Defaults to 5.
         */
        consecutiveErrors?: number | null;
        /**
         * The number of consecutive gateway failures (502, 503, 504 status or connection errors that are mapped to one of those status codes) before a consecutive gateway failure ejection occurs. Defaults to 3.
         */
        consecutiveGatewayFailure?: number | null;
        /**
         * The percentage chance that a backend endpoint will be ejected when an outlier status is detected through consecutive 5xx. This setting can be used to disable ejection or to ramp it up slowly. Defaults to 0.
         */
        enforcingConsecutiveErrors?: number | null;
        /**
         * The percentage chance that a backend endpoint will be ejected when an outlier status is detected through consecutive gateway failures. This setting can be used to disable ejection or to ramp it up slowly. Defaults to 100.
         */
        enforcingConsecutiveGatewayFailure?: number | null;
        /**
         * The percentage chance that a backend endpoint will be ejected when an outlier status is detected through success rate statistics. This setting can be used to disable ejection or to ramp it up slowly. Defaults to 100. Not supported when the backend service uses Serverless NEG.
         */
        enforcingSuccessRate?: number | null;
        /**
         * Time interval between ejection analysis sweeps. This can result in both new ejections and backend endpoints being returned to service. The interval is equal to the number of seconds as defined in outlierDetection.interval.seconds plus the number of nanoseconds as defined in outlierDetection.interval.nanos. Defaults to 1 second.
         */
        interval?: Schema$Duration;
        /**
         * Maximum percentage of backend endpoints in the load balancing pool for the backend service that can be ejected if the ejection conditions are met. Defaults to 50%.
         */
        maxEjectionPercent?: number | null;
        /**
         * The number of backend endpoints in the load balancing pool that must have enough request volume to detect success rate outliers. If the number of backend endpoints is fewer than this setting, outlier detection via success rate statistics is not performed for any backend endpoint in the load balancing pool. Defaults to 5. Not supported when the backend service uses Serverless NEG.
         */
        successRateMinimumHosts?: number | null;
        /**
         * The minimum number of total requests that must be collected in one interval (as defined by the interval duration above) to include this backend endpoint in success rate based outlier detection. If the volume is lower than this setting, outlier detection via success rate statistics is not performed for that backend endpoint. Defaults to 100. Not supported when the backend service uses Serverless NEG.
         */
        successRateRequestVolume?: number | null;
        /**
         * This factor is used to determine the ejection threshold for success rate outlier ejection. The ejection threshold is the difference between the mean success rate, and the product of this factor and the standard deviation of the mean success rate: mean - (stdev * successRateStdevFactor). This factor is divided by a thousand to get a double. That is, if the desired factor is 1.9, the runtime value should be 1900. Defaults to 1900. Not supported when the backend service uses Serverless NEG.
         */
        successRateStdevFactor?: number | null;
    }
    /**
     * Next free: 7
     */
    export interface Schema$PacketIntervals {
        /**
         * Average observed inter-packet interval in milliseconds.
         */
        avgMs?: string | null;
        /**
         * From how long ago in the past these intervals were observed.
         */
        duration?: string | null;
        /**
         * Maximum observed inter-packet interval in milliseconds.
         */
        maxMs?: string | null;
        /**
         * Minimum observed inter-packet interval in milliseconds.
         */
        minMs?: string | null;
        /**
         * Number of inter-packet intervals from which these statistics were derived.
         */
        numIntervals?: string | null;
        /**
         * The type of packets for which inter-packet intervals were computed.
         */
        type?: string | null;
    }
    /**
     * Represents a Packet Mirroring resource. Packet Mirroring clones the traffic of specified instances in your Virtual Private Cloud (VPC) network and forwards it to a collector destination, such as an instance group of an internal TCP/UDP load balancer, for analysis or examination. For more information about setting up Packet Mirroring, see Using Packet Mirroring.
     */
    export interface Schema$PacketMirroring {
        /**
         * The Forwarding Rule resource of type loadBalancingScheme=INTERNAL that will be used as collector for mirrored traffic. The specified forwarding rule must have isMirroringCollector set to true.
         */
        collectorIlb?: Schema$PacketMirroringForwardingRuleInfo;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * Indicates whether or not this packet mirroring takes effect. If set to FALSE, this packet mirroring policy will not be enforced on the network. The default is TRUE.
         */
        enable?: string | null;
        /**
         * Filter for mirrored traffic. If unspecified, all traffic is mirrored.
         */
        filter?: Schema$PacketMirroringFilter;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#packetMirroring for packet mirrorings.
         */
        kind?: string | null;
        /**
         * PacketMirroring mirroredResourceInfos. MirroredResourceInfo specifies a set of mirrored VM instances, subnetworks and/or tags for which traffic from/to all VM instances will be mirrored.
         */
        mirroredResources?: Schema$PacketMirroringMirroredResourceInfo;
        /**
         * Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * Specifies the mirrored VPC network. Only packets in this network will be mirrored. All mirrored VMs should have a NIC in the given network. All mirrored subnetworks should belong to the given network.
         */
        network?: Schema$PacketMirroringNetworkInfo;
        /**
         * The priority of applying this configuration. Priority is used to break ties in cases where there is more than one matching rule. In the case of two rules that apply for a given Instance, the one with the lowest-numbered priority value wins. Default value is 1000. Valid range is 0 through 65535.
         */
        priority?: number | null;
        /**
         * [Output Only] URI of the region where the packetMirroring resides.
         */
        region?: string | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
    }
    /**
     * Contains a list of packetMirrorings.
     */
    export interface Schema$PacketMirroringAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of PacketMirroring resources.
         */
        items?: {
            [key: string]: Schema$PacketMirroringsScopedList;
        } | null;
        /**
         * Type of resource.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$PacketMirroringFilter {
        /**
         * IP CIDR ranges that apply as filter on the source (ingress) or destination (egress) IP in the IP header. Only IPv4 is supported. If no ranges are specified, all traffic that matches the specified IPProtocols is mirrored. If neither cidrRanges nor IPProtocols is specified, all traffic is mirrored.
         */
        cidrRanges?: string[] | null;
        /**
         * Direction of traffic to mirror, either INGRESS, EGRESS, or BOTH. The default is BOTH.
         */
        direction?: string | null;
        /**
         * Protocols that apply as filter on mirrored traffic. If no protocols are specified, all traffic that matches the specified CIDR ranges is mirrored. If neither cidrRanges nor IPProtocols is specified, all traffic is mirrored.
         */
        IPProtocols?: string[] | null;
    }
    export interface Schema$PacketMirroringForwardingRuleInfo {
        /**
         * [Output Only] Unique identifier for the forwarding rule; defined by the server.
         */
        canonicalUrl?: string | null;
        /**
         * Resource URL to the forwarding rule representing the ILB configured as destination of the mirrored traffic.
         */
        url?: string | null;
    }
    /**
     * Contains a list of PacketMirroring resources.
     */
    export interface Schema$PacketMirroringList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of PacketMirroring resources.
         */
        items?: Schema$PacketMirroring[];
        /**
         * [Output Only] Type of resource. Always compute#packetMirroring for packetMirrorings.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$PacketMirroringMirroredResourceInfo {
        /**
         * A set of virtual machine instances that are being mirrored. They must live in zones contained in the same region as this packetMirroring. Note that this config will apply only to those network interfaces of the Instances that belong to the network specified in this packetMirroring. You may specify a maximum of 50 Instances.
         */
        instances?: Schema$PacketMirroringMirroredResourceInfoInstanceInfo[];
        /**
         * A set of subnetworks for which traffic from/to all VM instances will be mirrored. They must live in the same region as this packetMirroring. You may specify a maximum of 5 subnetworks.
         */
        subnetworks?: Schema$PacketMirroringMirroredResourceInfoSubnetInfo[];
        /**
         * A set of mirrored tags. Traffic from/to all VM instances that have one or more of these tags will be mirrored.
         */
        tags?: string[] | null;
    }
    export interface Schema$PacketMirroringMirroredResourceInfoInstanceInfo {
        /**
         * [Output Only] Unique identifier for the instance; defined by the server.
         */
        canonicalUrl?: string | null;
        /**
         * Resource URL to the virtual machine instance which is being mirrored.
         */
        url?: string | null;
    }
    export interface Schema$PacketMirroringMirroredResourceInfoSubnetInfo {
        /**
         * [Output Only] Unique identifier for the subnetwork; defined by the server.
         */
        canonicalUrl?: string | null;
        /**
         * Resource URL to the subnetwork for which traffic from/to all VM instances will be mirrored.
         */
        url?: string | null;
    }
    export interface Schema$PacketMirroringNetworkInfo {
        /**
         * [Output Only] Unique identifier for the network; defined by the server.
         */
        canonicalUrl?: string | null;
        /**
         * URL of the network resource.
         */
        url?: string | null;
    }
    export interface Schema$PacketMirroringsScopedList {
        /**
         * A list of packetMirrorings contained in this scope.
         */
        packetMirrorings?: Schema$PacketMirroring[];
        /**
         * Informational warning which replaces the list of packetMirrorings when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Model definition of partner_metadata field. To be used in dedicated Partner Metadata methods and to be inlined in the Instance and InstanceTemplate resources.
     */
    export interface Schema$PartnerMetadata {
        /**
         * Instance-level hash to be used for optimistic locking.
         */
        fingerprint?: string | null;
        /**
         * Partner Metadata assigned to the instance. A map from a subdomain to entries map. Subdomain name must be compliant with RFC1035 definition. The total size of all keys and values must be less than 2MB. Subdomain 'metadata.compute.googleapis.com' is reserverd for instance's metadata.
         */
        partnerMetadata?: {
            [key: string]: Schema$StructuredEntries;
        } | null;
    }
    /**
     * A matcher for the path portion of the URL. The BackendService from the longest-matched rule will serve the URL. If no rule was matched, the default service is used.
     */
    export interface Schema$PathMatcher {
        /**
         * defaultCustomErrorResponsePolicy specifies how the Load Balancer returns error responses when BackendServiceor BackendBucket responds with an error. This policy takes effect at the PathMatcher level and applies only when no policy has been defined for the error code at lower levels like RouteRule and PathRule within this PathMatcher. If an error code does not have a policy defined in defaultCustomErrorResponsePolicy, then a policy defined for the error code in UrlMap.defaultCustomErrorResponsePolicy takes effect. For example, consider a UrlMap with the following configuration: - UrlMap.defaultCustomErrorResponsePolicy is configured with policies for 5xx and 4xx errors - A RouteRule for /coming_soon/ is configured for the error code 404. If the request is for www.myotherdomain.com and a 404 is encountered, the policy under UrlMap.defaultCustomErrorResponsePolicy takes effect. If a 404 response is encountered for the request www.example.com/current_events/, the pathMatcher's policy takes effect. If however, the request for www.example.com/coming_soon/ encounters a 404, the policy in RouteRule.customErrorResponsePolicy takes effect. If any of the requests in this example encounter a 500 error code, the policy at UrlMap.defaultCustomErrorResponsePolicy takes effect. When used in conjunction with pathMatcher.defaultRouteAction.retryPolicy, retries take precedence. Only once all retries are exhausted, the defaultCustomErrorResponsePolicy is applied. While attempting a retry, if load balancer is successful in reaching the service, the defaultCustomErrorResponsePolicy is ignored and the response from the service is returned to the client. defaultCustomErrorResponsePolicy is supported only for global external Application Load Balancers.
         */
        defaultCustomErrorResponsePolicy?: Schema$CustomErrorResponsePolicy;
        /**
         * defaultRouteAction takes effect when none of the pathRules or routeRules match. The load balancer performs advanced routing actions, such as URL rewrites and header transformations, before forwarding the request to the selected backend. If defaultRouteAction specifies any weightedBackendServices, defaultService must not be set. Conversely if defaultService is set, defaultRouteAction cannot contain any weightedBackendServices. Only one of defaultRouteAction or defaultUrlRedirect must be set. URL maps for classic Application Load Balancers only support the urlRewrite action within a path matcher's defaultRouteAction.
         */
        defaultRouteAction?: Schema$HttpRouteAction;
        /**
         * The full or partial URL to the BackendService resource. This URL is used if none of the pathRules or routeRules defined by this PathMatcher are matched. For example, the following are all valid URLs to a BackendService resource: - https://www.googleapis.com/compute/v1/projects/project /global/backendServices/backendService - compute/v1/projects/project/global/backendServices/backendService - global/backendServices/backendService If defaultRouteAction is also specified, advanced routing actions, such as URL rewrites, take effect before sending the request to the backend. However, if defaultService is specified, defaultRouteAction cannot contain any weightedBackendServices. Conversely, if defaultRouteAction specifies any weightedBackendServices, defaultService must not be specified. Only one of defaultService, defaultUrlRedirect , or defaultRouteAction.weightedBackendService must be set. Authorization requires one or more of the following Google IAM permissions on the specified resource default_service: - compute.backendBuckets.use - compute.backendServices.use
         */
        defaultService?: string | null;
        /**
         * When none of the specified pathRules or routeRules match, the request is redirected to a URL specified by defaultUrlRedirect. If defaultUrlRedirect is specified, defaultService or defaultRouteAction must not be set. Not supported when the URL map is bound to a target gRPC proxy.
         */
        defaultUrlRedirect?: Schema$HttpRedirectAction;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * Specifies changes to request and response headers that need to take effect for the selected backend service. HeaderAction specified here are applied after the matching HttpRouteRule HeaderAction and before the HeaderAction in the UrlMap HeaderAction is not supported for load balancers that have their loadBalancingScheme set to EXTERNAL. Not supported when the URL map is bound to a target gRPC proxy that has validateForProxyless field set to true.
         */
        headerAction?: Schema$HttpHeaderAction;
        /**
         * The name to which this PathMatcher is referred by the HostRule.
         */
        name?: string | null;
        /**
         * The list of path rules. Use this list instead of routeRules when routing based on simple path matching is all that's required. The order by which path rules are specified does not matter. Matches are always done on the longest-path-first basis. For example: a pathRule with a path /a/b/c/x will match before /a/b/x irrespective of the order in which those paths appear in this list. Within a given pathMatcher, only one of pathRules or routeRules must be set.
         */
        pathRules?: Schema$PathRule[];
        /**
         * The list of HTTP route rules. Use this list instead of pathRules when advanced route matching and routing actions are desired. routeRules are evaluated in order of priority, from the lowest to highest number. Within a given pathMatcher, you can set only one of pathRules or routeRules.
         */
        routeRules?: Schema$HttpRouteRule[];
    }
    /**
     * A path-matching rule for a URL. If matched, will use the specified BackendService to handle the traffic arriving at this URL.
     */
    export interface Schema$PathRule {
        /**
         * customErrorResponsePolicy specifies how the Load Balancer returns error responses when BackendServiceor BackendBucket responds with an error. If a policy for an error code is not configured for the PathRule, a policy for the error code configured in pathMatcher.defaultCustomErrorResponsePolicy is applied. If one is not specified in pathMatcher.defaultCustomErrorResponsePolicy, the policy configured in UrlMap.defaultCustomErrorResponsePolicy takes effect. For example, consider a UrlMap with the following configuration: - UrlMap.defaultCustomErrorResponsePolicy are configured with policies for 5xx and 4xx errors - A PathRule for /coming_soon/ is configured for the error code 404. If the request is for www.myotherdomain.com and a 404 is encountered, the policy under UrlMap.defaultCustomErrorResponsePolicy takes effect. If a 404 response is encountered for the request www.example.com/current_events/, the pathMatcher's policy takes effect. If however, the request for www.example.com/coming_soon/ encounters a 404, the policy in PathRule.customErrorResponsePolicy takes effect. If any of the requests in this example encounter a 500 error code, the policy at UrlMap.defaultCustomErrorResponsePolicy takes effect. customErrorResponsePolicy is supported only for global external Application Load Balancers.
         */
        customErrorResponsePolicy?: Schema$CustomErrorResponsePolicy;
        /**
         * The list of path patterns to match. Each must start with / and the only place a * is allowed is at the end following a /. The string fed to the path matcher does not include any text after the first ? or #, and those chars are not allowed here.
         */
        paths?: string[] | null;
        /**
         * In response to a matching path, the load balancer performs advanced routing actions, such as URL rewrites and header transformations, before forwarding the request to the selected backend. If routeAction specifies any weightedBackendServices, service must not be set. Conversely if service is set, routeAction cannot contain any weightedBackendServices. Only one of routeAction or urlRedirect must be set. URL maps for classic Application Load Balancers only support the urlRewrite action within a path rule's routeAction.
         */
        routeAction?: Schema$HttpRouteAction;
        /**
         * The full or partial URL of the backend service resource to which traffic is directed if this rule is matched. If routeAction is also specified, advanced routing actions, such as URL rewrites, take effect before sending the request to the backend. However, if service is specified, routeAction cannot contain any weightedBackendServices. Conversely, if routeAction specifies any weightedBackendServices, service must not be specified. Only one of urlRedirect, service or routeAction.weightedBackendService must be set.
         */
        service?: string | null;
        /**
         * When a path pattern is matched, the request is redirected to a URL specified by urlRedirect. If urlRedirect is specified, service or routeAction must not be set. Not supported when the URL map is bound to a target gRPC proxy.
         */
        urlRedirect?: Schema$HttpRedirectAction;
    }
    /**
     * [Deprecated] Configuration for the peer authentication method. Configuration for the peer authentication method.
     */
    export interface Schema$PeerAuthenticationMethod {
        /**
         * Set if mTLS is used for peer authentication.
         */
        mtls?: Schema$MutualTls;
    }
    export interface Schema$PerInstanceConfig {
        /**
         * Fingerprint of this per-instance config. This field can be used in optimistic locking. It is ignored when inserting a per-instance config. An up-to-date fingerprint must be provided in order to update an existing per-instance configuration or the field needs to be unset.
         */
        fingerprint?: string | null;
        /**
         * The name of a per-instance configuration and its corresponding instance. Serves as a merge key during UpdatePerInstanceConfigs operations, that is, if a per-instance configuration with the same name exists then it will be updated, otherwise a new one will be created for the VM instance with the same name. An attempt to create a per-instance configconfiguration for a VM instance that either doesn't exist or is not part of the group will result in an error.
         */
        name?: string | null;
        /**
         * The intended preserved state for the given instance. Does not contain preserved state generated from a stateful policy.
         */
        preservedState?: Schema$PreservedState;
        /**
         * The status of applying this per-instance configuration on the corresponding managed instance.
         */
        status?: string | null;
    }
    /**
     * [Deprecated] All fields defined in a permission are ANDed.
     */
    export interface Schema$Permission {
        /**
         * Extra custom constraints. The constraints are ANDed together.
         */
        constraints?: Schema$PermissionConstraint[];
        /**
         * Used in Ingress or Egress Gateway cases to specify hosts that the policy applies to. Exact match, prefix match, and suffix match are supported.
         */
        hosts?: string[] | null;
        /**
         * HTTP method.
         */
        methods?: string[] | null;
        /**
         * Negate of hosts. Specifies exclusions.
         */
        notHosts?: string[] | null;
        /**
         * Negate of methods. Specifies exclusions.
         */
        notMethods?: string[] | null;
        /**
         * Negate of paths. Specifies exclusions.
         */
        notPaths?: string[] | null;
        /**
         * Negate of ports. Specifies exclusions.
         */
        notPorts?: string[] | null;
        /**
         * HTTP request paths or gRPC methods. Exact match, prefix match, and suffix match are supported.
         */
        paths?: string[] | null;
        /**
         * Port names or numbers.
         */
        ports?: string[] | null;
    }
    /**
     * Custom constraint that specifies a key and a list of allowed values for Istio attributes.
     */
    export interface Schema$PermissionConstraint {
        /**
         * Key of the constraint.
         */
        key?: string | null;
        /**
         * A list of allowed values.
         */
        values?: string[] | null;
    }
    /**
     * An Identity and Access Management (IAM) policy, which specifies access controls for Google Cloud resources. A `Policy` is a collection of `bindings`. A `binding` binds one or more `members`, or principals, to a single `role`. Principals can be user accounts, service accounts, Google groups, and domains (such as G Suite). A `role` is a named list of permissions; each `role` can be an IAM predefined role or a user-created custom role. For some types of Google Cloud resources, a `binding` can also specify a `condition`, which is a logical expression that allows access to a resource only if the expression evaluates to `true`. A condition can add constraints based on attributes of the request, the resource, or both. To learn which resources support conditions in their IAM policies, see the [IAM documentation](https://cloud.google.com/iam/help/conditions/resource-policies). **JSON example:** ``` { "bindings": [ { "role": "roles/resourcemanager.organizationAdmin", "members": [ "user:mike@example.com", "group:admins@example.com", "domain:google.com", "serviceAccount:my-project-id@appspot.gserviceaccount.com" ] \}, { "role": "roles/resourcemanager.organizationViewer", "members": [ "user:eve@example.com" ], "condition": { "title": "expirable access", "description": "Does not grant access after Sep 2020", "expression": "request.time < timestamp('2020-10-01T00:00:00.000Z')", \} \} ], "etag": "BwWWja0YfJA=", "version": 3 \} ``` **YAML example:** ``` bindings: - members: - user:mike@example.com - group:admins@example.com - domain:google.com - serviceAccount:my-project-id@appspot.gserviceaccount.com role: roles/resourcemanager.organizationAdmin - members: - user:eve@example.com role: roles/resourcemanager.organizationViewer condition: title: expirable access description: Does not grant access after Sep 2020 expression: request.time < timestamp('2020-10-01T00:00:00.000Z') etag: BwWWja0YfJA= version: 3 ``` For a description of IAM and its features, see the [IAM documentation](https://cloud.google.com/iam/docs/).
     */
    export interface Schema$Policy {
        /**
         * Specifies cloud audit logging configuration for this policy.
         */
        auditConfigs?: Schema$AuditConfig[];
        /**
         * Associates a list of `members`, or principals, with a `role`. Optionally, may specify a `condition` that determines how and when the `bindings` are applied. Each of the `bindings` must contain at least one principal. The `bindings` in a `Policy` can refer to up to 1,500 principals; up to 250 of these principals can be Google groups. Each occurrence of a principal counts towards these limits. For example, if the `bindings` grant 50 different roles to `user:alice@example.com`, and not to any other principal, then you can add another 1,450 principals to the `bindings` in the `Policy`.
         */
        bindings?: Schema$Binding[];
        /**
         * `etag` is used for optimistic concurrency control as a way to help prevent simultaneous updates of a policy from overwriting each other. It is strongly suggested that systems make use of the `etag` in the read-modify-write cycle to perform policy updates in order to avoid race conditions: An `etag` is returned in the response to `getIamPolicy`, and systems are expected to put that etag in the request to `setIamPolicy` to ensure that their change will be applied to the same version of the policy. **Important:** If you use IAM Conditions, you must include the `etag` field whenever you call `setIamPolicy`. If you omit this field, then IAM allows you to overwrite a version `3` policy with a version `1` policy, and all of the conditions in the version `3` policy are lost.
         */
        etag?: string | null;
        /**
         * This is deprecated and has no effect. Do not use.
         */
        rules?: Schema$Rule[];
        /**
         * Specifies the format of the policy. Valid values are `0`, `1`, and `3`. Requests that specify an invalid value are rejected. Any operation that affects conditional role bindings must specify version `3`. This requirement applies to the following operations: * Getting a policy that includes a conditional role binding * Adding a conditional role binding to a policy * Changing a conditional role binding in a policy * Removing any role binding, with or without a condition, from a policy that includes conditions **Important:** If you use IAM Conditions, you must include the `etag` field whenever you call `setIamPolicy`. If you omit this field, then IAM allows you to overwrite a version `3` policy with a version `1` policy, and all of the conditions in the version `3` policy are lost. If a policy does not include any conditions, operations on that policy may specify any valid version or leave the field unset. To learn which resources support conditions in their IAM policies, see the [IAM documentation](https://cloud.google.com/iam/help/conditions/resource-policies).
         */
        version?: number | null;
    }
    export interface Schema$PreconfiguredWafSet {
        /**
         * List of entities that are currently supported for WAF rules.
         */
        expressionSets?: Schema$WafExpressionSet[];
    }
    /**
     * Preserved state for a given instance.
     */
    export interface Schema$PreservedState {
        /**
         * Preserved disks defined for this instance. This map is keyed with the device names of the disks.
         */
        disks?: {
            [key: string]: Schema$PreservedStatePreservedDisk;
        } | null;
        /**
         * Preserved external IPs defined for this instance. This map is keyed with the name of the network interface.
         */
        externalIPs?: {
            [key: string]: Schema$PreservedStatePreservedNetworkIp;
        } | null;
        /**
         * Preserved internal IPs defined for this instance. This map is keyed with the name of the network interface.
         */
        internalIPs?: {
            [key: string]: Schema$PreservedStatePreservedNetworkIp;
        } | null;
        /**
         * Preserved metadata defined for this instance.
         */
        metadata?: {
            [key: string]: string;
        } | null;
    }
    export interface Schema$PreservedStatePreservedDisk {
        /**
         * These stateful disks will never be deleted during autohealing, update, instance recreate operations. This flag is used to configure if the disk should be deleted after it is no longer used by the group, e.g. when the given instance or the whole MIG is deleted. Note: disks attached in READ_ONLY mode cannot be auto-deleted.
         */
        autoDelete?: string | null;
        /**
         * The mode in which to attach this disk, either READ_WRITE or READ_ONLY. If not specified, the default is to attach the disk in READ_WRITE mode.
         */
        mode?: string | null;
        /**
         * The URL of the disk resource that is stateful and should be attached to the VM instance.
         */
        source?: string | null;
    }
    export interface Schema$PreservedStatePreservedNetworkIp {
        /**
         * These stateful IPs will never be released during autohealing, update or VM instance recreate operations. This flag is used to configure if the IP reservation should be deleted after it is no longer used by the group, e.g. when the given instance or the whole group is deleted.
         */
        autoDelete?: string | null;
        /**
         * Ip address representation
         */
        ipAddress?: Schema$PreservedStatePreservedNetworkIpIpAddress;
    }
    export interface Schema$PreservedStatePreservedNetworkIpIpAddress {
        /**
         * The URL of the reservation for this IP address.
         */
        address?: string | null;
        /**
         * An IPv4 internal network address to assign to the instance for this network interface.
         */
        literal?: string | null;
    }
    /**
     * [Deprecated] All fields defined in a principal are ANDed.
     */
    export interface Schema$Principal {
        /**
         * An expression to specify custom condition.
         */
        condition?: string | null;
        /**
         * The groups the principal belongs to. Exact match, prefix match, and suffix match are supported.
         */
        groups?: string[] | null;
        /**
         * IPv4 or IPv6 address or range (In CIDR format)
         */
        ips?: string[] | null;
        /**
         * The namespaces. Exact match, prefix match, and suffix match are supported.
         */
        namespaces?: string[] | null;
        /**
         * Negate of groups. Specifies exclusions.
         */
        notGroups?: string[] | null;
        /**
         * Negate of IPs. Specifies exclusions.
         */
        notIps?: string[] | null;
        /**
         * Negate of namespaces. Specifies exclusions.
         */
        notNamespaces?: string[] | null;
        /**
         * Negate of users. Specifies exclusions.
         */
        notUsers?: string[] | null;
        /**
         * A map of Istio attribute to expected values. Exact match, prefix match, and suffix match are supported for values. For example, `request.headers[version]: "v1"`. The properties are ANDed together.
         */
        properties?: {
            [key: string]: string;
        } | null;
        /**
         * The user names/IDs or service accounts. Exact match, prefix match, and suffix match are supported.
         */
        users?: string[] | null;
    }
    /**
     * Represents a Project resource. A project is used to organize resources in a Google Cloud Platform environment. For more information, read about the Resource Hierarchy.
     */
    export interface Schema$Project {
        /**
         * Metadata key/value pairs available to all instances contained in this project. See Custom metadata for more information.
         */
        commonInstanceMetadata?: Schema$Metadata;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * This signifies the default network tier used for configuring resources of the project and can only take the following values: PREMIUM, STANDARD. Initially the default network tier is PREMIUM.
         */
        defaultNetworkTier?: string | null;
        /**
         * [Output Only] Default service account used by VMs running in this project.
         */
        defaultServiceAccount?: string | null;
        /**
         * An optional textual description of the resource.
         */
        description?: string | null;
        /**
         * Restricted features enabled for use on this project.
         */
        enabledFeatures?: string[] | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server. This is *not* the project ID, and is just a unique ID used by Compute Engine to identify resources.
         */
        id?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#project for projects.
         */
        kind?: string | null;
        /**
         * [Output Only] The Cloud Armor Managed Protection (CAMP) tier for this project. It can be one of the following values: CA_STANDARD, CAMP_PLUS_MONTHLY. If this field is not specified, it is assumed to be CA_STANDARD.
         */
        managedProtectionTier?: string | null;
        /**
         * The project ID. For example: my-example-project. Use the project ID to make requests to Compute Engine.
         */
        name?: string | null;
        /**
         * [Output Only] Quotas assigned to this project.
         */
        quotas?: Schema$Quota[];
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * The naming prefix for daily usage reports and the Google Cloud Storage bucket where they are stored.
         */
        usageExportLocation?: Schema$UsageExportLocation;
        /**
         * [Output Only] Default internal DNS setting used by VMs running in this project.
         */
        vmDnsSetting?: string | null;
        /**
         * [Output Only] The role this project has in a shared VPC configuration. Currently, only projects with the host role, which is specified by the value HOST, are differentiated.
         */
        xpnProjectStatus?: string | null;
    }
    export interface Schema$ProjectsDisableXpnResourceRequest {
        /**
         * Service resource (a.k.a service project) ID.
         */
        xpnResource?: Schema$XpnResourceId;
    }
    export interface Schema$ProjectsEnableXpnResourceRequest {
        /**
         * Service resource (a.k.a service project) ID.
         */
        xpnResource?: Schema$XpnResourceId;
    }
    export interface Schema$ProjectsGetXpnResources {
        /**
         * [Output Only] Type of resource. Always compute#projectsGetXpnResources for lists of service resources (a.k.a service projects)
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * Service resources (a.k.a service projects) attached to this project as their shared VPC host.
         */
        resources?: Schema$XpnResourceId[];
    }
    export interface Schema$ProjectsListXpnHostsRequest {
        /**
         * Optional organization ID managed by Cloud Resource Manager, for which to list shared VPC host projects. If not specified, the organization will be inferred from the project.
         */
        organization?: string | null;
        /**
         * Opt-in for partial page behavior which provides a partial filled page (number of items on which may be smaller than maxResults) within the API deadline. If opt-in, then the user should rely on if nextPageToken is empty in the response to determine if there is a next page. Empty page is also valid and possible. The default value is false.
         */
        returnPartialPage?: boolean | null;
    }
    export interface Schema$ProjectsSetDefaultNetworkTierRequest {
        /**
         * Default network tier to be set.
         */
        networkTier?: string | null;
    }
    export interface Schema$ProjectsSetDefaultServiceAccountRequest {
        /**
         * Email address of the service account.
         */
        email?: string | null;
    }
    export interface Schema$ProjectsSetManagedProtectionTierRequest {
        /**
         * Managed protection tier to be set.
         */
        managedProtectionTier?: string | null;
    }
    /**
     * A public advertised prefix represents an aggregated IP prefix or netblock which customers bring to cloud. The IP prefix is a single unit of route advertisement and is announced globally to the internet.
     */
    export interface Schema$PublicAdvertisedPrefix {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * The address to be used for reverse DNS verification.
         */
        dnsVerificationIp?: string | null;
        /**
         * Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a new PublicAdvertisedPrefix. An up-to-date fingerprint must be provided in order to update the PublicAdvertisedPrefix, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a PublicAdvertisedPrefix.
         */
        fingerprint?: string | null;
        /**
         * [Output Only] The unique identifier for the resource type. The server generates this identifier.
         */
        id?: string | null;
        /**
         * The address range, in CIDR format, represented by this public advertised prefix.
         */
        ipCidrRange?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#publicAdvertisedPrefix for public advertised prefixes.
         */
        kind?: string | null;
        /**
         * Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * Specifies how child public delegated prefix will be scoped. It could be one of following values: - `REGIONAL`: The public delegated prefix is regional only. The provisioning will take a few minutes. - `GLOBAL`: The public delegated prefix is global only. The provisioning will take ~4 weeks. - `GLOBAL_AND_REGIONAL` [output only]: The public delegated prefixes is BYOIP V1 legacy prefix. This is output only value and no longer supported in BYOIP V2.
         */
        pdpScope?: string | null;
        /**
         * [Output Only] The list of public delegated prefixes that exist for this public advertised prefix.
         */
        publicDelegatedPrefixs?: Schema$PublicAdvertisedPrefixPublicDelegatedPrefix[];
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL with id for the resource.
         */
        selfLinkWithId?: string | null;
        /**
         * [Output Only] The shared secret to be used for reverse DNS verification.
         */
        sharedSecret?: string | null;
        /**
         * The status of the public advertised prefix. Possible values include: - `INITIAL`: RPKI validation is complete. - `PTR_CONFIGURED`: User has configured the PTR. - `VALIDATED`: Reverse DNS lookup is successful. - `REVERSE_DNS_LOOKUP_FAILED`: Reverse DNS lookup failed. - `PREFIX_CONFIGURATION_IN_PROGRESS`: The prefix is being configured. - `PREFIX_CONFIGURATION_COMPLETE`: The prefix is fully configured. - `PREFIX_REMOVAL_IN_PROGRESS`: The prefix is being removed.
         */
        status?: string | null;
    }
    export interface Schema$PublicAdvertisedPrefixList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of PublicAdvertisedPrefix resources.
         */
        items?: Schema$PublicAdvertisedPrefix[];
        /**
         * [Output Only] Type of the resource. Always compute#publicAdvertisedPrefix for public advertised prefixes.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Represents a CIDR range which can be used to assign addresses.
     */
    export interface Schema$PublicAdvertisedPrefixPublicDelegatedPrefix {
        /**
         * The IP address range of the public delegated prefix
         */
        ipRange?: string | null;
        /**
         * The name of the public delegated prefix
         */
        name?: string | null;
        /**
         * The project number of the public delegated prefix
         */
        project?: string | null;
        /**
         * The region of the public delegated prefix if it is regional. If absent, the prefix is global.
         */
        region?: string | null;
        /**
         * The status of the public delegated prefix. Possible values are: INITIALIZING: The public delegated prefix is being initialized and addresses cannot be created yet. ANNOUNCED: The public delegated prefix is active.
         */
        status?: string | null;
    }
    /**
     * A PublicDelegatedPrefix resource represents an IP block within a PublicAdvertisedPrefix that is configured within a single cloud scope (global or region). IPs in the block can be allocated to resources within that scope. Public delegated prefixes may be further broken up into smaller IP blocks in the same scope as the parent block.
     */
    export interface Schema$PublicDelegatedPrefix {
        /**
         * The allocatable prefix length supported by this public delegated prefix. This field is optional and cannot be set for prefixes in DELEGATION mode. It cannot be set for IPv4 prefixes either, and it always defaults to 32.
         */
        allocatablePrefixLength?: number | null;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a new PublicDelegatedPrefix. An up-to-date fingerprint must be provided in order to update the PublicDelegatedPrefix, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a PublicDelegatedPrefix.
         */
        fingerprint?: string | null;
        /**
         * [Output Only] The unique identifier for the resource type. The server generates this identifier.
         */
        id?: string | null;
        /**
         * The IP address range, in CIDR format, represented by this public delegated prefix.
         */
        ipCidrRange?: string | null;
        /**
         * If true, the prefix will be live migrated.
         */
        isLiveMigration?: boolean | null;
        /**
         * [Output Only] Type of the resource. Always compute#publicDelegatedPrefix for public delegated prefixes.
         */
        kind?: string | null;
        /**
         * The public delegated prefix mode for IPv6 only.
         */
        mode?: string | null;
        /**
         * Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * The URL of parent prefix. Either PublicAdvertisedPrefix or PublicDelegatedPrefix.
         */
        parentPrefix?: string | null;
        /**
         * The list of sub public delegated prefixes that exist for this public delegated prefix.
         */
        publicDelegatedSubPrefixs?: Schema$PublicDelegatedPrefixPublicDelegatedSubPrefix[];
        /**
         * [Output Only] URL of the region where the public delegated prefix resides. This field applies only to the region resource. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
         */
        region?: string | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL with id for the resource.
         */
        selfLinkWithId?: string | null;
        /**
         * [Output Only] The status of the public delegated prefix, which can be one of following values: - `INITIALIZING` The public delegated prefix is being initialized and addresses cannot be created yet. - `READY_TO_ANNOUNCE` The public delegated prefix is a live migration prefix and is active. - `ANNOUNCED` The public delegated prefix is active. - `DELETING` The public delegated prefix is being deprovsioned.
         */
        status?: string | null;
    }
    export interface Schema$PublicDelegatedPrefixAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of PublicDelegatedPrefixesScopedList resources.
         */
        items?: {
            [key: string]: Schema$PublicDelegatedPrefixesScopedList;
        } | null;
        /**
         * [Output Only] Type of the resource. Always compute#publicDelegatedPrefixAggregatedList for aggregated lists of public delegated prefixes.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$PublicDelegatedPrefixesScopedList {
        /**
         * [Output Only] A list of PublicDelegatedPrefixes contained in this scope.
         */
        publicDelegatedPrefixes?: Schema$PublicDelegatedPrefix[];
        /**
         * [Output Only] Informational warning which replaces the list of public delegated prefixes when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$PublicDelegatedPrefixList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of PublicDelegatedPrefix resources.
         */
        items?: Schema$PublicDelegatedPrefix[];
        /**
         * [Output Only] Type of the resource. Always compute#publicDelegatedPrefixList for public delegated prefixes.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Represents a sub PublicDelegatedPrefix.
     */
    export interface Schema$PublicDelegatedPrefixPublicDelegatedSubPrefix {
        /**
         * The allocatable prefix length supported by this PublicDelegatedSubPrefix.
         */
        allocatablePrefixLength?: number | null;
        /**
         * Name of the project scoping this PublicDelegatedSubPrefix.
         */
        delegateeProject?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * The IP address range, in CIDR format, represented by this sub public delegated prefix.
         */
        ipCidrRange?: string | null;
        /**
         * Whether the sub prefix is delegated to create Address resources in the delegatee project.
         */
        isAddress?: boolean | null;
        /**
         * The PublicDelegatedSubPrefix mode for IPv6 only.
         */
        mode?: string | null;
        /**
         * The name of the sub public delegated prefix.
         */
        name?: string | null;
        /**
         * [Output Only] The region of the sub public delegated prefix if it is regional. If absent, the sub prefix is global.
         */
        region?: string | null;
        /**
         * [Output Only] The status of the sub public delegated prefix.
         */
        status?: string | null;
    }
    /**
     * QueuedResource represents a request for future capacity. The capacity is delivered in the form of other GCE resources, either Instances or Reservations.
     */
    export interface Schema$QueuedResource {
        /**
         * Specification of VM instances to create.
         */
        bulkInsertInstanceResource?: Schema$BulkInsertInstanceResource;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#queuedResource for QueuedResources.
         */
        kind?: string | null;
        /**
         * Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * Queuing parameters for the requested capacity.
         */
        queuingPolicy?: Schema$QueuingPolicy;
        /**
         * [Output only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * [Output only] High-level status of the request.
         */
        state?: string | null;
        /**
         * [Output only] Result of queuing and provisioning based on deferred capacity.
         */
        status?: Schema$QueuedResourceStatus;
        /**
         * [Output Only] URL of the zone where the resource resides. Only applicable for zonal resources. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
         */
        zone?: string | null;
    }
    export interface Schema$QueuedResourceList {
        /**
         * Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of QueuedResource resources.
         */
        items?: Schema$QueuedResource[];
        /**
         * Type of resource.
         */
        kind?: string | null;
        /**
         * This token allows you to get the next page of results for maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$QueuedResourcesAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of QueuedResourcesScopedList resources.
         */
        items?: {
            [key: string]: Schema$QueuedResourcesScopedList;
        } | null;
        /**
         * [Output Only] Type of resource. Always compute#queuedResourcesAggregatedList for lists of QueuedResource.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$QueuedResourcesScopedList {
        /**
         * List of QueuedResources contained in this scope.
         */
        queuedResources?: Schema$QueuedResource[];
        /**
         * Informational warning which replaces the list of backend services when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * [Output only] Result of queuing and provisioning based on deferred capacity.
     */
    export interface Schema$QueuedResourceStatus {
        /**
         * Additional status detail for the FAILED state.
         */
        failedData?: Schema$QueuedResourceStatusFailedData;
        /**
         * [Output only] Fully qualified URL of the provisioning GCE operation to track the provisioning along with provisioning errors. The referenced operation may not exist after having been deleted or expired.
         */
        provisioningOperations?: string[] | null;
        /**
         * Constraints for the time when the resource(s) start provisioning. Always exposed as absolute times.
         */
        queuingPolicy?: Schema$QueuingPolicy;
    }
    /**
     * Additional status detail for the FAILED state.
     */
    export interface Schema$QueuedResourceStatusFailedData {
        /**
         * The error(s) that caused the QueuedResource to enter the FAILED state.
         */
        error?: {
            errors?: Array<{
                code?: string;
                errorDetails?: Array<{
                    errorInfo?: Schema$ErrorInfo;
                    help?: Schema$Help;
                    localizedMessage?: Schema$LocalizedMessage;
                    quotaInfo?: Schema$QuotaExceededInfo;
                }>;
                location?: string;
                message?: string;
            }>;
        } | null;
    }
    /**
     * Queuing parameters for the requested deferred capacity.
     */
    export interface Schema$QueuingPolicy {
        /**
         * Relative deadline for waiting for capacity.
         */
        validUntilDuration?: Schema$Duration;
        /**
         * Absolute deadline for waiting for capacity in RFC3339 text format.
         */
        validUntilTime?: string | null;
    }
    /**
     * A quotas entry.
     */
    export interface Schema$Quota {
        /**
         * [Output Only] Quota limit for this metric.
         */
        limit?: number | null;
        /**
         * [Output Only] Name of the quota metric.
         */
        metric?: string | null;
        /**
         * [Output Only] Owning resource. This is the resource on which this quota is applied.
         */
        owner?: string | null;
        /**
         * [Output Only] Current usage of this metric.
         */
        usage?: number | null;
    }
    /**
     * Additional details for quota exceeded error for resource quota.
     */
    export interface Schema$QuotaExceededInfo {
        /**
         * The map holding related quota dimensions.
         */
        dimensions?: {
            [key: string]: string;
        } | null;
        /**
         * Future quota limit being rolled out. The limit's unit depends on the quota type or metric.
         */
        futureLimit?: number | null;
        /**
         * Current effective quota limit. The limit's unit depends on the quota type or metric.
         */
        limit?: number | null;
        /**
         * The name of the quota limit.
         */
        limitName?: string | null;
        /**
         * The Compute Engine quota metric name.
         */
        metricName?: string | null;
        /**
         * Rollout status of the future quota limit.
         */
        rolloutStatus?: string | null;
    }
    export interface Schema$RbacPolicy {
        /**
         * Name of the RbacPolicy.
         */
        name?: string | null;
        /**
         * The list of permissions.
         */
        permissions?: Schema$Permission[];
        /**
         * The list of principals.
         */
        principals?: Schema$Principal[];
    }
    /**
     * Represents a reference to a resource.
     */
    export interface Schema$Reference {
        /**
         * [Output Only] Type of the resource. Always compute#reference for references.
         */
        kind?: string | null;
        /**
         * A description of the reference type with no implied semantics. Possible values include: 1. MEMBER_OF
         */
        referenceType?: string | null;
        /**
         * URL of the resource which refers to the target.
         */
        referrer?: string | null;
        /**
         * URL of the resource to which this reference points.
         */
        target?: string | null;
    }
    /**
     * Represents a Region resource. A region is a geographical area where a resource is located. For more information, read Regions and Zones.
     */
    export interface Schema$Region {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * [Output Only] The deprecation status associated with this region.
         */
        deprecated?: Schema$DeprecationStatus;
        /**
         * [Output Only] Textual description of the resource.
         */
        description?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#region for regions.
         */
        kind?: string | null;
        /**
         * [Output Only] Name of the resource.
         */
        name?: string | null;
        /**
         * [Output Only] Quotas assigned to this region.
         */
        quotas?: Schema$Quota[];
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * [Output Only] Status of the region, either UP or DOWN.
         */
        status?: string | null;
        /**
         * [Output Only] Reserved for future use.
         */
        supportsPzs?: boolean | null;
        /**
         * [Output Only] A list of zones available in this region, in the form of resource URLs.
         */
        zones?: string[] | null;
    }
    export interface Schema$RegionAddressesMoveRequest {
        /**
         * An optional destination address description if intended to be different from the source.
         */
        description?: string | null;
        /**
         * The URL of the destination address to move to. This can be a full or partial URL. For example, the following are all valid URLs to a address: - https://www.googleapis.com/compute/v1/projects/project/regions/region /addresses/address - projects/project/regions/region/addresses/address Note that destination project must be different from the source project. So /regions/region/addresses/address is not valid partial url.
         */
        destinationAddress?: string | null;
    }
    /**
     * Contains a list of autoscalers.
     */
    export interface Schema$RegionAutoscalerList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of Autoscaler resources.
         */
        items?: Schema$Autoscaler[];
        /**
         * Type of resource.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$RegionCommitmentsUpdateReservationsRequest {
        /**
         * A list of two reservations to transfer GPUs and local SSD between.
         */
        reservations?: Schema$Reservation[];
    }
    export interface Schema$RegionDisksAddResourcePoliciesRequest {
        /**
         * Resource policies to be added to this disk.
         */
        resourcePolicies?: string[] | null;
    }
    export interface Schema$RegionDisksRemoveResourcePoliciesRequest {
        /**
         * Resource policies to be removed from this disk.
         */
        resourcePolicies?: string[] | null;
    }
    export interface Schema$RegionDisksResizeRequest {
        /**
         * The new size of the regional persistent disk, which is specified in GB.
         */
        sizeGb?: string | null;
    }
    export interface Schema$RegionDisksStartAsyncReplicationRequest {
        /**
         * The secondary disk to start asynchronous replication to. You can provide this as a partial or full URL to the resource. For example, the following are valid values: - https://www.googleapis.com/compute/v1/projects/project/zones/zone /disks/disk - https://www.googleapis.com/compute/v1/projects/project/regions/region /disks/disk - projects/project/zones/zone/disks/disk - projects/project/regions/region/disks/disk - zones/zone/disks/disk - regions/region/disks/disk
         */
        asyncSecondaryDisk?: string | null;
    }
    export interface Schema$RegionDiskTypeList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of DiskType resources.
         */
        items?: Schema$DiskType[];
        /**
         * [Output Only] Type of resource. Always compute#regionDiskTypeList for region disk types.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Contains a list of InstanceGroup resources.
     */
    export interface Schema$RegionInstanceGroupList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of InstanceGroup resources.
         */
        items?: Schema$InstanceGroup[];
        /**
         * The resource type.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * RegionInstanceGroupManagers.deletePerInstanceConfigs
     */
    export interface Schema$RegionInstanceGroupManagerDeleteInstanceConfigReq {
        /**
         * The list of instance names for which we want to delete per-instance configs on this managed instance group.
         */
        names?: string[] | null;
    }
    /**
     * Contains a list of managed instance groups.
     */
    export interface Schema$RegionInstanceGroupManagerList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of InstanceGroupManager resources.
         */
        items?: Schema$InstanceGroupManager[];
        /**
         * [Output Only] The resource type, which is always compute#instanceGroupManagerList for a list of managed instance groups that exist in th regional scope.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * RegionInstanceGroupManagers.patchPerInstanceConfigs
     */
    export interface Schema$RegionInstanceGroupManagerPatchInstanceConfigReq {
        /**
         * The list of per-instance configurations to insert or patch on this managed instance group.
         */
        perInstanceConfigs?: Schema$PerInstanceConfig[];
    }
    export interface Schema$RegionInstanceGroupManagersAbandonInstancesRequest {
        /**
         * The URLs of one or more instances to abandon. This can be a full URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].
         */
        instances?: string[] | null;
    }
    /**
     * RegionInstanceGroupManagers.applyUpdatesToInstances
     */
    export interface Schema$RegionInstanceGroupManagersApplyUpdatesRequest {
        /**
         * Flag to update all instances instead of specified list of “instances”. If the flag is set to true then the instances may not be specified in the request.
         */
        allInstances?: boolean | null;
        /**
         * The list of URLs of one or more instances for which you want to apply updates. Each URL can be a full URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].
         */
        instances?: string[] | null;
        /**
         * The maximal action that should be performed on the instances. By default REPLACE. This field is deprecated, please use most_disruptive_allowed_action.
         */
        maximalAction?: string | null;
        /**
         * The minimal action that you want to perform on each instance during the update: - REPLACE: At minimum, delete the instance and create it again. - RESTART: Stop the instance and start it again. - REFRESH: Do not stop the instance and limit disruption as much as possible. - NONE: Do not disrupt the instance at all. By default, the minimum action is NONE. If your update requires a more disruptive action than you set with this flag, the necessary action is performed to execute the update.
         */
        minimalAction?: string | null;
        /**
         * The most disruptive action that you want to perform on each instance during the update: - REPLACE: Delete the instance and create it again. - RESTART: Stop the instance and start it again. - REFRESH: Do not stop the instance and limit disruption as much as possible. - NONE: Do not disrupt the instance at all. By default, the most disruptive allowed action is REPLACE. If your update requires a more disruptive action than you set with this flag, the update request will fail.
         */
        mostDisruptiveAllowedAction?: string | null;
    }
    /**
     * RegionInstanceGroupManagers.createInstances
     */
    export interface Schema$RegionInstanceGroupManagersCreateInstancesRequest {
        /**
         * [Required] List of specifications of per-instance configs.
         */
        instances?: Schema$PerInstanceConfig[];
    }
    export interface Schema$RegionInstanceGroupManagersDeleteInstancesRequest {
        /**
         * The URLs of one or more instances to delete. This can be a full URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].
         */
        instances?: string[] | null;
        /**
         * Skip instances which cannot be deleted (instances not belonging to this managed group, already being deleted or being abandoned). If `false`, fail whole flow, if such instance is passed. DEPRECATED: Use skip_instances_on_validation_error instead.
         */
        skipInapplicableInstances?: boolean | null;
        /**
         * Specifies whether the request should proceed despite the inclusion of instances that are not members of the group or that are already in the process of being deleted or abandoned. If this field is set to `false` and such an instance is specified in the request, the operation fails. The operation always fails if the request contains a malformed instance URL or a reference to an instance that exists in a zone or region other than the group's zone or region.
         */
        skipInstancesOnValidationError?: boolean | null;
    }
    export interface Schema$RegionInstanceGroupManagersListErrorsResponse {
        /**
         * [Output Only] The list of errors of the managed instance group.
         */
        items?: Schema$InstanceManagedByIgmError[];
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
    }
    export interface Schema$RegionInstanceGroupManagersListInstanceConfigsResp {
        /**
         * [Output Only] The list of PerInstanceConfig.
         */
        items?: Schema$PerInstanceConfig[];
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$RegionInstanceGroupManagersListInstancesResponse {
        /**
         * A list of managed instances.
         */
        managedInstances?: Schema$ManagedInstance[];
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
    }
    export interface Schema$RegionInstanceGroupManagersRecreateRequest {
        /**
         * The URLs of one or more instances to recreate. This can be a full URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].
         */
        instances?: string[] | null;
    }
    export interface Schema$RegionInstanceGroupManagersResizeAdvancedRequest {
        /**
         * If this flag is true, the managed instance group attempts to create all instances initiated by this resize request only once. If there is an error during creation, the managed instance group does not retry create this instance, and we will decrease the targetSize of the request instead. If the flag is false, the group attempts to recreate each instance continuously until it succeeds. This flag matters only in the first attempt of creation of an instance. After an instance is successfully created while this flag is enabled, the instance behaves the same way as all the other instances created with a regular resize request. In particular, if a running instance dies unexpectedly at a later time and needs to be recreated, this mode does not affect the recreation behavior in that scenario. This flag is applicable only to the current resize request. It does not influence other resize requests in any way. You can see which instances ar being created in which mode by calling the get or listManagedInstances API.
         */
        noCreationRetries?: boolean | null;
        /**
         * The number of running instances that the managed instance group should maintain at any given time. The group automatically adds or removes instances to maintain the number of instances specified by this parameter.
         */
        targetSize?: number | null;
    }
    export interface Schema$RegionInstanceGroupManagersResumeInstancesRequest {
        /**
         * The URLs of one or more instances to resume. This can be a full URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].
         */
        instances?: string[] | null;
    }
    export interface Schema$RegionInstanceGroupManagersSetAutoHealingRequest {
        autoHealingPolicies?: Schema$InstanceGroupManagerAutoHealingPolicy[];
    }
    export interface Schema$RegionInstanceGroupManagersSetTargetPoolsRequest {
        /**
         * Fingerprint of the target pools information, which is a hash of the contents. This field is used for optimistic locking when you update the target pool entries. This field is optional.
         */
        fingerprint?: string | null;
        /**
         * The URL of all TargetPool resources to which instances in the instanceGroup field are added. The target pools automatically apply to all of the instances in the managed instance group.
         */
        targetPools?: string[] | null;
    }
    export interface Schema$RegionInstanceGroupManagersSetTemplateRequest {
        /**
         * URL of the InstanceTemplate resource from which all new instances will be created.
         */
        instanceTemplate?: string | null;
    }
    export interface Schema$RegionInstanceGroupManagersStartInstancesRequest {
        /**
         * The URLs of one or more instances to start. This can be a full URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].
         */
        instances?: string[] | null;
    }
    export interface Schema$RegionInstanceGroupManagersStopInstancesRequest {
        /**
         * If this flag is set to true, the Instance Group Manager will proceed to stop the instances, skipping initialization on them.
         */
        forceStop?: boolean | null;
        /**
         * The URLs of one or more instances to stop. This can be a full URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].
         */
        instances?: string[] | null;
    }
    export interface Schema$RegionInstanceGroupManagersSuspendInstancesRequest {
        /**
         * If this flag is set to true, the Instance Group Manager will proceed to suspend the instances, skipping initialization on them.
         */
        forceSuspend?: boolean | null;
        /**
         * The URLs of one or more instances to suspend. This can be a full URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].
         */
        instances?: string[] | null;
    }
    /**
     * RegionInstanceGroupManagers.updatePerInstanceConfigs
     */
    export interface Schema$RegionInstanceGroupManagerUpdateInstanceConfigReq {
        /**
         * The list of per-instance configurations to insert or patch on this managed instance group.
         */
        perInstanceConfigs?: Schema$PerInstanceConfig[];
    }
    export interface Schema$RegionInstanceGroupsListInstances {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of InstanceWithNamedPorts resources.
         */
        items?: Schema$InstanceWithNamedPorts[];
        /**
         * The resource type.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$RegionInstanceGroupsListInstancesRequest {
        /**
         * Instances in which state should be returned. Valid options are: 'ALL', 'RUNNING'. By default, it lists all instances.
         */
        instanceState?: string | null;
        /**
         * Name of port user is interested in. It is optional. If it is set, only information about this ports will be returned. If it is not set, all the named ports will be returned. Always lists all instances.
         */
        portName?: string | null;
    }
    export interface Schema$RegionInstanceGroupsSetNamedPortsRequest {
        /**
         * The fingerprint of the named ports information for this instance group. Use this optional property to prevent conflicts when multiple users change the named ports settings concurrently. Obtain the fingerprint with the instanceGroups.get method. Then, include the fingerprint in your request to ensure that you do not overwrite changes that were applied from another concurrent request.
         */
        fingerprint?: string | null;
        /**
         * The list of named ports to set for this instance group.
         */
        namedPorts?: Schema$NamedPort[];
    }
    export interface Schema$RegionInstantSnapshotsExportRequest {
        /**
         * Parameters to export the changed blocks.
         */
        exportParams?: Schema$InstantSnapshotExportParams;
    }
    /**
     * Contains a list of region resources.
     */
    export interface Schema$RegionList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of Region resources.
         */
        items?: Schema$Region[];
        /**
         * [Output Only] Type of resource. Always compute#regionList for lists of regions.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$RegionNetworkEndpointGroupsAttachEndpointsRequest {
        /**
         * The list of network endpoints to be attached.
         */
        networkEndpoints?: Schema$NetworkEndpoint[];
    }
    export interface Schema$RegionNetworkEndpointGroupsDetachEndpointsRequest {
        /**
         * The list of network endpoints to be detached.
         */
        networkEndpoints?: Schema$NetworkEndpoint[];
    }
    export interface Schema$RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse {
        /**
         * Effective firewalls from firewall policy.
         */
        firewallPolicys?: Schema$RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy[];
        /**
         * Effective firewalls on the network.
         */
        firewalls?: Schema$Firewall[];
    }
    export interface Schema$RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy {
        /**
         * [Output Only] The display name of the firewall policy.
         */
        displayName?: string | null;
        /**
         * [Output Only] The name of the firewall policy.
         */
        name?: string | null;
        /**
         * The rules that apply to the network.
         */
        rules?: Schema$FirewallPolicyRule[];
        /**
         * [Output Only] The type of the firewall policy. Can be one of HIERARCHY, NETWORK, NETWORK_REGIONAL.
         */
        type?: string | null;
    }
    export interface Schema$RegionSetLabelsRequest {
        /**
         * The fingerprint of the previous set of labels for this resource, used to detect conflicts. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels. Make a get() request to the resource to get the latest fingerprint.
         */
        labelFingerprint?: string | null;
        /**
         * The labels to set for this resource.
         */
        labels?: {
            [key: string]: string;
        } | null;
    }
    export interface Schema$RegionSetPolicyRequest {
        /**
         * Flatten Policy to create a backwacd compatible wire-format. Deprecated. Use 'policy' to specify bindings.
         */
        bindings?: Schema$Binding[];
        /**
         * Flatten Policy to create a backward compatible wire-format. Deprecated. Use 'policy' to specify the etag.
         */
        etag?: string | null;
        /**
         * REQUIRED: The complete policy to be applied to the 'resource'. The size of the policy is limited to a few 10s of KB. An empty policy is in general a valid policy but certain services (like Projects) might reject them.
         */
        policy?: Schema$Policy;
    }
    export interface Schema$RegionTargetHttpsProxiesSetSslCertificatesRequest {
        /**
         * New set of SslCertificate resources to associate with this TargetHttpsProxy resource.
         */
        sslCertificates?: string[] | null;
    }
    export interface Schema$RegionUrlMapsValidateRequest {
        /**
         * Content of the UrlMap to be validated.
         */
        resource?: Schema$UrlMap;
    }
    /**
     * A policy that specifies how requests intended for the route's backends are shadowed to a separate mirrored backend service. The load balancer doesn't wait for responses from the shadow service. Before sending traffic to the shadow service, the host or authority header is suffixed with -shadow.
     */
    export interface Schema$RequestMirrorPolicy {
        /**
         * The full or partial URL to the BackendService resource being mirrored to. The backend service configured for a mirroring policy must reference backends that are of the same type as the original backend service matched in the URL map. Serverless NEG backends are not currently supported as a mirrored backend service.
         */
        backendService?: string | null;
    }
    /**
     * Represents a reservation resource. A reservation ensures that capacity is held in a specific zone even if the reserved VMs are not running. For more information, read Reserving zonal resources.
     */
    export interface Schema$Reservation {
        /**
         * Reservation for aggregated resources, providing shape flexibility.
         */
        aggregateReservation?: Schema$AllocationAggregateReservation;
        /**
         * [Output Only] Full or partial URL to a parent commitment. This field displays for reservations that are tied to a commitment.
         */
        commitment?: string | null;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * Duration time relative to reservation creation when GCE will automatically delete this resource.
         */
        deleteAfterDuration?: Schema$Duration;
        /**
         * Absolute time in future when the reservation will be auto-deleted by GCE. Timestamp is represented in RFC3339 text format.
         */
        deleteAtTime?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#reservations for reservations.
         */
        kind?: string | null;
        /**
         * The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * Resource policies to be added to this reservation. The key is defined by user, and the value is resource policy url. This is to define placement policy with reservation.
         */
        resourcePolicies?: {
            [key: string]: string;
        } | null;
        /**
         * [Output Only] Status information for Reservation resource.
         */
        resourceStatus?: Schema$AllocationResourceStatus;
        /**
         * [Output Only] Reserved for future use.
         */
        satisfiesPzs?: boolean | null;
        /**
         * [Output Only] Server-defined fully-qualified URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * Specify share-settings to create a shared reservation. This property is optional. For more information about the syntax and options for this field and its subfields, see the guide for creating a shared reservation.
         */
        shareSettings?: Schema$ShareSettings;
        /**
         * Reservation for instances with specific machine shapes.
         */
        specificReservation?: Schema$AllocationSpecificSKUReservation;
        /**
         * Indicates whether the reservation can be consumed by VMs with affinity for "any" reservation. If the field is set, then only VMs that target the reservation by name can consume from this reservation.
         */
        specificReservationRequired?: boolean | null;
        /**
         * [Output Only] The status of the reservation.
         */
        status?: string | null;
        /**
         * Zone in which the reservation resides. A zone must be provided if the reservation is created within a commitment.
         */
        zone?: string | null;
    }
    /**
     * Specifies the reservations that this instance can consume from.
     */
    export interface Schema$ReservationAffinity {
        /**
         * Specifies the type of reservation from which this instance can consume resources: ANY_RESERVATION (default), SPECIFIC_RESERVATION, or NO_RESERVATION. See Consuming reserved instances for examples.
         */
        consumeReservationType?: string | null;
        /**
         * Corresponds to the label key of a reservation resource. To target a SPECIFIC_RESERVATION by name, specify googleapis.com/reservation-name as the key and specify the name of your reservation as its value.
         */
        key?: string | null;
        /**
         * Corresponds to the label values of a reservation resource. This can be either a name to a reservation in the same project or "projects/different-project/reservations/some-reservation-name" to target a shared reservation in the same zone but in a different project.
         */
        values?: string[] | null;
    }
    /**
     * Contains a list of reservations.
     */
    export interface Schema$ReservationAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of Allocation resources.
         */
        items?: {
            [key: string]: Schema$ReservationsScopedList;
        } | null;
        /**
         * Type of resource.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$ReservationList {
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] A list of Allocation resources.
         */
        items?: Schema$Reservation[];
        /**
         * [Output Only] Type of resource.Always compute#reservationsList for listsof reservations
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$ReservationsResizeRequest {
        /**
         * Number of allocated resources can be resized with minimum = 1 and maximum = 1000.
         */
        specificSkuCount?: string | null;
    }
    export interface Schema$ReservationsScopedList {
        /**
         * A list of reservations contained in this scope.
         */
        reservations?: Schema$Reservation[];
        /**
         * Informational warning which replaces the list of reservations when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Commitment for a particular resource (a Commitment is composed of one or more of these).
     */
    export interface Schema$ResourceCommitment {
        /**
         * Name of the accelerator type resource. Applicable only when the type is ACCELERATOR.
         */
        acceleratorType?: string | null;
        /**
         * The amount of the resource purchased (in a type-dependent unit, such as bytes). For vCPUs, this can just be an integer. For memory, this must be provided in MB. Memory must be a multiple of 256 MB, with up to 6.5GB of memory per every vCPU.
         */
        amount?: string | null;
        /**
         * Type of resource for which this commitment applies. Possible values are VCPU, MEMORY, LOCAL_SSD, and ACCELERATOR.
         */
        type?: string | null;
    }
    export interface Schema$ResourceGroupReference {
        /**
         * A URI referencing one of the instance groups or network endpoint groups listed in the backend service.
         */
        group?: string | null;
    }
    export interface Schema$ResourcePoliciesScopedList {
        /**
         * A list of resourcePolicies contained in this scope.
         */
        resourcePolicies?: Schema$ResourcePolicy[];
        /**
         * Informational warning which replaces the list of resourcePolicies when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Represents a Resource Policy resource. You can use resource policies to schedule actions for some Compute Engine resources. For example, you can use them to schedule persistent disk snapshots.
     */
    export interface Schema$ResourcePolicy {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        description?: string | null;
        /**
         * Resource policy for disk consistency groups.
         */
        diskConsistencyGroupPolicy?: Schema$ResourcePolicyDiskConsistencyGroupPolicy;
        /**
         * Resource policy for instances for placement configuration.
         */
        groupPlacementPolicy?: Schema$ResourcePolicyGroupPlacementPolicy;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * Resource policy for scheduling instance operations.
         */
        instanceSchedulePolicy?: Schema$ResourcePolicyInstanceSchedulePolicy;
        /**
         * [Output Only] Type of the resource. Always compute#resource_policies for resource policies.
         */
        kind?: string | null;
        /**
         * The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        region?: string | null;
        /**
         * [Output Only] The system status of the resource policy.
         */
        resourceStatus?: Schema$ResourcePolicyResourceStatus;
        /**
         * [Output Only] Server-defined fully-qualified URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * Resource policy for persistent disks for creating snapshots.
         */
        snapshotSchedulePolicy?: Schema$ResourcePolicySnapshotSchedulePolicy;
        /**
         * [Output Only] The status of resource policy creation.
         */
        status?: string | null;
        /**
         * Resource policy applicable to VMs for infrastructure maintenance.
         */
        vmMaintenancePolicy?: Schema$ResourcePolicyVmMaintenancePolicy;
    }
    /**
     * Contains a list of resourcePolicies.
     */
    export interface Schema$ResourcePolicyAggregatedList {
        etag?: string | null;
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of ResourcePolicy resources.
         */
        items?: {
            [key: string]: Schema$ResourcePoliciesScopedList;
        } | null;
        /**
         * Type of resource.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Time window specified for daily operations.
     */
    export interface Schema$ResourcePolicyDailyCycle {
        /**
         * Defines a schedule with units measured in days. The value determines how many days pass between the start of each cycle.
         */
        daysInCycle?: number | null;
        /**
         * [Output only] A predetermined duration for the window, automatically chosen to be the smallest possible in the given scenario.
         */
        duration?: string | null;
        /**
         * Start time of the window. This must be in UTC format that resolves to one of 00:00, 04:00, 08:00, 12:00, 16:00, or 20:00. For example, both 13:00-5 and 08:00 are valid.
         */
        startTime?: string | null;
    }
    /**
     * Resource policy for disk consistency groups.
     */
    export interface Schema$ResourcePolicyDiskConsistencyGroupPolicy {
    }
    /**
     * A GroupPlacementPolicy specifies resource placement configuration. It specifies the failure bucket separation as well as network locality
     */
    export interface Schema$ResourcePolicyGroupPlacementPolicy {
        /**
         * The number of availability domains to spread instances across. If two instances are in different availability domain, they are not in the same low latency network.
         */
        availabilityDomainCount?: number | null;
        /**
         * Specifies network collocation
         */
        collocation?: string | null;
        /**
         * Specifies network locality
         */
        locality?: string | null;
        /**
         * Specifies the number of max logical switches.
         */
        maxDistance?: number | null;
        /**
         * Scope specifies the availability domain to which the VMs should be spread.
         */
        scope?: string | null;
        /**
         * Specifies the number of slices in a multislice workload.
         */
        sliceCount?: number | null;
        /**
         * Specifies instances to hosts placement relationship
         */
        style?: string | null;
        /**
         * Specifies the shape of the TPU slice
         */
        tpuTopology?: string | null;
        /**
         * Number of VMs in this placement group. Google does not recommend that you use this field unless you use a compact policy and you want your policy to work only if it contains this exact number of VMs.
         */
        vmCount?: number | null;
    }
    /**
     * Time window specified for hourly operations.
     */
    export interface Schema$ResourcePolicyHourlyCycle {
        /**
         * [Output only] Duration of the time window, automatically chosen to be smallest possible in the given scenario.
         */
        duration?: string | null;
        /**
         * Defines a schedule with units measured in hours. The value determines how many hours pass between the start of each cycle.
         */
        hoursInCycle?: number | null;
        /**
         * Time within the window to start the operations. It must be in format "HH:MM", where HH : [00-23] and MM : [00-00] GMT.
         */
        startTime?: string | null;
    }
    /**
     * An InstanceSchedulePolicy specifies when and how frequent certain operations are performed on the instance.
     */
    export interface Schema$ResourcePolicyInstanceSchedulePolicy {
        /**
         * The expiration time of the schedule. The timestamp is an RFC3339 string.
         */
        expirationTime?: string | null;
        /**
         * The start time of the schedule. The timestamp is an RFC3339 string.
         */
        startTime?: string | null;
        /**
         * Specifies the time zone to be used in interpreting Schedule.schedule. The value of this field must be a time zone name from the tz database: https://wikipedia.org/wiki/Tz_database.
         */
        timeZone?: string | null;
        /**
         * Specifies the schedule for starting instances.
         */
        vmStartSchedule?: Schema$ResourcePolicyInstanceSchedulePolicySchedule;
        /**
         * Specifies the schedule for stopping instances.
         */
        vmStopSchedule?: Schema$ResourcePolicyInstanceSchedulePolicySchedule;
    }
    /**
     * Schedule for an instance operation.
     */
    export interface Schema$ResourcePolicyInstanceSchedulePolicySchedule {
        /**
         * Specifies the frequency for the operation, using the unix-cron format.
         */
        schedule?: string | null;
    }
    export interface Schema$ResourcePolicyList {
        etag?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] A list of ResourcePolicy resources.
         */
        items?: Schema$ResourcePolicy[];
        /**
         * [Output Only] Type of resource.Always compute#resourcePoliciesList for listsof resourcePolicies
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Contains output only fields. Use this sub-message for all output fields set on ResourcePolicy. The internal structure of this "status" field should mimic the structure of ResourcePolicy proto specification.
     */
    export interface Schema$ResourcePolicyResourceStatus {
        /**
         * [Output Only] Specifies a set of output values reffering to the instance_schedule_policy system status. This field should have the same name as corresponding policy field.
         */
        instanceSchedulePolicy?: Schema$ResourcePolicyResourceStatusInstanceSchedulePolicyStatus;
    }
    export interface Schema$ResourcePolicyResourceStatusInstanceSchedulePolicyStatus {
        /**
         * [Output Only] The last time the schedule successfully ran. The timestamp is an RFC3339 string.
         */
        lastRunStartTime?: string | null;
        /**
         * [Output Only] The next time the schedule is planned to run. The actual time might be slightly different. The timestamp is an RFC3339 string.
         */
        nextRunStartTime?: string | null;
    }
    /**
     * A snapshot schedule policy specifies when and how frequently snapshots are to be created for the target disk. Also specifies how many and how long these scheduled snapshots should be retained.
     */
    export interface Schema$ResourcePolicySnapshotSchedulePolicy {
        /**
         * Retention policy applied to snapshots created by this resource policy.
         */
        retentionPolicy?: Schema$ResourcePolicySnapshotSchedulePolicyRetentionPolicy;
        /**
         * A Vm Maintenance Policy specifies what kind of infrastructure maintenance we are allowed to perform on this VM and when. Schedule that is applied to disks covered by this policy.
         */
        schedule?: Schema$ResourcePolicySnapshotSchedulePolicySchedule;
        /**
         * Properties with which snapshots are created such as labels, encryption keys.
         */
        snapshotProperties?: Schema$ResourcePolicySnapshotSchedulePolicySnapshotProperties;
    }
    /**
     * Policy for retention of scheduled snapshots.
     */
    export interface Schema$ResourcePolicySnapshotSchedulePolicyRetentionPolicy {
        /**
         * Maximum age of the snapshot that is allowed to be kept.
         */
        maxRetentionDays?: number | null;
        onPolicySwitch?: string | null;
        /**
         * Specifies the behavior to apply to scheduled snapshots when the source disk is deleted.
         */
        onSourceDiskDelete?: string | null;
    }
    /**
     * A schedule for disks where the schedueled operations are performed.
     */
    export interface Schema$ResourcePolicySnapshotSchedulePolicySchedule {
        dailySchedule?: Schema$ResourcePolicyDailyCycle;
        hourlySchedule?: Schema$ResourcePolicyHourlyCycle;
        weeklySchedule?: Schema$ResourcePolicyWeeklyCycle;
    }
    /**
     * Specified snapshot properties for scheduled snapshots created by this policy.
     */
    export interface Schema$ResourcePolicySnapshotSchedulePolicySnapshotProperties {
        /**
         * Chain name that the snapshot is created in.
         */
        chainName?: string | null;
        /**
         * Indication to perform a 'guest aware' snapshot.
         */
        guestFlush?: boolean | null;
        /**
         * Labels to apply to scheduled snapshots. These can be later modified by the setLabels method. Label values may be empty.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * Cloud Storage bucket storage location of the auto snapshot (regional or multi-regional).
         */
        storageLocations?: string[] | null;
    }
    export interface Schema$ResourcePolicyVmMaintenancePolicy {
        concurrencyControlGroup?: Schema$ResourcePolicyVmMaintenancePolicyConcurrencyControl;
        /**
         * Maintenance windows that are applied to VMs covered by this policy.
         */
        maintenanceWindow?: Schema$ResourcePolicyVmMaintenancePolicyMaintenanceWindow;
    }
    /**
     * A concurrency control configuration. Defines a group config that, when attached to an instance, recognizes that instance as part of a group of instances where only up the concurrency_limit of instances in that group can undergo simultaneous maintenance. For more information: go/concurrency-control-design-doc
     */
    export interface Schema$ResourcePolicyVmMaintenancePolicyConcurrencyControl {
        concurrencyLimit?: number | null;
    }
    /**
     * A maintenance window for VMs. When set, we restrict our maintenance operations to this window.
     */
    export interface Schema$ResourcePolicyVmMaintenancePolicyMaintenanceWindow {
        dailyMaintenanceWindow?: Schema$ResourcePolicyDailyCycle;
    }
    /**
     * Time window specified for weekly operations.
     */
    export interface Schema$ResourcePolicyWeeklyCycle {
        /**
         * Up to 7 intervals/windows, one for each day of the week.
         */
        dayOfWeeks?: Schema$ResourcePolicyWeeklyCycleDayOfWeek[];
    }
    export interface Schema$ResourcePolicyWeeklyCycleDayOfWeek {
        /**
         * Defines a schedule that runs on specific days of the week. Specify one or more days. The following options are available: MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY.
         */
        day?: string | null;
        /**
         * [Output only] Duration of the time window, automatically chosen to be smallest possible in the given scenario.
         */
        duration?: string | null;
        /**
         * Time within the window to start the operations. It must be in format "HH:MM", where HH : [00-23] and MM : [00-00] GMT.
         */
        startTime?: string | null;
    }
    /**
     * Contains output only fields. Use this sub-message for actual values set on Instance attributes as compared to the value requested by the user (intent) in their instance CRUD calls.
     */
    export interface Schema$ResourceStatus {
        /**
         * [Output Only] An opaque ID of the host on which the VM is running.
         */
        physicalHost?: string | null;
        scheduling?: Schema$ResourceStatusScheduling;
        /**
         * [Output Only] Represents the status of the service integration specs defined by the user in instance.serviceIntegrationSpecs.
         */
        serviceIntegrationStatuses?: {
            [key: string]: Schema$ResourceStatusServiceIntegrationStatus;
        } | null;
    }
    export interface Schema$ResourceStatusScheduling {
        /**
         * Specifies the availability domain (AD), which this instance should be scheduled on. The AD belongs to the spread GroupPlacementPolicy resource policy that has been assigned to the instance. Specify a value between 1-max count of availability domains in your GroupPlacementPolicy. See go/placement-policy-extension for more details.
         */
        availabilityDomain?: number | null;
        /**
         * Time in future when the instance will be terminated in RFC3339 text format.
         */
        terminationTimestamp?: string | null;
    }
    /**
     * Represents the status of integration between instance and another service. See go/gce-backupdr-design for more details.
     */
    export interface Schema$ResourceStatusServiceIntegrationStatus {
        backupDr?: Schema$ResourceStatusServiceIntegrationStatusBackupDRStatus;
    }
    /**
     * Message defining compute perspective of the result of integration with Backup and DR. FAILED status indicates that the operation specified did not complete correctly and should be retried with the same value.
     */
    export interface Schema$ResourceStatusServiceIntegrationStatusBackupDRStatus {
        /**
         * The PlanReference object created by Backup and DR to maintain the actual status of backups. May still be present if removing the backup plan fails.
         */
        integrationDetails?: string | null;
        /**
         * Enum representing the registration state of a Backup and DR backup plan for the instance.
         */
        state?: string | null;
    }
    /**
     * A rollout policy configuration.
     */
    export interface Schema$RolloutPolicy {
        /**
         * An optional RFC3339 timestamp on or after which the update is considered rolled out to any zone that is not explicitly stated.
         */
        defaultRolloutTime?: string | null;
        /**
         * Location based rollout policies to apply to the resource. Currently only zone names are supported and must be represented as valid URLs, like: zones/us-central1-a. The value expects an RFC3339 timestamp on or after which the update is considered rolled out to the specified location.
         */
        locationRolloutPolicies?: {
            [key: string]: string;
        } | null;
    }
    /**
     * Represents a Route resource. A route defines a path from VM instances in the VPC network to a specific destination. This destination can be inside or outside the VPC network. For more information, read the Routes overview.
     */
    export interface Schema$Route {
        /**
         * Whether this route can conflict with existing subnetworks. Setting this to true allows this route to conflict with subnetworks that have already been configured on the corresponding network.
         */
        allowConflictingSubnetworks?: boolean | null;
        /**
         * [Output Only] AS path.
         */
        asPaths?: Schema$RouteAsPath[];
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this field when you create the resource.
         */
        description?: string | null;
        /**
         * The destination range of outgoing packets that this route applies to. Both IPv4 and IPv6 are supported. Must specify an IPv4 range (e.g. 192.0.2.0/24) or an IPv6 range in RFC 4291 format (e.g. 2001:db8::/32). IPv6 range will be displayed using RFC 5952 compressed format.
         */
        destRange?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * ILB route behavior when ILB is deemed unhealthy based on user specified threshold on the Backend Service of the internal load balancing.
         */
        ilbRouteBehaviorOnUnhealthy?: string | null;
        /**
         * [Output Only] Type of this resource. Always compute#routes for Route resources.
         */
        kind?: string | null;
        /**
         * Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?`. The first character must be a lowercase letter, and all following characters (except for the last character) must be a dash, lowercase letter, or digit. The last character must be a lowercase letter or digit.
         */
        name?: string | null;
        /**
         * Fully-qualified URL of the network that this route applies to.
         */
        network?: string | null;
        /**
         * The URL to a gateway that should handle matching packets. You can only specify the internet gateway using a full or partial valid URL: projects/ project/global/gateways/default-internet-gateway
         */
        nextHopGateway?: string | null;
        /**
         * [Output Only] The full resource name of the Network Connectivity Center hub that will handle matching packets.
         */
        nextHopHub?: string | null;
        /**
         * The URL to a forwarding rule of type loadBalancingScheme=INTERNAL that should handle matching packets or the IP address of the forwarding Rule. For example, the following are all valid URLs: - 10.128.0.56 - https://www.googleapis.com/compute/v1/projects/project/regions/region /forwardingRules/forwardingRule - regions/region/forwardingRules/forwardingRule
         */
        nextHopIlb?: string | null;
        /**
         * The URL to an instance that should handle matching packets. You can specify this as a full or partial URL. For example: https://www.googleapis.com/compute/v1/projects/project/zones/zone/instances/
         */
        nextHopInstance?: string | null;
        /**
         * [Output Only] The URL to an InterconnectAttachment which is the next hop for the route. This field will only be populated for the dynamic routes generated by Cloud Router with a linked interconnectAttachment.
         */
        nextHopInterconnectAttachment?: string | null;
        /**
         * The network IP address of an instance that should handle matching packets. Both IPv6 address and IPv4 addresses are supported. Must specify an IPv4 address in dot-decimal notation (e.g. 192.0.2.99) or an IPv6 address in RFC 4291 format (e.g. 2001:db8::2d9:51:0:0 or 2001:db8:0:0:2d9:51:0:0). IPv6 addresses will be displayed using RFC 5952 compressed format (e.g. 2001:db8::2d9:51:0:0). Should never be an IPv4-mapped IPv6 address.
         */
        nextHopIp?: string | null;
        /**
         * The URL of the local network if it should handle matching packets.
         */
        nextHopNetwork?: string | null;
        /**
         * [Output Only] The network peering name that should handle matching packets, which should conform to RFC1035.
         */
        nextHopPeering?: string | null;
        /**
         * The URL to a VpnTunnel that should handle matching packets.
         */
        nextHopVpnTunnel?: string | null;
        /**
         * The priority of this route. Priority is used to break ties in cases where there is more than one matching route of equal prefix length. In cases where multiple routes have equal prefix length, the one with the lowest-numbered priority value wins. The default value is `1000`. The priority value must be from `0` to `65535`, inclusive.
         */
        priority?: number | null;
        /**
         * [Output only] The status of the route.
         */
        routeStatus?: string | null;
        /**
         * [Output Only] The type of this route, which can be one of the following values: - 'TRANSIT' for a transit route that this router learned from another Cloud Router and will readvertise to one of its BGP peers - 'SUBNET' for a route from a subnet of the VPC - 'BGP' for a route learned from a BGP peer of this router - 'STATIC' for a static route
         */
        routeType?: string | null;
        /**
         * [Output Only] Server-defined fully-qualified URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * A list of instance tags to which this route applies.
         */
        tags?: string[] | null;
        /**
         * [Output Only] If potential misconfigurations are detected for this route, this field will be populated with warning messages.
         */
        warnings?: Array<{
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        }> | null;
    }
    export interface Schema$RouteAsPath {
        /**
         * [Output Only] The AS numbers of the AS Path.
         */
        asLists?: number[] | null;
        /**
         * [Output Only] The type of the AS Path, which can be one of the following values: - 'AS_SET': unordered set of autonomous systems that the route in has traversed - 'AS_SEQUENCE': ordered set of autonomous systems that the route has traversed - 'AS_CONFED_SEQUENCE': ordered set of Member Autonomous Systems in the local confederation that the route has traversed - 'AS_CONFED_SET': unordered set of Member Autonomous Systems in the local confederation that the route has traversed
         */
        pathSegmentType?: string | null;
    }
    /**
     * Contains a list of Route resources.
     */
    export interface Schema$RouteList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of Route resources.
         */
        items?: Schema$Route[];
        /**
         * Type of resource.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$RoutePolicy {
        /**
         * A fingerprint for the Route Policy being applied to this Router, which is essentially a hash of the Route Policy used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update Route Policy. You must always provide an up-to-date fingerprint hash in order to update or change labels. To see the latest fingerprint, make a getRoutePolicy() request to retrieve a Route Policy.
         */
        fingerprint?: string | null;
        /**
         * Route Policy name, which must be a resource ID segment and unique within all the router's Route Policies. Name should conform to RFC1035.
         */
        name?: string | null;
        /**
         * List of terms (the order in the list is not important, they are evaluated in order of priority). Order of policies is not retained and might change when getting policy later.
         */
        terms?: Schema$RoutePolicyPolicyTerm[];
        type?: string | null;
    }
    export interface Schema$RoutePolicyPolicyTerm {
        /**
         * CEL expressions to evaluate to modify a route when this term matches.
         */
        actions?: Schema$Expr[];
        /**
         * CEL expression evaluated against a route to determine if this term applies. When not set, the term applies to all routes.
         */
        match?: Schema$Expr;
        /**
         * The evaluation priority for this term, which must be between 0 (inclusive) and 2^31 (exclusive), and unique within the list.
         */
        priority?: number | null;
    }
    /**
     * Represents a Cloud Router resource. For more information about Cloud Router, read the Cloud Router overview.
     */
    export interface Schema$Router {
        /**
         * BGP information specific to this router.
         */
        bgp?: Schema$RouterBgp;
        /**
         * BGP information that must be configured into the routing stack to establish BGP peering. This information must specify the peer ASN and either the interface name, IP address, or peer IP address. Please refer to RFC4273.
         */
        bgpPeers?: Schema$RouterBgpPeer[];
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * Indicates if a router is dedicated for use with encrypted VLAN attachments (interconnectAttachments).
         */
        encryptedInterconnectRouter?: boolean | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * Router interfaces. To create a BGP peer that uses a router interface, the interface must have one of the following fields specified: - linkedVpnTunnel - linkedInterconnectAttachment - subnetwork You can create a router interface without any of these fields specified. However, you cannot create a BGP peer that uses that interface.
         */
        interfaces?: Schema$RouterInterface[];
        /**
         * [Output Only] Type of resource. Always compute#router for routers.
         */
        kind?: string | null;
        /**
         * Keys used for MD5 authentication.
         */
        md5AuthenticationKeys?: Schema$RouterMd5AuthenticationKey[];
        /**
         * Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * A list of NAT services created in this router.
         */
        nats?: Schema$RouterNat[];
        /**
         * URI of the network to which this router belongs.
         */
        network?: string | null;
        /**
         * [Output Only] URI of the region where the router resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
         */
        region?: string | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
    }
    /**
     * Description-tagged IP ranges for the router to advertise.
     */
    export interface Schema$RouterAdvertisedIpRange {
        /**
         * User-specified description for the IP range.
         */
        description?: string | null;
        /**
         * The IP range to advertise. The value must be a CIDR-formatted string.
         */
        range?: string | null;
    }
    /**
     * Contains a list of routers.
     */
    export interface Schema$RouterAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of Router resources.
         */
        items?: {
            [key: string]: Schema$RoutersScopedList;
        } | null;
        /**
         * Type of resource.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$RouterBgp {
        /**
         * User-specified list of prefix groups to advertise in custom mode. This field can only be populated if advertise_mode is CUSTOM and is advertised to all peers of the router. These groups will be advertised in addition to any specified prefixes. Leave this field blank to advertise no custom groups.
         */
        advertisedGroups?: string[] | null;
        /**
         * User-specified list of individual IP ranges to advertise in custom mode. This field can only be populated if advertise_mode is CUSTOM and is advertised to all peers of the router. These IP ranges will be advertised in addition to any specified groups. Leave this field blank to advertise no custom IP ranges.
         */
        advertisedIpRanges?: Schema$RouterAdvertisedIpRange[];
        /**
         * User-specified flag to indicate which mode to use for advertisement. The options are DEFAULT or CUSTOM.
         */
        advertiseMode?: string | null;
        /**
         * Local BGP Autonomous System Number (ASN). Must be an RFC6996 private ASN, either 16-bit or 32-bit. The value will be fixed for this router resource. All VPN tunnels that link to this router will have the same local ASN.
         */
        asn?: number | null;
        /**
         * Explicitly specifies a range of valid BGP Identifiers for this Router. It is provided as a link-local IPv4 range (from 169.254.0.0/16), of size at least /30, even if the BGP sessions are over IPv6. It must not overlap with any IPv4 BGP session ranges. Other vendors commonly call this "router ID".
         */
        identifierRange?: string | null;
        /**
         * The interval in seconds between BGP keepalive messages that are sent to the peer. Hold time is three times the interval at which keepalive messages are sent, and the hold time is the maximum number of seconds allowed to elapse between successive keepalive messages that BGP receives from a peer. BGP will use the smaller of either the local hold time value or the peer's hold time value as the hold time for the BGP connection between the two peers. If set, this value must be between 20 and 60. The default is 20.
         */
        keepaliveInterval?: number | null;
    }
    export interface Schema$RouterBgpPeer {
        /**
         * User-specified list of prefix groups to advertise in custom mode, which currently supports the following option: - ALL_SUBNETS: Advertises all of the router's own VPC subnets. This excludes any routes learned for subnets that use VPC Network Peering. Note that this field can only be populated if advertise_mode is CUSTOM and overrides the list defined for the router (in the "bgp" message). These groups are advertised in addition to any specified prefixes. Leave this field blank to advertise no custom groups.
         */
        advertisedGroups?: string[] | null;
        /**
         * User-specified list of individual IP ranges to advertise in custom mode. This field can only be populated if advertise_mode is CUSTOM and overrides the list defined for the router (in the "bgp" message). These IP ranges are advertised in addition to any specified groups. Leave this field blank to advertise no custom IP ranges.
         */
        advertisedIpRanges?: Schema$RouterAdvertisedIpRange[];
        /**
         * The priority of routes advertised to this BGP peer. Where there is more than one matching route of maximum length, the routes with the lowest priority value win.
         */
        advertisedRoutePriority?: number | null;
        /**
         * User-specified flag to indicate which mode to use for advertisement.
         */
        advertiseMode?: string | null;
        /**
         * BFD configuration for the BGP peering.
         */
        bfd?: Schema$RouterBgpPeerBfd;
        /**
         * A list of user-defined custom learned route IP address ranges for a BGP session.
         */
        customLearnedIpRanges?: Schema$RouterBgpPeerCustomLearnedIpRange[];
        /**
         * The user-defined custom learned route priority for a BGP session. This value is applied to all custom learned route ranges for the session. You can choose a value from `0` to `65335`. If you don't provide a value, Google Cloud assigns a priority of `100` to the ranges.
         */
        customLearnedRoutePriority?: number | null;
        /**
         * The status of the BGP peer connection. If set to FALSE, any active session with the peer is terminated and all associated routing information is removed. If set to TRUE, the peer connection can be established with routing information. The default is TRUE.
         */
        enable?: string | null;
        /**
         * Enable IPv4 traffic over BGP Peer. It is enabled by default if the peerIpAddress is version 4.
         */
        enableIpv4?: boolean | null;
        /**
         * Enable IPv6 traffic over BGP Peer. If not specified, it is disabled by default.
         */
        enableIpv6?: boolean | null;
        /**
         * List of export policies applied to this peer, in the order they must be evaluated. The name must correspond to an existing policy that has ROUTE_POLICY_TYPE_EXPORT type.
         */
        exportPolicies?: string[] | null;
        /**
         * List of import policies applied to this peer, in the order they must be evaluated. The name must correspond to an existing policy that has ROUTE_POLICY_TYPE_IMPORT type.
         */
        importPolicies?: string[] | null;
        /**
         * Name of the interface the BGP peer is associated with.
         */
        interfaceName?: string | null;
        /**
         * IP address of the interface inside Google Cloud Platform. Only IPv4 is supported.
         */
        ipAddress?: string | null;
        /**
         * IPv4 address of the interface inside Google Cloud Platform.
         */
        ipv4NexthopAddress?: string | null;
        /**
         * IPv6 address of the interface inside Google Cloud Platform.
         */
        ipv6NexthopAddress?: string | null;
        /**
         * [Output Only] The resource that configures and manages this BGP peer. - MANAGED_BY_USER is the default value and can be managed by you or other users - MANAGED_BY_ATTACHMENT is a BGP peer that is configured and managed by Cloud Interconnect, specifically by an InterconnectAttachment of type PARTNER. Google automatically creates, updates, and deletes this type of BGP peer when the PARTNER InterconnectAttachment is created, updated, or deleted.
         */
        managementType?: string | null;
        /**
         * Present if MD5 authentication is enabled for the peering. Must be the name of one of the entries in the Router.md5_authentication_keys. The field must comply with RFC1035.
         */
        md5AuthenticationKeyName?: string | null;
        /**
         * Name of this BGP peer. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * Peer BGP Autonomous System Number (ASN). Each BGP interface may use a different value.
         */
        peerAsn?: number | null;
        /**
         * IP address of the BGP interface outside Google Cloud Platform. Only IPv4 is supported.
         */
        peerIpAddress?: string | null;
        /**
         * IPv4 address of the BGP interface outside Google Cloud Platform.
         */
        peerIpv4NexthopAddress?: string | null;
        /**
         * IPv6 address of the BGP interface outside Google Cloud Platform.
         */
        peerIpv6NexthopAddress?: string | null;
        /**
         * URI of the VM instance that is used as third-party router appliances such as Next Gen Firewalls, Virtual Routers, or Router Appliances. The VM instance must be located in zones contained in the same region as this Cloud Router. The VM instance is the peer side of the BGP session.
         */
        routerApplianceInstance?: string | null;
    }
    export interface Schema$RouterBgpPeerBfd {
        /**
         * The minimum interval, in milliseconds, between BFD control packets received from the peer router. The actual value is negotiated between the two routers and is equal to the greater of this value and the transmit interval of the other router. If set, this value must be between 1000 and 30000. The default is 1000.
         */
        minReceiveInterval?: number | null;
        /**
         * The minimum interval, in milliseconds, between BFD control packets transmitted to the peer router. The actual value is negotiated between the two routers and is equal to the greater of this value and the corresponding receive interval of the other router. If set, this value must be between 1000 and 30000. The default is 1000.
         */
        minTransmitInterval?: number | null;
        /**
         * The BFD session initialization mode for this BGP peer. If set to ACTIVE, the Cloud Router will initiate the BFD session for this BGP peer. If set to PASSIVE, the Cloud Router will wait for the peer router to initiate the BFD session for this BGP peer. If set to DISABLED, BFD is disabled for this BGP peer. The default is PASSIVE.
         */
        mode?: string | null;
        /**
         * The number of consecutive BFD packets that must be missed before BFD declares that a peer is unavailable. If set, the value must be a value between 5 and 16. The default is 5.
         */
        multiplier?: number | null;
        /**
         * The BFD packet mode for this BGP peer. If set to CONTROL_AND_ECHO, BFD echo mode is enabled for this BGP peer. In this mode, if the peer router also has BFD echo mode enabled, BFD echo packets will be sent to the other router. If the peer router does not have BFD echo mode enabled, only control packets will be sent. If set to CONTROL_ONLY, BFD echo mode is disabled for this BGP peer. If this router and the peer router have a multihop connection, this should be set to CONTROL_ONLY as BFD echo mode is only supported on singlehop connections. The default is CONTROL_AND_ECHO.
         */
        packetMode?: string | null;
        /**
         * The BFD session initialization mode for this BGP peer. If set to ACTIVE, the Cloud Router will initiate the BFD session for this BGP peer. If set to PASSIVE, the Cloud Router will wait for the peer router to initiate the BFD session for this BGP peer. If set to DISABLED, BFD is disabled for this BGP peer. The default is DISABLED.
         */
        sessionInitializationMode?: string | null;
        /**
         * The minimum interval, in milliseconds, between BFD control packets transmitted to and received from the peer router when BFD echo mode is enabled on both routers. The actual transmit and receive intervals are negotiated between the two routers and are equal to the greater of this value and the corresponding interval on the other router. If set, this value must be between 1000 and 30000. The default is 5000.
         */
        slowTimerInterval?: number | null;
    }
    export interface Schema$RouterBgpPeerCustomLearnedIpRange {
        /**
         * The custom learned route IP address range. Must be a valid CIDR-formatted prefix. If an IP address is provided without a subnet mask, it is interpreted as, for IPv4, a `/32` singular IP address range, and, for IPv6, `/128`.
         */
        range?: string | null;
    }
    export interface Schema$RouterInterface {
        /**
         * IP address and range of the interface. The IP range must be in the RFC3927 link-local IP address space. The value must be a CIDR-formatted string, for example: 169.254.0.1/30. NOTE: Do not truncate the address as it represents the IP address of the interface.
         */
        ipRange?: string | null;
        /**
         * IP version of this interface.
         */
        ipVersion?: string | null;
        /**
         * URI of the linked Interconnect attachment. It must be in the same region as the router. Each interface can have one linked resource, which can be a VPN tunnel, an Interconnect attachment, or a subnetwork.
         */
        linkedInterconnectAttachment?: string | null;
        /**
         * URI of the linked VPN tunnel, which must be in the same region as the router. Each interface can have one linked resource, which can be a VPN tunnel, an Interconnect attachment, or a subnetwork.
         */
        linkedVpnTunnel?: string | null;
        /**
         * [Output Only] The resource that configures and manages this interface. - MANAGED_BY_USER is the default value and can be managed directly by users. - MANAGED_BY_ATTACHMENT is an interface that is configured and managed by Cloud Interconnect, specifically, by an InterconnectAttachment of type PARTNER. Google automatically creates, updates, and deletes this type of interface when the PARTNER InterconnectAttachment is created, updated, or deleted.
         */
        managementType?: string | null;
        /**
         * Name of this interface entry. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * The regional private internal IP address that is used to establish BGP sessions to a VM instance acting as a third-party Router Appliance, such as a Next Gen Firewall, a Virtual Router, or an SD-WAN VM.
         */
        privateIpAddress?: string | null;
        /**
         * Name of the interface that will be redundant with the current interface you are creating. The redundantInterface must belong to the same Cloud Router as the interface here. To establish the BGP session to a Router Appliance VM, you must create two BGP peers. The two BGP peers must be attached to two separate interfaces that are redundant with each other. The redundant_interface must be 1-63 characters long, and comply with RFC1035. Specifically, the redundant_interface must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        redundantInterface?: string | null;
        /**
         * The URI of the subnetwork resource that this interface belongs to, which must be in the same region as the Cloud Router. When you establish a BGP session to a VM instance using this interface, the VM instance must belong to the same subnetwork as the subnetwork specified here.
         */
        subnetwork?: string | null;
    }
    /**
     * Contains a list of Router resources.
     */
    export interface Schema$RouterList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of Router resources.
         */
        items?: Schema$Router[];
        /**
         * [Output Only] Type of resource. Always compute#router for routers.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$RouterMd5AuthenticationKey {
        /**
         * [Input only] Value of the key. For patch and update calls, it can be skipped to copy the value from the previous configuration. This is allowed if the key with the same name existed before the operation. Maximum length is 80 characters. Can only contain printable ASCII characters.
         */
        key?: string | null;
        /**
         * Name used to identify the key. Must be unique within a router. Must be referenced by exactly one bgpPeer. Must comply with RFC1035.
         */
        name?: string | null;
    }
    /**
     * Represents a Nat resource. It enables the VMs within the specified subnetworks to access Internet without external IP addresses. It specifies a list of subnetworks (and the ranges within) that want to use NAT. Customers can also provide the external IPs that would be used for NAT. GCP would auto-allocate ephemeral IPs if no external IPs are provided.
     */
    export interface Schema$RouterNat {
        /**
         * The network tier to use when automatically reserving NAT IP addresses. Must be one of: PREMIUM, STANDARD. If not specified, then the current project-level default tier is used.
         */
        autoNetworkTier?: string | null;
        /**
         * A list of URLs of the IP resources to be drained. These IPs must be valid static external IPs that have been assigned to the NAT. These IPs should be used for updating/patching a NAT only.
         */
        drainNatIps?: string[] | null;
        /**
         * Enable Dynamic Port Allocation. If not specified, it is disabled by default. If set to true, - Dynamic Port Allocation will be enabled on this NAT config. - enableEndpointIndependentMapping cannot be set to true. - If minPorts is set, minPortsPerVm must be set to a power of two greater than or equal to 32. If minPortsPerVm is not set, a minimum of 32 ports will be allocated to a VM from this NAT config.
         */
        enableDynamicPortAllocation?: boolean | null;
        enableEndpointIndependentMapping?: boolean | null;
        /**
         * List of NAT-ted endpoint types supported by the Nat Gateway. If the list is empty, then it will be equivalent to include ENDPOINT_TYPE_VM
         */
        endpointTypes?: string[] | null;
        /**
         * Timeout (in seconds) for ICMP connections. Defaults to 30s if not set.
         */
        icmpIdleTimeoutSec?: number | null;
        /**
         * Configure logging on this NAT.
         */
        logConfig?: Schema$RouterNatLogConfig;
        /**
         * Maximum number of ports allocated to a VM from this NAT config when Dynamic Port Allocation is enabled. If Dynamic Port Allocation is not enabled, this field has no effect. If Dynamic Port Allocation is enabled, and this field is set, it must be set to a power of two greater than minPortsPerVm, or 64 if minPortsPerVm is not set. If Dynamic Port Allocation is enabled and this field is not set, a maximum of 65536 ports will be allocated to a VM from this NAT config.
         */
        maxPortsPerVm?: number | null;
        /**
         * Minimum number of ports allocated to a VM from this NAT config. If not set, a default number of ports is allocated to a VM. This is rounded up to the nearest power of 2. For example, if the value of this field is 50, at least 64 ports are allocated to a VM.
         */
        minPortsPerVm?: number | null;
        /**
         * Unique name of this Nat service. The name must be 1-63 characters long and comply with RFC1035.
         */
        name?: string | null;
        /**
         * Specify the NatIpAllocateOption, which can take one of the following values: - MANUAL_ONLY: Uses only Nat IP addresses provided by customers. When there are not enough specified Nat IPs, the Nat service fails for new VMs. - AUTO_ONLY: Nat IPs are allocated by Google Cloud Platform; customers can't specify any Nat IPs. When choosing AUTO_ONLY, then nat_ip should be empty.
         */
        natIpAllocateOption?: string | null;
        /**
         * A list of URLs of the IP resources used for this Nat service. These IP addresses must be valid static external IP addresses assigned to the project.
         */
        natIps?: string[] | null;
        /**
         * A list of rules associated with this NAT.
         */
        rules?: Schema$RouterNatRule[];
        /**
         * Specify the Nat option, which can take one of the following values: - ALL_SUBNETWORKS_ALL_IP_RANGES: All of the IP ranges in every Subnetwork are allowed to Nat. - ALL_SUBNETWORKS_ALL_PRIMARY_IP_RANGES: All of the primary IP ranges in every Subnetwork are allowed to Nat. - LIST_OF_SUBNETWORKS: A list of Subnetworks are allowed to Nat (specified in the field subnetwork below) The default is SUBNETWORK_IP_RANGE_TO_NAT_OPTION_UNSPECIFIED. Note that if this field contains ALL_SUBNETWORKS_ALL_IP_RANGES then there should not be any other Router.Nat section in any Router for this network in this region.
         */
        sourceSubnetworkIpRangesToNat?: string | null;
        /**
         * A list of Subnetwork resources whose traffic should be translated by NAT Gateway. It is used only when LIST_OF_SUBNETWORKS is selected for the SubnetworkIpRangeToNatOption above.
         */
        subnetworks?: Schema$RouterNatSubnetworkToNat[];
        /**
         * Timeout (in seconds) for TCP established connections. Defaults to 1200s if not set.
         */
        tcpEstablishedIdleTimeoutSec?: number | null;
        /**
         * Timeout (in seconds) for TCP connections that are in TIME_WAIT state. Defaults to 120s if not set.
         */
        tcpTimeWaitTimeoutSec?: number | null;
        /**
         * Timeout (in seconds) for TCP transitory connections. Defaults to 30s if not set.
         */
        tcpTransitoryIdleTimeoutSec?: number | null;
        /**
         * Indicates whether this NAT is used for public or private IP translation. If unspecified, it defaults to PUBLIC.
         */
        type?: string | null;
        /**
         * Timeout (in seconds) for UDP connections. Defaults to 30s if not set.
         */
        udpIdleTimeoutSec?: number | null;
    }
    /**
     * Configuration of logging on a NAT.
     */
    export interface Schema$RouterNatLogConfig {
        /**
         * Indicates whether or not to export logs. This is false by default.
         */
        enable?: boolean | null;
        /**
         * Specify the desired filtering of logs on this NAT. If unspecified, logs are exported for all connections handled by this NAT. This option can take one of the following values: - ERRORS_ONLY: Export logs only for connection failures. - TRANSLATIONS_ONLY: Export logs only for successful connections. - ALL: Export logs for all connections, successful and unsuccessful.
         */
        filter?: string | null;
    }
    export interface Schema$RouterNatRule {
        /**
         * The action to be enforced for traffic that matches this rule.
         */
        action?: Schema$RouterNatRuleAction;
        /**
         * An optional description of this rule.
         */
        description?: string | null;
        /**
         * CEL expression that specifies the match condition that egress traffic from a VM is evaluated against. If it evaluates to true, the corresponding `action` is enforced. The following examples are valid match expressions for public NAT: "inIpRange(destination.ip, '1.1.0.0/16') || inIpRange(destination.ip, '2.2.0.0/16')" "destination.ip == '1.1.0.1' || destination.ip == '8.8.8.8'" The following example is a valid match expression for private NAT: "nexthop.hub == '//networkconnectivity.googleapis.com/projects/my-project/locations/global/hubs/hub-1'"
         */
        match?: string | null;
        /**
         * An integer uniquely identifying a rule in the list. The rule number must be a positive value between 0 and 65000, and must be unique among rules within a NAT.
         */
        ruleNumber?: number | null;
    }
    export interface Schema$RouterNatRuleAction {
        /**
         * A list of URLs of the IP resources used for this NAT rule. These IP addresses must be valid static external IP addresses assigned to the project. This field is used for public NAT.
         */
        sourceNatActiveIps?: string[] | null;
        /**
         * A list of URLs of the subnetworks used as source ranges for this NAT Rule. These subnetworks must have purpose set to PRIVATE_NAT. This field is used for private NAT.
         */
        sourceNatActiveRanges?: string[] | null;
        /**
         * A list of URLs of the IP resources to be drained. These IPs must be valid static external IPs that have been assigned to the NAT. These IPs should be used for updating/patching a NAT rule only. This field is used for public NAT.
         */
        sourceNatDrainIps?: string[] | null;
        /**
         * A list of URLs of subnetworks representing source ranges to be drained. This is only supported on patch/update, and these subnetworks must have previously been used as active ranges in this NAT Rule. This field is used for private NAT.
         */
        sourceNatDrainRanges?: string[] | null;
    }
    /**
     * Defines the IP ranges that want to use NAT for a subnetwork.
     */
    export interface Schema$RouterNatSubnetworkToNat {
        /**
         * URL for the subnetwork resource that will use NAT.
         */
        name?: string | null;
        /**
         * A list of the secondary ranges of the Subnetwork that are allowed to use NAT. This can be populated only if "LIST_OF_SECONDARY_IP_RANGES" is one of the values in source_ip_ranges_to_nat.
         */
        secondaryIpRangeNames?: string[] | null;
        /**
         * Specify the options for NAT ranges in the Subnetwork. All options of a single value are valid except NAT_IP_RANGE_OPTION_UNSPECIFIED. The only valid option with multiple values is: ["PRIMARY_IP_RANGE", "LIST_OF_SECONDARY_IP_RANGES"] Default: [ALL_IP_RANGES]
         */
        sourceIpRangesToNat?: string[] | null;
    }
    export interface Schema$RoutersGetRoutePolicyResponse {
        /**
         * end_interface: MixerGetResponseWithEtagBuilder
         */
        etag?: string | null;
        resource?: Schema$RoutePolicy;
    }
    export interface Schema$RoutersListBgpRoutes {
        etag?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] Type of resource. Always compute#routersListBgpRoutes for lists of bgp routes.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] A list of bgp routes.
         */
        result?: Schema$BgpRoute[];
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$RoutersListRoutePolicies {
        etag?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] Type of resource. Always compute#routersListRoutePolicies for lists of route policies.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] A list of route policies.
         */
        result?: Schema$RoutePolicy[];
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$RoutersPreviewResponse {
        /**
         * Preview of given router.
         */
        resource?: Schema$Router;
    }
    export interface Schema$RoutersScopedList {
        /**
         * A list of routers contained in this scope.
         */
        routers?: Schema$Router[];
        /**
         * Informational warning which replaces the list of routers when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$RouterStatus {
        /**
         * Best routes for this router's network.
         */
        bestRoutes?: Schema$Route[];
        /**
         * Best routes learned by this router.
         */
        bestRoutesForRouter?: Schema$Route[];
        bgpPeerStatus?: Schema$RouterStatusBgpPeerStatus[];
        natStatus?: Schema$RouterStatusNatStatus[];
        /**
         * URI of the network to which this router belongs.
         */
        network?: string | null;
    }
    export interface Schema$RouterStatusBgpPeerStatus {
        /**
         * Routes that were advertised to the remote BGP peer
         */
        advertisedRoutes?: Schema$Route[];
        bfdStatus?: Schema$BfdStatus;
        /**
         * Enable IPv6 traffic over BGP Peer. If not specified, it is disabled by default.
         */
        enableIpv6?: boolean | null;
        /**
         * IP address of the local BGP interface.
         */
        ipAddress?: string | null;
        /**
         * IPv6 address of the local BGP interface.
         */
        ipv6NexthopAddress?: string | null;
        /**
         * URL of the VPN tunnel that this BGP peer controls.
         */
        linkedVpnTunnel?: string | null;
        /**
         * Informs whether MD5 authentication is enabled on this BGP peer.
         */
        md5AuthEnabled?: boolean | null;
        /**
         * Name of this BGP peer. Unique within the Routers resource.
         */
        name?: string | null;
        /**
         * Number of routes learned from the remote BGP Peer.
         */
        numLearnedRoutes?: number | null;
        /**
         * IP address of the remote BGP interface.
         */
        peerIpAddress?: string | null;
        /**
         * IPv6 address of the remote BGP interface.
         */
        peerIpv6NexthopAddress?: string | null;
        /**
         * [Output only] URI of the VM instance that is used as third-party router appliances such as Next Gen Firewalls, Virtual Routers, or Router Appliances. The VM instance is the peer side of the BGP session.
         */
        routerApplianceInstance?: string | null;
        /**
         * The state of the BGP session. For a list of possible values for this field, see BGP session states.
         */
        state?: string | null;
        /**
         * Status of the BGP peer: {UP, DOWN\}
         */
        status?: string | null;
        /**
         * Indicates why particular status was returned.
         */
        statusReason?: string | null;
        /**
         * Time this session has been up. Format: 14 years, 51 weeks, 6 days, 23 hours, 59 minutes, 59 seconds
         */
        uptime?: string | null;
        /**
         * Time this session has been up, in seconds. Format: 145
         */
        uptimeSeconds?: string | null;
    }
    /**
     * Status of a NAT contained in this router.
     */
    export interface Schema$RouterStatusNatStatus {
        /**
         * A list of IPs auto-allocated for NAT. Example: ["1.1.1.1", "129.2.16.89"]
         */
        autoAllocatedNatIps?: string[] | null;
        /**
         * A list of IPs auto-allocated for NAT that are in drain mode. Example: ["1.1.1.1", "179.12.26.133"].
         */
        drainAutoAllocatedNatIps?: string[] | null;
        /**
         * A list of IPs user-allocated for NAT that are in drain mode. Example: ["1.1.1.1", "179.12.26.133"].
         */
        drainUserAllocatedNatIps?: string[] | null;
        /**
         * The number of extra IPs to allocate. This will be greater than 0 only if user-specified IPs are NOT enough to allow all configured VMs to use NAT. This value is meaningful only when auto-allocation of NAT IPs is *not* used.
         */
        minExtraNatIpsNeeded?: number | null;
        /**
         * Unique name of this NAT.
         */
        name?: string | null;
        /**
         * Number of VM endpoints (i.e., Nics) that can use NAT.
         */
        numVmEndpointsWithNatMappings?: number | null;
        /**
         * Status of rules in this NAT.
         */
        ruleStatus?: Schema$RouterStatusNatStatusNatRuleStatus[];
        /**
         * A list of fully qualified URLs of reserved IP address resources.
         */
        userAllocatedNatIpResources?: string[] | null;
        /**
         * A list of IPs user-allocated for NAT. They will be raw IP strings like "179.12.26.133".
         */
        userAllocatedNatIps?: string[] | null;
    }
    /**
     * Status of a NAT Rule contained in this NAT.
     */
    export interface Schema$RouterStatusNatStatusNatRuleStatus {
        /**
         * A list of active IPs for NAT. Example: ["1.1.1.1", "179.12.26.133"].
         */
        activeNatIps?: string[] | null;
        /**
         * A list of IPs for NAT that are in drain mode. Example: ["1.1.1.1", "179.12.26.133"].
         */
        drainNatIps?: string[] | null;
        /**
         * The number of extra IPs to allocate. This will be greater than 0 only if the existing IPs in this NAT Rule are NOT enough to allow all configured VMs to use NAT.
         */
        minExtraIpsNeeded?: number | null;
        /**
         * Number of VM endpoints (i.e., NICs) that have NAT Mappings from this NAT Rule.
         */
        numVmEndpointsWithNatMappings?: number | null;
        /**
         * Rule number of the rule.
         */
        ruleNumber?: number | null;
    }
    export interface Schema$RouterStatusResponse {
        /**
         * Type of resource.
         */
        kind?: string | null;
        result?: Schema$RouterStatus;
    }
    /**
     * This is deprecated and has no effect. Do not use.
     */
    export interface Schema$Rule {
        /**
         * This is deprecated and has no effect. Do not use.
         */
        action?: string | null;
        /**
         * This is deprecated and has no effect. Do not use.
         */
        conditions?: Schema$Condition[];
        /**
         * This is deprecated and has no effect. Do not use.
         */
        description?: string | null;
        /**
         * This is deprecated and has no effect. Do not use.
         */
        ins?: string[] | null;
        /**
         * This is deprecated and has no effect. Do not use.
         */
        logConfigs?: Schema$LogConfig[];
        /**
         * This is deprecated and has no effect. Do not use.
         */
        notIns?: string[] | null;
        /**
         * This is deprecated and has no effect. Do not use.
         */
        permissions?: string[] | null;
    }
    /**
     * DEPRECATED: Please use compute#savedDisk instead. An instance-attached disk resource.
     */
    export interface Schema$SavedAttachedDisk {
        /**
         * Specifies whether the disk will be auto-deleted when the instance is deleted (but not when the disk is detached from the instance).
         */
        autoDelete?: boolean | null;
        /**
         * Indicates that this is a boot disk. The virtual machine will use the first partition of the disk for its root filesystem.
         */
        boot?: boolean | null;
        /**
         * Specifies the name of the disk attached to the source instance.
         */
        deviceName?: string | null;
        /**
         * The encryption key for the disk.
         */
        diskEncryptionKey?: Schema$CustomerEncryptionKey;
        /**
         * The size of the disk in base-2 GB.
         */
        diskSizeGb?: string | null;
        /**
         * [Output Only] URL of the disk type resource. For example: projects/project /zones/zone/diskTypes/pd-standard or pd-ssd
         */
        diskType?: string | null;
        /**
         * A list of features to enable on the guest operating system. Applicable only for bootable images. Read Enabling guest operating system features to see a list of available options.
         */
        guestOsFeatures?: Schema$GuestOsFeature[];
        /**
         * Specifies zero-based index of the disk that is attached to the source instance.
         */
        index?: number | null;
        /**
         * Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME.
         */
        interface?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#attachedDisk for attached disks.
         */
        kind?: string | null;
        /**
         * [Output Only] Any valid publicly visible licenses.
         */
        licenses?: string[] | null;
        /**
         * The mode in which this disk is attached to the source instance, either READ_WRITE or READ_ONLY.
         */
        mode?: string | null;
        /**
         * Specifies a URL of the disk attached to the source instance.
         */
        source?: string | null;
        /**
         * [Output Only] A size of the storage used by the disk's snapshot by this machine image.
         */
        storageBytes?: string | null;
        /**
         * [Output Only] An indicator whether storageBytes is in a stable state or it is being adjusted as a result of shared storage reallocation. This status can either be UPDATING, meaning the size of the snapshot is being updated, or UP_TO_DATE, meaning the size of the snapshot is up-to-date.
         */
        storageBytesStatus?: string | null;
        /**
         * Specifies the type of the attached disk, either SCRATCH or PERSISTENT.
         */
        type?: string | null;
    }
    /**
     * An instance-attached disk resource.
     */
    export interface Schema$SavedDisk {
        /**
         * [Output Only] The architecture of the attached disk.
         */
        architecture?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#savedDisk for attached disks.
         */
        kind?: string | null;
        /**
         * Specifies a URL of the disk attached to the source instance.
         */
        sourceDisk?: string | null;
        /**
         * [Output Only] Size of the individual disk snapshot used by this machine image.
         */
        storageBytes?: string | null;
        /**
         * [Output Only] An indicator whether storageBytes is in a stable state or it is being adjusted as a result of shared storage reallocation. This status can either be UPDATING, meaning the size of the snapshot is being updated, or UP_TO_DATE, meaning the size of the snapshot is up-to-date.
         */
        storageBytesStatus?: string | null;
    }
    export interface Schema$ScalingScheduleStatus {
        /**
         * [Output Only] The last time the scaling schedule became active. Note: this is a timestamp when a schedule actually became active, not when it was planned to do so. The timestamp is in RFC3339 text format.
         */
        lastStartTime?: string | null;
        /**
         * [Output Only] The next time the scaling schedule is to become active. Note: this is a timestamp when a schedule is planned to run, but the actual time might be slightly different. The timestamp is in RFC3339 text format.
         */
        nextStartTime?: string | null;
        /**
         * [Output Only] The current state of a scaling schedule.
         */
        state?: string | null;
    }
    /**
     * Sets the scheduling options for an Instance.
     */
    export interface Schema$Scheduling {
        /**
         * Specifies whether the instance should be automatically restarted if it is terminated by Compute Engine (not terminated by a user). You can only set the automatic restart option for standard instances. Preemptible instances cannot be automatically restarted. By default, this is set to true so an instance is automatically restarted if it is terminated by Compute Engine.
         */
        automaticRestart?: boolean | null;
        /**
         * Specifies the availability domain (AD), which this instance should be scheduled on. The AD belongs to the spread GroupPlacementPolicy resource policy that has been assigned to the instance. Specify a value between 1-max count of availability domains in your GroupPlacementPolicy. See go/placement-policy-extension for more details.
         */
        availabilityDomain?: number | null;
        /**
         * Current number of vCPUs available for VM. 0 or unset means default vCPUs of the current machine type.
         */
        currentCpus?: number | null;
        /**
         * Current amount of memory (in MB) available for VM. 0 or unset means default amount of memory of the current machine type.
         */
        currentMemoryMb?: string | null;
        /**
         * Specify the time in seconds for host error detection, the value must be within the range of [90, 330] with the increment of 30, if unset, the default behavior of host error recovery will be used.
         */
        hostErrorTimeoutSeconds?: number | null;
        /**
         * Specifies the termination action for the instance.
         */
        instanceTerminationAction?: string | null;
        /**
         * Defines whether the instance is tolerant of higher cpu latency. This can only be set during instance creation, or when the instance is not currently running. It must not be set if the preemptible option is also set.
         */
        latencyTolerant?: boolean | null;
        /**
         * Specifies the maximum amount of time a Local Ssd Vm should wait while recovery of the Local Ssd state is attempted. Its value should be in between 0 and 168 hours with hour granularity and the default value being 1 hour.
         */
        localSsdRecoveryTimeout?: Schema$Duration;
        /**
         * An opaque location hint used to place the instance close to other resources. This field is for use by internal tools that use the public API.
         */
        locationHint?: string | null;
        /**
         * Specifies the number of hours after VM instance creation where the VM won't be scheduled for maintenance.
         */
        maintenanceFreezeDurationHours?: number | null;
        /**
         * Specifies the frequency of planned maintenance events. The accepted values are: `PERIODIC`.
         */
        maintenanceInterval?: string | null;
        /**
         * Specifies the max run duration for the given instance. If specified, the instance termination action will be performed at the end of the run duration.
         */
        maxRunDuration?: Schema$Duration;
        /**
         * The minimum number of virtual CPUs this instance will consume when running on a sole-tenant node.
         */
        minNodeCpus?: number | null;
        /**
         * A set of node affinity and anti-affinity configurations. Refer to Configuring node affinity for more information. Overrides reservationAffinity.
         */
        nodeAffinities?: Schema$SchedulingNodeAffinity[];
        /**
         * Defines the maintenance behavior for this instance. For standard instances, the default behavior is MIGRATE. For preemptible instances, the default and only possible behavior is TERMINATE. For more information, see Set VM host maintenance policy.
         */
        onHostMaintenance?: string | null;
        /**
         * Defines whether the instance is preemptible. This can only be set during instance creation or while the instance is stopped and therefore, in a `TERMINATED` state. See Instance Life Cycle for more information on the possible instance states.
         */
        preemptible?: boolean | null;
        /**
         * Specifies the provisioning model of the instance.
         */
        provisioningModel?: string | null;
        /**
         * Specifies the timestamp, when the instance will be terminated, in RFC3339 text format. If specified, the instance termination action will be performed at the termination time.
         */
        terminationTime?: string | null;
    }
    /**
     * Node Affinity: the configuration of desired nodes onto which this Instance could be scheduled.
     */
    export interface Schema$SchedulingNodeAffinity {
        /**
         * Corresponds to the label key of Node resource.
         */
        key?: string | null;
        /**
         * Defines the operation of node selection. Valid operators are IN for affinity and NOT_IN for anti-affinity.
         */
        operator?: string | null;
        /**
         * Corresponds to the label values of Node resource.
         */
        values?: string[] | null;
    }
    /**
     * An instance's screenshot.
     */
    export interface Schema$Screenshot {
        /**
         * [Output Only] The Base64-encoded screenshot data.
         */
        contents?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#screenshot for the screenshots.
         */
        kind?: string | null;
    }
    /**
     * [Deprecated] The configuration to access the SDS server. The configuration to access the SDS server.
     */
    export interface Schema$SdsConfig {
        /**
         * The configuration to access the SDS server over GRPC.
         */
        grpcServiceConfig?: Schema$GrpcServiceConfig;
    }
    export interface Schema$SecurityPoliciesAggregatedList {
        etag?: string | null;
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of SecurityPoliciesScopedList resources.
         */
        items?: {
            [key: string]: Schema$SecurityPoliciesScopedList;
        } | null;
        /**
         * [Output Only] Type of resource. Always compute#securityPolicyAggregatedList for lists of Security Policies.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$SecurityPoliciesListPreconfiguredExpressionSetsResponse {
        preconfiguredExpressionSets?: Schema$SecurityPoliciesWafConfig;
    }
    export interface Schema$SecurityPoliciesScopedList {
        /**
         * A list of SecurityPolicies contained in this scope.
         */
        securityPolicies?: Schema$SecurityPolicy[];
        /**
         * Informational warning which replaces the list of security policies when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$SecurityPoliciesWafConfig {
        wafRules?: Schema$PreconfiguredWafSet;
    }
    /**
     * Represents a Google Cloud Armor security policy resource. Only external backend services that use load balancers can reference a security policy. For more information, see Google Cloud Armor security policy overview.
     */
    export interface Schema$SecurityPolicy {
        adaptiveProtectionConfig?: Schema$SecurityPolicyAdaptiveProtectionConfig;
        advancedOptionsConfig?: Schema$SecurityPolicyAdvancedOptionsConfig;
        /**
         * A list of associations that belong to this policy.
         */
        associations?: Schema$SecurityPolicyAssociation[];
        cloudArmorConfig?: Schema$SecurityPolicyCloudArmorConfig;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        ddosProtectionConfig?: Schema$SecurityPolicyDdosProtectionConfig;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * User-provided name of the Organization security plicy. The name should be unique in the organization in which the security policy is created. This should only be used when SecurityPolicyType is FIREWALL. The name must be 1-63 characters long, and comply with https://www.ietf.org/rfc/rfc1035.txt. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        displayName?: string | null;
        /**
         * Specifies a fingerprint for this resource, which is essentially a hash of the metadata's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update metadata. You must always provide an up-to-date fingerprint hash in order to update or change metadata, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make get() request to the security policy.
         */
        fingerprint?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output only] Type of the resource. Always compute#securityPolicyfor security policies
         */
        kind?: string | null;
        /**
         * A fingerprint for the labels being applied to this security policy, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels. To see the latest fingerprint, make get() request to the security policy.
         */
        labelFingerprint?: string | null;
        /**
         * Labels for this resource. These can only be added or modified by the setLabels method. Each label key/value pair must comply with RFC1035. Label values may be empty.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * [Output Only] The parent of the security policy.
         */
        parent?: string | null;
        recaptchaOptionsConfig?: Schema$SecurityPolicyRecaptchaOptionsConfig;
        /**
         * [Output Only] URL of the region where the regional security policy resides. This field is not applicable to global security policies.
         */
        region?: string | null;
        /**
         * A list of rules that belong to this policy. There must always be a default rule which is a rule with priority 2147483647 and match all condition (for the match condition this means match "*" for srcIpRanges and for the networkMatch condition every field must be either match "*" or not set). If no rules are provided when creating a security policy, a default rule with action "allow" will be added.
         */
        rules?: Schema$SecurityPolicyRule[];
        /**
         * [Output Only] Total count of all security policy rule tuples. A security policy can not exceed a set number of tuples.
         */
        ruleTupleCount?: number | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * The type indicates the intended use of the security policy. - CLOUD_ARMOR: Cloud Armor backend security policies can be configured to filter incoming HTTP requests targeting backend services. They filter requests before they hit the origin servers. - CLOUD_ARMOR_EDGE: Cloud Armor edge security policies can be configured to filter incoming HTTP requests targeting backend services (including Cloud CDN-enabled) as well as backend buckets (Cloud Storage). They filter requests before the request is served from Google's cache. - CLOUD_ARMOR_INTERNAL_SERVICE: Cloud Armor internal service policies can be configured to filter HTTP requests targeting services managed by Traffic Director in a service mesh. They filter requests before the request is served from the application. - CLOUD_ARMOR_NETWORK: Cloud Armor network policies can be configured to filter packets targeting network load balancing resources such as backend services, target pools, target instances, and instances with external IPs. They filter requests before the request is served from the application. This field can be set only at resource creation time.
         */
        type?: string | null;
        /**
         * Definitions of user-defined fields for CLOUD_ARMOR_NETWORK policies. A user-defined field consists of up to 4 bytes extracted from a fixed offset in the packet, relative to the IPv4, IPv6, TCP, or UDP header, with an optional mask to select certain bits. Rules may then specify matching values for these fields. Example: userDefinedFields: - name: "ipv4_fragment_offset" base: IPV4 offset: 6 size: 2 mask: "0x1fff"
         */
        userDefinedFields?: Schema$SecurityPolicyUserDefinedField[];
    }
    /**
     * Configuration options for Cloud Armor Adaptive Protection (CAAP).
     */
    export interface Schema$SecurityPolicyAdaptiveProtectionConfig {
        autoDeployConfig?: Schema$SecurityPolicyAdaptiveProtectionConfigAutoDeployConfig;
        /**
         * If set to true, enables Cloud Armor Machine Learning.
         */
        layer7DdosDefenseConfig?: Schema$SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig;
    }
    /**
     * Configuration options for Adaptive Protection auto-deploy feature.
     */
    export interface Schema$SecurityPolicyAdaptiveProtectionConfigAutoDeployConfig {
        confidenceThreshold?: number | null;
        expirationSec?: number | null;
        impactedBaselineThreshold?: number | null;
        loadThreshold?: number | null;
    }
    /**
     * Configuration options for L7 DDoS detection. This field is only supported in Global Security Policies of type CLOUD_ARMOR.
     */
    export interface Schema$SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig {
        /**
         * If set to true, enables CAAP for L7 DDoS detection. This field is only supported in Global Security Policies of type CLOUD_ARMOR.
         */
        enable?: boolean | null;
        /**
         * Rule visibility can be one of the following: STANDARD - opaque rules. (default) PREMIUM - transparent rules. This field is only supported in Global Security Policies of type CLOUD_ARMOR.
         */
        ruleVisibility?: string | null;
        /**
         * Configuration options for layer7 adaptive protection for various customizable thresholds.
         */
        thresholdConfigs?: Schema$SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig[];
    }
    export interface Schema$SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig {
        autoDeployConfidenceThreshold?: number | null;
        autoDeployExpirationSec?: number | null;
        autoDeployImpactedBaselineThreshold?: number | null;
        autoDeployLoadThreshold?: number | null;
        /**
         * The name must be 1-63 characters long, and comply with RFC1035. The name must be unique within the security policy.
         */
        name?: string | null;
    }
    export interface Schema$SecurityPolicyAdvancedOptionsConfig {
        /**
         * Custom configuration to apply the JSON parsing. Only applicable when json_parsing is set to STANDARD.
         */
        jsonCustomConfig?: Schema$SecurityPolicyAdvancedOptionsConfigJsonCustomConfig;
        jsonParsing?: string | null;
        logLevel?: string | null;
        /**
         * An optional list of case-insensitive request header names to use for resolving the callers client IP address.
         */
        userIpRequestHeaders?: string[] | null;
    }
    export interface Schema$SecurityPolicyAdvancedOptionsConfigJsonCustomConfig {
        /**
         * A list of custom Content-Type header values to apply the JSON parsing. As per RFC 1341, a Content-Type header value has the following format: Content-Type := type "/" subtype *[";" parameter] When configuring a custom Content-Type header value, only the type/subtype needs to be specified, and the parameters should be excluded.
         */
        contentTypes?: string[] | null;
    }
    export interface Schema$SecurityPolicyAssociation {
        /**
         * The resource that the security policy is attached to.
         */
        attachmentId?: string | null;
        /**
         * [Output Only] The display name of the security policy of the association.
         */
        displayName?: string | null;
        /**
         * The name for an association.
         */
        name?: string | null;
        /**
         * [Output Only] The security policy ID of the association.
         */
        securityPolicyId?: string | null;
    }
    /**
     * Configuration options for Cloud Armor.
     */
    export interface Schema$SecurityPolicyCloudArmorConfig {
        /**
         * If set to true, enables Cloud Armor Machine Learning.
         */
        enableMl?: boolean | null;
    }
    export interface Schema$SecurityPolicyDdosProtectionConfig {
        ddosProtection?: string | null;
    }
    export interface Schema$SecurityPolicyList {
        etag?: string | null;
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of SecurityPolicy resources.
         */
        items?: Schema$SecurityPolicy[];
        /**
         * [Output Only] Type of resource. Always compute#securityPolicyList for listsof securityPolicies
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$SecurityPolicyRecaptchaOptionsConfig {
        /**
         * An optional field to supply a reCAPTCHA site key to be used for all the rules using the redirect action with the type of GOOGLE_RECAPTCHA under the security policy. The specified site key needs to be created from the reCAPTCHA API. The user is responsible for the validity of the specified site key. If not specified, a Google-managed site key is used. This field is only supported in Global Security Policies of type CLOUD_ARMOR.
         */
        redirectSiteKey?: string | null;
    }
    export interface Schema$SecurityPolicyReference {
        securityPolicy?: string | null;
    }
    /**
     * Represents a rule that describes one or more match conditions along with the action to be taken when traffic matches this condition (allow or deny).
     */
    export interface Schema$SecurityPolicyRule {
        /**
         * The Action to perform when the rule is matched. The following are the valid actions: - allow: allow access to target. - deny(STATUS): deny access to target, returns the HTTP response code specified. Valid values for `STATUS` are 403, 404, and 502. - rate_based_ban: limit client traffic to the configured threshold and ban the client if the traffic exceeds the threshold. Configure parameters for this action in RateLimitOptions. Requires rate_limit_options to be set. - redirect: redirect to a different target. This can either be an internal reCAPTCHA redirect, or an external URL-based redirect via a 302 response. Parameters for this action can be configured via redirectOptions. This action is only supported in Global Security Policies of type CLOUD_ARMOR. - throttle: limit client traffic to the configured threshold. Configure parameters for this action in rateLimitOptions. Requires rate_limit_options to be set for this.
         */
        action?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * The direction in which this rule applies. This field may only be specified when versioned_expr is set to FIREWALL.
         */
        direction?: string | null;
        /**
         * Denotes whether to enable logging for a particular rule. If logging is enabled, logs will be exported to the configured export destination in Stackdriver. Logs may be exported to BigQuery or Pub/Sub. Note: you cannot enable logging on "goto_next" rules. This field may only be specified when the versioned_expr is set to FIREWALL.
         */
        enableLogging?: boolean | null;
        /**
         * Optional, additional actions that are performed on headers. This field is only supported in Global Security Policies of type CLOUD_ARMOR.
         */
        headerAction?: Schema$SecurityPolicyRuleHttpHeaderAction;
        /**
         * [Output only] Type of the resource. Always compute#securityPolicyRule for security policy rules
         */
        kind?: string | null;
        /**
         * A match condition that incoming traffic is evaluated against. If it evaluates to true, the corresponding 'action' is enforced.
         */
        match?: Schema$SecurityPolicyRuleMatcher;
        /**
         * A match condition that incoming packets are evaluated against for CLOUD_ARMOR_NETWORK security policies. If it matches, the corresponding 'action' is enforced. The match criteria for a rule consists of built-in match fields (like 'srcIpRanges') and potentially multiple user-defined match fields ('userDefinedFields'). Field values may be extracted directly from the packet or derived from it (e.g. 'srcRegionCodes'). Some fields may not be present in every packet (e.g. 'srcPorts'). A user-defined field is only present if the base header is found in the packet and the entire field is in bounds. Each match field may specify which values can match it, listing one or more ranges, prefixes, or exact values that are considered a match for the field. A field value must be present in order to match a specified match field. If no match values are specified for a match field, then any field value is considered to match it, and it's not required to be present. For strings specifying '*' is also equivalent to match all. For a packet to match a rule, all specified match fields must match the corresponding field values derived from the packet. Example: networkMatch: srcIpRanges: - "192.0.2.0/24" - "198.51.100.0/24" userDefinedFields: - name: "ipv4_fragment_offset" values: - "1-0x1fff" The above match condition matches packets with a source IP in 192.0.2.0/24 or 198.51.100.0/24 and a user-defined field named "ipv4_fragment_offset" with a value between 1 and 0x1fff inclusive.
         */
        networkMatch?: Schema$SecurityPolicyRuleNetworkMatcher;
        /**
         * Preconfigured WAF configuration to be applied for the rule. If the rule does not evaluate preconfigured WAF rules, i.e., if evaluatePreconfiguredWaf() is not used, this field will have no effect.
         */
        preconfiguredWafConfig?: Schema$SecurityPolicyRulePreconfiguredWafConfig;
        /**
         * If set to true, the specified action is not enforced.
         */
        preview?: boolean | null;
        /**
         * An integer indicating the priority of a rule in the list. The priority must be a positive value between 0 and 2147483647. Rules are evaluated from highest to lowest priority where 0 is the highest priority and 2147483647 is the lowest priority.
         */
        priority?: number | null;
        /**
         * Must be specified if the action is "rate_based_ban" or "throttle". Cannot be specified for any other actions.
         */
        rateLimitOptions?: Schema$SecurityPolicyRuleRateLimitOptions;
        /**
         * Parameters defining the redirect action. Cannot be specified for any other actions. This field is only supported in Global Security Policies of type CLOUD_ARMOR.
         */
        redirectOptions?: Schema$SecurityPolicyRuleRedirectOptions;
        /**
         * This must be specified for redirect actions. Cannot be specified for any other actions.
         */
        redirectTarget?: string | null;
        /**
         * [Output Only] The minimum managed protection tier required for this rule. [Deprecated] Use requiredManagedProtectionTiers instead.
         */
        ruleManagedProtectionTier?: string | null;
        /**
         * Identifier for the rule. This is only unique within the given security policy. This can only be set during rule creation, if rule number is not specified it will be generated by the server.
         */
        ruleNumber?: string | null;
        /**
         * [Output Only] Calculation of the complexity of a single firewall security policy rule.
         */
        ruleTupleCount?: number | null;
        /**
         * A list of network resource URLs to which this rule applies. This field allows you to control which network's VMs get this rule. If this field is left blank, all VMs within the organization will receive the rule. This field may only be specified when versioned_expr is set to FIREWALL.
         */
        targetResources?: string[] | null;
        /**
         * A list of service accounts indicating the sets of instances that are applied with this rule.
         */
        targetServiceAccounts?: string[] | null;
    }
    export interface Schema$SecurityPolicyRuleHttpHeaderAction {
        /**
         * The list of request headers to add or overwrite if they're already present.
         */
        requestHeadersToAdds?: Schema$SecurityPolicyRuleHttpHeaderActionHttpHeaderOption[];
    }
    export interface Schema$SecurityPolicyRuleHttpHeaderActionHttpHeaderOption {
        /**
         * The name of the header to set.
         */
        headerName?: string | null;
        /**
         * The value to set the named header to.
         */
        headerValue?: string | null;
    }
    /**
     * Represents a match condition that incoming traffic is evaluated against. Exactly one field must be specified.
     */
    export interface Schema$SecurityPolicyRuleMatcher {
        /**
         * The configuration options available when specifying versioned_expr. This field must be specified if versioned_expr is specified and cannot be specified if versioned_expr is not specified.
         */
        config?: Schema$SecurityPolicyRuleMatcherConfig;
        /**
         * User defined CEVAL expression. A CEVAL expression is used to specify match criteria such as origin.ip, source.region_code and contents in the request header. Expressions containing `evaluateThreatIntelligence` require Cloud Armor Managed Protection Plus tier and are not supported in Edge Policies nor in Regional Policies. Expressions containing `evaluatePreconfiguredExpr('sourceiplist-*')` require Cloud Armor Managed Protection Plus tier and are only supported in Global Security Policies.
         */
        expr?: Schema$Expr;
        /**
         * The configuration options available when specifying a user defined CEVAL expression (i.e., 'expr').
         */
        exprOptions?: Schema$SecurityPolicyRuleMatcherExprOptions;
        /**
         * Preconfigured versioned expression. If this field is specified, config must also be specified. Available preconfigured expressions along with their requirements are: SRC_IPS_V1 - must specify the corresponding src_ip_range field in config.
         */
        versionedExpr?: string | null;
    }
    export interface Schema$SecurityPolicyRuleMatcherConfig {
        /**
         * CIDR IP address range. This field may only be specified when versioned_expr is set to FIREWALL.
         */
        destIpRanges?: string[] | null;
        /**
         * Pairs of IP protocols and ports that the rule should match. This field may only be specified when versioned_expr is set to FIREWALL.
         */
        destPorts?: Schema$SecurityPolicyRuleMatcherConfigDestinationPort[];
        /**
         * Pairs of IP protocols and ports that the rule should match. This field may only be specified when versioned_expr is set to FIREWALL.
         */
        layer4Configs?: Schema$SecurityPolicyRuleMatcherConfigLayer4Config[];
        /**
         * CIDR IP address range. Maximum number of src_ip_ranges allowed is 10.
         */
        srcIpRanges?: string[] | null;
    }
    export interface Schema$SecurityPolicyRuleMatcherConfigDestinationPort {
        /**
         * The IP protocol to which this rule applies. The protocol type is required when creating a firewall rule. This value can either be one of the following well known protocol strings (tcp, udp, icmp, esp, ah, ipip, sctp), or the IP protocol number.
         */
        ipProtocol?: string | null;
        /**
         * An optional list of ports to which this rule applies. This field is only applicable for UDP or TCP protocol. Each entry must be either an integer or a range. If not specified, this rule applies to connections through any port. Example inputs include: ["22"], ["80","443"], and ["12345-12349"]. This field may only be specified when versioned_expr is set to FIREWALL.
         */
        ports?: string[] | null;
    }
    export interface Schema$SecurityPolicyRuleMatcherConfigLayer4Config {
        /**
         * The IP protocol to which this rule applies. The protocol type is required when creating a firewall rule. This value can either be one of the following well known protocol strings (tcp, udp, icmp, esp, ah, ipip, sctp), or the IP protocol number.
         */
        ipProtocol?: string | null;
        /**
         * An optional list of ports to which this rule applies. This field is only applicable for UDP or TCP protocol. Each entry must be either an integer or a range. If not specified, this rule applies to connections through any port. Example inputs include: ["22"], ["80","443"], and ["12345-12349"]. This field may only be specified when versioned_expr is set to FIREWALL.
         */
        ports?: string[] | null;
    }
    export interface Schema$SecurityPolicyRuleMatcherExprOptions {
        /**
         * reCAPTCHA configuration options to be applied for the rule. If the rule does not evaluate reCAPTCHA tokens, this field will have no effect.
         */
        recaptchaOptions?: Schema$SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions;
    }
    export interface Schema$SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions {
        /**
         * A list of site keys to be used during the validation of reCAPTCHA action-tokens. The provided site keys need to be created from reCAPTCHA API under the same project where the security policy is created.
         */
        actionTokenSiteKeys?: string[] | null;
        /**
         * A list of site keys to be used during the validation of reCAPTCHA session-tokens. The provided site keys need to be created from reCAPTCHA API under the same project where the security policy is created.
         */
        sessionTokenSiteKeys?: string[] | null;
    }
    /**
     * Represents a match condition that incoming network traffic is evaluated against.
     */
    export interface Schema$SecurityPolicyRuleNetworkMatcher {
        /**
         * Destination IPv4/IPv6 addresses or CIDR prefixes, in standard text format.
         */
        destIpRanges?: string[] | null;
        /**
         * Destination port numbers for TCP/UDP/SCTP. Each element can be a 16-bit unsigned decimal number (e.g. "80") or range (e.g. "0-1023").
         */
        destPorts?: string[] | null;
        /**
         * IPv4 protocol / IPv6 next header (after extension headers). Each element can be an 8-bit unsigned decimal number (e.g. "6"), range (e.g. "253-254"), or one of the following protocol names: "tcp", "udp", "icmp", "esp", "ah", "ipip", or "sctp".
         */
        ipProtocols?: string[] | null;
        /**
         * BGP Autonomous System Number associated with the source IP address.
         */
        srcAsns?: number[] | null;
        /**
         * Source IPv4/IPv6 addresses or CIDR prefixes, in standard text format.
         */
        srcIpRanges?: string[] | null;
        /**
         * Source port numbers for TCP/UDP/SCTP. Each element can be a 16-bit unsigned decimal number (e.g. "80") or range (e.g. "0-1023").
         */
        srcPorts?: string[] | null;
        /**
         * Two-letter ISO 3166-1 alpha-2 country code associated with the source IP address.
         */
        srcRegionCodes?: string[] | null;
        /**
         * User-defined fields. Each element names a defined field and lists the matching values for that field.
         */
        userDefinedFields?: Schema$SecurityPolicyRuleNetworkMatcherUserDefinedFieldMatch[];
    }
    export interface Schema$SecurityPolicyRuleNetworkMatcherUserDefinedFieldMatch {
        /**
         * Name of the user-defined field, as given in the definition.
         */
        name?: string | null;
        /**
         * Matching values of the field. Each element can be a 32-bit unsigned decimal or hexadecimal (starting with "0x") number (e.g. "64") or range (e.g. "0x400-0x7ff").
         */
        values?: string[] | null;
    }
    export interface Schema$SecurityPolicyRulePreconfiguredWafConfig {
        /**
         * A list of exclusions to apply during preconfigured WAF evaluation.
         */
        exclusions?: Schema$SecurityPolicyRulePreconfiguredWafConfigExclusion[];
    }
    export interface Schema$SecurityPolicyRulePreconfiguredWafConfigExclusion {
        /**
         * A list of request cookie names whose value will be excluded from inspection during preconfigured WAF evaluation.
         */
        requestCookiesToExclude?: Schema$SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams[];
        /**
         * A list of request header names whose value will be excluded from inspection during preconfigured WAF evaluation.
         */
        requestHeadersToExclude?: Schema$SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams[];
        /**
         * A list of request query parameter names whose value will be excluded from inspection during preconfigured WAF evaluation. Note that the parameter can be in the query string or in the POST body.
         */
        requestQueryParamsToExclude?: Schema$SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams[];
        /**
         * A list of request URIs from the request line to be excluded from inspection during preconfigured WAF evaluation. When specifying this field, the query or fragment part should be excluded.
         */
        requestUrisToExclude?: Schema$SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams[];
        /**
         * A list of target rule IDs under the WAF rule set to apply the preconfigured WAF exclusion. If omitted, it refers to all the rule IDs under the WAF rule set.
         */
        targetRuleIds?: string[] | null;
        /**
         * Target WAF rule set to apply the preconfigured WAF exclusion.
         */
        targetRuleSet?: string | null;
    }
    export interface Schema$SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams {
        /**
         * The match operator for the field.
         */
        op?: string | null;
        /**
         * The value of the field.
         */
        val?: string | null;
    }
    export interface Schema$SecurityPolicyRuleRateLimitOptions {
        /**
         * Can only be specified if the action for the rule is "rate_based_ban". If specified, determines the time (in seconds) the traffic will continue to be banned by the rate limit after the rate falls below the threshold.
         */
        banDurationSec?: number | null;
        /**
         * Can only be specified if the action for the rule is "rate_based_ban". If specified, the key will be banned for the configured 'ban_duration_sec' when the number of requests that exceed the 'rate_limit_threshold' also exceed this 'ban_threshold'.
         */
        banThreshold?: Schema$SecurityPolicyRuleRateLimitOptionsThreshold;
        /**
         * Action to take for requests that are under the configured rate limit threshold. Valid option is "allow" only.
         */
        conformAction?: string | null;
        /**
         * Determines the key to enforce the rate_limit_threshold on. Possible values are: - ALL: A single rate limit threshold is applied to all the requests matching this rule. This is the default value if "enforceOnKey" is not configured. - IP: The source IP address of the request is the key. Each IP has this limit enforced separately. - HTTP_HEADER: The value of the HTTP header whose name is configured under "enforceOnKeyName". The key value is truncated to the first 128 bytes of the header value. If no such header is present in the request, the key type defaults to ALL. - XFF_IP: The first IP address (i.e. the originating client IP address) specified in the list of IPs under X-Forwarded-For HTTP header. If no such header is present or the value is not a valid IP, the key defaults to the source IP address of the request i.e. key type IP. - HTTP_COOKIE: The value of the HTTP cookie whose name is configured under "enforceOnKeyName". The key value is truncated to the first 128 bytes of the cookie value. If no such cookie is present in the request, the key type defaults to ALL. - HTTP_PATH: The URL path of the HTTP request. The key value is truncated to the first 128 bytes. - SNI: Server name indication in the TLS session of the HTTPS request. The key value is truncated to the first 128 bytes. The key type defaults to ALL on a HTTP session. - REGION_CODE: The country/region from which the request originates.
         */
        enforceOnKey?: string | null;
        /**
         * If specified, any combination of values of enforce_on_key_type/enforce_on_key_name is treated as the key on which ratelimit threshold/action is enforced. You can specify up to 3 enforce_on_key_configs. If enforce_on_key_configs is specified, enforce_on_key must not be specified.
         */
        enforceOnKeyConfigs?: Schema$SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig[];
        /**
         * Rate limit key name applicable only for the following key types: HTTP_HEADER -- Name of the HTTP header whose value is taken as the key value. HTTP_COOKIE -- Name of the HTTP cookie whose value is taken as the key value.
         */
        enforceOnKeyName?: string | null;
        /**
         * Action to take for requests that are above the configured rate limit threshold, to either deny with a specified HTTP response code, or redirect to a different endpoint. Valid options are `deny(STATUS)`, where valid values for `STATUS` are 403, 404, 429, and 502, and `redirect`, where the redirect parameters come from `exceedRedirectOptions` below. The `redirect` action is only supported in Global Security Policies of type CLOUD_ARMOR.
         */
        exceedAction?: string | null;
        /**
         * Specified gRPC response status for proxyless gRPC requests that are above the configured rate limit threshold
         */
        exceedActionRpcStatus?: Schema$SecurityPolicyRuleRateLimitOptionsRpcStatus;
        /**
         * Parameters defining the redirect action that is used as the exceed action. Cannot be specified if the exceed action is not redirect. This field is only supported in Global Security Policies of type CLOUD_ARMOR.
         */
        exceedRedirectOptions?: Schema$SecurityPolicyRuleRedirectOptions;
        /**
         * Threshold at which to begin ratelimiting.
         */
        rateLimitThreshold?: Schema$SecurityPolicyRuleRateLimitOptionsThreshold;
    }
    export interface Schema$SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig {
        /**
         * Rate limit key name applicable only for the following key types: HTTP_HEADER -- Name of the HTTP header whose value is taken as the key value. HTTP_COOKIE -- Name of the HTTP cookie whose value is taken as the key value.
         */
        enforceOnKeyName?: string | null;
        /**
         * Determines the key to enforce the rate_limit_threshold on. Possible values are: - ALL: A single rate limit threshold is applied to all the requests matching this rule. This is the default value if "enforceOnKeyConfigs" is not configured. - IP: The source IP address of the request is the key. Each IP has this limit enforced separately. - HTTP_HEADER: The value of the HTTP header whose name is configured under "enforceOnKeyName". The key value is truncated to the first 128 bytes of the header value. If no such header is present in the request, the key type defaults to ALL. - XFF_IP: The first IP address (i.e. the originating client IP address) specified in the list of IPs under X-Forwarded-For HTTP header. If no such header is present or the value is not a valid IP, the key defaults to the source IP address of the request i.e. key type IP. - HTTP_COOKIE: The value of the HTTP cookie whose name is configured under "enforceOnKeyName". The key value is truncated to the first 128 bytes of the cookie value. If no such cookie is present in the request, the key type defaults to ALL. - HTTP_PATH: The URL path of the HTTP request. The key value is truncated to the first 128 bytes. - SNI: Server name indication in the TLS session of the HTTPS request. The key value is truncated to the first 128 bytes. The key type defaults to ALL on a HTTP session. - REGION_CODE: The country/region from which the request originates.
         */
        enforceOnKeyType?: string | null;
    }
    /**
     * Simplified google.rpc.Status type (omitting details).
     */
    export interface Schema$SecurityPolicyRuleRateLimitOptionsRpcStatus {
        /**
         * The status code, which should be an enum value of google.rpc.Code.
         */
        code?: number | null;
        /**
         * A developer-facing error message, which should be in English.
         */
        message?: string | null;
    }
    export interface Schema$SecurityPolicyRuleRateLimitOptionsThreshold {
        /**
         * Number of HTTP(S) requests for calculating the threshold.
         */
        count?: number | null;
        /**
         * Interval over which the threshold is computed.
         */
        intervalSec?: number | null;
    }
    export interface Schema$SecurityPolicyRuleRedirectOptions {
        /**
         * Target for the redirect action. This is required if the type is EXTERNAL_302 and cannot be specified for GOOGLE_RECAPTCHA.
         */
        target?: string | null;
        /**
         * Type of the redirect action.
         */
        type?: string | null;
    }
    export interface Schema$SecurityPolicyUserDefinedField {
        /**
         * The base relative to which 'offset' is measured. Possible values are: - IPV4: Points to the beginning of the IPv4 header. - IPV6: Points to the beginning of the IPv6 header. - TCP: Points to the beginning of the TCP header, skipping over any IPv4 options or IPv6 extension headers. Not present for non-first fragments. - UDP: Points to the beginning of the UDP header, skipping over any IPv4 options or IPv6 extension headers. Not present for non-first fragments. required
         */
        base?: string | null;
        /**
         * If specified, apply this mask (bitwise AND) to the field to ignore bits before matching. Encoded as a hexadecimal number (starting with "0x"). The last byte of the field (in network byte order) corresponds to the least significant byte of the mask.
         */
        mask?: string | null;
        /**
         * The name of this field. Must be unique within the policy.
         */
        name?: string | null;
        /**
         * Offset of the first byte of the field (in network byte order) relative to 'base'.
         */
        offset?: number | null;
        /**
         * Size of the field in bytes. Valid values: 1-4.
         */
        size?: number | null;
    }
    /**
     * The authentication and authorization settings for a BackendService.
     */
    export interface Schema$SecuritySettings {
        /**
         * [Deprecated] Use clientTlsPolicy instead.
         */
        authentication?: string | null;
        /**
         * [Deprecated] Authentication policy defines what authentication methods can be accepted on backends, and if authenticated, which method/certificate will set the request principal. request principal.
         */
        authenticationPolicy?: Schema$AuthenticationPolicy;
        /**
         * [Deprecated] Authorization config defines the Role Based Access Control (RBAC) config. Authorization config defines the Role Based Access Control (RBAC) config.
         */
        authorizationConfig?: Schema$AuthorizationConfig;
        /**
         * The configuration needed to generate a signature for access to private storage buckets that support AWS's Signature Version 4 for authentication. Allowed only for INTERNET_IP_PORT and INTERNET_FQDN_PORT NEG backends.
         */
        awsV4Authentication?: Schema$AWSV4Signature;
        /**
         * Optional. A URL referring to a networksecurity.ClientTlsPolicy resource that describes how clients should authenticate with this service's backends. clientTlsPolicy only applies to a global BackendService with the loadBalancingScheme set to INTERNAL_SELF_MANAGED. If left blank, communications are not encrypted.
         */
        clientTlsPolicy?: string | null;
        /**
         * [Deprecated] TLS Settings for the backend service.
         */
        clientTlsSettings?: Schema$ClientTlsSettings;
        /**
         * Optional. A list of Subject Alternative Names (SANs) that the client verifies during a mutual TLS handshake with an server/endpoint for this BackendService. When the server presents its X.509 certificate to the client, the client inspects the certificate's subjectAltName field. If the field contains one of the specified values, the communication continues. Otherwise, it fails. This additional check enables the client to verify that the server is authorized to run the requested service. Note that the contents of the server certificate's subjectAltName field are configured by the Public Key Infrastructure which provisions server identities. Only applies to a global BackendService with loadBalancingScheme set to INTERNAL_SELF_MANAGED. Only applies when BackendService has an attached clientTlsPolicy with clientCertificate (mTLS mode).
         */
        subjectAltNames?: string[] | null;
    }
    /**
     * An instance serial console output.
     */
    export interface Schema$SerialPortOutput {
        /**
         * [Output Only] The contents of the console output.
         */
        contents?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#serialPortOutput for serial port output.
         */
        kind?: string | null;
        /**
         * [Output Only] The position of the next byte of content, regardless of whether the content exists, following the output returned in the `contents` property. Use this value in the next request as the start parameter.
         */
        next?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * The starting byte position of the output that was returned. This should match the start parameter sent with the request. If the serial console output exceeds the size of the buffer (1 MB), older output is overwritten by newer content. The output start value will indicate the byte position of the output that was returned, which might be different than the `start` value that was specified in the request.
         */
        start?: string | null;
    }
    export interface Schema$ServerBinding {
        type?: string | null;
    }
    /**
     * The TLS settings for the server.
     */
    export interface Schema$ServerTlsSettings {
        /**
         * Configures the mechanism to obtain security certificates and identity information.
         */
        proxyTlsContext?: Schema$TlsContext;
        /**
         * A list of alternate names to verify the subject identity in the certificate presented by the client.
         */
        subjectAltNames?: string[] | null;
        /**
         * Indicates whether connections should be secured using TLS. The value of this field determines how TLS is enforced. This field can be set to one of the following: - SIMPLE Secure connections with standard TLS semantics. - MUTUAL Secure connections to the backends using mutual TLS by presenting client certificates for authentication.
         */
        tlsMode?: string | null;
    }
    /**
     * A service account.
     */
    export interface Schema$ServiceAccount {
        /**
         * Email address of the service account.
         */
        email?: string | null;
        /**
         * The list of scopes to be made available for this service account.
         */
        scopes?: string[] | null;
    }
    /**
     * Represents a ServiceAttachment resource. A service attachment represents a service that a producer has exposed. It encapsulates the load balancer which fronts the service runs and a list of NAT IP ranges that the producers uses to represent the consumers connecting to the service.
     */
    export interface Schema$ServiceAttachment {
        /**
         * [Output Only] An array of connections for all the consumers connected to this service attachment.
         */
        connectedEndpoints?: Schema$ServiceAttachmentConnectedEndpoint[];
        /**
         * The connection preference of service attachment. The value can be set to ACCEPT_AUTOMATIC. An ACCEPT_AUTOMATIC service attachment is one that always accepts the connection from consumer forwarding rules.
         */
        connectionPreference?: string | null;
        /**
         * Projects that are allowed to connect to this service attachment.
         */
        consumerAcceptLists?: Schema$ServiceAttachmentConsumerProjectLimit[];
        /**
         * Projects that are not allowed to connect to this service attachment. The project can be specified using its id or number.
         */
        consumerRejectLists?: string[] | null;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * If specified, the domain name will be used during the integration between the PSC connected endpoints and the Cloud DNS. For example, this is a valid domain name: "p.mycompany.com.". Current max number of domain names supported is 1.
         */
        domainNames?: string[] | null;
        /**
         * If true, enable the proxy protocol which is for supplying client TCP/IP address data in TCP connections that traverse proxies on their way to destination servers.
         */
        enableProxyProtocol?: boolean | null;
        /**
         * Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a ServiceAttachment. An up-to-date fingerprint must be provided in order to patch/update the ServiceAttachment; otherwise, the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the ServiceAttachment.
         */
        fingerprint?: string | null;
        /**
         * [Output Only] The unique identifier for the resource type. The server generates this identifier.
         */
        id?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#serviceAttachment for service attachments.
         */
        kind?: string | null;
        /**
         * Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * An array of URLs where each entry is the URL of a subnet provided by the service producer to use for NAT in this service attachment.
         */
        natSubnets?: string[] | null;
        /**
         * The URL of a forwarding rule with loadBalancingScheme INTERNAL* that is serving the endpoint identified by this service attachment.
         */
        producerForwardingRule?: string | null;
        /**
         * The number of VPCs to which this endpoint is allowed to be propagated per accept list resource (project or network). For ACCEPT_AUTOMATIC service attachment, this limit is default to per project.
         */
        propagatedConnectionLimit?: number | null;
        /**
         * [Output Only] An 128-bit global unique ID of the PSC service attachment.
         */
        pscServiceAttachmentId?: Schema$Uint128;
        /**
         * This flag determines whether a consumer accept/reject list change can reconcile the statuses of existing ACCEPTED or REJECTED PSC endpoints. - If false, connection policy update will only affect existing PENDING PSC endpoints. Existing ACCEPTED/REJECTED endpoints will remain untouched regardless how the connection policy is modified . - If true, update will affect both PENDING and ACCEPTED/REJECTED PSC endpoints. For example, an ACCEPTED PSC endpoint will be moved to REJECTED if its project is added to the reject list. For newly created service attachment, this boolean defaults to false.
         */
        reconcileConnections?: boolean | null;
        /**
         * [Output Only] URL of the region where the service attachment resides. This field applies only to the region resource. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
         */
        region?: string | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * The URL of a service serving the endpoint identified by this service attachment.
         */
        targetService?: string | null;
        /**
         * When a tunneling config is set on this service attachment it will encapsulate traffic between consumer and producer. When tunneling is enabled: - nat_subnets must be unset - enable_proxy_protocol must be false - producer_forwarding_rule must be a L4 ILB. -
         */
        tunnelingConfig?: Schema$ServiceAttachmentTunnelingConfig;
    }
    /**
     * Contains a list of ServiceAttachmentsScopedList.
     */
    export interface Schema$ServiceAttachmentAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of ServiceAttachmentsScopedList resources.
         */
        items?: {
            [key: string]: Schema$ServiceAttachmentsScopedList;
        } | null;
        /**
         * Type of resource.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * [Output Only] A connection connected to this service attachment.
     */
    export interface Schema$ServiceAttachmentConnectedEndpoint {
        /**
         * The url of the consumer network.
         */
        consumerNetwork?: string | null;
        /**
         * The url of a connected endpoint.
         */
        endpoint?: string | null;
        /**
         * The PSC connection id of the connected endpoint.
         */
        pscConnectionId?: string | null;
        /**
         * The status of a connected endpoint to this service attachment.
         */
        status?: string | null;
    }
    export interface Schema$ServiceAttachmentConsumerProjectLimit {
        /**
         * The value of the limit to set.
         */
        connectionLimit?: number | null;
        /**
         * The network URL for the network to set the limit for.
         */
        networkUrl?: string | null;
        /**
         * The project id or number for the project to set the limit for.
         */
        projectIdOrNum?: string | null;
    }
    export interface Schema$ServiceAttachmentList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of ServiceAttachment resources.
         */
        items?: Schema$ServiceAttachment[];
        /**
         * [Output Only] Type of the resource. Always compute#serviceAttachment for service attachments.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$ServiceAttachmentsScopedList {
        /**
         * A list of ServiceAttachments contained in this scope.
         */
        serviceAttachments?: Schema$ServiceAttachment[];
        /**
         * Informational warning which replaces the list of service attachments when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Use to configure this PSC connection in tunneling mode. In tunneling mode traffic from consumer to producer will be encapsulated as it crosses the VPC boundary and traffic from producer to consumer will be decapsulated in the same manner.
     */
    export interface Schema$ServiceAttachmentTunnelingConfig {
        /**
         * Specify the encapsulation protocol and what metadata to include in incoming encapsulated packet headers.
         */
        encapsulationProfile?: string | null;
        /**
         * How this Service Attachment will treat traffic sent to the tunnel_ip, destined for the consumer network.
         */
        routingMode?: string | null;
    }
    /**
     * Specifies the parameters to configure an integration with instances.
     */
    export interface Schema$ServiceIntegrationSpec {
        backupDr?: Schema$ServiceIntegrationSpecBackupDRSpec;
    }
    /**
     * Specifies parameters to Backup and DR to attach a BackupPlan to a compute instance for managed VM backup.
     */
    export interface Schema$ServiceIntegrationSpecBackupDRSpec {
        /**
         * The BackupPlan resource to attach to the instance. Specified as a resource reference in instances, and regional instance templates, and as just the plan name in global instance templates
         */
        plan?: string | null;
    }
    export interface Schema$SetCommonInstanceMetadataOperationMetadata {
        /**
         * [Output Only] The client operation id.
         */
        clientOperationId?: string | null;
        /**
         * [Output Only] Status information per location (location name is key). Example key: zones/us-central1-a
         */
        perLocationOperations?: {
            [key: string]: Schema$SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo;
        } | null;
    }
    export interface Schema$SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo {
        /**
         * [Output Only] If state is `ABANDONED` or `FAILED`, this field is populated.
         */
        error?: Schema$Status;
        /**
         * [Output Only] Status of the action, which can be one of the following: `PROPAGATING`, `PROPAGATED`, `ABANDONED`, `FAILED`, or `DONE`.
         */
        state?: string | null;
    }
    /**
     * The share setting for reservations and sole tenancy node groups.
     */
    export interface Schema$ShareSettings {
        /**
         * A map of folder id and folder config to specify consumer projects for this shared-reservation. This is only valid when share_type's value is DIRECT_PROJECTS_UNDER_SPECIFIC_FOLDERS. Folder id should be a string of number, and without "folders/" prefix.
         */
        folderMap?: {
            [key: string]: Schema$ShareSettingsFolderConfig;
        } | null;
        /**
         * A map of project id and project config. This is only valid when share_type's value is SPECIFIC_PROJECTS.
         */
        projectMap?: {
            [key: string]: Schema$ShareSettingsProjectConfig;
        } | null;
        /**
         * A List of Project names to specify consumer projects for this shared-reservation. This is only valid when share_type's value is SPECIFIC_PROJECTS.
         */
        projects?: string[] | null;
        /**
         * Type of sharing for this shared-reservation
         */
        shareType?: string | null;
    }
    /**
     * Config for each folder in the share settings.
     */
    export interface Schema$ShareSettingsFolderConfig {
        /**
         * The folder ID, should be same as the key of this folder config in the parent map. Folder id should be a string of number, and without "folders/" prefix.
         */
        folderId?: string | null;
    }
    /**
     * Config for each project in the share settings.
     */
    export interface Schema$ShareSettingsProjectConfig {
        /**
         * The project ID, should be same as the key of this project config in the parent map.
         */
        projectId?: string | null;
    }
    /**
     * A set of Shielded Instance options.
     */
    export interface Schema$ShieldedInstanceConfig {
        /**
         * Defines whether the instance has integrity monitoring enabled. Enabled by default.
         */
        enableIntegrityMonitoring?: boolean | null;
        /**
         * Defines whether the instance has Secure Boot enabled. Disabled by default.
         */
        enableSecureBoot?: boolean | null;
        /**
         * Defines whether the instance has the vTPM enabled. Enabled by default.
         */
        enableVtpm?: boolean | null;
    }
    /**
     * A Shielded Instance Identity.
     */
    export interface Schema$ShieldedInstanceIdentity {
        /**
         * An Endorsement Key (EK) made by the ECC P256 algorithm issued to the Shielded Instance's vTPM.
         */
        eccP256EncryptionKey?: Schema$ShieldedInstanceIdentityEntry;
        /**
         * An Attestation Key (AK) made by the ECC P256 algorithm issued to the Shielded Instance's vTPM.
         */
        eccP256SigningKey?: Schema$ShieldedInstanceIdentityEntry;
        /**
         * An Endorsement Key (EK) made by the RSA 2048 algorithm issued to the Shielded Instance's vTPM.
         */
        encryptionKey?: Schema$ShieldedInstanceIdentityEntry;
        /**
         * [Output Only] Type of the resource. Always compute#shieldedInstanceIdentity for shielded Instance identity entry.
         */
        kind?: string | null;
        /**
         * An Attestation Key (AK) made by the RSA 2048 algorithm issued to the Shielded Instance's vTPM.
         */
        signingKey?: Schema$ShieldedInstanceIdentityEntry;
    }
    /**
     * A Shielded Instance Identity Entry.
     */
    export interface Schema$ShieldedInstanceIdentityEntry {
        /**
         * A PEM-encoded X.509 certificate. This field can be empty.
         */
        ekCert?: string | null;
        /**
         * A PEM-encoded public key.
         */
        ekPub?: string | null;
    }
    /**
     * The policy describes the baseline against which Instance boot integrity is measured.
     */
    export interface Schema$ShieldedInstanceIntegrityPolicy {
        /**
         * Updates the integrity policy baseline using the measurements from the VM instance's most recent boot.
         */
        updateAutoLearnPolicy?: boolean | null;
    }
    /**
     * A set of Shielded VM options.
     */
    export interface Schema$ShieldedVmConfig {
        /**
         * Defines whether the instance has integrity monitoring enabled.
         */
        enableIntegrityMonitoring?: boolean | null;
        /**
         * Defines whether the instance has Secure Boot enabled.
         */
        enableSecureBoot?: boolean | null;
        /**
         * Defines whether the instance has the vTPM enabled.
         */
        enableVtpm?: boolean | null;
    }
    /**
     * A Shielded VM Identity.
     */
    export interface Schema$ShieldedVmIdentity {
        /**
         * An Endorsement Key (EK) issued to the Shielded VM's vTPM.
         */
        encryptionKey?: Schema$ShieldedVmIdentityEntry;
        /**
         * [Output Only] Type of the resource. Always compute#shieldedVmIdentity for shielded VM identity entry.
         */
        kind?: string | null;
        /**
         * An Attestation Key (AK) issued to the Shielded VM's vTPM.
         */
        signingKey?: Schema$ShieldedVmIdentityEntry;
    }
    /**
     * A Shielded Instance Identity Entry.
     */
    export interface Schema$ShieldedVmIdentityEntry {
        /**
         * A PEM-encoded X.509 certificate. This field can be empty.
         */
        ekCert?: string | null;
        /**
         * A PEM-encoded public key.
         */
        ekPub?: string | null;
    }
    /**
     * The policy describes the baseline against which VM instance boot integrity is measured.
     */
    export interface Schema$ShieldedVmIntegrityPolicy {
        /**
         * Updates the integrity policy baseline using the measurements from the VM instance's most recent boot.
         */
        updateAutoLearnPolicy?: boolean | null;
    }
    /**
     * Represents a customer-supplied Signing Key used by Cloud CDN Signed URLs
     */
    export interface Schema$SignedUrlKey {
        /**
         * Name of the key. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        keyName?: string | null;
        /**
         * 128-bit key value used for signing the URL. The key value must be a valid RFC 4648 Section 5 base64url encoded string.
         */
        keyValue?: string | null;
    }
    /**
     * Represents a Persistent Disk Snapshot resource. You can use snapshots to back up data on a regular interval. For more information, read Creating persistent disk snapshots.
     */
    export interface Schema$Snapshot {
        /**
         * [Output Only] The architecture of the snapshot. Valid values are ARM64 or X86_64.
         */
        architecture?: string | null;
        /**
         * [Output Only] Set to true if snapshots are automatically created by applying resource policy on the target disk.
         */
        autoCreated?: boolean | null;
        /**
         * Creates the new snapshot in the snapshot chain labeled with the specified name. The chain name must be 1-63 characters long and comply with RFC1035. This is an uncommon option only for advanced service owners who needs to create separate snapshot chains, for example, for chargeback tracking. When you describe your snapshot resource, this field is visible only if it has a non-empty value.
         */
        chainName?: string | null;
        /**
         * [Output Only] Size in bytes of the snapshot at creation time.
         */
        creationSizeBytes?: string | null;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * [Output Only] Size of the source disk, specified in GB.
         */
        diskSizeGb?: string | null;
        /**
         * [Output Only] Number of bytes downloaded to restore a snapshot to a disk.
         */
        downloadBytes?: string | null;
        /**
         * Whether this snapshot is created from a confidential compute mode disk. [Output Only]: This field is not set by user, but from source disk.
         */
        enableConfidentialCompute?: boolean | null;
        /**
         * [Input Only] Whether to attempt an application consistent snapshot by informing the OS to prepare for the snapshot process.
         */
        guestFlush?: boolean | null;
        /**
         * [Output Only] A list of features to enable on the guest operating system. Applicable only for bootable images. Read Enabling guest operating system features to see a list of available options.
         */
        guestOsFeatures?: Schema$GuestOsFeature[];
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#snapshot for Snapshot resources.
         */
        kind?: string | null;
        /**
         * A fingerprint for the labels being applied to this snapshot, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a snapshot.
         */
        labelFingerprint?: string | null;
        /**
         * Labels to apply to this snapshot. These can be later modified by the setLabels method. Label values may be empty.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * [Output Only] Integer license codes indicating which licenses are attached to this snapshot.
         */
        licenseCodes?: string[] | null;
        /**
         * [Output Only] A list of public visible licenses that apply to this snapshot. This can be because the original image had licenses attached (such as a Windows image).
         */
        licenses?: string[] | null;
        /**
         * An opaque location hint used to place the snapshot close to other resources. This field is for use by internal tools that use the public API.
         */
        locationHint?: string | null;
        /**
         * Number of days the snapshot should be retained before being deleted automatically.
         */
        maxRetentionDays?: number | null;
        /**
         * Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * [Output Only] URL of the region where the snapshot resides. Only applicable for regional snapshots.
         */
        region?: string | null;
        /**
         * [Output Only] Reserved for future use.
         */
        satisfiesPzs?: boolean | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource's resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * Encrypts the snapshot using a customer-supplied encryption key. After you encrypt a snapshot using a customer-supplied key, you must provide the same key if you use the snapshot later. For example, you must provide the encryption key when you create a disk from the encrypted snapshot in a future request. Customer-supplied encryption keys do not protect access to metadata of the snapshot. If you do not provide an encryption key when creating the snapshot, then the snapshot will be encrypted using an automatically generated key and you do not need to provide a key to use the snapshot later.
         */
        snapshotEncryptionKey?: Schema$CustomerEncryptionKey;
        /**
         * Indicates the type of the snapshot.
         */
        snapshotType?: string | null;
        /**
         * The source disk used to create this snapshot.
         */
        sourceDisk?: string | null;
        /**
         * The customer-supplied encryption key of the source disk. Required if the source disk is protected by a customer-supplied encryption key.
         */
        sourceDiskEncryptionKey?: Schema$CustomerEncryptionKey;
        /**
         * The source disk whose recovery checkpoint will be used to create this snapshot.
         */
        sourceDiskForRecoveryCheckpoint?: string | null;
        /**
         * [Output Only] The ID value of the disk used to create this snapshot. This value may be used to determine whether the snapshot was taken from the current or a previous instance of a given disk name.
         */
        sourceDiskId?: string | null;
        /**
         * The source instant snapshot used to create this snapshot. You can provide this as a partial or full URL to the resource. For example, the following are valid values: - https://www.googleapis.com/compute/v1/projects/project/zones/zone /instantSnapshots/instantSnapshot - projects/project/zones/zone/instantSnapshots/instantSnapshot - zones/zone/instantSnapshots/instantSnapshot
         */
        sourceInstantSnapshot?: string | null;
        /**
         * Customer provided encryption key when creating Snapshot from Instant Snapshot.
         */
        sourceInstantSnapshotEncryptionKey?: Schema$CustomerEncryptionKey;
        /**
         * [Output Only] The unique ID of the instant snapshot used to create this snapshot. This value identifies the exact instant snapshot that was used to create this persistent disk. For example, if you created the persistent disk from an instant snapshot that was later deleted and recreated under the same name, the source instant snapshot ID would identify the exact instant snapshot that was used.
         */
        sourceInstantSnapshotId?: string | null;
        /**
         * [Output Only] URL of the resource policy which created this scheduled snapshot.
         */
        sourceSnapshotSchedulePolicy?: string | null;
        /**
         * [Output Only] ID of the resource policy which created this scheduled snapshot.
         */
        sourceSnapshotSchedulePolicyId?: string | null;
        /**
         * [Output Only] The status of the snapshot. This can be CREATING, DELETING, FAILED, READY, or UPLOADING.
         */
        status?: string | null;
        /**
         * [Output Only] A size of the storage used by the snapshot. As snapshots share storage, this number is expected to change with snapshot creation/deletion.
         */
        storageBytes?: string | null;
        /**
         * [Output Only] An indicator whether storageBytes is in a stable state or it is being adjusted as a result of shared storage reallocation. This status can either be UPDATING, meaning the size of the snapshot is being updated, or UP_TO_DATE, meaning the size of the snapshot is up-to-date.
         */
        storageBytesStatus?: string | null;
        /**
         * Cloud Storage bucket storage location of the snapshot (regional or multi-regional).
         */
        storageLocations?: string[] | null;
        /**
         * [Output Only] A list of user provided licenses represented by a list of URLs to the license resource.
         */
        userLicenses?: string[] | null;
    }
    /**
     * Contains a list of Snapshot resources.
     */
    export interface Schema$SnapshotList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of Snapshot resources.
         */
        items?: Schema$Snapshot[];
        /**
         * Type of resource.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$SnapshotSettings {
        /**
         * Policy of which storage location is going to be resolved, and additional data that particularizes how the policy is going to be carried out.
         */
        storageLocation?: Schema$SnapshotSettingsStorageLocationSettings;
    }
    export interface Schema$SnapshotSettingsStorageLocationSettings {
        /**
         * When the policy is SPECIFIC_LOCATIONS, snapshots will be stored in the locations listed in this field. Keys are GCS bucket locations.
         */
        locations?: {
            [key: string]: Schema$SnapshotSettingsStorageLocationSettingsStorageLocationPreference;
        } | null;
        /**
         * The chosen location policy.
         */
        policy?: string | null;
    }
    /**
     * A structure for specifying storage locations.
     */
    export interface Schema$SnapshotSettingsStorageLocationSettingsStorageLocationPreference {
        /**
         * Name of the location. It should be one of the GCS buckets.
         */
        name?: string | null;
    }
    export interface Schema$SourceDiskEncryptionKey {
        /**
         * The customer-supplied encryption key of the source disk. Required if the source disk is protected by a customer-supplied encryption key.
         */
        diskEncryptionKey?: Schema$CustomerEncryptionKey;
        /**
         * URL of the disk attached to the source instance. This can be a full or valid partial URL. For example, the following are valid values: - https://www.googleapis.com/compute/v1/projects/project/zones/zone /disks/disk - projects/project/zones/zone/disks/disk - zones/zone/disks/disk
         */
        sourceDisk?: string | null;
    }
    /**
     * A specification of the parameters to use when creating the instance template from a source instance.
     */
    export interface Schema$SourceInstanceParams {
        /**
         * Attached disks configuration. If not provided, defaults are applied: For boot disk and any other R/W disks, the source images for each disk will be used. For read-only disks, they will be attached in read-only mode. Local SSD disks will be created as blank volumes.
         */
        diskConfigs?: Schema$DiskInstantiationConfig[];
    }
    /**
     * DEPRECATED: Please use compute#instanceProperties instead. New properties will not be added to this field.
     */
    export interface Schema$SourceInstanceProperties {
        /**
         * Enables instances created based on this machine image to send packets with source IP addresses other than their own and receive packets with destination IP addresses other than their own. If these instances will be used as an IP gateway or it will be set as the next-hop in a Route resource, specify true. If unsure, leave this set to false. See the Enable IP forwarding documentation for more information.
         */
        canIpForward?: boolean | null;
        /**
         * Whether the instance created from this machine image should be protected against deletion.
         */
        deletionProtection?: boolean | null;
        /**
         * An optional text description for the instances that are created from this machine image.
         */
        description?: string | null;
        /**
         * An array of disks that are associated with the instances that are created from this machine image.
         */
        disks?: Schema$SavedAttachedDisk[];
        /**
         * A list of guest accelerator cards' type and count to use for instances created from this machine image.
         */
        guestAccelerators?: Schema$AcceleratorConfig[];
        /**
         * KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified.
         */
        keyRevocationActionType?: string | null;
        /**
         * Labels to apply to instances that are created from this machine image.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * The machine type to use for instances that are created from this machine image.
         */
        machineType?: string | null;
        /**
         * The metadata key/value pairs to assign to instances that are created from this machine image. These pairs can consist of custom metadata or predefined keys. See Project and instance metadata for more information.
         */
        metadata?: Schema$Metadata;
        /**
         * Minimum cpu/platform to be used by instances created from this machine image. The instance may be scheduled on the specified or newer cpu/platform. Applicable values are the friendly names of CPU platforms, such as minCpuPlatform: "Intel Haswell" or minCpuPlatform: "Intel Sandy Bridge". For more information, read Specifying a Minimum CPU Platform.
         */
        minCpuPlatform?: string | null;
        /**
         * An array of network access configurations for this interface.
         */
        networkInterfaces?: Schema$NetworkInterface[];
        /**
         * PostKeyRevocationActionType of the instance.
         */
        postKeyRevocationActionType?: string | null;
        /**
         * Specifies the scheduling options for the instances that are created from this machine image.
         */
        scheduling?: Schema$Scheduling;
        /**
         * A list of service accounts with specified scopes. Access tokens for these service accounts are available to the instances that are created from this machine image. Use metadata queries to obtain the access tokens for these instances.
         */
        serviceAccounts?: Schema$ServiceAccount[];
        /**
         * A list of tags to apply to the instances that are created from this machine image. The tags identify valid sources or targets for network firewalls. The setTags method can modify this list of tags. Each tag within the list must comply with RFC1035.
         */
        tags?: Schema$Tags;
    }
    /**
     * Represents an SSL certificate resource. Google Compute Engine has two SSL certificate resources: * [Global](/compute/docs/reference/rest/alpha/sslCertificates) * [Regional](/compute/docs/reference/rest/alpha/regionSslCertificates) The global SSL certificates (sslCertificates) are used by: - Global external Application Load Balancers - Classic Application Load Balancers - Proxy Network Load Balancers (with target SSL proxies) The regional SSL certificates (regionSslCertificates) are used by: - Regional external Application Load Balancers - Regional internal Application Load Balancers Optionally, certificate file contents that you upload can contain a set of up to five PEM-encoded certificates. The API call creates an object (sslCertificate) that holds this data. You can use SSL keys and certificates to secure connections to a load balancer. For more information, read Creating and using SSL certificates, SSL certificates quotas and limits, and Troubleshooting SSL certificates.
     */
    export interface Schema$SslCertificate {
        /**
         * A value read into memory from a certificate file. The certificate file must be in PEM format. The certificate chain must be no greater than 5 certs long. The chain must include at least one intermediate cert.
         */
        certificate?: string | null;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * [Output Only] Expire time of the certificate. RFC3339
         */
        expireTime?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#sslCertificate for SSL certificates.
         */
        kind?: string | null;
        /**
         * Configuration and status of a managed SSL certificate.
         */
        managed?: Schema$SslCertificateManagedSslCertificate;
        /**
         * Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * A value read into memory from a write-only private key file. The private key file must be in PEM format. For security, only insert requests include this field.
         */
        privateKey?: string | null;
        /**
         * [Output Only] URL of the region where the regional SSL Certificate resides. This field is not applicable to global SSL Certificate.
         */
        region?: string | null;
        /**
         * [Output only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * Configuration and status of a self-managed SSL certificate.
         */
        selfManaged?: Schema$SslCertificateSelfManagedSslCertificate;
        /**
         * [Output Only] Domains associated with the certificate via Subject Alternative Name.
         */
        subjectAlternativeNames?: string[] | null;
        /**
         * (Optional) Specifies the type of SSL certificate, either "SELF_MANAGED" or "MANAGED". If not specified, the certificate is self-managed and the fields certificate and private_key are used.
         */
        type?: string | null;
    }
    export interface Schema$SslCertificateAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of SslCertificatesScopedList resources.
         */
        items?: {
            [key: string]: Schema$SslCertificatesScopedList;
        } | null;
        /**
         * [Output Only] Type of resource. Always compute#sslCertificateAggregatedList for lists of SSL Certificates.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Contains a list of SslCertificate resources.
     */
    export interface Schema$SslCertificateList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of SslCertificate resources.
         */
        items?: Schema$SslCertificate[];
        /**
         * Type of resource.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Configuration and status of a managed SSL certificate.
     */
    export interface Schema$SslCertificateManagedSslCertificate {
        /**
         * The domains for which a managed SSL certificate will be generated. Each Google-managed SSL certificate supports up to the [maximum number of domains per Google-managed SSL certificate](/load-balancing/docs/quotas#ssl_certificates).
         */
        domains?: string[] | null;
        /**
         * [Output only] Detailed statuses of the domains specified for managed certificate resource.
         */
        domainStatus?: {
            [key: string]: string;
        } | null;
        /**
         * [Output only] Status of the managed certificate resource.
         */
        status?: string | null;
    }
    /**
     * Configuration and status of a self-managed SSL certificate.
     */
    export interface Schema$SslCertificateSelfManagedSslCertificate {
        /**
         * A local certificate file. The certificate must be in PEM format. The certificate chain must be no greater than 5 certs long. The chain must include at least one intermediate cert.
         */
        certificate?: string | null;
        /**
         * A write-only private key in PEM format. Only insert requests will include this field.
         */
        privateKey?: string | null;
    }
    export interface Schema$SslCertificatesScopedList {
        /**
         * List of SslCertificates contained in this scope.
         */
        sslCertificates?: Schema$SslCertificate[];
        /**
         * Informational warning which replaces the list of backend services when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$SSLHealthCheck {
        /**
         * The TCP port number to which the health check prober sends packets. The default value is 443. Valid values are 1 through 65535.
         */
        port?: number | null;
        /**
         * Not supported.
         */
        portName?: string | null;
        /**
         * Specifies how a port is selected for health checking. Can be one of the following values: USE_FIXED_PORT: Specifies a port number explicitly using the port field in the health check. Supported by backend services for pass-through load balancers and backend services for proxy load balancers. Not supported by target pools. The health check supports all backends supported by the backend service provided the backend can be health checked. For example, GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network endpoint groups, and instance group backends. USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an indirect method of specifying the health check port by referring to the backend service. Only supported by backend services for proxy load balancers. Not supported by target pools. Not supported by backend services for pass-through load balancers. Supports all backends that can be health checked; for example, GCE_VM_IP_PORT network endpoint groups and instance group backends. For GCE_VM_IP_PORT network endpoint group backends, the health check uses the port number specified for each endpoint in the network endpoint group. For instance group backends, the health check uses the port number determined by looking up the backend service's named port in the instance group's list of named ports.
         */
        portSpecification?: string | null;
        /**
         * Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE.
         */
        proxyHeader?: string | null;
        /**
         * Instructs the health check prober to send this exact ASCII string, up to 1024 bytes in length, after establishing the TCP connection and SSL handshake.
         */
        request?: string | null;
        /**
         * Creates a content-based SSL health check. In addition to establishing a TCP connection and the TLS handshake, you can configure the health check to pass only when the backend sends this exact response ASCII string, up to 1024 bytes in length. For details, see: https://cloud.google.com/load-balancing/docs/health-check-concepts#criteria-protocol-ssl-tcp
         */
        response?: string | null;
    }
    export interface Schema$SslPoliciesAggregatedList {
        etag?: string | null;
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of SslPoliciesScopedList resources.
         */
        items?: {
            [key: string]: Schema$SslPoliciesScopedList;
        } | null;
        /**
         * [Output Only] Type of resource. Always compute#sslPolicyAggregatedList for lists of SSL Policies.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$SslPoliciesList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of SslPolicy resources.
         */
        items?: Schema$SslPolicy[];
        /**
         * [Output Only] Type of the resource. Always compute#sslPoliciesList for lists of sslPolicies.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$SslPoliciesListAvailableFeaturesResponse {
        features?: string[] | null;
    }
    export interface Schema$SslPoliciesScopedList {
        /**
         * A list of SslPolicies contained in this scope.
         */
        sslPolicies?: Schema$SslPolicy[];
        /**
         * Informational warning which replaces the list of SSL policies when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Represents an SSL Policy resource. Use SSL policies to control the SSL features, such as versions and cipher suites, offered by an HTTPS or SSL Proxy load balancer. For more information, read SSL Policy Concepts.
     */
    export interface Schema$SslPolicy {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * A list of features enabled when the selected profile is CUSTOM. The method returns the set of features that can be specified in this list. This field must be empty if the profile is not CUSTOM.
         */
        customFeatures?: string[] | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * [Output Only] The list of features enabled in the SSL policy.
         */
        enabledFeatures?: string[] | null;
        /**
         * Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a SslPolicy. An up-to-date fingerprint must be provided in order to update the SslPolicy, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve an SslPolicy.
         */
        fingerprint?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output only] Type of the resource. Always compute#sslPolicyfor SSL policies.
         */
        kind?: string | null;
        /**
         * The minimum version of SSL protocol that can be used by the clients to establish a connection with the load balancer. This can be one of TLS_1_0, TLS_1_1, TLS_1_2.
         */
        minTlsVersion?: string | null;
        /**
         * Name of the resource. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * Profile specifies the set of SSL features that can be used by the load balancer when negotiating SSL with clients. This can be one of COMPATIBLE, MODERN, RESTRICTED, or CUSTOM. If using CUSTOM, the set of SSL features to enable must be specified in the customFeatures field.
         */
        profile?: string | null;
        /**
         * [Output Only] URL of the region where the regional SSL policy resides. This field is not applicable to global SSL policies.
         */
        region?: string | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * Security settings for the proxy. This field is only applicable to a global backend service with the loadBalancingScheme set to INTERNAL_SELF_MANAGED.
         */
        tlsSettings?: Schema$ServerTlsSettings;
        /**
         * [Output Only] If potential misconfigurations are detected for this SSL policy, this field will be populated with warning messages.
         */
        warnings?: Array<{
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        }> | null;
    }
    export interface Schema$SslPolicyReference {
        /**
         * URL of the SSL policy resource. Set this to empty string to clear any existing SSL policy associated with the target proxy resource.
         */
        sslPolicy?: string | null;
    }
    export interface Schema$StatefulPolicy {
        preservedState?: Schema$StatefulPolicyPreservedState;
    }
    /**
     * Configuration of preserved resources.
     */
    export interface Schema$StatefulPolicyPreservedState {
        /**
         * Disks created on the instances that will be preserved on instance delete, update, etc. This map is keyed with the device names of the disks.
         */
        disks?: {
            [key: string]: Schema$StatefulPolicyPreservedStateDiskDevice;
        } | null;
        /**
         * External network IPs assigned to the instances that will be preserved on instance delete, update, etc. This map is keyed with the network interface name.
         */
        externalIPs?: {
            [key: string]: Schema$StatefulPolicyPreservedStateNetworkIp;
        } | null;
        /**
         * Internal network IPs assigned to the instances that will be preserved on instance delete, update, etc. This map is keyed with the network interface name.
         */
        internalIPs?: {
            [key: string]: Schema$StatefulPolicyPreservedStateNetworkIp;
        } | null;
    }
    export interface Schema$StatefulPolicyPreservedStateDiskDevice {
        /**
         * These stateful disks will never be deleted during autohealing, update or VM instance recreate operations. This flag is used to configure if the disk should be deleted after it is no longer used by the group, e.g. when the given instance or the whole group is deleted. Note: disks attached in READ_ONLY mode cannot be auto-deleted.
         */
        autoDelete?: string | null;
    }
    export interface Schema$StatefulPolicyPreservedStateNetworkIp {
        /**
         * These stateful IPs will never be released during autohealing, update or VM instance recreate operations. This flag is used to configure if the IP reservation should be deleted after it is no longer used by the group, e.g. when the given instance or the whole group is deleted.
         */
        autoDelete?: string | null;
    }
    /**
     * The `Status` type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by [gRPC](https://github.com/grpc). Each `Status` message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the [API Design Guide](https://cloud.google.com/apis/design/errors).
     */
    export interface Schema$Status {
        /**
         * The status code, which should be an enum value of google.rpc.Code.
         */
        code?: number | null;
        /**
         * A list of messages that carry the error details. There is a common set of message types for APIs to use.
         */
        details?: Array<{
            [key: string]: any;
        }> | null;
        /**
         * A developer-facing error message, which should be in English. Any user-facing error message should be localized and sent in the google.rpc.Status.details field, or localized by the client.
         */
        message?: string | null;
    }
    /**
     * Represents a zonal storage pool resource.
     */
    export interface Schema$StoragePool {
        /**
         * Provisioning type of the byte capacity of the pool.
         */
        capacityProvisioningType?: string | null;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#storagePool for storage pools.
         */
        kind?: string | null;
        /**
         * A fingerprint for the labels being applied to this storage pool, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a storage pool.
         */
        labelFingerprint?: string | null;
        /**
         * Labels to apply to this storage pool. These can be later modified by the setLabels method.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * Provisioning type of the performance-related parameters of the pool, such as throughput and IOPS.
         */
        performanceProvisioningType?: string | null;
        /**
         * Provsioned IOPS of the storage pool.
         */
        provisionedIops?: string | null;
        /**
         * Provisioned throughput of the storage pool. Only relevant if the storage pool type is hyperdisk-balanced or hyperdisk-throughput.
         */
        provisionedThroughput?: string | null;
        /**
         * [Output Only] Status information for the storage pool resource.
         */
        resourceStatus?: Schema$StoragePoolResourceStatus;
        /**
         * [Output Only] Server-defined fully-qualified URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource's resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * Size, in GiB, of the storage pool.
         */
        sizeGb?: string | null;
        /**
         * [Output Only] The status of storage pool creation. - CREATING: Storage pool is provisioning. storagePool. - FAILED: Storage pool creation failed. - READY: Storage pool is ready for use. - DELETING: Storage pool is deleting.
         */
        state?: string | null;
        /**
         * [Output Only] Status information for the storage pool resource.
         */
        status?: Schema$StoragePoolResourceStatus;
        /**
         * Type of the storage pool.
         */
        storagePoolType?: string | null;
        /**
         * [Output Only] URL of the zone where the storage pool resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
         */
        zone?: string | null;
    }
    export interface Schema$StoragePoolAggregatedList {
        etag?: string | null;
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of StoragePoolsScopedList resources.
         */
        items?: {
            [key: string]: Schema$StoragePoolsScopedList;
        } | null;
        /**
         * [Output Only] Type of resource. Always compute#storagePoolAggregatedList for aggregated lists of storage pools.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$StoragePoolDisk {
        /**
         * [Output Only] Instances this disk is attached to.
         */
        attachedInstances?: string[] | null;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * [Output Only] The URL of the disk.
         */
        disk?: string | null;
        /**
         * [Output Only] The name of the disk.
         */
        name?: string | null;
        /**
         * [Output Only] The number of IOPS provisioned for the disk.
         */
        provisionedIops?: string | null;
        /**
         * [Output Only] The throughput provisioned for the disk.
         */
        provisionedThroughput?: string | null;
        /**
         * [Output Only] Resource policies applied to disk for automatic snapshot creations.
         */
        resourcePolicies?: string[] | null;
        /**
         * [Output Only] The disk size, in GB.
         */
        sizeGb?: string | null;
        /**
         * [Output Only] The disk status.
         */
        status?: string | null;
        /**
         * [Output Only] The disk type.
         */
        type?: string | null;
        /**
         * [Output Only] Amount of disk space used.
         */
        usedBytes?: string | null;
    }
    /**
     * A list of StoragePool resources.
     */
    export interface Schema$StoragePoolList {
        etag?: string | null;
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of StoragePool resources.
         */
        items?: Schema$StoragePool[];
        /**
         * [Output Only] Type of resource. Always compute#storagePoolList for lists of storagePools.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$StoragePoolListDisks {
        etag?: string | null;
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of StoragePoolDisk resources.
         */
        items?: Schema$StoragePoolDisk[];
        /**
         * [Output Only] Type of resource. Always compute#storagePoolListDisks for lists of disks in a storagePool.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * [Output Only] Contains output only fields.
     */
    export interface Schema$StoragePoolResourceStatus {
        /**
         * [Output Only] Sum of all the disks' provisioned IOPS.
         */
        aggregateDiskProvisionedIops?: string | null;
        /**
         * [Output Only] Sum of all the capacity provisioned in disks in this storage pool. A disk's provisioned capacity is the same as its total capacity.
         */
        aggregateDiskSizeGb?: string | null;
        /**
         * [Output Only] Timestamp of the last successful resize in RFC3339 text format.
         */
        lastResizeTimestamp?: string | null;
        /**
         * [Output Only] Maximum allowed aggregate disk size in gigabytes.
         */
        maxAggregateDiskSizeGb?: string | null;
        /**
         * [Output Only] Number of disks used.
         */
        numberOfDisks?: string | null;
        /**
         * [Output Only] Space used by data stored in disks within the storage pool (in bytes).
         */
        usedBytes?: string | null;
        /**
         * [Output Only] Space used by compressed and deduped data stored in disks within the storage pool (in bytes).
         */
        usedReducedBytes?: string | null;
        /**
         * [Output Only] Sum of all the disks' provisioned throughput in MB/s.
         */
        usedThroughput?: string | null;
    }
    export interface Schema$StoragePoolsScopedList {
        /**
         * [Output Only] A list of storage pool contained in this scope.
         */
        storagePools?: Schema$StoragePool[];
        /**
         * [Output Only] Informational warning which replaces the list of storage pool when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$StoragePoolType {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * [Output Only] The deprecation status associated with this storage pool type.
         */
        deprecated?: Schema$DeprecationStatus;
        /**
         * [Output Only] An optional description of this resource.
         */
        description?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#storagePoolType for storage pool types.
         */
        kind?: string | null;
        /**
         * [Output Only] Maximum provisioned IOPS.
         */
        maxProvisionedIops?: string | null;
        /**
         * [Output Only] Maximum provisioned throughput.
         */
        maxProvisionedThroughput?: string | null;
        /**
         * [Output Only] Maximum storage pool size in GB.
         */
        maxSizeGb?: string | null;
        /**
         * [Output Only] Minimum provisioned IOPS.
         */
        minProvisionedIops?: string | null;
        /**
         * [Output Only] Minimum provisioned throughput.
         */
        minProvisionedThroughput?: string | null;
        /**
         * [Output Only] Minimum storage pool size in GB.
         */
        minSizeGb?: string | null;
        /**
         * [Output Only] Name of the resource.
         */
        name?: string | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * [Output Only] The list of disk types supported in this storage pool type.
         */
        supportedDiskTypes?: string[] | null;
        /**
         * [Output Only] URL of the zone where the storage pool type resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
         */
        zone?: string | null;
    }
    export interface Schema$StoragePoolTypeAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of StoragePoolTypesScopedList resources.
         */
        items?: {
            [key: string]: Schema$StoragePoolTypesScopedList;
        } | null;
        /**
         * [Output Only] Type of resource. Always compute#storagePoolTypeAggregatedList .
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Contains a list of storage pool types.
     */
    export interface Schema$StoragePoolTypeList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of StoragePoolType resources.
         */
        items?: Schema$StoragePoolType[];
        /**
         * [Output Only] Type of resource. Always compute#storagePoolTypeList for storage pool types.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$StoragePoolTypesScopedList {
        /**
         * [Output Only] A list of storage pool types contained in this scope.
         */
        storagePoolTypes?: Schema$StoragePoolType[];
        /**
         * [Output Only] Informational warning which replaces the list of storage pool types when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$StructuredEntries {
        /**
         * Map of a partner metadata that belong to the same subdomain. It accepts any value including google.protobuf.Struct.
         */
        entries?: {
            [key: string]: any;
        } | null;
    }
    /**
     * Represents a Subnetwork resource. A subnetwork (also known as a subnet) is a logical partition of a Virtual Private Cloud network with one primary IP range and zero or more secondary IP ranges. For more information, read Virtual Private Cloud (VPC) Network.
     */
    export interface Schema$Subnetwork {
        /**
         * Can only be specified if VPC flow logging for this subnetwork is enabled. Sets the aggregation interval for collecting flow logs. Increasing the interval time reduces the amount of generated flow logs for long-lasting connections. Default is an interval of 5 seconds per connection. Valid values: INTERVAL_5_SEC, INTERVAL_30_SEC, INTERVAL_1_MIN, INTERVAL_5_MIN, INTERVAL_10_MIN, INTERVAL_15_MIN.
         */
        aggregationInterval?: string | null;
        /**
         * Whether this subnetwork's ranges can conflict with existing static routes. Setting this to true allows this subnetwork's primary and secondary ranges to overlap with (and contain) static routes that have already been configured on the corresponding network. For example if a static route has range 10.1.0.0/16, a subnet range 10.0.0.0/8 could only be created if allow_conflicting_routes=true. Overlapping is only allowed on subnetwork operations; routes whose ranges conflict with this subnetwork's ranges won't be allowed unless route.allow_conflicting_subnetworks is set to true. Typically packets destined to IPs within the subnetwork (which may contain private/sensitive data) are prevented from leaving the virtual network. Setting this field to true will disable this feature. The default value is false and applies to all existing subnetworks and automatically created subnetworks. This field cannot be set to true at resource creation time.
         */
        allowSubnetCidrRoutesOverlap?: boolean | null;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource. This field can be set only at resource creation time.
         */
        description?: string | null;
        /**
         * Whether to enable flow logging for this subnetwork. If this field is not explicitly set, it will not appear in get listings. If not set the default behavior is determined by the org policy, if there is no org policy specified, then it will default to disabled. This field isn't supported if the subnet purpose field is set to REGIONAL_MANAGED_PROXY.
         */
        enableFlowLogs?: boolean | null;
        /**
         * Enables Layer2 communication on the subnetwork.
         */
        enableL2?: boolean | null;
        /**
         * Deprecated in favor of enable in PrivateIpv6GoogleAccess. Whether the VMs in this subnet can directly access Google services via internal IPv6 addresses. This field can be both set at resource creation time and updated using patch.
         */
        enablePrivateV6Access?: boolean | null;
        /**
         * The external IPv6 address range that is owned by this subnetwork.
         */
        externalIpv6Prefix?: string | null;
        /**
         * Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a Subnetwork. An up-to-date fingerprint must be provided in order to update the Subnetwork, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a Subnetwork.
         */
        fingerprint?: string | null;
        /**
         * Can only be specified if VPC flow logging for this subnetwork is enabled. The value of the field must be in [0, 1]. Set the sampling rate of VPC flow logs within the subnetwork where 1.0 means all collected logs are reported and 0.0 means no logs are reported. Default is 0.5 unless otherwise specified by the org policy, which means half of all collected logs are reported.
         */
        flowSampling?: number | null;
        /**
         * [Output Only] The gateway address for default routes to reach destination addresses outside this subnetwork.
         */
        gatewayAddress?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] The internal IPv6 address range that is assigned to this subnetwork.
         */
        internalIpv6Prefix?: string | null;
        /**
         * The range of internal addresses that are owned by this subnetwork. Provide this property when you create the subnetwork. For example, 10.0.0.0/8 or 100.64.0.0/10. Ranges must be unique and non-overlapping within a network. Only IPv4 is supported. This field is set at resource creation time. The range can be any range listed in the Valid ranges list. The range can be expanded after creation using expandIpCidrRange.
         */
        ipCidrRange?: string | null;
        /**
         * The access type of IPv6 address this subnet holds. It's immutable and can only be specified during creation or the first time the subnet is updated into IPV4_IPV6 dual stack.
         */
        ipv6AccessType?: string | null;
        /**
         * [Output Only] This field is for internal use.
         */
        ipv6CidrRange?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#subnetwork for Subnetwork resources.
         */
        kind?: string | null;
        /**
         * This field denotes the VPC flow logging options for this subnetwork. If logging is enabled, logs are exported to Cloud Logging.
         */
        logConfig?: Schema$SubnetworkLogConfig;
        /**
         * Can only be specified if VPC flow logging for this subnetwork is enabled. Configures whether metadata fields should be added to the reported VPC flow logs. Options are INCLUDE_ALL_METADATA, EXCLUDE_ALL_METADATA, and CUSTOM_METADATA. Default is EXCLUDE_ALL_METADATA.
         */
        metadata?: string | null;
        /**
         * The name of the resource, provided by the client when initially creating the resource. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * The URL of the network to which this subnetwork belongs, provided by the client when initially creating the subnetwork. This field can be set only at resource creation time.
         */
        network?: string | null;
        /**
         * Whether the VMs in this subnet can access Google services without assigned external IP addresses. This field can be both set at resource creation time and updated using setPrivateIpGoogleAccess.
         */
        privateIpGoogleAccess?: boolean | null;
        /**
         * This field is for internal use. This field can be both set at resource creation time and updated using patch.
         */
        privateIpv6GoogleAccess?: string | null;
        /**
         * The purpose of the resource. This field can be either PRIVATE, REGIONAL_MANAGED_PROXY, PRIVATE_SERVICE_CONNECT, or INTERNAL_HTTPS_LOAD_BALANCER. PRIVATE is the default purpose for user-created subnets or subnets that are automatically created in auto mode networks. A subnet with purpose set to REGIONAL_MANAGED_PROXY is a user-created subnetwork that is reserved for regional Envoy-based load balancers. A subnet with purpose set to PRIVATE_SERVICE_CONNECT is used to publish services using Private Service Connect. A subnet with purpose set to INTERNAL_HTTPS_LOAD_BALANCER is a proxy-only subnet that can be used only by regional internal HTTP(S) load balancers. Note that REGIONAL_MANAGED_PROXY is the preferred setting for all regional Envoy load balancers. If unspecified, the subnet purpose defaults to PRIVATE. The enableFlowLogs field isn't supported if the subnet purpose field is set to REGIONAL_MANAGED_PROXY.
         */
        purpose?: string | null;
        /**
         * URL of the region where the Subnetwork resides. This field can be set only at resource creation time.
         */
        region?: string | null;
        /**
         * The URL of the reserved internal range.
         */
        reservedInternalRange?: string | null;
        /**
         * The role of subnetwork. Currently, this field is only used when purpose = REGIONAL_MANAGED_PROXY. The value can be set to ACTIVE or BACKUP. An ACTIVE subnetwork is one that is currently being used for Envoy-based load balancers in a region. A BACKUP subnetwork is one that is ready to be promoted to ACTIVE or is currently draining. This field can be updated with a patch request.
         */
        role?: string | null;
        /**
         * An array of configurations for secondary IP ranges for VM instances contained in this subnetwork. The primary IP of such VM must belong to the primary ipCidrRange of the subnetwork. The alias IPs may belong to either primary or secondary ranges. This field can be updated with a patch request.
         */
        secondaryIpRanges?: Schema$SubnetworkSecondaryRange[];
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * The stack type for the subnet. If set to IPV4_ONLY, new VMs in the subnet are assigned IPv4 addresses only. If set to IPV4_IPV6, new VMs in the subnet can be assigned both IPv4 and IPv6 addresses. If not specified, IPV4_ONLY is used. This field can be both set at resource creation time and updated using patch.
         */
        stackType?: string | null;
        /**
         * [Output Only] The state of the subnetwork, which can be one of the following values: READY: Subnetwork is created and ready to use DRAINING: only applicable to subnetworks that have the purpose set to INTERNAL_HTTPS_LOAD_BALANCER and indicates that connections to the load balancer are being drained. A subnetwork that is draining cannot be used or modified until it reaches a status of READY
         */
        state?: string | null;
        /**
         * A repeated field indicating the VLAN IDs supported on this subnetwork. During Subnet creation, specifying vlan is valid only if enable_l2 is true. During Subnet Update, specifying vlan is allowed only for l2 enabled subnets. Restricted to only one VLAN.
         */
        vlans?: number[] | null;
    }
    export interface Schema$SubnetworkAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of SubnetworksScopedList resources.
         */
        items?: {
            [key: string]: Schema$SubnetworksScopedList;
        } | null;
        /**
         * [Output Only] Type of resource. Always compute#subnetworkAggregatedList for aggregated lists of subnetworks.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Contains a list of Subnetwork resources.
     */
    export interface Schema$SubnetworkList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of Subnetwork resources.
         */
        items?: Schema$Subnetwork[];
        /**
         * [Output Only] Type of resource. Always compute#subnetworkList for lists of subnetworks.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * The available logging options for this subnetwork.
     */
    export interface Schema$SubnetworkLogConfig {
        /**
         * Can only be specified if VPC flow logging for this subnetwork is enabled. Toggles the aggregation interval for collecting flow logs. Increasing the interval time will reduce the amount of generated flow logs for long lasting connections. Default is an interval of 5 seconds per connection.
         */
        aggregationInterval?: string | null;
        /**
         * Whether to enable flow logging for this subnetwork. If this field is not explicitly set, it will not appear in get listings. If not set the default behavior is determined by the org policy, if there is no org policy specified, then it will default to disabled. Flow logging isn't supported if the subnet purpose field is set to REGIONAL_MANAGED_PROXY.
         */
        enable?: boolean | null;
        /**
         * Can only be specified if VPC flow logs for this subnetwork is enabled. The filter expression is used to define which VPC flow logs should be exported to Cloud Logging.
         */
        filterExpr?: string | null;
        /**
         * Can only be specified if VPC flow logging for this subnetwork is enabled. The value of the field must be in [0, 1]. Set the sampling rate of VPC flow logs within the subnetwork where 1.0 means all collected logs are reported and 0.0 means no logs are reported. Default is 0.5 unless otherwise specified by the org policy, which means half of all collected logs are reported.
         */
        flowSampling?: number | null;
        /**
         * Can only be specified if VPC flow logs for this subnetwork is enabled. Configures whether all, none or a subset of metadata fields should be added to the reported VPC flow logs. Default is EXCLUDE_ALL_METADATA.
         */
        metadata?: string | null;
        /**
         * Can only be specified if VPC flow logs for this subnetwork is enabled and "metadata" was set to CUSTOM_METADATA.
         */
        metadataFields?: string[] | null;
    }
    /**
     * Represents a secondary IP range of a subnetwork.
     */
    export interface Schema$SubnetworkSecondaryRange {
        /**
         * The range of IP addresses belonging to this subnetwork secondary range. Provide this property when you create the subnetwork. Ranges must be unique and non-overlapping with all primary and secondary IP ranges within a network. Only IPv4 is supported. The range can be any range listed in the Valid ranges list.
         */
        ipCidrRange?: string | null;
        /**
         * The name associated with this subnetwork secondary range, used when adding an alias IP range to a VM instance. The name must be 1-63 characters long, and comply with RFC1035. The name must be unique within the subnetwork.
         */
        rangeName?: string | null;
        /**
         * The URL of the reserved internal range.
         */
        reservedInternalRange?: string | null;
    }
    export interface Schema$SubnetworksExpandIpCidrRangeRequest {
        /**
         * The IP (in CIDR format or netmask) of internal addresses that are legal on this Subnetwork. This range should be disjoint from other subnetworks within this network. This range can only be larger than (i.e. a superset of) the range previously defined before the update.
         */
        ipCidrRange?: string | null;
    }
    export interface Schema$SubnetworksScopedList {
        /**
         * A list of subnetworks contained in this scope.
         */
        subnetworks?: Schema$Subnetwork[];
        /**
         * An informational warning that appears when the list of addresses is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$SubnetworksSetPrivateIpGoogleAccessRequest {
        privateIpGoogleAccess?: boolean | null;
    }
    /**
     * Subsetting configuration for this BackendService. Currently this is applicable only for Internal TCP/UDP load balancing, Internal HTTP(S) load balancing and Traffic Director.
     */
    export interface Schema$Subsetting {
        policy?: string | null;
        /**
         * The number of backends per backend group assigned to each proxy instance or each service mesh client. An input parameter to the `CONSISTENT_HASH_SUBSETTING` algorithm. Can only be set if `policy` is set to `CONSISTENT_HASH_SUBSETTING`. Can only be set if load balancing scheme is `INTERNAL_MANAGED` or `INTERNAL_SELF_MANAGED`. `subset_size` is optional for Internal HTTP(S) load balancing and required for Traffic Director. If you do not provide this value, Cloud Load Balancing will calculate it dynamically to optimize the number of proxies/clients visible to each backend and vice versa. Must be greater than 0. If `subset_size` is larger than the number of backends/endpoints, then subsetting is disabled.
         */
        subsetSize?: number | null;
    }
    /**
     * A set of instance tags.
     */
    export interface Schema$Tags {
        /**
         * Specifies a fingerprint for this request, which is essentially a hash of the tags' contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update tags. You must always provide an up-to-date fingerprint hash in order to update or change tags. To see the latest fingerprint, make get() request to the instance.
         */
        fingerprint?: string | null;
        /**
         * An array of tags. Each tag must be 1-63 characters long, and comply with RFC1035.
         */
        items?: string[] | null;
    }
    /**
     * Represents a Target gRPC Proxy resource. A target gRPC proxy is a component of load balancers intended for load balancing gRPC traffic. Only global forwarding rules with load balancing scheme INTERNAL_SELF_MANAGED can reference a target gRPC proxy. The target gRPC Proxy references a URL map that specifies how traffic is routed to gRPC backend services.
     */
    export interface Schema$TargetGrpcProxy {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a TargetGrpcProxy. An up-to-date fingerprint must be provided in order to patch/update the TargetGrpcProxy; otherwise, the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the TargetGrpcProxy.
         */
        fingerprint?: string | null;
        /**
         * [Output Only] The unique identifier for the resource type. The server generates this identifier.
         */
        id?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#targetGrpcProxy for target grpc proxies.
         */
        kind?: string | null;
        /**
         * Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL with id for the resource.
         */
        selfLinkWithId?: string | null;
        /**
         * URL to the UrlMap resource that defines the mapping from URL to the BackendService. The protocol field in the BackendService must be set to GRPC.
         */
        urlMap?: string | null;
        /**
         * If true, indicates that the BackendServices referenced by the urlMap may be accessed by gRPC applications without using a sidecar proxy. This will enable configuration checks on urlMap and its referenced BackendServices to not allow unsupported features. A gRPC application must use "xds:///" scheme in the target URI of the service it is connecting to. If false, indicates that the BackendServices referenced by the urlMap will be accessed by gRPC applications via a sidecar proxy. In this case, a gRPC application must not use "xds:///" scheme in the target URI of the service it is connecting to
         */
        validateForProxyless?: boolean | null;
    }
    export interface Schema$TargetGrpcProxyList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of TargetGrpcProxy resources.
         */
        items?: Schema$TargetGrpcProxy[];
        /**
         * [Output Only] Type of the resource. Always compute#targetGrpcProxy for target grpc proxies.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$TargetHttpProxiesScopedList {
        /**
         * A list of TargetHttpProxies contained in this scope.
         */
        targetHttpProxies?: Schema$TargetHttpProxy[];
        /**
         * Informational warning which replaces the list of backend services when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Represents a Target HTTP Proxy resource. Google Compute Engine has two Target HTTP Proxy resources: * [Global](/compute/docs/reference/rest/alpha/targetHttpProxies) * [Regional](/compute/docs/reference/rest/alpha/regionTargetHttpProxies) A target HTTP proxy is a component of Google Cloud HTTP load balancers. * targetHttpProxies are used by global external Application Load Balancers, classic Application Load Balancers, cross-region internal Application Load Balancers, and Traffic Director. * regionTargetHttpProxies are used by regional internal Application Load Balancers and regional external Application Load Balancers. Forwarding rules reference a target HTTP proxy, and the target proxy then references a URL map. For more information, read Using Target Proxies and Forwarding rule concepts.
     */
    export interface Schema$TargetHttpProxy {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a TargetHttpProxy. An up-to-date fingerprint must be provided in order to patch/update the TargetHttpProxy; otherwise, the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the TargetHttpProxy.
         */
        fingerprint?: string | null;
        /**
         * URLs to networkservices.HttpFilter resources enabled for xDS clients using this configuration. For example, https://networkservices.googleapis.com/v1alpha1/projects/project/locations/ locationhttpFilters/httpFilter Only filters that handle outbound connection and stream events may be specified. These filters work in conjunction with a default set of HTTP filters that may already be configured by Traffic Director. Traffic Director will determine the final location of these filters within xDS configuration based on the name of the HTTP filter. If Traffic Director positions multiple filters at the same location, those filters will be in the same order as specified in this list. httpFilters only applies for loadbalancers with loadBalancingScheme set to INTERNAL_SELF_MANAGED. See ForwardingRule for more details.
         */
        httpFilters?: string[] | null;
        /**
         * Specifies how long to keep a connection open, after completing a response, while there is no matching traffic (in seconds). If an HTTP keep-alive is not specified, a default value (610 seconds) will be used. For global external Application Load Balancers, the minimum allowed value is 5 seconds and the maximum allowed value is 1200 seconds. For classic Application Load Balancers, this option is not supported.
         */
        httpKeepAliveTimeoutSec?: number | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] Type of resource. Always compute#targetHttpProxy for target HTTP proxies.
         */
        kind?: string | null;
        /**
         * Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * This field only applies when the forwarding rule that references this target proxy has a loadBalancingScheme set to INTERNAL_SELF_MANAGED. When this field is set to true, Envoy proxies set up inbound traffic interception and bind to the IP address and port specified in the forwarding rule. This is generally useful when using Traffic Director to configure Envoy as a gateway or middle proxy (in other words, not a sidecar proxy). The Envoy proxy listens for inbound requests and handles requests when it receives them. The default is false.
         */
        proxyBind?: boolean | null;
        /**
         * [Output Only] URL of the region where the regional Target HTTP Proxy resides. This field is not applicable to global Target HTTP Proxies.
         */
        region?: string | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * URL to the UrlMap resource that defines the mapping from URL to the BackendService.
         */
        urlMap?: string | null;
    }
    export interface Schema$TargetHttpProxyAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of TargetHttpProxiesScopedList resources.
         */
        items?: {
            [key: string]: Schema$TargetHttpProxiesScopedList;
        } | null;
        /**
         * [Output Only] Type of resource. Always compute#targetHttpProxyAggregatedList for lists of Target HTTP Proxies.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * A list of TargetHttpProxy resources.
     */
    export interface Schema$TargetHttpProxyList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of TargetHttpProxy resources.
         */
        items?: Schema$TargetHttpProxy[];
        /**
         * Type of resource. Always compute#targetHttpProxyList for lists of target HTTP proxies.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$TargetHttpsProxiesScopedList {
        /**
         * A list of TargetHttpsProxies contained in this scope.
         */
        targetHttpsProxies?: Schema$TargetHttpsProxy[];
        /**
         * Informational warning which replaces the list of backend services when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$TargetHttpsProxiesSetCertificateMapRequest {
        /**
         * URL of the Certificate Map to associate with this TargetHttpsProxy. Accepted format is //certificatemanager.googleapis.com/projects/{project \}/locations/{location\}/certificateMaps/{resourceName\}.
         */
        certificateMap?: string | null;
    }
    export interface Schema$TargetHttpsProxiesSetQuicOverrideRequest {
        /**
         * QUIC policy for the TargetHttpsProxy resource.
         */
        quicOverride?: string | null;
    }
    export interface Schema$TargetHttpsProxiesSetSslCertificatesRequest {
        /**
         * New set of SslCertificate resources to associate with this TargetHttpsProxy resource. At least one SSL certificate must be specified. Currently, you may specify up to 15 SSL certificates.
         */
        sslCertificates?: string[] | null;
    }
    /**
     * Represents a Target HTTPS Proxy resource. Google Compute Engine has two Target HTTPS Proxy resources: * [Global](/compute/docs/reference/rest/alpha/targetHttpsProxies) * [Regional](/compute/docs/reference/rest/alpha/regionTargetHttpsProxies) A target HTTPS proxy is a component of GCP HTTPS load balancers. * targetHttpProxies are used by global external Application Load Balancers, classic Application Load Balancers, cross-region internal Application Load Balancers, and Traffic Director. * regionTargetHttpProxies are used by regional internal Application Load Balancers and regional external Application Load Balancers. Forwarding rules reference a target HTTPS proxy, and the target proxy then references a URL map. For more information, read Using Target Proxies and Forwarding rule concepts.
     */
    export interface Schema$TargetHttpsProxy {
        /**
         * [Deprecated] Use serverTlsPolicy instead.
         */
        authentication?: string | null;
        /**
         * [Deprecated] Use authorizationPolicy instead.
         */
        authorization?: string | null;
        /**
         * Optional. A URL referring to a networksecurity.AuthorizationPolicy resource that describes how the proxy should authorize inbound traffic. If left blank, access will not be restricted by an authorization policy. Refer to the AuthorizationPolicy resource for additional details. authorizationPolicy only applies to a global TargetHttpsProxy attached to globalForwardingRules with the loadBalancingScheme set to INTERNAL_SELF_MANAGED. Note: This field currently has no impact.
         */
        authorizationPolicy?: string | null;
        /**
         * URL of a certificate map that identifies a certificate map associated with the given target proxy. This field can only be set for global target proxies. If set, sslCertificates will be ignored. Accepted format is //certificatemanager.googleapis.com/projects/{project \}/locations/{location\}/certificateMaps/{resourceName\}.
         */
        certificateMap?: string | null;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a TargetHttpsProxy. An up-to-date fingerprint must be provided in order to patch the TargetHttpsProxy; otherwise, the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the TargetHttpsProxy.
         */
        fingerprint?: string | null;
        /**
         * URLs to networkservices.HttpFilter resources enabled for xDS clients using this configuration. For example, https://networkservices.googleapis.com/beta/projects/project/locations/ locationhttpFilters/httpFilter Only filters that handle outbound connection and stream events may be specified. These filters work in conjunction with a default set of HTTP filters that may already be configured by Traffic Director. Traffic Director will determine the final location of these filters within xDS configuration based on the name of the HTTP filter. If Traffic Director positions multiple filters at the same location, those filters will be in the same order as specified in this list. httpFilters only applies for loadbalancers with loadBalancingScheme set to INTERNAL_SELF_MANAGED. See ForwardingRule for more details.
         */
        httpFilters?: string[] | null;
        /**
         * Specifies how long to keep a connection open, after completing a response, while there is no matching traffic (in seconds). If an HTTP keep-alive is not specified, a default value (610 seconds) will be used. For global external Application Load Balancers, the minimum allowed value is 5 seconds and the maximum allowed value is 1200 seconds. For classic Application Load Balancers, this option is not supported.
         */
        httpKeepAliveTimeoutSec?: number | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] Type of resource. Always compute#targetHttpsProxy for target HTTPS proxies.
         */
        kind?: string | null;
        /**
         * Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * This field only applies when the forwarding rule that references this target proxy has a loadBalancingScheme set to INTERNAL_SELF_MANAGED. When this field is set to true, Envoy proxies set up inbound traffic interception and bind to the IP address and port specified in the forwarding rule. This is generally useful when using Traffic Director to configure Envoy as a gateway or middle proxy (in other words, not a sidecar proxy). The Envoy proxy listens for inbound requests and handles requests when it receives them. The default is false.
         */
        proxyBind?: boolean | null;
        /**
         * Specifies the QUIC override policy for this TargetHttpsProxy resource. This setting determines whether the load balancer attempts to negotiate QUIC with clients. You can specify NONE, ENABLE, or DISABLE. - When quic-override is set to NONE, Google manages whether QUIC is used. - When quic-override is set to ENABLE, the load balancer uses QUIC when possible. - When quic-override is set to DISABLE, the load balancer doesn't use QUIC. - If the quic-override flag is not specified, NONE is implied.
         */
        quicOverride?: string | null;
        /**
         * [Output Only] URL of the region where the regional TargetHttpsProxy resides. This field is not applicable to global TargetHttpsProxies.
         */
        region?: string | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * Optional. A URL referring to a networksecurity.ServerTlsPolicy resource that describes how the proxy should authenticate inbound traffic. serverTlsPolicy only applies to a global TargetHttpsProxy attached to globalForwardingRules with the loadBalancingScheme set to INTERNAL_SELF_MANAGED or EXTERNAL or EXTERNAL_MANAGED. For details which ServerTlsPolicy resources are accepted with INTERNAL_SELF_MANAGED and which with EXTERNAL, EXTERNAL_MANAGED loadBalancingScheme consult ServerTlsPolicy documentation. If left blank, communications are not encrypted.
         */
        serverTlsPolicy?: string | null;
        /**
         * URLs to SslCertificate resources that are used to authenticate connections between users and the load balancer. At least one SSL certificate must be specified. Currently, you may specify up to 15 SSL certificates. sslCertificates do not apply when the load balancing scheme is set to INTERNAL_SELF_MANAGED.
         */
        sslCertificates?: string[] | null;
        /**
         * URL of SslPolicy resource that will be associated with the TargetHttpsProxy resource. If not set, the TargetHttpsProxy resource has no SSL policy configured.
         */
        sslPolicy?: string | null;
        /**
         * A fully-qualified or valid partial URL to the UrlMap resource that defines the mapping from URL to the BackendService. For example, the following are all valid URLs for specifying a URL map: - https://www.googleapis.compute/v1/projects/project/global/urlMaps/ url-map - projects/project/global/urlMaps/url-map - global/urlMaps/url-map
         */
        urlMap?: string | null;
    }
    export interface Schema$TargetHttpsProxyAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of TargetHttpsProxiesScopedList resources.
         */
        items?: {
            [key: string]: Schema$TargetHttpsProxiesScopedList;
        } | null;
        /**
         * [Output Only] Type of resource. Always compute#targetHttpsProxyAggregatedList for lists of Target HTTP Proxies.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Contains a list of TargetHttpsProxy resources.
     */
    export interface Schema$TargetHttpsProxyList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of TargetHttpsProxy resources.
         */
        items?: Schema$TargetHttpsProxy[];
        /**
         * Type of resource. Always compute#targetHttpsProxyList for lists of target HTTPS proxies.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Represents a Target Instance resource. You can use a target instance to handle traffic for one or more forwarding rules, which is ideal for forwarding protocol traffic that is managed by a single source. For example, ESP, AH, TCP, or UDP. For more information, read Target instances.
     */
    export interface Schema$TargetInstance {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * A URL to the virtual machine instance that handles traffic for this target instance. When creating a target instance, you can provide the fully-qualified URL or a valid partial URL to the desired virtual machine. For example, the following are all valid URLs: - https://www.googleapis.com/compute/v1/projects/project/zones/zone /instances/instance - projects/project/zones/zone/instances/instance - zones/zone/instances/instance
         */
        instance?: string | null;
        /**
         * [Output Only] The type of the resource. Always compute#targetInstance for target instances.
         */
        kind?: string | null;
        /**
         * Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * Must have a value of NO_NAT. Protocol forwarding delivers packets while preserving the destination IP address of the forwarding rule referencing the target instance.
         */
        natPolicy?: string | null;
        /**
         * The URL of the network this target instance uses to forward traffic. If not specified, the traffic will be forwarded to the network that the default network interface belongs to.
         */
        network?: string | null;
        /**
         * [Output Only] The resource URL for the security policy associated with this target instance.
         */
        securityPolicy?: string | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * [Output Only] URL of the zone where the target instance resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
         */
        zone?: string | null;
    }
    export interface Schema$TargetInstanceAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of TargetInstance resources.
         */
        items?: {
            [key: string]: Schema$TargetInstancesScopedList;
        } | null;
        /**
         * Type of resource.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Contains a list of TargetInstance resources.
     */
    export interface Schema$TargetInstanceList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of TargetInstance resources.
         */
        items?: Schema$TargetInstance[];
        /**
         * Type of resource.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$TargetInstancesScopedList {
        /**
         * A list of target instances contained in this scope.
         */
        targetInstances?: Schema$TargetInstance[];
        /**
         * Informational warning which replaces the list of addresses when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Represents a Target Pool resource. Target pools are used for network TCP/UDP load balancing. A target pool references member instances, an associated legacy HttpHealthCheck resource, and, optionally, a backup target pool. For more information, read Using target pools.
     */
    export interface Schema$TargetPool {
        /**
         * The server-defined URL for the resource. This field is applicable only when the containing target pool is serving a forwarding rule as the primary pool, and its failoverRatio field is properly set to a value between [0, 1]. backupPool and failoverRatio together define the fallback behavior of the primary target pool: if the ratio of the healthy instances in the primary pool is at or below failoverRatio, traffic arriving at the load-balanced IP will be directed to the backup pool. In case where failoverRatio and backupPool are not set, or all the instances in the backup pool are unhealthy, the traffic will be directed back to the primary pool in the "force" mode, where traffic will be spread to the healthy instances with the best effort, or to all instances when no instance is healthy.
         */
        backupPool?: string | null;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * This field is applicable only when the containing target pool is serving a forwarding rule as the primary pool (i.e., not as a backup pool to some other target pool). The value of the field must be in [0, 1]. If set, backupPool must also be set. They together define the fallback behavior of the primary target pool: if the ratio of the healthy instances in the primary pool is at or below this number, traffic arriving at the load-balanced IP will be directed to the backup pool. In case where failoverRatio is not set or all the instances in the backup pool are unhealthy, the traffic will be directed back to the primary pool in the "force" mode, where traffic will be spread to the healthy instances with the best effort, or to all instances when no instance is healthy.
         */
        failoverRatio?: number | null;
        /**
         * The URL of the HttpHealthCheck resource. A member instance in this pool is considered healthy if and only if the health checks pass. Only legacy HttpHealthChecks are supported. Only one health check may be specified.
         */
        healthChecks?: string[] | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * A list of resource URLs to the virtual machine instances serving this pool. They must live in zones contained in the same region as this pool.
         */
        instances?: string[] | null;
        /**
         * [Output Only] Type of the resource. Always compute#targetPool for target pools.
         */
        kind?: string | null;
        /**
         * Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * [Output Only] URL of the region where the target pool resides.
         */
        region?: string | null;
        /**
         * [Output Only] The resource URL for the security policy associated with this target pool.
         */
        securityPolicy?: string | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource with the resource id.
         */
        selfLinkWithId?: string | null;
        /**
         * Session affinity option, must be one of the following values: NONE: Connections from the same client IP may go to any instance in the pool. CLIENT_IP: Connections from the same client IP will go to the same instance in the pool while that instance remains healthy. CLIENT_IP_PROTO: Connections from the same client IP with the same IP protocol will go to the same instance in the pool while that instance remains healthy.
         */
        sessionAffinity?: string | null;
    }
    export interface Schema$TargetPoolAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of TargetPool resources.
         */
        items?: {
            [key: string]: Schema$TargetPoolsScopedList;
        } | null;
        /**
         * [Output Only] Type of resource. Always compute#targetPoolAggregatedList for aggregated lists of target pools.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$TargetPoolInstanceHealth {
        healthStatus?: Schema$HealthStatus[];
        /**
         * [Output Only] Type of resource. Always compute#targetPoolInstanceHealth when checking the health of an instance.
         */
        kind?: string | null;
    }
    /**
     * Contains a list of TargetPool resources.
     */
    export interface Schema$TargetPoolList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of TargetPool resources.
         */
        items?: Schema$TargetPool[];
        /**
         * [Output Only] Type of resource. Always compute#targetPoolList for lists of target pools.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$TargetPoolsAddHealthCheckRequest {
        /**
         * The HttpHealthCheck to add to the target pool.
         */
        healthChecks?: Schema$HealthCheckReference[];
    }
    export interface Schema$TargetPoolsAddInstanceRequest {
        /**
         * A full or partial URL to an instance to add to this target pool. This can be a full or partial URL. For example, the following are valid URLs: - https://www.googleapis.com/compute/v1/projects/project-id/zones/zone /instances/instance-name - projects/project-id/zones/zone/instances/instance-name - zones/zone/instances/instance-name
         */
        instances?: Schema$InstanceReference[];
    }
    export interface Schema$TargetPoolsRemoveHealthCheckRequest {
        /**
         * Health check URL to be removed. This can be a full or valid partial URL. For example, the following are valid URLs: - https://www.googleapis.com/compute/beta/projects/project /global/httpHealthChecks/health-check - projects/project/global/httpHealthChecks/health-check - global/httpHealthChecks/health-check
         */
        healthChecks?: Schema$HealthCheckReference[];
    }
    export interface Schema$TargetPoolsRemoveInstanceRequest {
        /**
         * URLs of the instances to be removed from target pool.
         */
        instances?: Schema$InstanceReference[];
    }
    export interface Schema$TargetPoolsScopedList {
        /**
         * A list of target pools contained in this scope.
         */
        targetPools?: Schema$TargetPool[];
        /**
         * Informational warning which replaces the list of addresses when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$TargetReference {
        target?: string | null;
    }
    export interface Schema$TargetSslProxiesSetBackendServiceRequest {
        /**
         * The URL of the new BackendService resource for the targetSslProxy.
         */
        service?: string | null;
    }
    export interface Schema$TargetSslProxiesSetCertificateMapRequest {
        /**
         * URL of the Certificate Map to associate with this TargetSslProxy. Accepted format is //certificatemanager.googleapis.com/projects/{project \}/locations/{location\}/certificateMaps/{resourceName\}.
         */
        certificateMap?: string | null;
    }
    export interface Schema$TargetSslProxiesSetProxyHeaderRequest {
        /**
         * The new type of proxy header to append before sending data to the backend. NONE or PROXY_V1 are allowed.
         */
        proxyHeader?: string | null;
    }
    export interface Schema$TargetSslProxiesSetSslCertificatesRequest {
        /**
         * New set of URLs to SslCertificate resources to associate with this TargetSslProxy. At least one SSL certificate must be specified. Currently, you may specify up to 15 SSL certificates.
         */
        sslCertificates?: string[] | null;
    }
    /**
     * Represents a Target SSL Proxy resource. A target SSL proxy is a component of a SSL Proxy load balancer. Global forwarding rules reference a target SSL proxy, and the target proxy then references an external backend service. For more information, read Using Target Proxies.
     */
    export interface Schema$TargetSslProxy {
        /**
         * URL of a certificate map that identifies a certificate map associated with the given target proxy. This field can only be set for global target proxies. If set, sslCertificates will be ignored. Accepted format is //certificatemanager.googleapis.com/projects/{project \}/locations/{location\}/certificateMaps/{resourceName\}.
         */
        certificateMap?: string | null;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#targetSslProxy for target SSL proxies.
         */
        kind?: string | null;
        /**
         * Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE.
         */
        proxyHeader?: string | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * URL to the BackendService resource.
         */
        service?: string | null;
        /**
         * URLs to SslCertificate resources that are used to authenticate connections to Backends. At least one SSL certificate must be specified. Currently, you may specify up to 15 SSL certificates. sslCertificates do not apply when the load balancing scheme is set to INTERNAL_SELF_MANAGED.
         */
        sslCertificates?: string[] | null;
        /**
         * URL of SslPolicy resource that will be associated with the TargetSslProxy resource. If not set, the TargetSslProxy resource will not have any SSL policy configured.
         */
        sslPolicy?: string | null;
    }
    /**
     * Contains a list of TargetSslProxy resources.
     */
    export interface Schema$TargetSslProxyList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of TargetSslProxy resources.
         */
        items?: Schema$TargetSslProxy[];
        /**
         * Type of resource.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$TargetTcpProxiesScopedList {
        /**
         * A list of TargetTcpProxies contained in this scope.
         */
        targetTcpProxies?: Schema$TargetTcpProxy[];
        /**
         * Informational warning which replaces the list of backend services when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$TargetTcpProxiesSetBackendServiceRequest {
        /**
         * The URL of the new BackendService resource for the targetTcpProxy.
         */
        service?: string | null;
    }
    export interface Schema$TargetTcpProxiesSetProxyHeaderRequest {
        /**
         * The new type of proxy header to append before sending data to the backend. NONE or PROXY_V1 are allowed.
         */
        proxyHeader?: string | null;
    }
    /**
     * Represents a Target TCP Proxy resource. A target TCP proxy is a component of a TCP Proxy load balancer. Global forwarding rules reference target TCP proxy, and the target proxy then references an external backend service. For more information, read TCP Proxy Load Balancing overview.
     */
    export interface Schema$TargetTcpProxy {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#targetTcpProxy for target TCP proxies.
         */
        kind?: string | null;
        /**
         * Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * This field only applies when the forwarding rule that references this target proxy has a loadBalancingScheme set to INTERNAL_SELF_MANAGED. When this field is set to true, Envoy proxies set up inbound traffic interception and bind to the IP address and port specified in the forwarding rule. This is generally useful when using Traffic Director to configure Envoy as a gateway or middle proxy (in other words, not a sidecar proxy). The Envoy proxy listens for inbound requests and handles requests when it receives them. The default is false.
         */
        proxyBind?: boolean | null;
        /**
         * Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE.
         */
        proxyHeader?: string | null;
        /**
         * [Output Only] URL of the region where the regional TCP proxy resides. This field is not applicable to global TCP proxy.
         */
        region?: string | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * URL to the BackendService resource.
         */
        service?: string | null;
    }
    export interface Schema$TargetTcpProxyAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of TargetTcpProxiesScopedList resources.
         */
        items?: {
            [key: string]: Schema$TargetTcpProxiesScopedList;
        } | null;
        /**
         * [Output Only] Type of resource. Always compute#targetTcpProxyAggregatedList for lists of Target TCP Proxies.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Contains a list of TargetTcpProxy resources.
     */
    export interface Schema$TargetTcpProxyList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of TargetTcpProxy resources.
         */
        items?: Schema$TargetTcpProxy[];
        /**
         * Type of resource.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Represents a Target VPN Gateway resource. The target VPN gateway resource represents a Classic Cloud VPN gateway. For more information, read the the Cloud VPN Overview.
     */
    export interface Schema$TargetVpnGateway {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * [Output Only] A list of URLs to the ForwardingRule resources. ForwardingRules are created using compute.forwardingRules.insert and associated with a VPN gateway.
         */
        forwardingRules?: string[] | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] Type of resource. Always compute#targetVpnGateway for target VPN gateways.
         */
        kind?: string | null;
        /**
         * A fingerprint for the labels being applied to this TargetVpnGateway, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a TargetVpnGateway.
         */
        labelFingerprint?: string | null;
        /**
         * Labels for this resource. These can only be added or modified by the setLabels method. Each label key/value pair must comply with RFC1035. Label values may be empty.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * URL of the network to which this VPN gateway is attached. Provided by the client when the VPN gateway is created.
         */
        network?: string | null;
        /**
         * [Output Only] URL of the region where the target VPN gateway resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
         */
        region?: string | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] The status of the VPN gateway, which can be one of the following: CREATING, READY, FAILED, or DELETING.
         */
        status?: string | null;
        /**
         * [Output Only] A list of URLs to VpnTunnel resources. VpnTunnels are created using the compute.vpntunnels.insert method and associated with a VPN gateway.
         */
        tunnels?: string[] | null;
    }
    export interface Schema$TargetVpnGatewayAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of TargetVpnGateway resources.
         */
        items?: {
            [key: string]: Schema$TargetVpnGatewaysScopedList;
        } | null;
        /**
         * [Output Only] Type of resource. Always compute#targetVpnGateway for target VPN gateways.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Contains a list of TargetVpnGateway resources.
     */
    export interface Schema$TargetVpnGatewayList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of TargetVpnGateway resources.
         */
        items?: Schema$TargetVpnGateway[];
        /**
         * [Output Only] Type of resource. Always compute#targetVpnGateway for target VPN gateways.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$TargetVpnGatewaysScopedList {
        /**
         * [Output Only] A list of target VPN gateways contained in this scope.
         */
        targetVpnGateways?: Schema$TargetVpnGateway[];
        /**
         * [Output Only] Informational warning which replaces the list of addresses when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$TCPHealthCheck {
        /**
         * The TCP port number to which the health check prober sends packets. The default value is 80. Valid values are 1 through 65535.
         */
        port?: number | null;
        /**
         * Not supported.
         */
        portName?: string | null;
        /**
         * Specifies how a port is selected for health checking. Can be one of the following values: USE_FIXED_PORT: Specifies a port number explicitly using the port field in the health check. Supported by backend services for pass-through load balancers and backend services for proxy load balancers. Not supported by target pools. The health check supports all backends supported by the backend service provided the backend can be health checked. For example, GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network endpoint groups, and instance group backends. USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an indirect method of specifying the health check port by referring to the backend service. Only supported by backend services for proxy load balancers. Not supported by target pools. Not supported by backend services for pass-through load balancers. Supports all backends that can be health checked; for example, GCE_VM_IP_PORT network endpoint groups and instance group backends. For GCE_VM_IP_PORT network endpoint group backends, the health check uses the port number specified for each endpoint in the network endpoint group. For instance group backends, the health check uses the port number determined by looking up the backend service's named port in the instance group's list of named ports.
         */
        portSpecification?: string | null;
        /**
         * Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE.
         */
        proxyHeader?: string | null;
        /**
         * Instructs the health check prober to send this exact ASCII string, up to 1024 bytes in length, after establishing the TCP connection.
         */
        request?: string | null;
        /**
         * Creates a content-based TCP health check. In addition to establishing a TCP connection, you can configure the health check to pass only when the backend sends this exact response ASCII string, up to 1024 bytes in length. For details, see: https://cloud.google.com/load-balancing/docs/health-check-concepts#criteria-protocol-ssl-tcp
         */
        response?: string | null;
    }
    export interface Schema$TestFailure {
        /**
         * The actual output URL evaluated by a load balancer containing the scheme, host, path and query parameters.
         */
        actualOutputUrl?: string | null;
        /**
         * Actual HTTP status code for rule with `urlRedirect` calculated by load balancer
         */
        actualRedirectResponseCode?: number | null;
        /**
         * BackendService or BackendBucket returned by load balancer.
         */
        actualService?: string | null;
        /**
         * The expected output URL evaluated by a load balancer containing the scheme, host, path and query parameters.
         */
        expectedOutputUrl?: string | null;
        /**
         * Expected HTTP status code for rule with `urlRedirect` calculated by load balancer
         */
        expectedRedirectResponseCode?: number | null;
        /**
         * Expected BackendService or BackendBucket resource the given URL should be mapped to.
         */
        expectedService?: string | null;
        /**
         * HTTP headers of the request.
         */
        headers?: Schema$UrlMapTestHeader[];
        /**
         * Host portion of the URL.
         */
        host?: string | null;
        /**
         * Path portion including query parameters in the URL.
         */
        path?: string | null;
    }
    export interface Schema$TestPermissionsRequest {
        /**
         * The set of permissions to check for the 'resource'. Permissions with wildcards (such as '*' or 'storage.*') are not allowed.
         */
        permissions?: string[] | null;
    }
    export interface Schema$TestPermissionsResponse {
        /**
         * A subset of `TestPermissionsRequest.permissions` that the caller is allowed.
         */
        permissions?: string[] | null;
    }
    /**
     * [Deprecated] Defines the mechanism to obtain the client or server certificate. Defines the mechanism to obtain the client or server certificate.
     */
    export interface Schema$TlsCertificateContext {
        /**
         * Specifies the certificate and private key paths. This field is applicable only if tlsCertificateSource is set to USE_PATH.
         */
        certificatePaths?: Schema$TlsCertificatePaths;
        /**
         * Defines how TLS certificates are obtained.
         */
        certificateSource?: string | null;
        /**
         * Specifies the config to retrieve certificates through SDS. This field is applicable only if tlsCertificateSource is set to USE_SDS.
         */
        sdsConfig?: Schema$SdsConfig;
    }
    /**
     * [Deprecated] The paths to the mounted TLS Certificates and private key. The paths to the mounted TLS Certificates and private key.
     */
    export interface Schema$TlsCertificatePaths {
        /**
         * The path to the file holding the client or server TLS certificate to use.
         */
        certificatePath?: string | null;
        /**
         * The path to the file holding the client or server private key.
         */
        privateKeyPath?: string | null;
    }
    /**
     * [Deprecated] The TLS settings for the client or server. The TLS settings for the client or server.
     */
    export interface Schema$TlsContext {
        /**
         * Defines the mechanism to obtain the client or server certificate.
         */
        certificateContext?: Schema$TlsCertificateContext;
        /**
         * Defines the mechanism to obtain the Certificate Authority certificate to validate the client/server certificate. If omitted, the proxy will not validate the server or client certificate.
         */
        validationContext?: Schema$TlsValidationContext;
    }
    /**
     * [Deprecated] Defines the mechanism to obtain the Certificate Authority certificate to validate the client/server certificate. validate the client/server certificate.
     */
    export interface Schema$TlsValidationContext {
        /**
         * The path to the file holding the CA certificate to validate the client or server certificate.
         */
        certificatePath?: string | null;
        /**
         * Specifies the config to retrieve certificates through SDS. This field is applicable only if tlsCertificateSource is set to USE_SDS.
         */
        sdsConfig?: Schema$SdsConfig;
        /**
         * Defines how TLS certificates are obtained.
         */
        validationSource?: string | null;
    }
    export interface Schema$UDPHealthCheck {
        /**
         * The UDP port number to which the health check prober sends packets. Valid values are 1 through 65535.
         */
        port?: number | null;
        /**
         * Not supported.
         */
        portName?: string | null;
        /**
         * Raw data of request to send in payload of UDP packet. It is an error if this is empty. The request data can only be ASCII.
         */
        request?: string | null;
        /**
         * The bytes to match against the beginning of the response data. It is an error if this is empty. The response data can only be ASCII.
         */
        response?: string | null;
    }
    export interface Schema$Uint128 {
        high?: string | null;
        low?: string | null;
    }
    /**
     * Upcoming Maintenance notification information.
     */
    export interface Schema$UpcomingMaintenance {
        /**
         * Indicates if the maintenance can be customer triggered.
         */
        canReschedule?: boolean | null;
        /**
         * [Output Only] The date when the maintenance will take place. This value is in RFC3339 text format. DEPRECATED: Use window_start_time instead.
         */
        date?: string | null;
        /**
         * The latest time for the planned maintenance window to start. This timestamp value is in RFC3339 text format.
         */
        latestWindowStartTime?: string | null;
        maintenanceStatus?: string | null;
        /**
         * [Output Only] The start time window of the maintenance disruption. DEPRECATED: Use window_start_time instead. TimeWindow is a container for two strings that represent timestamps in "yyyy-MM-dd'T'HH:mm:ssZ" text format.
         */
        startTimeWindow?: Schema$UpcomingMaintenanceTimeWindow;
        /**
         * [Output Only] The time when the maintenance will take place. This value is in RFC3339 text format. DEPRECATED: Use window_start_time instead.
         */
        time?: string | null;
        /**
         * Defines the type of maintenance.
         */
        type?: string | null;
        /**
         * The time by which the maintenance disruption will be completed. This timestamp value is in RFC3339 text format.
         */
        windowEndTime?: string | null;
        /**
         * The current start time of the maintenance window. This timestamp value is in RFC3339 text format.
         */
        windowStartTime?: string | null;
    }
    /**
     * Represents a window of time using two timestamps: `earliest` and `latest`.
     */
    export interface Schema$UpcomingMaintenanceTimeWindow {
        earliest?: string | null;
        latest?: string | null;
    }
    /**
     * Represents a URL Map resource. Compute Engine has two URL Map resources: * [Global](/compute/docs/reference/rest/alpha/urlMaps) * [Regional](/compute/docs/reference/rest/alpha/regionUrlMaps) A URL map resource is a component of certain types of cloud load balancers and Traffic Director: * urlMaps are used by global external Application Load Balancers, classic Application Load Balancers, and cross-region internal Application Load Balancers. * regionUrlMaps are used by internal Application Load Balancers, regional external Application Load Balancers and regional internal Application Load Balancers. For a list of supported URL map features by the load balancer type, see the Load balancing features: Routing and traffic management table. For a list of supported URL map features for Traffic Director, see the Traffic Director features: Routing and traffic management table. This resource defines mappings from hostnames and URL paths to either a backend service or a backend bucket. To use the global urlMaps resource, the backend service must have a loadBalancingScheme of either EXTERNAL or INTERNAL_SELF_MANAGED. To use the regionUrlMaps resource, the backend service must have a loadBalancingScheme of INTERNAL_MANAGED. For more information, read URL Map Concepts.
     */
    export interface Schema$UrlMap {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * defaultCustomErrorResponsePolicy specifies how the Load Balancer returns error responses when BackendServiceor BackendBucket responds with an error. This policy takes effect at the load balancer level and applies only when no policy has been defined for the error code at lower levels like PathMatcher, RouteRule and PathRule within this UrlMap. For example, consider a UrlMap with the following configuration: - defaultCustomErrorResponsePolicy containing policies for responding to 5xx and 4xx errors - A PathMatcher configured for *.example.com has defaultCustomErrorResponsePolicy for 4xx. If a request for http://www.example.com/ encounters a 404, the policy in pathMatcher.defaultCustomErrorResponsePolicy will be enforced. When the request for http://www.example.com/ encounters a 502, the policy in UrlMap.defaultCustomErrorResponsePolicy will be enforced. When a request that does not match any host in *.example.com such as http://www.myotherexample.com/, encounters a 404, UrlMap.defaultCustomErrorResponsePolicy takes effect. When used in conjunction with defaultRouteAction.retryPolicy, retries take precedence. Only once all retries are exhausted, the defaultCustomErrorResponsePolicy is applied. While attempting a retry, if load balancer is successful in reaching the service, the defaultCustomErrorResponsePolicy is ignored and the response from the service is returned to the client. defaultCustomErrorResponsePolicy is supported only for global external Application Load Balancers.
         */
        defaultCustomErrorResponsePolicy?: Schema$CustomErrorResponsePolicy;
        /**
         * defaultRouteAction takes effect when none of the hostRules match. The load balancer performs advanced routing actions, such as URL rewrites and header transformations, before forwarding the request to the selected backend. If defaultRouteAction specifies any weightedBackendServices, defaultService must not be set. Conversely if defaultService is set, defaultRouteAction cannot contain any weightedBackendServices. Only one of defaultRouteAction or defaultUrlRedirect must be set. URL maps for classic Application Load Balancers only support the urlRewrite action within defaultRouteAction. defaultRouteAction has no effect when the URL map is bound to a target gRPC proxy that has the validateForProxyless field set to true.
         */
        defaultRouteAction?: Schema$HttpRouteAction;
        /**
         * The full or partial URL of the defaultService resource to which traffic is directed if none of the hostRules match. If defaultRouteAction is also specified, advanced routing actions, such as URL rewrites, take effect before sending the request to the backend. However, if defaultService is specified, defaultRouteAction cannot contain any weightedBackendServices. Conversely, if routeAction specifies any weightedBackendServices, service must not be specified. Only one of defaultService, defaultUrlRedirect , or defaultRouteAction.weightedBackendService must be set. defaultService has no effect when the URL map is bound to a target gRPC proxy that has the validateForProxyless field set to true.
         */
        defaultService?: string | null;
        /**
         * When none of the specified hostRules match, the request is redirected to a URL specified by defaultUrlRedirect. If defaultUrlRedirect is specified, defaultService or defaultRouteAction must not be set. Not supported when the URL map is bound to a target gRPC proxy.
         */
        defaultUrlRedirect?: Schema$HttpRedirectAction;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field is ignored when inserting a UrlMap. An up-to-date fingerprint must be provided in order to update the UrlMap, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a UrlMap.
         */
        fingerprint?: string | null;
        /**
         * Specifies changes to request and response headers that need to take effect for the selected backendService. The headerAction specified here take effect after headerAction specified under pathMatcher. headerAction is not supported for load balancers that have their loadBalancingScheme set to EXTERNAL. Not supported when the URL map is bound to a target gRPC proxy that has validateForProxyless field set to true.
         */
        headerAction?: Schema$HttpHeaderAction;
        /**
         * The list of host rules to use against the URL.
         */
        hostRules?: Schema$HostRule[];
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#urlMaps for url maps.
         */
        kind?: string | null;
        /**
         * Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * The list of named PathMatchers to use against the URL.
         */
        pathMatchers?: Schema$PathMatcher[];
        /**
         * [Output Only] URL of the region where the regional URL map resides. This field is not applicable to global URL maps. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
         */
        region?: string | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * The list of expected URL mapping tests. Request to update the UrlMap succeeds only if all test cases pass. You can specify a maximum of 100 tests per UrlMap. Not supported when the URL map is bound to a target gRPC proxy that has validateForProxyless field set to true.
         */
        tests?: Schema$UrlMapTest[];
    }
    /**
     * Contains a list of UrlMap resources.
     */
    export interface Schema$UrlMapList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of UrlMap resources.
         */
        items?: Schema$UrlMap[];
        /**
         * Type of resource.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$UrlMapReference {
        urlMap?: string | null;
    }
    export interface Schema$UrlMapsAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of UrlMapsScopedList resources.
         */
        items?: {
            [key: string]: Schema$UrlMapsScopedList;
        } | null;
        /**
         * Type of resource.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$UrlMapsScopedList {
        /**
         * A list of UrlMaps contained in this scope.
         */
        urlMaps?: Schema$UrlMap[];
        /**
         * Informational warning which replaces the list of backend services when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$UrlMapsValidateRequest {
        /**
         * Specifies the load balancer type(s) this validation request is for. Use EXTERNAL_MANAGED for global external Application Load Balancers and regional external Application Load Balancers. Use EXTERNAL for classic Application Load Balancers. Use INTERNAL_MANAGED for internal Application Load Balancers. For more information, refer to Choosing a load balancer. If unspecified, the load balancing scheme will be inferred from the backend service resources this URL map references. If that can not be inferred (for example, this URL map only references backend buckets, or this Url map is for rewrites and redirects only and doesn't reference any backends), EXTERNAL will be used as the default type. If specified, the scheme(s) must not conflict with the load balancing scheme of the backend service resources this Url map references.
         */
        loadBalancingSchemes?: string[] | null;
        /**
         * Content of the UrlMap to be validated.
         */
        resource?: Schema$UrlMap;
    }
    export interface Schema$UrlMapsValidateResponse {
        result?: Schema$UrlMapValidationResult;
    }
    /**
     * Message for the expected URL mappings.
     */
    export interface Schema$UrlMapTest {
        /**
         * The weight to use for the supplied host and path when using advanced routing rules that involve traffic splitting.
         */
        backendServiceWeight?: number | null;
        /**
         * Description of this test case.
         */
        description?: string | null;
        /**
         * The expected output URL evaluated by the load balancer containing the scheme, host, path and query parameters. For rules that forward requests to backends, the test passes only when expectedOutputUrl matches the request forwarded by the load balancer to backends. For rules with urlRewrite, the test verifies that the forwarded request matches hostRewrite and pathPrefixRewrite in the urlRewrite action. When service is specified, expectedOutputUrl`s scheme is ignored. For rules with urlRedirect, the test passes only if expectedOutputUrl matches the URL in the load balancer's redirect response. If urlRedirect specifies https_redirect, the test passes only if the scheme in expectedOutputUrl is also set to HTTPS. If urlRedirect specifies strip_query, the test passes only if expectedOutputUrl does not contain any query parameters. expectedOutputUrl is optional when service is specified.
         */
        expectedOutputUrl?: string | null;
        /**
         * For rules with urlRedirect, the test passes only if expectedRedirectResponseCode matches the HTTP status code in load balancer's redirect response. expectedRedirectResponseCode cannot be set when service is set.
         */
        expectedRedirectResponseCode?: number | null;
        /**
         * The expected URL that should be redirected to for the host and path being tested. [Deprecated] This field is deprecated. Use expected_output_url instead.
         */
        expectedUrlRedirect?: string | null;
        /**
         * HTTP headers for this request. If headers contains a host header, then host must also match the header value.
         */
        headers?: Schema$UrlMapTestHeader[];
        /**
         * Host portion of the URL. If headers contains a host header, then host must also match the header value.
         */
        host?: string | null;
        /**
         * Path portion of the URL.
         */
        path?: string | null;
        /**
         * Expected BackendService or BackendBucket resource the given URL should be mapped to. The service field cannot be set if expectedRedirectResponseCode is set.
         */
        service?: string | null;
    }
    /**
     * HTTP headers used in UrlMapTests.
     */
    export interface Schema$UrlMapTestHeader {
        /**
         * Header name.
         */
        name?: string | null;
        /**
         * Header value.
         */
        value?: string | null;
    }
    /**
     * Message representing the validation result for a UrlMap.
     */
    export interface Schema$UrlMapValidationResult {
        loadErrors?: string[] | null;
        /**
         * Whether the given UrlMap can be successfully loaded. If false, 'loadErrors' indicates the reasons.
         */
        loadSucceeded?: boolean | null;
        testFailures?: Schema$TestFailure[];
        /**
         * If successfully loaded, this field indicates whether the test passed. If false, 'testFailures's indicate the reason of failure.
         */
        testPassed?: boolean | null;
    }
    /**
     * The spec for modifying the path before sending the request to the matched backend service.
     */
    export interface Schema$UrlRewrite {
        /**
         * Before forwarding the request to the selected service, the request's host header is replaced with contents of hostRewrite. The value must be from 1 to 255 characters.
         */
        hostRewrite?: string | null;
        /**
         * Before forwarding the request to the selected backend service, the matching portion of the request's path is replaced by pathPrefixRewrite. The value must be from 1 to 1024 characters.
         */
        pathPrefixRewrite?: string | null;
        /**
         *  If specified, the pattern rewrites the URL path (based on the :path header) using the HTTP template syntax. A corresponding path_template_match must be specified. Any template variables must exist in the path_template_match field. - -At least one variable must be specified in the path_template_match field - You can omit variables from the rewritten URL - The * and ** operators cannot be matched unless they have a corresponding variable name - e.g. {format=*\} or {var=**\}. For example, a path_template_match of /static/{format=**\} could be rewritten as /static/content/{format\} to prefix /content to the URL. Variables can also be re-ordered in a rewrite, so that /{country\}/{format\}/{suffix=**\} can be rewritten as /content/{format\}/{country\}/{suffix\}. At least one non-empty routeRules[].matchRules[].path_template_match is required. Only one of path_prefix_rewrite or path_template_rewrite may be specified.
         */
        pathTemplateRewrite?: string | null;
    }
    /**
     * Subnetwork which the current user has compute.subnetworks.use permission on.
     */
    export interface Schema$UsableSubnetwork {
        /**
         * [Output Only] The external IPv6 address range that is assigned to this subnetwork.
         */
        externalIpv6Prefix?: string | null;
        /**
         * [Output Only] The internal IPv6 address range that is assigned to this subnetwork.
         */
        internalIpv6Prefix?: string | null;
        /**
         * The range of internal addresses that are owned by this subnetwork.
         */
        ipCidrRange?: string | null;
        /**
         * The access type of IPv6 address this subnet holds. It's immutable and can only be specified during creation or the first time the subnet is updated into IPV4_IPV6 dual stack.
         */
        ipv6AccessType?: string | null;
        /**
         * Network URL.
         */
        network?: string | null;
        /**
         * The purpose of the resource. This field can be either PRIVATE, REGIONAL_MANAGED_PROXY, PRIVATE_SERVICE_CONNECT, or INTERNAL_HTTPS_LOAD_BALANCER. PRIVATE is the default purpose for user-created subnets or subnets that are automatically created in auto mode networks. A subnet with purpose set to REGIONAL_MANAGED_PROXY is a user-created subnetwork that is reserved for regional Envoy-based load balancers. A subnet with purpose set to PRIVATE_SERVICE_CONNECT is used to publish services using Private Service Connect. A subnet with purpose set to INTERNAL_HTTPS_LOAD_BALANCER is a proxy-only subnet that can be used only by regional internal HTTP(S) load balancers. Note that REGIONAL_MANAGED_PROXY is the preferred setting for all regional Envoy load balancers. If unspecified, the subnet purpose defaults to PRIVATE. The enableFlowLogs field isn't supported if the subnet purpose field is set to REGIONAL_MANAGED_PROXY.
         */
        purpose?: string | null;
        /**
         * The role of subnetwork. Currently, this field is only used when purpose = REGIONAL_MANAGED_PROXY. The value can be set to ACTIVE or BACKUP. An ACTIVE subnetwork is one that is currently being used for Envoy-based load balancers in a region. A BACKUP subnetwork is one that is ready to be promoted to ACTIVE or is currently draining. This field can be updated with a patch request.
         */
        role?: string | null;
        /**
         * Secondary IP ranges.
         */
        secondaryIpRanges?: Schema$UsableSubnetworkSecondaryRange[];
        /**
         * The stack type for the subnet. If set to IPV4_ONLY, new VMs in the subnet are assigned IPv4 addresses only. If set to IPV4_IPV6, new VMs in the subnet can be assigned both IPv4 and IPv6 addresses. If not specified, IPV4_ONLY is used. This field can be both set at resource creation time and updated using patch.
         */
        stackType?: string | null;
        /**
         * Subnetwork URL.
         */
        subnetwork?: string | null;
    }
    export interface Schema$UsableSubnetworksAggregatedList {
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output] A list of usable subnetwork URLs.
         */
        items?: Schema$UsableSubnetwork[];
        /**
         * [Output Only] Type of resource. Always compute#usableSubnetworksAggregatedList for aggregated lists of usable subnetworks.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. In special cases listUsable may return 0 subnetworks and nextPageToken which still should be used to get the next page of results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Secondary IP range of a usable subnetwork.
     */
    export interface Schema$UsableSubnetworkSecondaryRange {
        /**
         * The range of IP addresses belonging to this subnetwork secondary range.
         */
        ipCidrRange?: string | null;
        /**
         * The name associated with this subnetwork secondary range, used when adding an alias IP range to a VM instance. The name must be 1-63 characters long, and comply with RFC1035. The name must be unique within the subnetwork.
         */
        rangeName?: string | null;
    }
    /**
     * The location in Cloud Storage and naming method of the daily usage report. Contains bucket_name and report_name prefix.
     */
    export interface Schema$UsageExportLocation {
        /**
         * The name of an existing bucket in Cloud Storage where the usage report object is stored. The Google Service Account is granted write access to this bucket. This can either be the bucket name by itself, such as example-bucket, or the bucket name with gs:// or https://storage.googleapis.com/ in front of it, such as gs://example-bucket.
         */
        bucketName?: string | null;
        /**
         * An optional prefix for the name of the usage report object stored in bucketName. If not supplied, defaults to usage_gce. The report is stored as a CSV file named report_name_prefix_gce_YYYYMMDD.csv where YYYYMMDD is the day of the usage according to Pacific Time. If you supply a prefix, it should conform to Cloud Storage object naming conventions.
         */
        reportNamePrefix?: string | null;
    }
    /**
     * Contain information of Nat mapping for a VM endpoint (i.e., NIC).
     */
    export interface Schema$VmEndpointNatMappings {
        /**
         * Name of the VM instance which the endpoint belongs to
         */
        instanceName?: string | null;
        interfaceNatMappings?: Schema$VmEndpointNatMappingsInterfaceNatMappings[];
    }
    /**
     * Contain information of Nat mapping for an interface of this endpoint.
     */
    export interface Schema$VmEndpointNatMappingsInterfaceNatMappings {
        /**
         * List of all drain IP:port-range mappings assigned to this interface. These ranges are inclusive, that is, both the first and the last ports can be used for NAT. Example: ["2.2.2.2:12345-12355", "1.1.1.1:2234-2234"].
         */
        drainNatIpPortRanges?: string[] | null;
        /**
         * A list of all IP:port-range mappings assigned to this interface. These ranges are inclusive, that is, both the first and the last ports can be used for NAT. Example: ["2.2.2.2:12345-12355", "1.1.1.1:2234-2234"].
         */
        natIpPortRanges?: string[] | null;
        /**
         * Total number of drain ports across all NAT IPs allocated to this interface. It equals to the aggregated port number in the field drain_nat_ip_port_ranges.
         */
        numTotalDrainNatPorts?: number | null;
        /**
         * Total number of ports across all NAT IPs allocated to this interface. It equals to the aggregated port number in the field nat_ip_port_ranges.
         */
        numTotalNatPorts?: number | null;
        /**
         * Information about mappings provided by rules in this NAT.
         */
        ruleMappings?: Schema$VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings[];
        /**
         * Alias IP range for this interface endpoint. It will be a private (RFC 1918) IP range. Examples: "10.33.4.55/32", or "192.168.5.0/24".
         */
        sourceAliasIpRange?: string | null;
        /**
         * Primary IP of the VM for this NIC.
         */
        sourceVirtualIp?: string | null;
    }
    /**
     * Contains information of NAT Mappings provided by a NAT Rule.
     */
    export interface Schema$VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings {
        /**
         * List of all drain IP:port-range mappings assigned to this interface by this rule. These ranges are inclusive, that is, both the first and the last ports can be used for NAT. Example: ["2.2.2.2:12345-12355", "1.1.1.1:2234-2234"].
         */
        drainNatIpPortRanges?: string[] | null;
        /**
         * A list of all IP:port-range mappings assigned to this interface by this rule. These ranges are inclusive, that is, both the first and the last ports can be used for NAT. Example: ["2.2.2.2:12345-12355", "1.1.1.1:2234-2234"].
         */
        natIpPortRanges?: string[] | null;
        /**
         * Total number of drain ports across all NAT IPs allocated to this interface by this rule. It equals the aggregated port number in the field drain_nat_ip_port_ranges.
         */
        numTotalDrainNatPorts?: number | null;
        /**
         * Total number of ports across all NAT IPs allocated to this interface by this rule. It equals the aggregated port number in the field nat_ip_port_ranges.
         */
        numTotalNatPorts?: number | null;
        /**
         * Rule number of the NAT Rule.
         */
        ruleNumber?: number | null;
    }
    /**
     * Contains a list of VmEndpointNatMappings.
     */
    export interface Schema$VmEndpointNatMappingsList {
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] Type of resource. Always compute#vmEndpointNatMappingsList for lists of Nat mappings of VM endpoints.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] A list of Nat mapping information of VM endpoints.
         */
        result?: Schema$VmEndpointNatMappings[];
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Represents a HA VPN gateway. HA VPN is a high-availability (HA) Cloud VPN solution that lets you securely connect your on-premises network to your Google Cloud Virtual Private Cloud network through an IPsec VPN connection in a single region. For more information about Cloud HA VPN solutions, see Cloud VPN topologies .
     */
    export interface Schema$VpnGateway {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * The IP family of the gateway IPs for the HA-VPN gateway interfaces. If not specified, IPV4 will be used.
         */
        gatewayIpVersion?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] Type of resource. Always compute#vpnGateway for VPN gateways.
         */
        kind?: string | null;
        /**
         * A fingerprint for the labels being applied to this VpnGateway, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a VpnGateway.
         */
        labelFingerprint?: string | null;
        /**
         * Labels for this resource. These can only be added or modified by the setLabels method. Each label key/value pair must comply with RFC1035. Label values may be empty.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * URL of the network to which this VPN gateway is attached. Provided by the client when the VPN gateway is created.
         */
        network?: string | null;
        /**
         * [Output Only] URL of the region where the VPN gateway resides.
         */
        region?: string | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * The stack type for this VPN gateway to identify the IP protocols that are enabled. Possible values are: IPV4_ONLY, IPV4_IPV6. If not specified, IPV4_ONLY will be used.
         */
        stackType?: string | null;
        /**
         * The list of VPN interfaces associated with this VPN gateway.
         */
        vpnInterfaces?: Schema$VpnGatewayVpnGatewayInterface[];
    }
    export interface Schema$VpnGatewayAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of VpnGateway resources.
         */
        items?: {
            [key: string]: Schema$VpnGatewaysScopedList;
        } | null;
        /**
         * [Output Only] Type of resource. Always compute#vpnGateway for VPN gateways.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Contains a list of VpnGateway resources.
     */
    export interface Schema$VpnGatewayList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of VpnGateway resources.
         */
        items?: Schema$VpnGateway[];
        /**
         * [Output Only] Type of resource. Always compute#vpnGateway for VPN gateways.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$VpnGatewaysGetStatusResponse {
        result?: Schema$VpnGatewayStatus;
    }
    export interface Schema$VpnGatewaysScopedList {
        /**
         * [Output Only] A list of VPN gateways contained in this scope.
         */
        vpnGateways?: Schema$VpnGateway[];
        /**
         * [Output Only] Informational warning which replaces the list of addresses when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$VpnGatewayStatus {
        /**
         * List of VPN connection for this VpnGateway.
         */
        vpnConnections?: Schema$VpnGatewayStatusVpnConnection[];
    }
    /**
     * Describes the high availability requirement state for the VPN connection between this Cloud VPN gateway and a peer gateway.
     */
    export interface Schema$VpnGatewayStatusHighAvailabilityRequirementState {
        /**
         * Indicates the high availability requirement state for the VPN connection. Valid values are CONNECTION_REDUNDANCY_MET, CONNECTION_REDUNDANCY_NOT_MET.
         */
        state?: string | null;
        /**
         * Indicates the reason why the VPN connection does not meet the high availability redundancy criteria/requirement. Valid values is INCOMPLETE_TUNNELS_COVERAGE.
         */
        unsatisfiedReason?: string | null;
    }
    /**
     * Contains some information about a VPN tunnel.
     */
    export interface Schema$VpnGatewayStatusTunnel {
        /**
         * The VPN gateway interface this VPN tunnel is associated with.
         */
        localGatewayInterface?: number | null;
        /**
         * The peer gateway interface this VPN tunnel is connected to, the peer gateway could either be an external VPN gateway or a Google Cloud VPN gateway.
         */
        peerGatewayInterface?: number | null;
        /**
         * URL reference to the VPN tunnel.
         */
        tunnelUrl?: string | null;
    }
    /**
     * A VPN connection contains all VPN tunnels connected from this VpnGateway to the same peer gateway. The peer gateway could either be an external VPN gateway or a Google Cloud VPN gateway.
     */
    export interface Schema$VpnGatewayStatusVpnConnection {
        /**
         * URL reference to the peer external VPN gateways to which the VPN tunnels in this VPN connection are connected. This field is mutually exclusive with peer_gcp_gateway.
         */
        peerExternalGateway?: string | null;
        /**
         * URL reference to the peer side VPN gateways to which the VPN tunnels in this VPN connection are connected. This field is mutually exclusive with peer_gcp_gateway.
         */
        peerGcpGateway?: string | null;
        /**
         * HighAvailabilityRequirementState for the VPN connection.
         */
        state?: Schema$VpnGatewayStatusHighAvailabilityRequirementState;
        /**
         * List of VPN tunnels that are in this VPN connection.
         */
        tunnels?: Schema$VpnGatewayStatusTunnel[];
    }
    /**
     * A VPN gateway interface.
     */
    export interface Schema$VpnGatewayVpnGatewayInterface {
        /**
         * [Output Only] Numeric identifier for this VPN interface associated with the VPN gateway.
         */
        id?: number | null;
        /**
         * URL of the VLAN attachment (interconnectAttachment) resource for this VPN gateway interface. When the value of this field is present, the VPN gateway is used for HA VPN over Cloud Interconnect; all egress or ingress traffic for this VPN gateway interface goes through the specified VLAN attachment resource.
         */
        interconnectAttachment?: string | null;
        /**
         * [Output Only] IP address for this VPN interface associated with the VPN gateway. The IP address could be either a regional external IP address or a regional internal IP address. The two IP addresses for a VPN gateway must be all regional external or regional internal IP addresses. There cannot be a mix of regional external IP addresses and regional internal IP addresses. For HA VPN over Cloud Interconnect, the IP addresses for both interfaces could either be regional internal IP addresses or regional external IP addresses. For regular (non HA VPN over Cloud Interconnect) HA VPN tunnels, the IP address must be a regional external IP address.
         */
        ipAddress?: string | null;
        /**
         * [Output Only] IPv6 address for this VPN interface associated with the VPN gateway. The IPv6 address must be a regional external IPv6 address. The format is RFC 5952 format (e.g. 2001:db8::2d9:51:0:0).
         */
        ipv6Address?: string | null;
    }
    /**
     * Represents a Cloud VPN Tunnel resource. For more information about VPN, read the the Cloud VPN Overview.
     */
    export interface Schema$VpnTunnel {
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * An optional description of this resource. Provide this property when you create the resource.
         */
        description?: string | null;
        /**
         * [Output Only] Detailed status message for the VPN tunnel.
         */
        detailedStatus?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * IKE protocol version to use when establishing the VPN tunnel with the peer VPN gateway. Acceptable IKE versions are 1 or 2. The default version is 2.
         */
        ikeVersion?: number | null;
        /**
         * [Output Only] Type of resource. Always compute#vpnTunnel for VPN tunnels.
         */
        kind?: string | null;
        /**
         * A fingerprint for the labels being applied to this VpnTunnel, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a VpnTunnel.
         */
        labelFingerprint?: string | null;
        /**
         * Labels for this resource. These can only be added or modified by the setLabels method. Each label key/value pair must comply with RFC1035. Label values may be empty.
         */
        labels?: {
            [key: string]: string;
        } | null;
        /**
         * Local traffic selector to use when establishing the VPN tunnel with the peer VPN gateway. The value should be a CIDR formatted string, for example: 192.168.0.0/16. The ranges must be disjoint. Only IPv4 is supported.
         */
        localTrafficSelector?: string[] | null;
        /**
         * Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
         */
        name?: string | null;
        /**
         * URL of the peer side external VPN gateway to which this VPN tunnel is connected. Provided by the client when the VPN tunnel is created. This field is exclusive with the field peerGcpGateway.
         */
        peerExternalGateway?: string | null;
        /**
         * The interface ID of the external VPN gateway to which this VPN tunnel is connected. Provided by the client when the VPN tunnel is created. Possible values are: `0`, `1`, `2`, `3`. The number of IDs in use depends on the external VPN gateway redundancy type.
         */
        peerExternalGatewayInterface?: number | null;
        /**
         * URL of the peer side HA VPN gateway to which this VPN tunnel is connected. Provided by the client when the VPN tunnel is created. This field can be used when creating highly available VPN from VPC network to VPC network, the field is exclusive with the field peerExternalGateway. If provided, the VPN tunnel will automatically use the same vpnGatewayInterface ID in the peer Google Cloud VPN gateway.
         */
        peerGcpGateway?: string | null;
        /**
         * IP address of the peer VPN gateway. Only IPv4 is supported.
         */
        peerIp?: string | null;
        /**
         * [Output Only] URL of the region where the VPN tunnel resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
         */
        region?: string | null;
        /**
         * Remote traffic selectors to use when establishing the VPN tunnel with the peer VPN gateway. The value should be a CIDR formatted string, for example: 192.168.0.0/16. The ranges should be disjoint. Only IPv4 is supported.
         */
        remoteTrafficSelector?: string[] | null;
        /**
         * URL of the router resource to be used for dynamic routing.
         */
        router?: string | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * Shared secret used to set the secure session between the Cloud VPN gateway and the peer VPN gateway.
         */
        sharedSecret?: string | null;
        /**
         * Hash of the shared secret.
         */
        sharedSecretHash?: string | null;
        /**
         * [Output Only] The status of the VPN tunnel, which can be one of the following: - PROVISIONING: Resource is being allocated for the VPN tunnel. - WAITING_FOR_FULL_CONFIG: Waiting to receive all VPN-related configs from the user. Network, TargetVpnGateway, VpnTunnel, ForwardingRule, and Route resources are needed to setup the VPN tunnel. - FIRST_HANDSHAKE: Successful first handshake with the peer VPN. - ESTABLISHED: Secure session is successfully established with the peer VPN. - NETWORK_ERROR: Deprecated, replaced by NO_INCOMING_PACKETS - AUTHORIZATION_ERROR: Auth error (for example, bad shared secret). - NEGOTIATION_FAILURE: Handshake failed. - DEPROVISIONING: Resources are being deallocated for the VPN tunnel. - FAILED: Tunnel creation has failed and the tunnel is not ready to be used. - NO_INCOMING_PACKETS: No incoming packets from peer. - REJECTED: Tunnel configuration was rejected, can be result of being denied access. - ALLOCATING_RESOURCES: Cloud VPN is in the process of allocating all required resources. - STOPPED: Tunnel is stopped due to its Forwarding Rules being deleted for Classic VPN tunnels or the project is in frozen state. - PEER_IDENTITY_MISMATCH: Peer identity does not match peer IP, probably behind NAT. - TS_NARROWING_NOT_ALLOWED: Traffic selector narrowing not allowed for an HA-VPN tunnel.
         */
        status?: string | null;
        /**
         * URL of the Target VPN gateway with which this VPN tunnel is associated. Provided by the client when the VPN tunnel is created.
         */
        targetVpnGateway?: string | null;
        /**
         * URL of the VPN gateway with which this VPN tunnel is associated. Provided by the client when the VPN tunnel is created. This must be used (instead of target_vpn_gateway) if a High Availability VPN gateway resource is created.
         */
        vpnGateway?: string | null;
        /**
         * The interface ID of the VPN gateway with which this VPN tunnel is associated. Possible values are: `0`, `1`.
         */
        vpnGatewayInterface?: number | null;
    }
    export interface Schema$VpnTunnelAggregatedList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of VpnTunnelsScopedList resources.
         */
        items?: {
            [key: string]: Schema$VpnTunnelsScopedList;
        } | null;
        /**
         * [Output Only] Type of resource. Always compute#vpnTunnel for VPN tunnels.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Unreachable resources.
         */
        unreachables?: string[] | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Contains a list of VpnTunnel resources.
     */
    export interface Schema$VpnTunnelList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of VpnTunnel resources.
         */
        items?: Schema$VpnTunnel[];
        /**
         * [Output Only] Type of resource. Always compute#vpnTunnel for VPN tunnels.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$VpnTunnelsScopedList {
        /**
         * A list of VPN tunnels contained in this scope.
         */
        vpnTunnels?: Schema$VpnTunnel[];
        /**
         * Informational warning which replaces the list of addresses when the list is empty.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$WafExpressionSet {
        /**
         * A list of alternate IDs. The format should be: - E.g. XSS-stable Generic suffix like "stable" is particularly useful if a policy likes to avail newer set of expressions without having to change the policy. A given alias name can't be used for more than one entity set.
         */
        aliases?: string[] | null;
        /**
         * List of available expressions.
         */
        expressions?: Schema$WafExpressionSetExpression[];
        /**
         * Google specified expression set ID. The format should be: - E.g. XSS-20170329 required
         */
        id?: string | null;
    }
    export interface Schema$WafExpressionSetExpression {
        /**
         * Expression ID should uniquely identify the origin of the expression. E.g. owasp-crs-v020901-id973337 identifies Owasp core rule set version 2.9.1 rule id 973337. The ID could be used to determine the individual attack definition that has been detected. It could also be used to exclude it from the policy in case of false positive. required
         */
        id?: string | null;
        /**
         * The sensitivity value associated with the WAF rule ID. This corresponds to the ModSecurity paranoia level, ranging from 1 to 4. 0 is reserved for opt-in only rules.
         */
        sensitivity?: number | null;
    }
    /**
     * In contrast to a single BackendService in HttpRouteAction to which all matching traffic is directed to, WeightedBackendService allows traffic to be split across multiple backend services. The volume of traffic for each backend service is proportional to the weight specified in each WeightedBackendService
     */
    export interface Schema$WeightedBackendService {
        /**
         * The full or partial URL to the default BackendService resource. Before forwarding the request to backendService, the load balancer applies any relevant headerActions specified as part of this backendServiceWeight.
         */
        backendService?: string | null;
        /**
         * Specifies changes to request and response headers that need to take effect for the selected backendService. headerAction specified here take effect before headerAction in the enclosing HttpRouteRule, PathMatcher and UrlMap. headerAction is not supported for load balancers that have their loadBalancingScheme set to EXTERNAL. Not supported when the URL map is bound to a target gRPC proxy that has validateForProxyless field set to true.
         */
        headerAction?: Schema$HttpHeaderAction;
        /**
         * Specifies the fraction of traffic sent to a backend service, computed as weight / (sum of all weightedBackendService weights in routeAction) . The selection of a backend service is determined only for new traffic. Once a user's request has been directed to a backend service, subsequent requests are sent to the same backend service as determined by the backend service's session affinity policy. The value must be from 0 to 1000.
         */
        weight?: number | null;
    }
    export interface Schema$XpnHostList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] A list of shared VPC host project URLs.
         */
        items?: Schema$Project[];
        /**
         * [Output Only] Type of resource. Always compute#xpnHostList for lists of shared VPC hosts.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    /**
     * Service resource (a.k.a service project) ID.
     */
    export interface Schema$XpnResourceId {
        /**
         * The ID of the service resource. In the case of projects, this field supports project id (e.g., my-project-123) and project number (e.g. 12345678).
         */
        id?: string | null;
        /**
         * The type of the service resource.
         */
        type?: string | null;
    }
    /**
     * Represents a Zone resource. A zone is a deployment area. These deployment areas are subsets of a region. For example the zone us-east1-a is located in the us-east1 region. For more information, read Regions and Zones.
     */
    export interface Schema$Zone {
        /**
         * [Output Only] Available cpu/platform selections for the zone.
         */
        availableCpuPlatforms?: string[] | null;
        /**
         * [Output Only] Creation timestamp in RFC3339 text format.
         */
        creationTimestamp?: string | null;
        /**
         * [Output Only] The deprecation status associated with this zone.
         */
        deprecated?: Schema$DeprecationStatus;
        /**
         * [Output Only] Textual description of the resource.
         */
        description?: string | null;
        /**
         * [Output Only] The unique identifier for the resource. This identifier is defined by the server.
         */
        id?: string | null;
        /**
         * [Output Only] Type of the resource. Always compute#zone for zones.
         */
        kind?: string | null;
        /**
         * [Output Only] Name of the resource.
         */
        name?: string | null;
        /**
         * [Output Only] Full URL reference to the region which hosts the zone.
         */
        region?: string | null;
        /**
         * [Output Only] Server-defined URL for the resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Status of the zone, either UP or DOWN.
         */
        status?: string | null;
        /**
         * [Output Only] Reserved for future use.
         */
        supportsPzs?: boolean | null;
    }
    /**
     * Contains a list of zone resources.
     */
    export interface Schema$ZoneList {
        /**
         * [Output Only] Unique identifier for the resource; defined by the server.
         */
        id?: string | null;
        /**
         * A list of Zone resources.
         */
        items?: Schema$Zone[];
        /**
         * Type of resource.
         */
        kind?: string | null;
        /**
         * [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
         */
        nextPageToken?: string | null;
        /**
         * [Output Only] Server-defined URL for this resource.
         */
        selfLink?: string | null;
        /**
         * [Output Only] Informational warning message.
         */
        warning?: {
            code?: string;
            data?: Array<{
                key?: string;
                value?: string;
            }>;
            message?: string;
        } | null;
    }
    export interface Schema$ZoneSetLabelsRequest {
        /**
         * The fingerprint of the previous set of labels for this resource, used to detect conflicts. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels. Make a get() request to the resource to get the latest fingerprint.
         */
        labelFingerprint?: string | null;
        /**
         * The labels to set for this resource.
         */
        labels?: {
            [key: string]: string;
        } | null;
    }
    export interface Schema$ZoneSetPolicyRequest {
        /**
         * Flatten Policy to create a backwacd compatible wire-format. Deprecated. Use 'policy' to specify bindings.
         */
        bindings?: Schema$Binding[];
        /**
         * Flatten Policy to create a backward compatible wire-format. Deprecated. Use 'policy' to specify the etag.
         */
        etag?: string | null;
        /**
         * REQUIRED: The complete policy to be applied to the 'resource'. The size of the policy is limited to a few 10s of KB. An empty policy is in general a valid policy but certain services (like Projects) might reject them.
         */
        policy?: Schema$Policy;
    }
    export class Resource$Acceleratortypes {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves an aggregated list of accelerator types.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Acceleratortypes$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Acceleratortypes$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$AcceleratorTypeAggregatedList>;
        aggregatedList(params: Params$Resource$Acceleratortypes$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Acceleratortypes$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$AcceleratorTypeAggregatedList>, callback: BodyResponseCallback<Schema$AcceleratorTypeAggregatedList>): void;
        aggregatedList(params: Params$Resource$Acceleratortypes$Aggregatedlist, callback: BodyResponseCallback<Schema$AcceleratorTypeAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$AcceleratorTypeAggregatedList>): void;
        /**
         * Returns the specified accelerator type.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Acceleratortypes$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Acceleratortypes$Get, options?: MethodOptions): GaxiosPromise<Schema$AcceleratorType>;
        get(params: Params$Resource$Acceleratortypes$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Acceleratortypes$Get, options: MethodOptions | BodyResponseCallback<Schema$AcceleratorType>, callback: BodyResponseCallback<Schema$AcceleratorType>): void;
        get(params: Params$Resource$Acceleratortypes$Get, callback: BodyResponseCallback<Schema$AcceleratorType>): void;
        get(callback: BodyResponseCallback<Schema$AcceleratorType>): void;
        /**
         * Retrieves a list of accelerator types that are available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Acceleratortypes$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Acceleratortypes$List, options?: MethodOptions): GaxiosPromise<Schema$AcceleratorTypeList>;
        list(params: Params$Resource$Acceleratortypes$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Acceleratortypes$List, options: MethodOptions | BodyResponseCallback<Schema$AcceleratorTypeList>, callback: BodyResponseCallback<Schema$AcceleratorTypeList>): void;
        list(params: Params$Resource$Acceleratortypes$List, callback: BodyResponseCallback<Schema$AcceleratorTypeList>): void;
        list(callback: BodyResponseCallback<Schema$AcceleratorTypeList>): void;
    }
    export interface Params$Resource$Acceleratortypes$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Acceleratortypes$Get extends StandardParameters {
        /**
         * Name of the accelerator type to return.
         */
        acceleratorType?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Acceleratortypes$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export class Resource$Addresses {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves an aggregated list of addresses.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Addresses$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Addresses$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$AddressAggregatedList>;
        aggregatedList(params: Params$Resource$Addresses$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Addresses$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$AddressAggregatedList>, callback: BodyResponseCallback<Schema$AddressAggregatedList>): void;
        aggregatedList(params: Params$Resource$Addresses$Aggregatedlist, callback: BodyResponseCallback<Schema$AddressAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$AddressAggregatedList>): void;
        /**
         * Deletes the specified address resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Addresses$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Addresses$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Addresses$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Addresses$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Addresses$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified address resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Addresses$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Addresses$Get, options?: MethodOptions): GaxiosPromise<Schema$Address>;
        get(params: Params$Resource$Addresses$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Addresses$Get, options: MethodOptions | BodyResponseCallback<Schema$Address>, callback: BodyResponseCallback<Schema$Address>): void;
        get(params: Params$Resource$Addresses$Get, callback: BodyResponseCallback<Schema$Address>): void;
        get(callback: BodyResponseCallback<Schema$Address>): void;
        /**
         * Creates an address resource in the specified project by using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Addresses$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Addresses$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Addresses$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Addresses$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Addresses$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves a list of addresses contained within the specified region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Addresses$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Addresses$List, options?: MethodOptions): GaxiosPromise<Schema$AddressList>;
        list(params: Params$Resource$Addresses$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Addresses$List, options: MethodOptions | BodyResponseCallback<Schema$AddressList>, callback: BodyResponseCallback<Schema$AddressList>): void;
        list(params: Params$Resource$Addresses$List, callback: BodyResponseCallback<Schema$AddressList>): void;
        list(callback: BodyResponseCallback<Schema$AddressList>): void;
        /**
         * Moves the specified address resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        move(params: Params$Resource$Addresses$Move, options: StreamMethodOptions): GaxiosPromise<Readable>;
        move(params?: Params$Resource$Addresses$Move, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        move(params: Params$Resource$Addresses$Move, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        move(params: Params$Resource$Addresses$Move, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        move(params: Params$Resource$Addresses$Move, callback: BodyResponseCallback<Schema$Operation>): void;
        move(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the labels on an Address. To learn more about labels, read the Labeling Resources documentation.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setLabels(params: Params$Resource$Addresses$Setlabels, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setLabels(params?: Params$Resource$Addresses$Setlabels, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setLabels(params: Params$Resource$Addresses$Setlabels, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setLabels(params: Params$Resource$Addresses$Setlabels, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(params: Params$Resource$Addresses$Setlabels, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Addresses$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Addresses$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Addresses$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Addresses$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Addresses$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Addresses$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Addresses$Delete extends StandardParameters {
        /**
         * Name of the address resource to delete.
         */
        address?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Addresses$Get extends StandardParameters {
        /**
         * Name of the address resource to return.
         */
        address?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
    }
    export interface Params$Resource$Addresses$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Address;
    }
    export interface Params$Resource$Addresses$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Addresses$Move extends StandardParameters {
        /**
         * Name of the address resource to move.
         */
        address?: string;
        /**
         * Source project ID which the Address is moved from.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionAddressesMoveRequest;
    }
    export interface Params$Resource$Addresses$Setlabels extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionSetLabelsRequest;
    }
    export interface Params$Resource$Addresses$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Autoscalers {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves an aggregated list of autoscalers.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Autoscalers$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Autoscalers$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$AutoscalerAggregatedList>;
        aggregatedList(params: Params$Resource$Autoscalers$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Autoscalers$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$AutoscalerAggregatedList>, callback: BodyResponseCallback<Schema$AutoscalerAggregatedList>): void;
        aggregatedList(params: Params$Resource$Autoscalers$Aggregatedlist, callback: BodyResponseCallback<Schema$AutoscalerAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$AutoscalerAggregatedList>): void;
        /**
         * Deletes the specified autoscaler.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Autoscalers$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Autoscalers$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Autoscalers$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Autoscalers$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Autoscalers$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified autoscaler resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Autoscalers$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Autoscalers$Get, options?: MethodOptions): GaxiosPromise<Schema$Autoscaler>;
        get(params: Params$Resource$Autoscalers$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Autoscalers$Get, options: MethodOptions | BodyResponseCallback<Schema$Autoscaler>, callback: BodyResponseCallback<Schema$Autoscaler>): void;
        get(params: Params$Resource$Autoscalers$Get, callback: BodyResponseCallback<Schema$Autoscaler>): void;
        get(callback: BodyResponseCallback<Schema$Autoscaler>): void;
        /**
         * Creates an autoscaler in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Autoscalers$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Autoscalers$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Autoscalers$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Autoscalers$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Autoscalers$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves a list of autoscalers contained within the specified zone.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Autoscalers$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Autoscalers$List, options?: MethodOptions): GaxiosPromise<Schema$AutoscalerList>;
        list(params: Params$Resource$Autoscalers$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Autoscalers$List, options: MethodOptions | BodyResponseCallback<Schema$AutoscalerList>, callback: BodyResponseCallback<Schema$AutoscalerList>): void;
        list(params: Params$Resource$Autoscalers$List, callback: BodyResponseCallback<Schema$AutoscalerList>): void;
        list(callback: BodyResponseCallback<Schema$AutoscalerList>): void;
        /**
         * Updates an autoscaler in the specified project using the data included in the request. This method supports PATCH semantics and uses the JSON merge patch format and processing rules.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Autoscalers$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Autoscalers$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Autoscalers$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Autoscalers$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Autoscalers$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Autoscalers$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Autoscalers$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Autoscalers$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Autoscalers$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Autoscalers$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        /**
         * Updates an autoscaler in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        update(params: Params$Resource$Autoscalers$Update, options: StreamMethodOptions): GaxiosPromise<Readable>;
        update(params?: Params$Resource$Autoscalers$Update, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        update(params: Params$Resource$Autoscalers$Update, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        update(params: Params$Resource$Autoscalers$Update, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        update(params: Params$Resource$Autoscalers$Update, callback: BodyResponseCallback<Schema$Operation>): void;
        update(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    export interface Params$Resource$Autoscalers$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Autoscalers$Delete extends StandardParameters {
        /**
         * Name of the autoscaler to delete.
         */
        autoscaler?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Autoscalers$Get extends StandardParameters {
        /**
         * Name of the autoscaler to return.
         */
        autoscaler?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Autoscalers$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Autoscaler;
    }
    export interface Params$Resource$Autoscalers$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         * Name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Autoscalers$Patch extends StandardParameters {
        /**
         * Name of the autoscaler to patch.
         */
        autoscaler?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Autoscaler;
    }
    export interface Params$Resource$Autoscalers$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export interface Params$Resource$Autoscalers$Update extends StandardParameters {
        /**
         * Name of the autoscaler to update.
         */
        autoscaler?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Autoscaler;
    }
    export class Resource$Backendbuckets {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Adds a key for validating requests with signed URLs for this backend bucket.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        addSignedUrlKey(params: Params$Resource$Backendbuckets$Addsignedurlkey, options: StreamMethodOptions): GaxiosPromise<Readable>;
        addSignedUrlKey(params?: Params$Resource$Backendbuckets$Addsignedurlkey, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        addSignedUrlKey(params: Params$Resource$Backendbuckets$Addsignedurlkey, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        addSignedUrlKey(params: Params$Resource$Backendbuckets$Addsignedurlkey, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        addSignedUrlKey(params: Params$Resource$Backendbuckets$Addsignedurlkey, callback: BodyResponseCallback<Schema$Operation>): void;
        addSignedUrlKey(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Deletes the specified BackendBucket resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Backendbuckets$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Backendbuckets$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Backendbuckets$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Backendbuckets$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Backendbuckets$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Deletes a key for validating requests with signed URLs for this backend bucket.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        deleteSignedUrlKey(params: Params$Resource$Backendbuckets$Deletesignedurlkey, options: StreamMethodOptions): GaxiosPromise<Readable>;
        deleteSignedUrlKey(params?: Params$Resource$Backendbuckets$Deletesignedurlkey, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        deleteSignedUrlKey(params: Params$Resource$Backendbuckets$Deletesignedurlkey, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        deleteSignedUrlKey(params: Params$Resource$Backendbuckets$Deletesignedurlkey, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        deleteSignedUrlKey(params: Params$Resource$Backendbuckets$Deletesignedurlkey, callback: BodyResponseCallback<Schema$Operation>): void;
        deleteSignedUrlKey(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified BackendBucket resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Backendbuckets$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Backendbuckets$Get, options?: MethodOptions): GaxiosPromise<Schema$BackendBucket>;
        get(params: Params$Resource$Backendbuckets$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Backendbuckets$Get, options: MethodOptions | BodyResponseCallback<Schema$BackendBucket>, callback: BodyResponseCallback<Schema$BackendBucket>): void;
        get(params: Params$Resource$Backendbuckets$Get, callback: BodyResponseCallback<Schema$BackendBucket>): void;
        get(callback: BodyResponseCallback<Schema$BackendBucket>): void;
        /**
         * Gets the access control policy for a resource. May be empty if no such policy or resource exists.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getIamPolicy(params: Params$Resource$Backendbuckets$Getiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getIamPolicy(params?: Params$Resource$Backendbuckets$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        getIamPolicy(params: Params$Resource$Backendbuckets$Getiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getIamPolicy(params: Params$Resource$Backendbuckets$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(params: Params$Resource$Backendbuckets$Getiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Creates a BackendBucket resource in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Backendbuckets$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Backendbuckets$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Backendbuckets$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Backendbuckets$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Backendbuckets$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of BackendBucket resources available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Backendbuckets$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Backendbuckets$List, options?: MethodOptions): GaxiosPromise<Schema$BackendBucketList>;
        list(params: Params$Resource$Backendbuckets$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Backendbuckets$List, options: MethodOptions | BodyResponseCallback<Schema$BackendBucketList>, callback: BodyResponseCallback<Schema$BackendBucketList>): void;
        list(params: Params$Resource$Backendbuckets$List, callback: BodyResponseCallback<Schema$BackendBucketList>): void;
        list(callback: BodyResponseCallback<Schema$BackendBucketList>): void;
        /**
         * Updates the specified BackendBucket resource with the data included in the request. This method supports PATCH semantics and uses the JSON merge patch format and processing rules.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Backendbuckets$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Backendbuckets$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Backendbuckets$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Backendbuckets$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Backendbuckets$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the edge security policy for the specified backend bucket.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setEdgeSecurityPolicy(params: Params$Resource$Backendbuckets$Setedgesecuritypolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setEdgeSecurityPolicy(params?: Params$Resource$Backendbuckets$Setedgesecuritypolicy, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setEdgeSecurityPolicy(params: Params$Resource$Backendbuckets$Setedgesecuritypolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setEdgeSecurityPolicy(params: Params$Resource$Backendbuckets$Setedgesecuritypolicy, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setEdgeSecurityPolicy(params: Params$Resource$Backendbuckets$Setedgesecuritypolicy, callback: BodyResponseCallback<Schema$Operation>): void;
        setEdgeSecurityPolicy(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the access control policy on the specified resource. Replaces any existing policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setIamPolicy(params: Params$Resource$Backendbuckets$Setiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setIamPolicy(params?: Params$Resource$Backendbuckets$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        setIamPolicy(params: Params$Resource$Backendbuckets$Setiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setIamPolicy(params: Params$Resource$Backendbuckets$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(params: Params$Resource$Backendbuckets$Setiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Backendbuckets$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Backendbuckets$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Backendbuckets$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Backendbuckets$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Backendbuckets$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        /**
         * Updates the specified BackendBucket resource with the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        update(params: Params$Resource$Backendbuckets$Update, options: StreamMethodOptions): GaxiosPromise<Readable>;
        update(params?: Params$Resource$Backendbuckets$Update, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        update(params: Params$Resource$Backendbuckets$Update, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        update(params: Params$Resource$Backendbuckets$Update, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        update(params: Params$Resource$Backendbuckets$Update, callback: BodyResponseCallback<Schema$Operation>): void;
        update(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    export interface Params$Resource$Backendbuckets$Addsignedurlkey extends StandardParameters {
        /**
         * Name of the BackendBucket resource to which the Signed URL Key should be added. The name should conform to RFC1035.
         */
        backendBucket?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SignedUrlKey;
    }
    export interface Params$Resource$Backendbuckets$Delete extends StandardParameters {
        /**
         * Name of the BackendBucket resource to delete.
         */
        backendBucket?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Backendbuckets$Deletesignedurlkey extends StandardParameters {
        /**
         * Name of the BackendBucket resource to which the Signed URL Key should be added. The name should conform to RFC1035.
         */
        backendBucket?: string;
        /**
         * The name of the Signed URL Key to delete.
         */
        keyName?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Backendbuckets$Get extends StandardParameters {
        /**
         * Name of the BackendBucket resource to return.
         */
        backendBucket?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    export interface Params$Resource$Backendbuckets$Getiampolicy extends StandardParameters {
        /**
         * Requested IAM Policy version.
         */
        optionsRequestedPolicyVersion?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
    }
    export interface Params$Resource$Backendbuckets$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$BackendBucket;
    }
    export interface Params$Resource$Backendbuckets$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Backendbuckets$Patch extends StandardParameters {
        /**
         * Name of the BackendBucket resource to patch.
         */
        backendBucket?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$BackendBucket;
    }
    export interface Params$Resource$Backendbuckets$Setedgesecuritypolicy extends StandardParameters {
        /**
         * Name of the BackendService resource to which the security policy should be set. The name should conform to RFC1035.
         */
        backendBucket?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SecurityPolicyReference;
    }
    export interface Params$Resource$Backendbuckets$Setiampolicy extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GlobalSetPolicyRequest;
    }
    export interface Params$Resource$Backendbuckets$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export interface Params$Resource$Backendbuckets$Update extends StandardParameters {
        /**
         * Name of the BackendBucket resource to update.
         */
        backendBucket?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$BackendBucket;
    }
    export class Resource$Backendservices {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Adds a key for validating requests with signed URLs for this backend service.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        addSignedUrlKey(params: Params$Resource$Backendservices$Addsignedurlkey, options: StreamMethodOptions): GaxiosPromise<Readable>;
        addSignedUrlKey(params?: Params$Resource$Backendservices$Addsignedurlkey, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        addSignedUrlKey(params: Params$Resource$Backendservices$Addsignedurlkey, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        addSignedUrlKey(params: Params$Resource$Backendservices$Addsignedurlkey, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        addSignedUrlKey(params: Params$Resource$Backendservices$Addsignedurlkey, callback: BodyResponseCallback<Schema$Operation>): void;
        addSignedUrlKey(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of all BackendService resources, regional and global, available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Backendservices$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Backendservices$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$BackendServiceAggregatedList>;
        aggregatedList(params: Params$Resource$Backendservices$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Backendservices$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$BackendServiceAggregatedList>, callback: BodyResponseCallback<Schema$BackendServiceAggregatedList>): void;
        aggregatedList(params: Params$Resource$Backendservices$Aggregatedlist, callback: BodyResponseCallback<Schema$BackendServiceAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$BackendServiceAggregatedList>): void;
        /**
         * Deletes the specified BackendService resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Backendservices$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Backendservices$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Backendservices$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Backendservices$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Backendservices$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Deletes a key for validating requests with signed URLs for this backend service.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        deleteSignedUrlKey(params: Params$Resource$Backendservices$Deletesignedurlkey, options: StreamMethodOptions): GaxiosPromise<Readable>;
        deleteSignedUrlKey(params?: Params$Resource$Backendservices$Deletesignedurlkey, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        deleteSignedUrlKey(params: Params$Resource$Backendservices$Deletesignedurlkey, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        deleteSignedUrlKey(params: Params$Resource$Backendservices$Deletesignedurlkey, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        deleteSignedUrlKey(params: Params$Resource$Backendservices$Deletesignedurlkey, callback: BodyResponseCallback<Schema$Operation>): void;
        deleteSignedUrlKey(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified BackendService resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Backendservices$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Backendservices$Get, options?: MethodOptions): GaxiosPromise<Schema$BackendService>;
        get(params: Params$Resource$Backendservices$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Backendservices$Get, options: MethodOptions | BodyResponseCallback<Schema$BackendService>, callback: BodyResponseCallback<Schema$BackendService>): void;
        get(params: Params$Resource$Backendservices$Get, callback: BodyResponseCallback<Schema$BackendService>): void;
        get(callback: BodyResponseCallback<Schema$BackendService>): void;
        /**
         * Gets the most recent health check results for this BackendService. Example request body: { "group": "/zones/us-east1-b/instanceGroups/lb-backend-example" \}
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getHealth(params: Params$Resource$Backendservices$Gethealth, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getHealth(params?: Params$Resource$Backendservices$Gethealth, options?: MethodOptions): GaxiosPromise<Schema$BackendServiceGroupHealth>;
        getHealth(params: Params$Resource$Backendservices$Gethealth, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getHealth(params: Params$Resource$Backendservices$Gethealth, options: MethodOptions | BodyResponseCallback<Schema$BackendServiceGroupHealth>, callback: BodyResponseCallback<Schema$BackendServiceGroupHealth>): void;
        getHealth(params: Params$Resource$Backendservices$Gethealth, callback: BodyResponseCallback<Schema$BackendServiceGroupHealth>): void;
        getHealth(callback: BodyResponseCallback<Schema$BackendServiceGroupHealth>): void;
        /**
         * Gets the access control policy for a resource. May be empty if no such policy or resource exists.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getIamPolicy(params: Params$Resource$Backendservices$Getiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getIamPolicy(params?: Params$Resource$Backendservices$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        getIamPolicy(params: Params$Resource$Backendservices$Getiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getIamPolicy(params: Params$Resource$Backendservices$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(params: Params$Resource$Backendservices$Getiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Creates a BackendService resource in the specified project using the data included in the request. For more information, see Backend services overview .
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Backendservices$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Backendservices$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Backendservices$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Backendservices$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Backendservices$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of BackendService resources available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Backendservices$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Backendservices$List, options?: MethodOptions): GaxiosPromise<Schema$BackendServiceList>;
        list(params: Params$Resource$Backendservices$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Backendservices$List, options: MethodOptions | BodyResponseCallback<Schema$BackendServiceList>, callback: BodyResponseCallback<Schema$BackendServiceList>): void;
        list(params: Params$Resource$Backendservices$List, callback: BodyResponseCallback<Schema$BackendServiceList>): void;
        list(callback: BodyResponseCallback<Schema$BackendServiceList>): void;
        /**
         * Retrieves an aggregated list of all usable backend services in the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        listUsable(params: Params$Resource$Backendservices$Listusable, options: StreamMethodOptions): GaxiosPromise<Readable>;
        listUsable(params?: Params$Resource$Backendservices$Listusable, options?: MethodOptions): GaxiosPromise<Schema$BackendServiceListUsable>;
        listUsable(params: Params$Resource$Backendservices$Listusable, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        listUsable(params: Params$Resource$Backendservices$Listusable, options: MethodOptions | BodyResponseCallback<Schema$BackendServiceListUsable>, callback: BodyResponseCallback<Schema$BackendServiceListUsable>): void;
        listUsable(params: Params$Resource$Backendservices$Listusable, callback: BodyResponseCallback<Schema$BackendServiceListUsable>): void;
        listUsable(callback: BodyResponseCallback<Schema$BackendServiceListUsable>): void;
        /**
         * Patches the specified BackendService resource with the data included in the request. For more information, see Backend services overview. This method supports PATCH semantics and uses the JSON merge patch format and processing rules.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Backendservices$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Backendservices$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Backendservices$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Backendservices$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Backendservices$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the edge security policy for the specified backend service.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setEdgeSecurityPolicy(params: Params$Resource$Backendservices$Setedgesecuritypolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setEdgeSecurityPolicy(params?: Params$Resource$Backendservices$Setedgesecuritypolicy, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setEdgeSecurityPolicy(params: Params$Resource$Backendservices$Setedgesecuritypolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setEdgeSecurityPolicy(params: Params$Resource$Backendservices$Setedgesecuritypolicy, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setEdgeSecurityPolicy(params: Params$Resource$Backendservices$Setedgesecuritypolicy, callback: BodyResponseCallback<Schema$Operation>): void;
        setEdgeSecurityPolicy(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the access control policy on the specified resource. Replaces any existing policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setIamPolicy(params: Params$Resource$Backendservices$Setiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setIamPolicy(params?: Params$Resource$Backendservices$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        setIamPolicy(params: Params$Resource$Backendservices$Setiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setIamPolicy(params: Params$Resource$Backendservices$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(params: Params$Resource$Backendservices$Setiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Sets the Google Cloud Armor security policy for the specified backend service. For more information, see Google Cloud Armor Overview
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setSecurityPolicy(params: Params$Resource$Backendservices$Setsecuritypolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setSecurityPolicy(params?: Params$Resource$Backendservices$Setsecuritypolicy, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setSecurityPolicy(params: Params$Resource$Backendservices$Setsecuritypolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setSecurityPolicy(params: Params$Resource$Backendservices$Setsecuritypolicy, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setSecurityPolicy(params: Params$Resource$Backendservices$Setsecuritypolicy, callback: BodyResponseCallback<Schema$Operation>): void;
        setSecurityPolicy(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Backendservices$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Backendservices$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Backendservices$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Backendservices$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Backendservices$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        /**
         * Updates the specified BackendService resource with the data included in the request. For more information, see Backend services overview.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        update(params: Params$Resource$Backendservices$Update, options: StreamMethodOptions): GaxiosPromise<Readable>;
        update(params?: Params$Resource$Backendservices$Update, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        update(params: Params$Resource$Backendservices$Update, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        update(params: Params$Resource$Backendservices$Update, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        update(params: Params$Resource$Backendservices$Update, callback: BodyResponseCallback<Schema$Operation>): void;
        update(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    export interface Params$Resource$Backendservices$Addsignedurlkey extends StandardParameters {
        /**
         * Name of the BackendService resource to which the Signed URL Key should be added. The name should conform to RFC1035.
         */
        backendService?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SignedUrlKey;
    }
    export interface Params$Resource$Backendservices$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Name of the project scoping this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Backendservices$Delete extends StandardParameters {
        /**
         * Name of the BackendService resource to delete.
         */
        backendService?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Backendservices$Deletesignedurlkey extends StandardParameters {
        /**
         * Name of the BackendService resource to which the Signed URL Key should be added. The name should conform to RFC1035.
         */
        backendService?: string;
        /**
         * The name of the Signed URL Key to delete.
         */
        keyName?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Backendservices$Get extends StandardParameters {
        /**
         * Name of the BackendService resource to return.
         */
        backendService?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    export interface Params$Resource$Backendservices$Gethealth extends StandardParameters {
        /**
         * Name of the BackendService resource to which the queried instance belongs.
         */
        backendService?: string;
        /**
         *
         */
        project?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ResourceGroupReference;
    }
    export interface Params$Resource$Backendservices$Getiampolicy extends StandardParameters {
        /**
         * Requested IAM Policy version.
         */
        optionsRequestedPolicyVersion?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
    }
    export interface Params$Resource$Backendservices$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$BackendService;
    }
    export interface Params$Resource$Backendservices$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Backendservices$Listusable extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Backendservices$Patch extends StandardParameters {
        /**
         * Name of the BackendService resource to patch.
         */
        backendService?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$BackendService;
    }
    export interface Params$Resource$Backendservices$Setedgesecuritypolicy extends StandardParameters {
        /**
         * Name of the BackendService resource to which the edge security policy should be set. The name should conform to RFC1035.
         */
        backendService?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SecurityPolicyReference;
    }
    export interface Params$Resource$Backendservices$Setiampolicy extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GlobalSetPolicyRequest;
    }
    export interface Params$Resource$Backendservices$Setsecuritypolicy extends StandardParameters {
        /**
         * Name of the BackendService resource to which the security policy should be set. The name should conform to RFC1035.
         */
        backendService?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SecurityPolicyReference;
    }
    export interface Params$Resource$Backendservices$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export interface Params$Resource$Backendservices$Update extends StandardParameters {
        /**
         * Name of the BackendService resource to update.
         */
        backendService?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$BackendService;
    }
    export class Resource$Disks {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Adds existing resource policies to a disk. You can only add one policy which will be applied to this disk for scheduling snapshot creation.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        addResourcePolicies(params: Params$Resource$Disks$Addresourcepolicies, options: StreamMethodOptions): GaxiosPromise<Readable>;
        addResourcePolicies(params?: Params$Resource$Disks$Addresourcepolicies, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        addResourcePolicies(params: Params$Resource$Disks$Addresourcepolicies, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        addResourcePolicies(params: Params$Resource$Disks$Addresourcepolicies, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        addResourcePolicies(params: Params$Resource$Disks$Addresourcepolicies, callback: BodyResponseCallback<Schema$Operation>): void;
        addResourcePolicies(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves an aggregated list of persistent disks.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Disks$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Disks$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$DiskAggregatedList>;
        aggregatedList(params: Params$Resource$Disks$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Disks$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$DiskAggregatedList>, callback: BodyResponseCallback<Schema$DiskAggregatedList>): void;
        aggregatedList(params: Params$Resource$Disks$Aggregatedlist, callback: BodyResponseCallback<Schema$DiskAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$DiskAggregatedList>): void;
        /**
         * Bulk create a set of disks.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        bulkInsert(params: Params$Resource$Disks$Bulkinsert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        bulkInsert(params?: Params$Resource$Disks$Bulkinsert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        bulkInsert(params: Params$Resource$Disks$Bulkinsert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        bulkInsert(params: Params$Resource$Disks$Bulkinsert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        bulkInsert(params: Params$Resource$Disks$Bulkinsert, callback: BodyResponseCallback<Schema$Operation>): void;
        bulkInsert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Creates a snapshot of a specified persistent disk. For regular snapshot creation, consider using snapshots.insert instead, as that method supports more features, such as creating snapshots in a project different from the source disk project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        createSnapshot(params: Params$Resource$Disks$Createsnapshot, options: StreamMethodOptions): GaxiosPromise<Readable>;
        createSnapshot(params?: Params$Resource$Disks$Createsnapshot, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        createSnapshot(params: Params$Resource$Disks$Createsnapshot, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        createSnapshot(params: Params$Resource$Disks$Createsnapshot, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        createSnapshot(params: Params$Resource$Disks$Createsnapshot, callback: BodyResponseCallback<Schema$Operation>): void;
        createSnapshot(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Deletes the specified persistent disk. Deleting a disk removes its data permanently and is irreversible. However, deleting a disk does not delete any snapshots previously made from the disk. You must separately delete snapshots.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Disks$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Disks$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Disks$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Disks$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Disks$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified persistent disk.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Disks$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Disks$Get, options?: MethodOptions): GaxiosPromise<Schema$Disk>;
        get(params: Params$Resource$Disks$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Disks$Get, options: MethodOptions | BodyResponseCallback<Schema$Disk>, callback: BodyResponseCallback<Schema$Disk>): void;
        get(params: Params$Resource$Disks$Get, callback: BodyResponseCallback<Schema$Disk>): void;
        get(callback: BodyResponseCallback<Schema$Disk>): void;
        /**
         * Gets the access control policy for a resource. May be empty if no such policy or resource exists.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getIamPolicy(params: Params$Resource$Disks$Getiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getIamPolicy(params?: Params$Resource$Disks$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        getIamPolicy(params: Params$Resource$Disks$Getiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getIamPolicy(params: Params$Resource$Disks$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(params: Params$Resource$Disks$Getiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Creates a persistent disk in the specified project using the data in the request. You can create a disk from a source (sourceImage, sourceSnapshot, or sourceDisk) or create an empty 500 GB data disk by omitting all properties. You can also create a disk that is larger than the default size by specifying the sizeGb property.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Disks$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Disks$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Disks$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Disks$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Disks$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves a list of persistent disks contained within the specified zone.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Disks$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Disks$List, options?: MethodOptions): GaxiosPromise<Schema$DiskList>;
        list(params: Params$Resource$Disks$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Disks$List, options: MethodOptions | BodyResponseCallback<Schema$DiskList>, callback: BodyResponseCallback<Schema$DiskList>): void;
        list(params: Params$Resource$Disks$List, callback: BodyResponseCallback<Schema$DiskList>): void;
        list(callback: BodyResponseCallback<Schema$DiskList>): void;
        /**
         * Removes resource policies from a disk.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        removeResourcePolicies(params: Params$Resource$Disks$Removeresourcepolicies, options: StreamMethodOptions): GaxiosPromise<Readable>;
        removeResourcePolicies(params?: Params$Resource$Disks$Removeresourcepolicies, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        removeResourcePolicies(params: Params$Resource$Disks$Removeresourcepolicies, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        removeResourcePolicies(params: Params$Resource$Disks$Removeresourcepolicies, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        removeResourcePolicies(params: Params$Resource$Disks$Removeresourcepolicies, callback: BodyResponseCallback<Schema$Operation>): void;
        removeResourcePolicies(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Resizes the specified persistent disk. You can only increase the size of the disk.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        resize(params: Params$Resource$Disks$Resize, options: StreamMethodOptions): GaxiosPromise<Readable>;
        resize(params?: Params$Resource$Disks$Resize, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        resize(params: Params$Resource$Disks$Resize, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        resize(params: Params$Resource$Disks$Resize, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        resize(params: Params$Resource$Disks$Resize, callback: BodyResponseCallback<Schema$Operation>): void;
        resize(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the access control policy on the specified resource. Replaces any existing policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setIamPolicy(params: Params$Resource$Disks$Setiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setIamPolicy(params?: Params$Resource$Disks$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        setIamPolicy(params: Params$Resource$Disks$Setiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setIamPolicy(params: Params$Resource$Disks$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(params: Params$Resource$Disks$Setiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Sets the labels on a disk. To learn more about labels, read the Labeling Resources documentation.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setLabels(params: Params$Resource$Disks$Setlabels, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setLabels(params?: Params$Resource$Disks$Setlabels, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setLabels(params: Params$Resource$Disks$Setlabels, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setLabels(params: Params$Resource$Disks$Setlabels, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(params: Params$Resource$Disks$Setlabels, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Starts asynchronous replication. Must be invoked on the primary disk.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        startAsyncReplication(params: Params$Resource$Disks$Startasyncreplication, options: StreamMethodOptions): GaxiosPromise<Readable>;
        startAsyncReplication(params?: Params$Resource$Disks$Startasyncreplication, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        startAsyncReplication(params: Params$Resource$Disks$Startasyncreplication, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        startAsyncReplication(params: Params$Resource$Disks$Startasyncreplication, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        startAsyncReplication(params: Params$Resource$Disks$Startasyncreplication, callback: BodyResponseCallback<Schema$Operation>): void;
        startAsyncReplication(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Stops asynchronous replication. Can be invoked either on the primary or on the secondary disk.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        stopAsyncReplication(params: Params$Resource$Disks$Stopasyncreplication, options: StreamMethodOptions): GaxiosPromise<Readable>;
        stopAsyncReplication(params?: Params$Resource$Disks$Stopasyncreplication, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        stopAsyncReplication(params: Params$Resource$Disks$Stopasyncreplication, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        stopAsyncReplication(params: Params$Resource$Disks$Stopasyncreplication, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        stopAsyncReplication(params: Params$Resource$Disks$Stopasyncreplication, callback: BodyResponseCallback<Schema$Operation>): void;
        stopAsyncReplication(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Stops asynchronous replication for a consistency group of disks. Can be invoked either in the primary or secondary scope.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        stopGroupAsyncReplication(params: Params$Resource$Disks$Stopgroupasyncreplication, options: StreamMethodOptions): GaxiosPromise<Readable>;
        stopGroupAsyncReplication(params?: Params$Resource$Disks$Stopgroupasyncreplication, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        stopGroupAsyncReplication(params: Params$Resource$Disks$Stopgroupasyncreplication, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        stopGroupAsyncReplication(params: Params$Resource$Disks$Stopgroupasyncreplication, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        stopGroupAsyncReplication(params: Params$Resource$Disks$Stopgroupasyncreplication, callback: BodyResponseCallback<Schema$Operation>): void;
        stopGroupAsyncReplication(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Disks$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Disks$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Disks$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Disks$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Disks$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        /**
         * Updates the specified disk with the data included in the request. The update is performed only on selected fields included as part of update-mask. Only the following fields can be modified: user_license.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        update(params: Params$Resource$Disks$Update, options: StreamMethodOptions): GaxiosPromise<Readable>;
        update(params?: Params$Resource$Disks$Update, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        update(params: Params$Resource$Disks$Update, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        update(params: Params$Resource$Disks$Update, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        update(params: Params$Resource$Disks$Update, callback: BodyResponseCallback<Schema$Operation>): void;
        update(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    export interface Params$Resource$Disks$Addresourcepolicies extends StandardParameters {
        /**
         * The disk name for this request.
         */
        disk?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$DisksAddResourcePoliciesRequest;
    }
    export interface Params$Resource$Disks$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Disks$Bulkinsert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$BulkInsertDiskResource;
    }
    export interface Params$Resource$Disks$Createsnapshot extends StandardParameters {
        /**
         * Name of the persistent disk to snapshot.
         */
        disk?: string;
        /**
         * [Input Only] Whether to attempt an application consistent snapshot by informing the OS to prepare for the snapshot process.
         */
        guestFlush?: boolean;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Snapshot;
    }
    export interface Params$Resource$Disks$Delete extends StandardParameters {
        /**
         * Name of the persistent disk to delete.
         */
        disk?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Disks$Get extends StandardParameters {
        /**
         * Name of the persistent disk to return.
         */
        disk?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Disks$Getiampolicy extends StandardParameters {
        /**
         * Requested IAM Policy version.
         */
        optionsRequestedPolicyVersion?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Disks$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Source image to restore onto a disk. This field is optional.
         */
        sourceImage?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Disk;
    }
    export interface Params$Resource$Disks$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Disks$Removeresourcepolicies extends StandardParameters {
        /**
         * The disk name for this request.
         */
        disk?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$DisksRemoveResourcePoliciesRequest;
    }
    export interface Params$Resource$Disks$Resize extends StandardParameters {
        /**
         * The name of the persistent disk.
         */
        disk?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$DisksResizeRequest;
    }
    export interface Params$Resource$Disks$Setiampolicy extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ZoneSetPolicyRequest;
    }
    export interface Params$Resource$Disks$Setlabels extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ZoneSetLabelsRequest;
    }
    export interface Params$Resource$Disks$Startasyncreplication extends StandardParameters {
        /**
         * The name of the persistent disk.
         */
        disk?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$DisksStartAsyncReplicationRequest;
    }
    export interface Params$Resource$Disks$Stopasyncreplication extends StandardParameters {
        /**
         * The name of the persistent disk.
         */
        disk?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Disks$Stopgroupasyncreplication extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request. This must be the zone of the primary or secondary disks in the consistency group.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$DisksStopGroupAsyncReplicationResource;
    }
    export interface Params$Resource$Disks$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export interface Params$Resource$Disks$Update extends StandardParameters {
        /**
         * The disk name for this request.
         */
        disk?: string;
        /**
         *
         */
        paths?: string[];
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * update_mask indicates fields to be updated as part of this request.
         */
        updateMask?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Disk;
    }
    export class Resource$Disksettings {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Get Zonal Disk Settings.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Disksettings$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Disksettings$Get, options?: MethodOptions): GaxiosPromise<Schema$DiskSettings>;
        get(params: Params$Resource$Disksettings$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Disksettings$Get, options: MethodOptions | BodyResponseCallback<Schema$DiskSettings>, callback: BodyResponseCallback<Schema$DiskSettings>): void;
        get(params: Params$Resource$Disksettings$Get, callback: BodyResponseCallback<Schema$DiskSettings>): void;
        get(callback: BodyResponseCallback<Schema$DiskSettings>): void;
        /**
         * Patch Zonal Disk Settings
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Disksettings$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Disksettings$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Disksettings$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Disksettings$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Disksettings$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    export interface Params$Resource$Disksettings$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Disksettings$Patch extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * update_mask indicates fields to be updated as part of this request.
         */
        updateMask?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$DiskSettings;
    }
    export class Resource$Disktypes {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves an aggregated list of disk types.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Disktypes$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Disktypes$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$DiskTypeAggregatedList>;
        aggregatedList(params: Params$Resource$Disktypes$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Disktypes$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$DiskTypeAggregatedList>, callback: BodyResponseCallback<Schema$DiskTypeAggregatedList>): void;
        aggregatedList(params: Params$Resource$Disktypes$Aggregatedlist, callback: BodyResponseCallback<Schema$DiskTypeAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$DiskTypeAggregatedList>): void;
        /**
         * Returns the specified disk type.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Disktypes$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Disktypes$Get, options?: MethodOptions): GaxiosPromise<Schema$DiskType>;
        get(params: Params$Resource$Disktypes$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Disktypes$Get, options: MethodOptions | BodyResponseCallback<Schema$DiskType>, callback: BodyResponseCallback<Schema$DiskType>): void;
        get(params: Params$Resource$Disktypes$Get, callback: BodyResponseCallback<Schema$DiskType>): void;
        get(callback: BodyResponseCallback<Schema$DiskType>): void;
        /**
         * Retrieves a list of disk types available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Disktypes$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Disktypes$List, options?: MethodOptions): GaxiosPromise<Schema$DiskTypeList>;
        list(params: Params$Resource$Disktypes$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Disktypes$List, options: MethodOptions | BodyResponseCallback<Schema$DiskTypeList>, callback: BodyResponseCallback<Schema$DiskTypeList>): void;
        list(params: Params$Resource$Disktypes$List, callback: BodyResponseCallback<Schema$DiskTypeList>): void;
        list(callback: BodyResponseCallback<Schema$DiskTypeList>): void;
    }
    export interface Params$Resource$Disktypes$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Disktypes$Get extends StandardParameters {
        /**
         * Name of the disk type to return.
         */
        diskType?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Disktypes$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export class Resource$Externalvpngateways {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Deletes the specified externalVpnGateway.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Externalvpngateways$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Externalvpngateways$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Externalvpngateways$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Externalvpngateways$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Externalvpngateways$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified externalVpnGateway. Get a list of available externalVpnGateways by making a list() request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Externalvpngateways$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Externalvpngateways$Get, options?: MethodOptions): GaxiosPromise<Schema$ExternalVpnGateway>;
        get(params: Params$Resource$Externalvpngateways$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Externalvpngateways$Get, options: MethodOptions | BodyResponseCallback<Schema$ExternalVpnGateway>, callback: BodyResponseCallback<Schema$ExternalVpnGateway>): void;
        get(params: Params$Resource$Externalvpngateways$Get, callback: BodyResponseCallback<Schema$ExternalVpnGateway>): void;
        get(callback: BodyResponseCallback<Schema$ExternalVpnGateway>): void;
        /**
         * Creates a ExternalVpnGateway in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Externalvpngateways$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Externalvpngateways$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Externalvpngateways$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Externalvpngateways$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Externalvpngateways$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of ExternalVpnGateway available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Externalvpngateways$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Externalvpngateways$List, options?: MethodOptions): GaxiosPromise<Schema$ExternalVpnGatewayList>;
        list(params: Params$Resource$Externalvpngateways$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Externalvpngateways$List, options: MethodOptions | BodyResponseCallback<Schema$ExternalVpnGatewayList>, callback: BodyResponseCallback<Schema$ExternalVpnGatewayList>): void;
        list(params: Params$Resource$Externalvpngateways$List, callback: BodyResponseCallback<Schema$ExternalVpnGatewayList>): void;
        list(callback: BodyResponseCallback<Schema$ExternalVpnGatewayList>): void;
        /**
         * Sets the labels on an ExternalVpnGateway. To learn more about labels, read the Labeling Resources documentation.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setLabels(params: Params$Resource$Externalvpngateways$Setlabels, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setLabels(params?: Params$Resource$Externalvpngateways$Setlabels, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setLabels(params: Params$Resource$Externalvpngateways$Setlabels, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setLabels(params: Params$Resource$Externalvpngateways$Setlabels, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(params: Params$Resource$Externalvpngateways$Setlabels, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Externalvpngateways$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Externalvpngateways$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Externalvpngateways$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Externalvpngateways$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Externalvpngateways$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Externalvpngateways$Delete extends StandardParameters {
        /**
         * Name of the externalVpnGateways to delete.
         */
        externalVpnGateway?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Externalvpngateways$Get extends StandardParameters {
        /**
         * Name of the externalVpnGateway to return.
         */
        externalVpnGateway?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    export interface Params$Resource$Externalvpngateways$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ExternalVpnGateway;
    }
    export interface Params$Resource$Externalvpngateways$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Externalvpngateways$Setlabels extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GlobalSetLabelsRequest;
    }
    export interface Params$Resource$Externalvpngateways$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Firewallpolicies {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Inserts an association for the specified firewall policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        addAssociation(params: Params$Resource$Firewallpolicies$Addassociation, options: StreamMethodOptions): GaxiosPromise<Readable>;
        addAssociation(params?: Params$Resource$Firewallpolicies$Addassociation, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        addAssociation(params: Params$Resource$Firewallpolicies$Addassociation, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        addAssociation(params: Params$Resource$Firewallpolicies$Addassociation, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        addAssociation(params: Params$Resource$Firewallpolicies$Addassociation, callback: BodyResponseCallback<Schema$Operation>): void;
        addAssociation(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Inserts a rule into a firewall policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        addRule(params: Params$Resource$Firewallpolicies$Addrule, options: StreamMethodOptions): GaxiosPromise<Readable>;
        addRule(params?: Params$Resource$Firewallpolicies$Addrule, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        addRule(params: Params$Resource$Firewallpolicies$Addrule, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        addRule(params: Params$Resource$Firewallpolicies$Addrule, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        addRule(params: Params$Resource$Firewallpolicies$Addrule, callback: BodyResponseCallback<Schema$Operation>): void;
        addRule(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Copies rules to the specified firewall policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cloneRules(params: Params$Resource$Firewallpolicies$Clonerules, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cloneRules(params?: Params$Resource$Firewallpolicies$Clonerules, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        cloneRules(params: Params$Resource$Firewallpolicies$Clonerules, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cloneRules(params: Params$Resource$Firewallpolicies$Clonerules, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        cloneRules(params: Params$Resource$Firewallpolicies$Clonerules, callback: BodyResponseCallback<Schema$Operation>): void;
        cloneRules(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Deletes the specified policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Firewallpolicies$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Firewallpolicies$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Firewallpolicies$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Firewallpolicies$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Firewallpolicies$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified firewall policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Firewallpolicies$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Firewallpolicies$Get, options?: MethodOptions): GaxiosPromise<Schema$FirewallPolicy>;
        get(params: Params$Resource$Firewallpolicies$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Firewallpolicies$Get, options: MethodOptions | BodyResponseCallback<Schema$FirewallPolicy>, callback: BodyResponseCallback<Schema$FirewallPolicy>): void;
        get(params: Params$Resource$Firewallpolicies$Get, callback: BodyResponseCallback<Schema$FirewallPolicy>): void;
        get(callback: BodyResponseCallback<Schema$FirewallPolicy>): void;
        /**
         * Gets an association with the specified name.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getAssociation(params: Params$Resource$Firewallpolicies$Getassociation, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getAssociation(params?: Params$Resource$Firewallpolicies$Getassociation, options?: MethodOptions): GaxiosPromise<Schema$FirewallPolicyAssociation>;
        getAssociation(params: Params$Resource$Firewallpolicies$Getassociation, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getAssociation(params: Params$Resource$Firewallpolicies$Getassociation, options: MethodOptions | BodyResponseCallback<Schema$FirewallPolicyAssociation>, callback: BodyResponseCallback<Schema$FirewallPolicyAssociation>): void;
        getAssociation(params: Params$Resource$Firewallpolicies$Getassociation, callback: BodyResponseCallback<Schema$FirewallPolicyAssociation>): void;
        getAssociation(callback: BodyResponseCallback<Schema$FirewallPolicyAssociation>): void;
        /**
         * Gets the access control policy for a resource. May be empty if no such policy or resource exists.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getIamPolicy(params: Params$Resource$Firewallpolicies$Getiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getIamPolicy(params?: Params$Resource$Firewallpolicies$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        getIamPolicy(params: Params$Resource$Firewallpolicies$Getiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getIamPolicy(params: Params$Resource$Firewallpolicies$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(params: Params$Resource$Firewallpolicies$Getiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Gets a rule of the specified priority.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getRule(params: Params$Resource$Firewallpolicies$Getrule, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getRule(params?: Params$Resource$Firewallpolicies$Getrule, options?: MethodOptions): GaxiosPromise<Schema$FirewallPolicyRule>;
        getRule(params: Params$Resource$Firewallpolicies$Getrule, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getRule(params: Params$Resource$Firewallpolicies$Getrule, options: MethodOptions | BodyResponseCallback<Schema$FirewallPolicyRule>, callback: BodyResponseCallback<Schema$FirewallPolicyRule>): void;
        getRule(params: Params$Resource$Firewallpolicies$Getrule, callback: BodyResponseCallback<Schema$FirewallPolicyRule>): void;
        getRule(callback: BodyResponseCallback<Schema$FirewallPolicyRule>): void;
        /**
         * Creates a new policy in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Firewallpolicies$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Firewallpolicies$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Firewallpolicies$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Firewallpolicies$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Firewallpolicies$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Lists all the policies that have been configured for the specified folder or organization.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Firewallpolicies$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Firewallpolicies$List, options?: MethodOptions): GaxiosPromise<Schema$FirewallPolicyList>;
        list(params: Params$Resource$Firewallpolicies$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Firewallpolicies$List, options: MethodOptions | BodyResponseCallback<Schema$FirewallPolicyList>, callback: BodyResponseCallback<Schema$FirewallPolicyList>): void;
        list(params: Params$Resource$Firewallpolicies$List, callback: BodyResponseCallback<Schema$FirewallPolicyList>): void;
        list(callback: BodyResponseCallback<Schema$FirewallPolicyList>): void;
        /**
         * Lists associations of a specified target, i.e., organization or folder.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        listAssociations(params: Params$Resource$Firewallpolicies$Listassociations, options: StreamMethodOptions): GaxiosPromise<Readable>;
        listAssociations(params?: Params$Resource$Firewallpolicies$Listassociations, options?: MethodOptions): GaxiosPromise<Schema$FirewallPoliciesListAssociationsResponse>;
        listAssociations(params: Params$Resource$Firewallpolicies$Listassociations, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        listAssociations(params: Params$Resource$Firewallpolicies$Listassociations, options: MethodOptions | BodyResponseCallback<Schema$FirewallPoliciesListAssociationsResponse>, callback: BodyResponseCallback<Schema$FirewallPoliciesListAssociationsResponse>): void;
        listAssociations(params: Params$Resource$Firewallpolicies$Listassociations, callback: BodyResponseCallback<Schema$FirewallPoliciesListAssociationsResponse>): void;
        listAssociations(callback: BodyResponseCallback<Schema$FirewallPoliciesListAssociationsResponse>): void;
        /**
         * Moves the specified firewall policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        move(params: Params$Resource$Firewallpolicies$Move, options: StreamMethodOptions): GaxiosPromise<Readable>;
        move(params?: Params$Resource$Firewallpolicies$Move, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        move(params: Params$Resource$Firewallpolicies$Move, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        move(params: Params$Resource$Firewallpolicies$Move, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        move(params: Params$Resource$Firewallpolicies$Move, callback: BodyResponseCallback<Schema$Operation>): void;
        move(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Patches the specified policy with the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Firewallpolicies$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Firewallpolicies$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Firewallpolicies$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Firewallpolicies$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Firewallpolicies$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Patches a rule of the specified priority.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patchRule(params: Params$Resource$Firewallpolicies$Patchrule, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patchRule(params?: Params$Resource$Firewallpolicies$Patchrule, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patchRule(params: Params$Resource$Firewallpolicies$Patchrule, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patchRule(params: Params$Resource$Firewallpolicies$Patchrule, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patchRule(params: Params$Resource$Firewallpolicies$Patchrule, callback: BodyResponseCallback<Schema$Operation>): void;
        patchRule(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Removes an association for the specified firewall policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        removeAssociation(params: Params$Resource$Firewallpolicies$Removeassociation, options: StreamMethodOptions): GaxiosPromise<Readable>;
        removeAssociation(params?: Params$Resource$Firewallpolicies$Removeassociation, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        removeAssociation(params: Params$Resource$Firewallpolicies$Removeassociation, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        removeAssociation(params: Params$Resource$Firewallpolicies$Removeassociation, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        removeAssociation(params: Params$Resource$Firewallpolicies$Removeassociation, callback: BodyResponseCallback<Schema$Operation>): void;
        removeAssociation(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Deletes a rule of the specified priority.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        removeRule(params: Params$Resource$Firewallpolicies$Removerule, options: StreamMethodOptions): GaxiosPromise<Readable>;
        removeRule(params?: Params$Resource$Firewallpolicies$Removerule, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        removeRule(params: Params$Resource$Firewallpolicies$Removerule, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        removeRule(params: Params$Resource$Firewallpolicies$Removerule, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        removeRule(params: Params$Resource$Firewallpolicies$Removerule, callback: BodyResponseCallback<Schema$Operation>): void;
        removeRule(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the access control policy on the specified resource. Replaces any existing policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setIamPolicy(params: Params$Resource$Firewallpolicies$Setiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setIamPolicy(params?: Params$Resource$Firewallpolicies$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        setIamPolicy(params: Params$Resource$Firewallpolicies$Setiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setIamPolicy(params: Params$Resource$Firewallpolicies$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(params: Params$Resource$Firewallpolicies$Setiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Firewallpolicies$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Firewallpolicies$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Firewallpolicies$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Firewallpolicies$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Firewallpolicies$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Firewallpolicies$Addassociation extends StandardParameters {
        /**
         * Name of the firewall policy to update.
         */
        firewallPolicy?: string;
        /**
         * Indicates whether or not to replace it if an association of the attachment already exists. This is false by default, in which case an error will be returned if an association already exists.
         */
        replaceExistingAssociation?: boolean;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$FirewallPolicyAssociation;
    }
    export interface Params$Resource$Firewallpolicies$Addrule extends StandardParameters {
        /**
         * Name of the firewall policy to update.
         */
        firewallPolicy?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$FirewallPolicyRule;
    }
    export interface Params$Resource$Firewallpolicies$Clonerules extends StandardParameters {
        /**
         * Name of the firewall policy to update.
         */
        firewallPolicy?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The firewall policy from which to copy rules.
         */
        sourceFirewallPolicy?: string;
    }
    export interface Params$Resource$Firewallpolicies$Delete extends StandardParameters {
        /**
         * Name of the firewall policy to delete.
         */
        firewallPolicy?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Firewallpolicies$Get extends StandardParameters {
        /**
         * Name of the firewall policy to get.
         */
        firewallPolicy?: string;
    }
    export interface Params$Resource$Firewallpolicies$Getassociation extends StandardParameters {
        /**
         * Name of the firewall policy to which the queried rule belongs.
         */
        firewallPolicy?: string;
        /**
         * The name of the association to get from the firewall policy.
         */
        name?: string;
    }
    export interface Params$Resource$Firewallpolicies$Getiampolicy extends StandardParameters {
        /**
         * Requested IAM Policy version.
         */
        optionsRequestedPolicyVersion?: number;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
    }
    export interface Params$Resource$Firewallpolicies$Getrule extends StandardParameters {
        /**
         * Name of the firewall policy to which the queried rule belongs.
         */
        firewallPolicy?: string;
        /**
         * The priority of the rule to get from the firewall policy.
         */
        priority?: number;
    }
    export interface Params$Resource$Firewallpolicies$Insert extends StandardParameters {
        /**
         * Parent ID for this request. The ID can be either be "folders/[FOLDER_ID]" if the parent is a folder or "organizations/[ORGANIZATION_ID]" if the parent is an organization.
         */
        parentId?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$FirewallPolicy;
    }
    export interface Params$Resource$Firewallpolicies$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Parent ID for this request. The ID can be either be "folders/[FOLDER_ID]" if the parent is a folder or "organizations/[ORGANIZATION_ID]" if the parent is an organization.
         */
        parentId?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Firewallpolicies$Listassociations extends StandardParameters {
        /**
         * The target resource to list associations. It is an organization, or a folder.
         */
        targetResource?: string;
    }
    export interface Params$Resource$Firewallpolicies$Move extends StandardParameters {
        /**
         * Name of the firewall policy to update.
         */
        firewallPolicy?: string;
        /**
         * The new parent of the firewall policy. The ID can be either be "folders/[FOLDER_ID]" if the parent is a folder or "organizations/[ORGANIZATION_ID]" if the parent is an organization.
         */
        parentId?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Firewallpolicies$Patch extends StandardParameters {
        /**
         * Name of the firewall policy to update.
         */
        firewallPolicy?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$FirewallPolicy;
    }
    export interface Params$Resource$Firewallpolicies$Patchrule extends StandardParameters {
        /**
         * Name of the firewall policy to update.
         */
        firewallPolicy?: string;
        /**
         * The priority of the rule to patch.
         */
        priority?: number;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$FirewallPolicyRule;
    }
    export interface Params$Resource$Firewallpolicies$Removeassociation extends StandardParameters {
        /**
         * Name of the firewall policy to update.
         */
        firewallPolicy?: string;
        /**
         * Name for the attachment that will be removed.
         */
        name?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Firewallpolicies$Removerule extends StandardParameters {
        /**
         * Name of the firewall policy to update.
         */
        firewallPolicy?: string;
        /**
         * The priority of the rule to remove from the firewall policy.
         */
        priority?: number;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Firewallpolicies$Setiampolicy extends StandardParameters {
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GlobalOrganizationSetPolicyRequest;
    }
    export interface Params$Resource$Firewallpolicies$Testiampermissions extends StandardParameters {
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Firewalls {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Deletes the specified firewall.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Firewalls$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Firewalls$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Firewalls$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Firewalls$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Firewalls$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified firewall.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Firewalls$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Firewalls$Get, options?: MethodOptions): GaxiosPromise<Schema$Firewall>;
        get(params: Params$Resource$Firewalls$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Firewalls$Get, options: MethodOptions | BodyResponseCallback<Schema$Firewall>, callback: BodyResponseCallback<Schema$Firewall>): void;
        get(params: Params$Resource$Firewalls$Get, callback: BodyResponseCallback<Schema$Firewall>): void;
        get(callback: BodyResponseCallback<Schema$Firewall>): void;
        /**
         * Creates a firewall rule in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Firewalls$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Firewalls$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Firewalls$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Firewalls$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Firewalls$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of firewall rules available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Firewalls$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Firewalls$List, options?: MethodOptions): GaxiosPromise<Schema$FirewallList>;
        list(params: Params$Resource$Firewalls$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Firewalls$List, options: MethodOptions | BodyResponseCallback<Schema$FirewallList>, callback: BodyResponseCallback<Schema$FirewallList>): void;
        list(params: Params$Resource$Firewalls$List, callback: BodyResponseCallback<Schema$FirewallList>): void;
        list(callback: BodyResponseCallback<Schema$FirewallList>): void;
        /**
         * Updates the specified firewall rule with the data included in the request. This method supports PATCH semantics and uses the JSON merge patch format and processing rules.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Firewalls$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Firewalls$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Firewalls$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Firewalls$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Firewalls$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Firewalls$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Firewalls$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Firewalls$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Firewalls$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Firewalls$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        /**
         * Updates the specified firewall rule with the data included in the request. Note that all fields will be updated if using PUT, even fields that are not specified. To update individual fields, please use PATCH instead.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        update(params: Params$Resource$Firewalls$Update, options: StreamMethodOptions): GaxiosPromise<Readable>;
        update(params?: Params$Resource$Firewalls$Update, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        update(params: Params$Resource$Firewalls$Update, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        update(params: Params$Resource$Firewalls$Update, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        update(params: Params$Resource$Firewalls$Update, callback: BodyResponseCallback<Schema$Operation>): void;
        update(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    export interface Params$Resource$Firewalls$Delete extends StandardParameters {
        /**
         * Name of the firewall rule to delete.
         */
        firewall?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Firewalls$Get extends StandardParameters {
        /**
         * Name of the firewall rule to return.
         */
        firewall?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    export interface Params$Resource$Firewalls$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Firewall;
    }
    export interface Params$Resource$Firewalls$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Firewalls$Patch extends StandardParameters {
        /**
         * Name of the firewall rule to patch.
         */
        firewall?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Firewall;
    }
    export interface Params$Resource$Firewalls$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export interface Params$Resource$Firewalls$Update extends StandardParameters {
        /**
         * Name of the firewall rule to update.
         */
        firewall?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Firewall;
    }
    export class Resource$Forwardingrules {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves an aggregated list of forwarding rules.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Forwardingrules$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Forwardingrules$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$ForwardingRuleAggregatedList>;
        aggregatedList(params: Params$Resource$Forwardingrules$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Forwardingrules$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$ForwardingRuleAggregatedList>, callback: BodyResponseCallback<Schema$ForwardingRuleAggregatedList>): void;
        aggregatedList(params: Params$Resource$Forwardingrules$Aggregatedlist, callback: BodyResponseCallback<Schema$ForwardingRuleAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$ForwardingRuleAggregatedList>): void;
        /**
         * Deletes the specified ForwardingRule resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Forwardingrules$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Forwardingrules$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Forwardingrules$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Forwardingrules$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Forwardingrules$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified ForwardingRule resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Forwardingrules$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Forwardingrules$Get, options?: MethodOptions): GaxiosPromise<Schema$ForwardingRule>;
        get(params: Params$Resource$Forwardingrules$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Forwardingrules$Get, options: MethodOptions | BodyResponseCallback<Schema$ForwardingRule>, callback: BodyResponseCallback<Schema$ForwardingRule>): void;
        get(params: Params$Resource$Forwardingrules$Get, callback: BodyResponseCallback<Schema$ForwardingRule>): void;
        get(callback: BodyResponseCallback<Schema$ForwardingRule>): void;
        /**
         * Creates a ForwardingRule resource in the specified project and region using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Forwardingrules$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Forwardingrules$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Forwardingrules$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Forwardingrules$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Forwardingrules$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves a list of ForwardingRule resources available to the specified project and region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Forwardingrules$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Forwardingrules$List, options?: MethodOptions): GaxiosPromise<Schema$ForwardingRuleList>;
        list(params: Params$Resource$Forwardingrules$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Forwardingrules$List, options: MethodOptions | BodyResponseCallback<Schema$ForwardingRuleList>, callback: BodyResponseCallback<Schema$ForwardingRuleList>): void;
        list(params: Params$Resource$Forwardingrules$List, callback: BodyResponseCallback<Schema$ForwardingRuleList>): void;
        list(callback: BodyResponseCallback<Schema$ForwardingRuleList>): void;
        /**
         * Updates the specified forwarding rule with the data included in the request. This method supports PATCH semantics and uses the JSON merge patch format and processing rules. Currently, you can only patch the network_tier field.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Forwardingrules$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Forwardingrules$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Forwardingrules$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Forwardingrules$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Forwardingrules$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the labels on the specified resource. To learn more about labels, read the Labeling Resources documentation.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setLabels(params: Params$Resource$Forwardingrules$Setlabels, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setLabels(params?: Params$Resource$Forwardingrules$Setlabels, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setLabels(params: Params$Resource$Forwardingrules$Setlabels, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setLabels(params: Params$Resource$Forwardingrules$Setlabels, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(params: Params$Resource$Forwardingrules$Setlabels, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Changes target URL for forwarding rule. The new target should be of the same type as the old target.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setTarget(params: Params$Resource$Forwardingrules$Settarget, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setTarget(params?: Params$Resource$Forwardingrules$Settarget, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setTarget(params: Params$Resource$Forwardingrules$Settarget, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setTarget(params: Params$Resource$Forwardingrules$Settarget, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setTarget(params: Params$Resource$Forwardingrules$Settarget, callback: BodyResponseCallback<Schema$Operation>): void;
        setTarget(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Forwardingrules$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Forwardingrules$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Forwardingrules$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Forwardingrules$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Forwardingrules$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Forwardingrules$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Forwardingrules$Delete extends StandardParameters {
        /**
         * Name of the ForwardingRule resource to delete.
         */
        forwardingRule?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Forwardingrules$Get extends StandardParameters {
        /**
         * Name of the ForwardingRule resource to return.
         */
        forwardingRule?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
    }
    export interface Params$Resource$Forwardingrules$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ForwardingRule;
    }
    export interface Params$Resource$Forwardingrules$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Forwardingrules$Patch extends StandardParameters {
        /**
         * Name of the ForwardingRule resource to patch.
         */
        forwardingRule?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ForwardingRule;
    }
    export interface Params$Resource$Forwardingrules$Setlabels extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionSetLabelsRequest;
    }
    export interface Params$Resource$Forwardingrules$Settarget extends StandardParameters {
        /**
         * Name of the ForwardingRule resource in which target is to be set.
         */
        forwardingRule?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetReference;
    }
    export interface Params$Resource$Forwardingrules$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Futurereservations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves an aggregated list of future reservations.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Futurereservations$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Futurereservations$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$FutureReservationsAggregatedListResponse>;
        aggregatedList(params: Params$Resource$Futurereservations$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Futurereservations$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$FutureReservationsAggregatedListResponse>, callback: BodyResponseCallback<Schema$FutureReservationsAggregatedListResponse>): void;
        aggregatedList(params: Params$Resource$Futurereservations$Aggregatedlist, callback: BodyResponseCallback<Schema$FutureReservationsAggregatedListResponse>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$FutureReservationsAggregatedListResponse>): void;
        /**
         * Cancel the specified future reservation.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Futurereservations$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Futurereservations$Cancel, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        cancel(params: Params$Resource$Futurereservations$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Futurereservations$Cancel, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        cancel(params: Params$Resource$Futurereservations$Cancel, callback: BodyResponseCallback<Schema$Operation>): void;
        cancel(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Deletes the specified future reservation.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Futurereservations$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Futurereservations$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Futurereservations$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Futurereservations$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Futurereservations$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves information about the specified future reservation.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Futurereservations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Futurereservations$Get, options?: MethodOptions): GaxiosPromise<Schema$FutureReservation>;
        get(params: Params$Resource$Futurereservations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Futurereservations$Get, options: MethodOptions | BodyResponseCallback<Schema$FutureReservation>, callback: BodyResponseCallback<Schema$FutureReservation>): void;
        get(params: Params$Resource$Futurereservations$Get, callback: BodyResponseCallback<Schema$FutureReservation>): void;
        get(callback: BodyResponseCallback<Schema$FutureReservation>): void;
        /**
         * Creates a new Future Reservation.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Futurereservations$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Futurereservations$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Futurereservations$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Futurereservations$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Futurereservations$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * A list of all the future reservations that have been configured for the specified project in specified zone.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Futurereservations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Futurereservations$List, options?: MethodOptions): GaxiosPromise<Schema$FutureReservationsListResponse>;
        list(params: Params$Resource$Futurereservations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Futurereservations$List, options: MethodOptions | BodyResponseCallback<Schema$FutureReservationsListResponse>, callback: BodyResponseCallback<Schema$FutureReservationsListResponse>): void;
        list(params: Params$Resource$Futurereservations$List, callback: BodyResponseCallback<Schema$FutureReservationsListResponse>): void;
        list(callback: BodyResponseCallback<Schema$FutureReservationsListResponse>): void;
        /**
         * Updates the specified future reservation.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        update(params: Params$Resource$Futurereservations$Update, options: StreamMethodOptions): GaxiosPromise<Readable>;
        update(params?: Params$Resource$Futurereservations$Update, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        update(params: Params$Resource$Futurereservations$Update, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        update(params: Params$Resource$Futurereservations$Update, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        update(params: Params$Resource$Futurereservations$Update, callback: BodyResponseCallback<Schema$Operation>): void;
        update(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    export interface Params$Resource$Futurereservations$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Futurereservations$Cancel extends StandardParameters {
        /**
         * Name of the future reservation to retrieve. Name should conform to RFC1035.
         */
        futureReservation?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the zone for this request. Name should conform to RFC1035.
         */
        zone?: string;
    }
    export interface Params$Resource$Futurereservations$Delete extends StandardParameters {
        /**
         * Name of the future reservation to retrieve. Name should conform to RFC1035.
         */
        futureReservation?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the zone for this request. Name should conform to RFC1035.
         */
        zone?: string;
    }
    export interface Params$Resource$Futurereservations$Get extends StandardParameters {
        /**
         * Name of the future reservation to retrieve. Name should conform to RFC1035.
         */
        futureReservation?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the zone for this request. Name should conform to RFC1035.
         */
        zone?: string;
    }
    export interface Params$Resource$Futurereservations$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the zone for this request. Name should conform to RFC1035.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$FutureReservation;
    }
    export interface Params$Resource$Futurereservations$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         * Name of the zone for this request. Name should conform to RFC1035.
         */
        zone?: string;
    }
    export interface Params$Resource$Futurereservations$Update extends StandardParameters {
        /**
         * Name of the reservation to update. Name should conform to RFC1035.
         */
        futureReservation?: string;
        /**
         *
         */
        paths?: string[];
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * update_mask indicates fields to be updated as part of this request.
         */
        updateMask?: string;
        /**
         * Name of the zone for this request. Name should conform to RFC1035.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$FutureReservation;
    }
    export class Resource$Globaladdresses {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Deletes the specified address resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Globaladdresses$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Globaladdresses$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Globaladdresses$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Globaladdresses$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Globaladdresses$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified address resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Globaladdresses$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Globaladdresses$Get, options?: MethodOptions): GaxiosPromise<Schema$Address>;
        get(params: Params$Resource$Globaladdresses$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Globaladdresses$Get, options: MethodOptions | BodyResponseCallback<Schema$Address>, callback: BodyResponseCallback<Schema$Address>): void;
        get(params: Params$Resource$Globaladdresses$Get, callback: BodyResponseCallback<Schema$Address>): void;
        get(callback: BodyResponseCallback<Schema$Address>): void;
        /**
         * Find owner instance from given ip address
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getOwnerInstance(params: Params$Resource$Globaladdresses$Getownerinstance, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getOwnerInstance(params?: Params$Resource$Globaladdresses$Getownerinstance, options?: MethodOptions): GaxiosPromise<Schema$GetOwnerInstanceResponse>;
        getOwnerInstance(params: Params$Resource$Globaladdresses$Getownerinstance, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getOwnerInstance(params: Params$Resource$Globaladdresses$Getownerinstance, options: MethodOptions | BodyResponseCallback<Schema$GetOwnerInstanceResponse>, callback: BodyResponseCallback<Schema$GetOwnerInstanceResponse>): void;
        getOwnerInstance(params: Params$Resource$Globaladdresses$Getownerinstance, callback: BodyResponseCallback<Schema$GetOwnerInstanceResponse>): void;
        getOwnerInstance(callback: BodyResponseCallback<Schema$GetOwnerInstanceResponse>): void;
        /**
         * Creates an address resource in the specified project by using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Globaladdresses$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Globaladdresses$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Globaladdresses$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Globaladdresses$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Globaladdresses$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves a list of global addresses.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Globaladdresses$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Globaladdresses$List, options?: MethodOptions): GaxiosPromise<Schema$AddressList>;
        list(params: Params$Resource$Globaladdresses$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Globaladdresses$List, options: MethodOptions | BodyResponseCallback<Schema$AddressList>, callback: BodyResponseCallback<Schema$AddressList>): void;
        list(params: Params$Resource$Globaladdresses$List, callback: BodyResponseCallback<Schema$AddressList>): void;
        list(callback: BodyResponseCallback<Schema$AddressList>): void;
        /**
         * Moves the specified address resource from one project to another project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        move(params: Params$Resource$Globaladdresses$Move, options: StreamMethodOptions): GaxiosPromise<Readable>;
        move(params?: Params$Resource$Globaladdresses$Move, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        move(params: Params$Resource$Globaladdresses$Move, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        move(params: Params$Resource$Globaladdresses$Move, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        move(params: Params$Resource$Globaladdresses$Move, callback: BodyResponseCallback<Schema$Operation>): void;
        move(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the labels on a GlobalAddress. To learn more about labels, read the Labeling Resources documentation.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setLabels(params: Params$Resource$Globaladdresses$Setlabels, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setLabels(params?: Params$Resource$Globaladdresses$Setlabels, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setLabels(params: Params$Resource$Globaladdresses$Setlabels, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setLabels(params: Params$Resource$Globaladdresses$Setlabels, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(params: Params$Resource$Globaladdresses$Setlabels, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Globaladdresses$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Globaladdresses$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Globaladdresses$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Globaladdresses$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Globaladdresses$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Globaladdresses$Delete extends StandardParameters {
        /**
         * Name of the address resource to delete.
         */
        address?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Globaladdresses$Get extends StandardParameters {
        /**
         * Name of the address resource to return.
         */
        address?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    export interface Params$Resource$Globaladdresses$Getownerinstance extends StandardParameters {
        /**
         * The VM IP address.
         */
        ipAddress?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    export interface Params$Resource$Globaladdresses$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Address;
    }
    export interface Params$Resource$Globaladdresses$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Globaladdresses$Move extends StandardParameters {
        /**
         * Name of the address resource to move.
         */
        address?: string;
        /**
         * Source project ID which the Address is moved from.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GlobalAddressesMoveRequest;
    }
    export interface Params$Resource$Globaladdresses$Setlabels extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GlobalSetLabelsRequest;
    }
    export interface Params$Resource$Globaladdresses$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Globalforwardingrules {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Deletes the specified GlobalForwardingRule resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Globalforwardingrules$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Globalforwardingrules$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Globalforwardingrules$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Globalforwardingrules$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Globalforwardingrules$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified GlobalForwardingRule resource. Gets a list of available forwarding rules by making a list() request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Globalforwardingrules$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Globalforwardingrules$Get, options?: MethodOptions): GaxiosPromise<Schema$ForwardingRule>;
        get(params: Params$Resource$Globalforwardingrules$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Globalforwardingrules$Get, options: MethodOptions | BodyResponseCallback<Schema$ForwardingRule>, callback: BodyResponseCallback<Schema$ForwardingRule>): void;
        get(params: Params$Resource$Globalforwardingrules$Get, callback: BodyResponseCallback<Schema$ForwardingRule>): void;
        get(callback: BodyResponseCallback<Schema$ForwardingRule>): void;
        /**
         * Creates a GlobalForwardingRule resource in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Globalforwardingrules$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Globalforwardingrules$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Globalforwardingrules$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Globalforwardingrules$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Globalforwardingrules$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves a list of GlobalForwardingRule resources available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Globalforwardingrules$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Globalforwardingrules$List, options?: MethodOptions): GaxiosPromise<Schema$ForwardingRuleList>;
        list(params: Params$Resource$Globalforwardingrules$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Globalforwardingrules$List, options: MethodOptions | BodyResponseCallback<Schema$ForwardingRuleList>, callback: BodyResponseCallback<Schema$ForwardingRuleList>): void;
        list(params: Params$Resource$Globalforwardingrules$List, callback: BodyResponseCallback<Schema$ForwardingRuleList>): void;
        list(callback: BodyResponseCallback<Schema$ForwardingRuleList>): void;
        /**
         * Updates the specified forwarding rule with the data included in the request. This method supports PATCH semantics and uses the JSON merge patch format and processing rules. Currently, you can only patch the network_tier field.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Globalforwardingrules$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Globalforwardingrules$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Globalforwardingrules$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Globalforwardingrules$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Globalforwardingrules$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the labels on the specified resource. To learn more about labels, read the Labeling resources documentation.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setLabels(params: Params$Resource$Globalforwardingrules$Setlabels, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setLabels(params?: Params$Resource$Globalforwardingrules$Setlabels, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setLabels(params: Params$Resource$Globalforwardingrules$Setlabels, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setLabels(params: Params$Resource$Globalforwardingrules$Setlabels, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(params: Params$Resource$Globalforwardingrules$Setlabels, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Changes target URL for the GlobalForwardingRule resource. The new target should be of the same type as the old target.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setTarget(params: Params$Resource$Globalforwardingrules$Settarget, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setTarget(params?: Params$Resource$Globalforwardingrules$Settarget, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setTarget(params: Params$Resource$Globalforwardingrules$Settarget, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setTarget(params: Params$Resource$Globalforwardingrules$Settarget, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setTarget(params: Params$Resource$Globalforwardingrules$Settarget, callback: BodyResponseCallback<Schema$Operation>): void;
        setTarget(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Globalforwardingrules$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Globalforwardingrules$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Globalforwardingrules$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Globalforwardingrules$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Globalforwardingrules$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Globalforwardingrules$Delete extends StandardParameters {
        /**
         * Name of the ForwardingRule resource to delete.
         */
        forwardingRule?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Globalforwardingrules$Get extends StandardParameters {
        /**
         * Name of the ForwardingRule resource to return.
         */
        forwardingRule?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    export interface Params$Resource$Globalforwardingrules$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ForwardingRule;
    }
    export interface Params$Resource$Globalforwardingrules$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Globalforwardingrules$Patch extends StandardParameters {
        /**
         * Name of the ForwardingRule resource to patch.
         */
        forwardingRule?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ForwardingRule;
    }
    export interface Params$Resource$Globalforwardingrules$Setlabels extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GlobalSetLabelsRequest;
    }
    export interface Params$Resource$Globalforwardingrules$Settarget extends StandardParameters {
        /**
         * Name of the ForwardingRule resource in which target is to be set.
         */
        forwardingRule?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetReference;
    }
    export interface Params$Resource$Globalforwardingrules$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Globalnetworkendpointgroups {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Attach a network endpoint to the specified network endpoint group.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        attachNetworkEndpoints(params: Params$Resource$Globalnetworkendpointgroups$Attachnetworkendpoints, options: StreamMethodOptions): GaxiosPromise<Readable>;
        attachNetworkEndpoints(params?: Params$Resource$Globalnetworkendpointgroups$Attachnetworkendpoints, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        attachNetworkEndpoints(params: Params$Resource$Globalnetworkendpointgroups$Attachnetworkendpoints, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        attachNetworkEndpoints(params: Params$Resource$Globalnetworkendpointgroups$Attachnetworkendpoints, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        attachNetworkEndpoints(params: Params$Resource$Globalnetworkendpointgroups$Attachnetworkendpoints, callback: BodyResponseCallback<Schema$Operation>): void;
        attachNetworkEndpoints(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Deletes the specified network endpoint group.Note that the NEG cannot be deleted if there are backend services referencing it.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Globalnetworkendpointgroups$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Globalnetworkendpointgroups$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Globalnetworkendpointgroups$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Globalnetworkendpointgroups$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Globalnetworkendpointgroups$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Detach the network endpoint from the specified network endpoint group.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        detachNetworkEndpoints(params: Params$Resource$Globalnetworkendpointgroups$Detachnetworkendpoints, options: StreamMethodOptions): GaxiosPromise<Readable>;
        detachNetworkEndpoints(params?: Params$Resource$Globalnetworkendpointgroups$Detachnetworkendpoints, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        detachNetworkEndpoints(params: Params$Resource$Globalnetworkendpointgroups$Detachnetworkendpoints, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        detachNetworkEndpoints(params: Params$Resource$Globalnetworkendpointgroups$Detachnetworkendpoints, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        detachNetworkEndpoints(params: Params$Resource$Globalnetworkendpointgroups$Detachnetworkendpoints, callback: BodyResponseCallback<Schema$Operation>): void;
        detachNetworkEndpoints(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified network endpoint group.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Globalnetworkendpointgroups$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Globalnetworkendpointgroups$Get, options?: MethodOptions): GaxiosPromise<Schema$NetworkEndpointGroup>;
        get(params: Params$Resource$Globalnetworkendpointgroups$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Globalnetworkendpointgroups$Get, options: MethodOptions | BodyResponseCallback<Schema$NetworkEndpointGroup>, callback: BodyResponseCallback<Schema$NetworkEndpointGroup>): void;
        get(params: Params$Resource$Globalnetworkendpointgroups$Get, callback: BodyResponseCallback<Schema$NetworkEndpointGroup>): void;
        get(callback: BodyResponseCallback<Schema$NetworkEndpointGroup>): void;
        /**
         * Creates a network endpoint group in the specified project using the parameters that are included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Globalnetworkendpointgroups$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Globalnetworkendpointgroups$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Globalnetworkendpointgroups$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Globalnetworkendpointgroups$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Globalnetworkendpointgroups$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of network endpoint groups that are located in the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Globalnetworkendpointgroups$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Globalnetworkendpointgroups$List, options?: MethodOptions): GaxiosPromise<Schema$NetworkEndpointGroupList>;
        list(params: Params$Resource$Globalnetworkendpointgroups$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Globalnetworkendpointgroups$List, options: MethodOptions | BodyResponseCallback<Schema$NetworkEndpointGroupList>, callback: BodyResponseCallback<Schema$NetworkEndpointGroupList>): void;
        list(params: Params$Resource$Globalnetworkendpointgroups$List, callback: BodyResponseCallback<Schema$NetworkEndpointGroupList>): void;
        list(callback: BodyResponseCallback<Schema$NetworkEndpointGroupList>): void;
        /**
         * Lists the network endpoints in the specified network endpoint group.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        listNetworkEndpoints(params: Params$Resource$Globalnetworkendpointgroups$Listnetworkendpoints, options: StreamMethodOptions): GaxiosPromise<Readable>;
        listNetworkEndpoints(params?: Params$Resource$Globalnetworkendpointgroups$Listnetworkendpoints, options?: MethodOptions): GaxiosPromise<Schema$NetworkEndpointGroupsListNetworkEndpoints>;
        listNetworkEndpoints(params: Params$Resource$Globalnetworkendpointgroups$Listnetworkendpoints, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        listNetworkEndpoints(params: Params$Resource$Globalnetworkendpointgroups$Listnetworkendpoints, options: MethodOptions | BodyResponseCallback<Schema$NetworkEndpointGroupsListNetworkEndpoints>, callback: BodyResponseCallback<Schema$NetworkEndpointGroupsListNetworkEndpoints>): void;
        listNetworkEndpoints(params: Params$Resource$Globalnetworkendpointgroups$Listnetworkendpoints, callback: BodyResponseCallback<Schema$NetworkEndpointGroupsListNetworkEndpoints>): void;
        listNetworkEndpoints(callback: BodyResponseCallback<Schema$NetworkEndpointGroupsListNetworkEndpoints>): void;
    }
    export interface Params$Resource$Globalnetworkendpointgroups$Attachnetworkendpoints extends StandardParameters {
        /**
         * The name of the network endpoint group where you are attaching network endpoints to. It should comply with RFC1035.
         */
        networkEndpointGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GlobalNetworkEndpointGroupsAttachEndpointsRequest;
    }
    export interface Params$Resource$Globalnetworkendpointgroups$Delete extends StandardParameters {
        /**
         * The name of the network endpoint group to delete. It should comply with RFC1035.
         */
        networkEndpointGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Globalnetworkendpointgroups$Detachnetworkendpoints extends StandardParameters {
        /**
         * The name of the network endpoint group where you are removing network endpoints. It should comply with RFC1035.
         */
        networkEndpointGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GlobalNetworkEndpointGroupsDetachEndpointsRequest;
    }
    export interface Params$Resource$Globalnetworkendpointgroups$Get extends StandardParameters {
        /**
         * The name of the network endpoint group. It should comply with RFC1035.
         */
        networkEndpointGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    export interface Params$Resource$Globalnetworkendpointgroups$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$NetworkEndpointGroup;
    }
    export interface Params$Resource$Globalnetworkendpointgroups$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Globalnetworkendpointgroups$Listnetworkendpoints extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * The name of the network endpoint group from which you want to generate a list of included network endpoints. It should comply with RFC1035.
         */
        networkEndpointGroup?: string;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export class Resource$Globaloperations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves an aggregated list of all operations.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Globaloperations$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Globaloperations$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$OperationAggregatedList>;
        aggregatedList(params: Params$Resource$Globaloperations$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Globaloperations$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$OperationAggregatedList>, callback: BodyResponseCallback<Schema$OperationAggregatedList>): void;
        aggregatedList(params: Params$Resource$Globaloperations$Aggregatedlist, callback: BodyResponseCallback<Schema$OperationAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$OperationAggregatedList>): void;
        /**
         * Deletes the specified Operations resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Globaloperations$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Globaloperations$Delete, options?: MethodOptions): GaxiosPromise<void>;
        delete(params: Params$Resource$Globaloperations$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Globaloperations$Delete, options: MethodOptions | BodyResponseCallback<void>, callback: BodyResponseCallback<void>): void;
        delete(params: Params$Resource$Globaloperations$Delete, callback: BodyResponseCallback<void>): void;
        delete(callback: BodyResponseCallback<void>): void;
        /**
         * Retrieves the specified Operations resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Globaloperations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Globaloperations$Get, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        get(params: Params$Resource$Globaloperations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Globaloperations$Get, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        get(params: Params$Resource$Globaloperations$Get, callback: BodyResponseCallback<Schema$Operation>): void;
        get(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves a list of Operation resources contained within the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Globaloperations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Globaloperations$List, options?: MethodOptions): GaxiosPromise<Schema$OperationList>;
        list(params: Params$Resource$Globaloperations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Globaloperations$List, options: MethodOptions | BodyResponseCallback<Schema$OperationList>, callback: BodyResponseCallback<Schema$OperationList>): void;
        list(params: Params$Resource$Globaloperations$List, callback: BodyResponseCallback<Schema$OperationList>): void;
        list(callback: BodyResponseCallback<Schema$OperationList>): void;
        /**
         * Waits for the specified Operation resource to return as `DONE` or for the request to approach the 2 minute deadline, and retrieves the specified Operation resource. This method differs from the `GET` method in that it waits for no more than the default deadline (2 minutes) and then returns the current state of the operation, which might be `DONE` or still in progress. This method is called on a best-effort basis. Specifically: - In uncommon cases, when the server is overloaded, the request might return before the default deadline is reached, or might return after zero seconds. - If the default deadline is reached, there is no guarantee that the operation is actually done when the method returns. Be prepared to retry if the operation is not `DONE`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        wait(params: Params$Resource$Globaloperations$Wait, options: StreamMethodOptions): GaxiosPromise<Readable>;
        wait(params?: Params$Resource$Globaloperations$Wait, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        wait(params: Params$Resource$Globaloperations$Wait, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        wait(params: Params$Resource$Globaloperations$Wait, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        wait(params: Params$Resource$Globaloperations$Wait, callback: BodyResponseCallback<Schema$Operation>): void;
        wait(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    export interface Params$Resource$Globaloperations$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Globaloperations$Delete extends StandardParameters {
        /**
         * Name of the Operations resource to delete.
         */
        operation?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    export interface Params$Resource$Globaloperations$Get extends StandardParameters {
        /**
         * Name of the Operations resource to return.
         */
        operation?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    export interface Params$Resource$Globaloperations$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Globaloperations$Wait extends StandardParameters {
        /**
         * Name of the Operations resource to return.
         */
        operation?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    export class Resource$Globalorganizationoperations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Deletes the specified Operations resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Globalorganizationoperations$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Globalorganizationoperations$Delete, options?: MethodOptions): GaxiosPromise<void>;
        delete(params: Params$Resource$Globalorganizationoperations$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Globalorganizationoperations$Delete, options: MethodOptions | BodyResponseCallback<void>, callback: BodyResponseCallback<void>): void;
        delete(params: Params$Resource$Globalorganizationoperations$Delete, callback: BodyResponseCallback<void>): void;
        delete(callback: BodyResponseCallback<void>): void;
        /**
         * Retrieves the specified Operations resource. Gets a list of operations by making a `list()` request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Globalorganizationoperations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Globalorganizationoperations$Get, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        get(params: Params$Resource$Globalorganizationoperations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Globalorganizationoperations$Get, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        get(params: Params$Resource$Globalorganizationoperations$Get, callback: BodyResponseCallback<Schema$Operation>): void;
        get(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves a list of Operation resources contained within the specified organization.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Globalorganizationoperations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Globalorganizationoperations$List, options?: MethodOptions): GaxiosPromise<Schema$OperationList>;
        list(params: Params$Resource$Globalorganizationoperations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Globalorganizationoperations$List, options: MethodOptions | BodyResponseCallback<Schema$OperationList>, callback: BodyResponseCallback<Schema$OperationList>): void;
        list(params: Params$Resource$Globalorganizationoperations$List, callback: BodyResponseCallback<Schema$OperationList>): void;
        list(callback: BodyResponseCallback<Schema$OperationList>): void;
    }
    export interface Params$Resource$Globalorganizationoperations$Delete extends StandardParameters {
        /**
         * Name of the Operations resource to delete.
         */
        operation?: string;
        /**
         * Parent ID for this request.
         */
        parentId?: string;
    }
    export interface Params$Resource$Globalorganizationoperations$Get extends StandardParameters {
        /**
         * Name of the Operations resource to return.
         */
        operation?: string;
        /**
         * Parent ID for this request.
         */
        parentId?: string;
    }
    export interface Params$Resource$Globalorganizationoperations$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Parent ID for this request.
         */
        parentId?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export class Resource$Globalpublicdelegatedprefixes {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Deletes the specified global PublicDelegatedPrefix.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Globalpublicdelegatedprefixes$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Globalpublicdelegatedprefixes$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Globalpublicdelegatedprefixes$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Globalpublicdelegatedprefixes$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Globalpublicdelegatedprefixes$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified global PublicDelegatedPrefix resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Globalpublicdelegatedprefixes$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Globalpublicdelegatedprefixes$Get, options?: MethodOptions): GaxiosPromise<Schema$PublicDelegatedPrefix>;
        get(params: Params$Resource$Globalpublicdelegatedprefixes$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Globalpublicdelegatedprefixes$Get, options: MethodOptions | BodyResponseCallback<Schema$PublicDelegatedPrefix>, callback: BodyResponseCallback<Schema$PublicDelegatedPrefix>): void;
        get(params: Params$Resource$Globalpublicdelegatedprefixes$Get, callback: BodyResponseCallback<Schema$PublicDelegatedPrefix>): void;
        get(callback: BodyResponseCallback<Schema$PublicDelegatedPrefix>): void;
        /**
         * Creates a global PublicDelegatedPrefix in the specified project using the parameters that are included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Globalpublicdelegatedprefixes$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Globalpublicdelegatedprefixes$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Globalpublicdelegatedprefixes$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Globalpublicdelegatedprefixes$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Globalpublicdelegatedprefixes$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Lists the global PublicDelegatedPrefixes for a project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Globalpublicdelegatedprefixes$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Globalpublicdelegatedprefixes$List, options?: MethodOptions): GaxiosPromise<Schema$PublicDelegatedPrefixList>;
        list(params: Params$Resource$Globalpublicdelegatedprefixes$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Globalpublicdelegatedprefixes$List, options: MethodOptions | BodyResponseCallback<Schema$PublicDelegatedPrefixList>, callback: BodyResponseCallback<Schema$PublicDelegatedPrefixList>): void;
        list(params: Params$Resource$Globalpublicdelegatedprefixes$List, callback: BodyResponseCallback<Schema$PublicDelegatedPrefixList>): void;
        list(callback: BodyResponseCallback<Schema$PublicDelegatedPrefixList>): void;
        /**
         * Patches the specified global PublicDelegatedPrefix resource with the data included in the request. This method supports PATCH semantics and uses JSON merge patch format and processing rules.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Globalpublicdelegatedprefixes$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Globalpublicdelegatedprefixes$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Globalpublicdelegatedprefixes$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Globalpublicdelegatedprefixes$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Globalpublicdelegatedprefixes$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    export interface Params$Resource$Globalpublicdelegatedprefixes$Delete extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the PublicDelegatedPrefix resource to delete.
         */
        publicDelegatedPrefix?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Globalpublicdelegatedprefixes$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the PublicDelegatedPrefix resource to return.
         */
        publicDelegatedPrefix?: string;
    }
    export interface Params$Resource$Globalpublicdelegatedprefixes$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$PublicDelegatedPrefix;
    }
    export interface Params$Resource$Globalpublicdelegatedprefixes$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Globalpublicdelegatedprefixes$Patch extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the PublicDelegatedPrefix resource to patch.
         */
        publicDelegatedPrefix?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$PublicDelegatedPrefix;
    }
    export class Resource$Healthchecks {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves the list of all HealthCheck resources, regional and global, available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Healthchecks$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Healthchecks$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$HealthChecksAggregatedList>;
        aggregatedList(params: Params$Resource$Healthchecks$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Healthchecks$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$HealthChecksAggregatedList>, callback: BodyResponseCallback<Schema$HealthChecksAggregatedList>): void;
        aggregatedList(params: Params$Resource$Healthchecks$Aggregatedlist, callback: BodyResponseCallback<Schema$HealthChecksAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$HealthChecksAggregatedList>): void;
        /**
         * Deletes the specified HealthCheck resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Healthchecks$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Healthchecks$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Healthchecks$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Healthchecks$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Healthchecks$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified HealthCheck resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Healthchecks$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Healthchecks$Get, options?: MethodOptions): GaxiosPromise<Schema$HealthCheck>;
        get(params: Params$Resource$Healthchecks$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Healthchecks$Get, options: MethodOptions | BodyResponseCallback<Schema$HealthCheck>, callback: BodyResponseCallback<Schema$HealthCheck>): void;
        get(params: Params$Resource$Healthchecks$Get, callback: BodyResponseCallback<Schema$HealthCheck>): void;
        get(callback: BodyResponseCallback<Schema$HealthCheck>): void;
        /**
         * Creates a HealthCheck resource in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Healthchecks$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Healthchecks$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Healthchecks$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Healthchecks$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Healthchecks$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of HealthCheck resources available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Healthchecks$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Healthchecks$List, options?: MethodOptions): GaxiosPromise<Schema$HealthCheckList>;
        list(params: Params$Resource$Healthchecks$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Healthchecks$List, options: MethodOptions | BodyResponseCallback<Schema$HealthCheckList>, callback: BodyResponseCallback<Schema$HealthCheckList>): void;
        list(params: Params$Resource$Healthchecks$List, callback: BodyResponseCallback<Schema$HealthCheckList>): void;
        list(callback: BodyResponseCallback<Schema$HealthCheckList>): void;
        /**
         * Updates a HealthCheck resource in the specified project using the data included in the request. This method supports PATCH semantics and uses the JSON merge patch format and processing rules.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Healthchecks$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Healthchecks$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Healthchecks$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Healthchecks$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Healthchecks$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Healthchecks$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Healthchecks$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Healthchecks$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Healthchecks$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Healthchecks$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        /**
         * Updates a HealthCheck resource in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        update(params: Params$Resource$Healthchecks$Update, options: StreamMethodOptions): GaxiosPromise<Readable>;
        update(params?: Params$Resource$Healthchecks$Update, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        update(params: Params$Resource$Healthchecks$Update, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        update(params: Params$Resource$Healthchecks$Update, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        update(params: Params$Resource$Healthchecks$Update, callback: BodyResponseCallback<Schema$Operation>): void;
        update(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    export interface Params$Resource$Healthchecks$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Name of the project scoping this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Healthchecks$Delete extends StandardParameters {
        /**
         * Name of the HealthCheck resource to delete.
         */
        healthCheck?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Healthchecks$Get extends StandardParameters {
        /**
         * Name of the HealthCheck resource to return.
         */
        healthCheck?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    export interface Params$Resource$Healthchecks$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$HealthCheck;
    }
    export interface Params$Resource$Healthchecks$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Healthchecks$Patch extends StandardParameters {
        /**
         * Name of the HealthCheck resource to patch.
         */
        healthCheck?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$HealthCheck;
    }
    export interface Params$Resource$Healthchecks$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export interface Params$Resource$Healthchecks$Update extends StandardParameters {
        /**
         * Name of the HealthCheck resource to update.
         */
        healthCheck?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$HealthCheck;
    }
    export class Resource$Httphealthchecks {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Deletes the specified HttpHealthCheck resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Httphealthchecks$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Httphealthchecks$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Httphealthchecks$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Httphealthchecks$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Httphealthchecks$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified HttpHealthCheck resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Httphealthchecks$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Httphealthchecks$Get, options?: MethodOptions): GaxiosPromise<Schema$HttpHealthCheck>;
        get(params: Params$Resource$Httphealthchecks$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Httphealthchecks$Get, options: MethodOptions | BodyResponseCallback<Schema$HttpHealthCheck>, callback: BodyResponseCallback<Schema$HttpHealthCheck>): void;
        get(params: Params$Resource$Httphealthchecks$Get, callback: BodyResponseCallback<Schema$HttpHealthCheck>): void;
        get(callback: BodyResponseCallback<Schema$HttpHealthCheck>): void;
        /**
         * Creates a HttpHealthCheck resource in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Httphealthchecks$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Httphealthchecks$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Httphealthchecks$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Httphealthchecks$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Httphealthchecks$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of HttpHealthCheck resources available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Httphealthchecks$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Httphealthchecks$List, options?: MethodOptions): GaxiosPromise<Schema$HttpHealthCheckList>;
        list(params: Params$Resource$Httphealthchecks$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Httphealthchecks$List, options: MethodOptions | BodyResponseCallback<Schema$HttpHealthCheckList>, callback: BodyResponseCallback<Schema$HttpHealthCheckList>): void;
        list(params: Params$Resource$Httphealthchecks$List, callback: BodyResponseCallback<Schema$HttpHealthCheckList>): void;
        list(callback: BodyResponseCallback<Schema$HttpHealthCheckList>): void;
        /**
         * Updates a HttpHealthCheck resource in the specified project using the data included in the request. This method supports PATCH semantics and uses the JSON merge patch format and processing rules.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Httphealthchecks$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Httphealthchecks$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Httphealthchecks$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Httphealthchecks$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Httphealthchecks$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Httphealthchecks$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Httphealthchecks$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Httphealthchecks$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Httphealthchecks$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Httphealthchecks$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        /**
         * Updates a HttpHealthCheck resource in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        update(params: Params$Resource$Httphealthchecks$Update, options: StreamMethodOptions): GaxiosPromise<Readable>;
        update(params?: Params$Resource$Httphealthchecks$Update, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        update(params: Params$Resource$Httphealthchecks$Update, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        update(params: Params$Resource$Httphealthchecks$Update, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        update(params: Params$Resource$Httphealthchecks$Update, callback: BodyResponseCallback<Schema$Operation>): void;
        update(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    export interface Params$Resource$Httphealthchecks$Delete extends StandardParameters {
        /**
         * Name of the HttpHealthCheck resource to delete.
         */
        httpHealthCheck?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Httphealthchecks$Get extends StandardParameters {
        /**
         * Name of the HttpHealthCheck resource to return.
         */
        httpHealthCheck?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    export interface Params$Resource$Httphealthchecks$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$HttpHealthCheck;
    }
    export interface Params$Resource$Httphealthchecks$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Httphealthchecks$Patch extends StandardParameters {
        /**
         * Name of the HttpHealthCheck resource to patch.
         */
        httpHealthCheck?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$HttpHealthCheck;
    }
    export interface Params$Resource$Httphealthchecks$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export interface Params$Resource$Httphealthchecks$Update extends StandardParameters {
        /**
         * Name of the HttpHealthCheck resource to update.
         */
        httpHealthCheck?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$HttpHealthCheck;
    }
    export class Resource$Httpshealthchecks {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Deletes the specified HttpsHealthCheck resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Httpshealthchecks$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Httpshealthchecks$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Httpshealthchecks$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Httpshealthchecks$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Httpshealthchecks$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified HttpsHealthCheck resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Httpshealthchecks$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Httpshealthchecks$Get, options?: MethodOptions): GaxiosPromise<Schema$HttpsHealthCheck>;
        get(params: Params$Resource$Httpshealthchecks$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Httpshealthchecks$Get, options: MethodOptions | BodyResponseCallback<Schema$HttpsHealthCheck>, callback: BodyResponseCallback<Schema$HttpsHealthCheck>): void;
        get(params: Params$Resource$Httpshealthchecks$Get, callback: BodyResponseCallback<Schema$HttpsHealthCheck>): void;
        get(callback: BodyResponseCallback<Schema$HttpsHealthCheck>): void;
        /**
         * Creates a HttpsHealthCheck resource in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Httpshealthchecks$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Httpshealthchecks$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Httpshealthchecks$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Httpshealthchecks$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Httpshealthchecks$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of HttpsHealthCheck resources available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Httpshealthchecks$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Httpshealthchecks$List, options?: MethodOptions): GaxiosPromise<Schema$HttpsHealthCheckList>;
        list(params: Params$Resource$Httpshealthchecks$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Httpshealthchecks$List, options: MethodOptions | BodyResponseCallback<Schema$HttpsHealthCheckList>, callback: BodyResponseCallback<Schema$HttpsHealthCheckList>): void;
        list(params: Params$Resource$Httpshealthchecks$List, callback: BodyResponseCallback<Schema$HttpsHealthCheckList>): void;
        list(callback: BodyResponseCallback<Schema$HttpsHealthCheckList>): void;
        /**
         * Updates a HttpsHealthCheck resource in the specified project using the data included in the request. This method supports PATCH semantics and uses the JSON merge patch format and processing rules.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Httpshealthchecks$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Httpshealthchecks$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Httpshealthchecks$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Httpshealthchecks$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Httpshealthchecks$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Httpshealthchecks$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Httpshealthchecks$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Httpshealthchecks$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Httpshealthchecks$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Httpshealthchecks$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        /**
         * Updates a HttpsHealthCheck resource in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        update(params: Params$Resource$Httpshealthchecks$Update, options: StreamMethodOptions): GaxiosPromise<Readable>;
        update(params?: Params$Resource$Httpshealthchecks$Update, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        update(params: Params$Resource$Httpshealthchecks$Update, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        update(params: Params$Resource$Httpshealthchecks$Update, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        update(params: Params$Resource$Httpshealthchecks$Update, callback: BodyResponseCallback<Schema$Operation>): void;
        update(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    export interface Params$Resource$Httpshealthchecks$Delete extends StandardParameters {
        /**
         * Name of the HttpsHealthCheck resource to delete.
         */
        httpsHealthCheck?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Httpshealthchecks$Get extends StandardParameters {
        /**
         * Name of the HttpsHealthCheck resource to return.
         */
        httpsHealthCheck?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    export interface Params$Resource$Httpshealthchecks$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$HttpsHealthCheck;
    }
    export interface Params$Resource$Httpshealthchecks$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Httpshealthchecks$Patch extends StandardParameters {
        /**
         * Name of the HttpsHealthCheck resource to patch.
         */
        httpsHealthCheck?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$HttpsHealthCheck;
    }
    export interface Params$Resource$Httpshealthchecks$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export interface Params$Resource$Httpshealthchecks$Update extends StandardParameters {
        /**
         * Name of the HttpsHealthCheck resource to update.
         */
        httpsHealthCheck?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$HttpsHealthCheck;
    }
    export class Resource$Imagefamilyviews {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Returns the latest image that is part of an image family, is not deprecated and is rolled out in the specified zone.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Imagefamilyviews$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Imagefamilyviews$Get, options?: MethodOptions): GaxiosPromise<Schema$ImageFamilyView>;
        get(params: Params$Resource$Imagefamilyviews$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Imagefamilyviews$Get, options: MethodOptions | BodyResponseCallback<Schema$ImageFamilyView>, callback: BodyResponseCallback<Schema$ImageFamilyView>): void;
        get(params: Params$Resource$Imagefamilyviews$Get, callback: BodyResponseCallback<Schema$ImageFamilyView>): void;
        get(callback: BodyResponseCallback<Schema$ImageFamilyView>): void;
    }
    export interface Params$Resource$Imagefamilyviews$Get extends StandardParameters {
        /**
         * Name of the image family to search for.
         */
        family?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export class Resource$Images {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Deletes the specified image.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Images$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Images$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Images$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Images$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Images$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the deprecation status of an image. If an empty request body is given, clears the deprecation status instead.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        deprecate(params: Params$Resource$Images$Deprecate, options: StreamMethodOptions): GaxiosPromise<Readable>;
        deprecate(params?: Params$Resource$Images$Deprecate, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        deprecate(params: Params$Resource$Images$Deprecate, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        deprecate(params: Params$Resource$Images$Deprecate, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        deprecate(params: Params$Resource$Images$Deprecate, callback: BodyResponseCallback<Schema$Operation>): void;
        deprecate(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified image.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Images$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Images$Get, options?: MethodOptions): GaxiosPromise<Schema$Image>;
        get(params: Params$Resource$Images$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Images$Get, options: MethodOptions | BodyResponseCallback<Schema$Image>, callback: BodyResponseCallback<Schema$Image>): void;
        get(params: Params$Resource$Images$Get, callback: BodyResponseCallback<Schema$Image>): void;
        get(callback: BodyResponseCallback<Schema$Image>): void;
        /**
         * Returns the latest image that is part of an image family and is not deprecated. For more information on image families, see Public image families documentation.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getFromFamily(params: Params$Resource$Images$Getfromfamily, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getFromFamily(params?: Params$Resource$Images$Getfromfamily, options?: MethodOptions): GaxiosPromise<Schema$Image>;
        getFromFamily(params: Params$Resource$Images$Getfromfamily, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getFromFamily(params: Params$Resource$Images$Getfromfamily, options: MethodOptions | BodyResponseCallback<Schema$Image>, callback: BodyResponseCallback<Schema$Image>): void;
        getFromFamily(params: Params$Resource$Images$Getfromfamily, callback: BodyResponseCallback<Schema$Image>): void;
        getFromFamily(callback: BodyResponseCallback<Schema$Image>): void;
        /**
         * Gets the access control policy for a resource. May be empty if no such policy or resource exists.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getIamPolicy(params: Params$Resource$Images$Getiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getIamPolicy(params?: Params$Resource$Images$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        getIamPolicy(params: Params$Resource$Images$Getiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getIamPolicy(params: Params$Resource$Images$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(params: Params$Resource$Images$Getiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Creates an image in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Images$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Images$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Images$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Images$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Images$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of custom images available to the specified project. Custom images are images you create that belong to your project. This method does not get any images that belong to other projects, including publicly-available images, like Debian 8. If you want to get a list of publicly-available images, use this method to make a request to the respective image project, such as debian-cloud or windows-cloud.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Images$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Images$List, options?: MethodOptions): GaxiosPromise<Schema$ImageList>;
        list(params: Params$Resource$Images$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Images$List, options: MethodOptions | BodyResponseCallback<Schema$ImageList>, callback: BodyResponseCallback<Schema$ImageList>): void;
        list(params: Params$Resource$Images$List, callback: BodyResponseCallback<Schema$ImageList>): void;
        list(callback: BodyResponseCallback<Schema$ImageList>): void;
        /**
         * Patches the specified image with the data included in the request. Only the following fields can be modified: family, description, deprecation status.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Images$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Images$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Images$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Images$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Images$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the access control policy on the specified resource. Replaces any existing policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setIamPolicy(params: Params$Resource$Images$Setiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setIamPolicy(params?: Params$Resource$Images$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        setIamPolicy(params: Params$Resource$Images$Setiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setIamPolicy(params: Params$Resource$Images$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(params: Params$Resource$Images$Setiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Sets the labels on an image. To learn more about labels, read the Labeling Resources documentation.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setLabels(params: Params$Resource$Images$Setlabels, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setLabels(params?: Params$Resource$Images$Setlabels, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setLabels(params: Params$Resource$Images$Setlabels, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setLabels(params: Params$Resource$Images$Setlabels, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(params: Params$Resource$Images$Setlabels, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Images$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Images$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Images$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Images$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Images$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Images$Delete extends StandardParameters {
        /**
         * Name of the image resource to delete.
         */
        image?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Images$Deprecate extends StandardParameters {
        /**
         * Image name.
         */
        image?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$DeprecationStatus;
    }
    export interface Params$Resource$Images$Get extends StandardParameters {
        /**
         * Name of the image resource to return.
         */
        image?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    export interface Params$Resource$Images$Getfromfamily extends StandardParameters {
        /**
         * Name of the image family to search for.
         */
        family?: string;
        /**
         * The image project that the image belongs to. For example, to get a CentOS image, specify centos-cloud as the image project.
         */
        project?: string;
    }
    export interface Params$Resource$Images$Getiampolicy extends StandardParameters {
        /**
         * Requested IAM Policy version.
         */
        optionsRequestedPolicyVersion?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
    }
    export interface Params$Resource$Images$Insert extends StandardParameters {
        /**
         * Force image creation if true.
         */
        forceCreate?: boolean;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Image;
    }
    export interface Params$Resource$Images$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         * The zone query parameter.
         */
        zone?: string;
    }
    export interface Params$Resource$Images$Patch extends StandardParameters {
        /**
         * Name of the image resource to patch.
         */
        image?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Image;
    }
    export interface Params$Resource$Images$Setiampolicy extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GlobalSetPolicyRequest;
    }
    export interface Params$Resource$Images$Setlabels extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GlobalSetLabelsRequest;
    }
    export interface Params$Resource$Images$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Instancegroupmanagerresizerequests {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Cancels the specified resize request and removes it from the queue. Cancelled resize request does no longer wait for the resources to be provisioned. Cancel is only possible for requests that are accepted in the queue.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Instancegroupmanagerresizerequests$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Instancegroupmanagerresizerequests$Cancel, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        cancel(params: Params$Resource$Instancegroupmanagerresizerequests$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Instancegroupmanagerresizerequests$Cancel, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        cancel(params: Params$Resource$Instancegroupmanagerresizerequests$Cancel, callback: BodyResponseCallback<Schema$Operation>): void;
        cancel(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Deletes the specified, inactive resize request. Requests that are still active cannot be deleted. Deleting request does not delete instances that were provisioned previously.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Instancegroupmanagerresizerequests$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Instancegroupmanagerresizerequests$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Instancegroupmanagerresizerequests$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Instancegroupmanagerresizerequests$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Instancegroupmanagerresizerequests$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns all of the details about the specified resize request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Instancegroupmanagerresizerequests$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Instancegroupmanagerresizerequests$Get, options?: MethodOptions): GaxiosPromise<Schema$InstanceGroupManagerResizeRequest>;
        get(params: Params$Resource$Instancegroupmanagerresizerequests$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Instancegroupmanagerresizerequests$Get, options: MethodOptions | BodyResponseCallback<Schema$InstanceGroupManagerResizeRequest>, callback: BodyResponseCallback<Schema$InstanceGroupManagerResizeRequest>): void;
        get(params: Params$Resource$Instancegroupmanagerresizerequests$Get, callback: BodyResponseCallback<Schema$InstanceGroupManagerResizeRequest>): void;
        get(callback: BodyResponseCallback<Schema$InstanceGroupManagerResizeRequest>): void;
        /**
         * Creates a new resize request that starts provisioning VMs immediately or queues VM creation.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Instancegroupmanagerresizerequests$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Instancegroupmanagerresizerequests$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Instancegroupmanagerresizerequests$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Instancegroupmanagerresizerequests$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Instancegroupmanagerresizerequests$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves a list of resize requests that are contained in the managed instance group.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Instancegroupmanagerresizerequests$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Instancegroupmanagerresizerequests$List, options?: MethodOptions): GaxiosPromise<Schema$InstanceGroupManagerResizeRequestsListResponse>;
        list(params: Params$Resource$Instancegroupmanagerresizerequests$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Instancegroupmanagerresizerequests$List, options: MethodOptions | BodyResponseCallback<Schema$InstanceGroupManagerResizeRequestsListResponse>, callback: BodyResponseCallback<Schema$InstanceGroupManagerResizeRequestsListResponse>): void;
        list(params: Params$Resource$Instancegroupmanagerresizerequests$List, callback: BodyResponseCallback<Schema$InstanceGroupManagerResizeRequestsListResponse>): void;
        list(callback: BodyResponseCallback<Schema$InstanceGroupManagerResizeRequestsListResponse>): void;
    }
    export interface Params$Resource$Instancegroupmanagerresizerequests$Cancel extends StandardParameters {
        /**
         * The name of the managed instance group. The name should conform to RFC1035 or be a resource ID.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the resize request to cancel. The name should conform to RFC1035 or be a resource ID.
         */
        resizeRequest?: string;
        /**
         * The name of the zone where the managed instance group is located. The name should conform to RFC1035.
         */
        zone?: string;
    }
    export interface Params$Resource$Instancegroupmanagerresizerequests$Delete extends StandardParameters {
        /**
         * The name of the managed instance group. The name should conform to RFC1035 or be a resource ID.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the resize request to delete. The name should conform to RFC1035 or be a resource ID.
         */
        resizeRequest?: string;
        /**
         * The name of the zone where the managed instance group is located. The name should conform to RFC1035.
         */
        zone?: string;
    }
    export interface Params$Resource$Instancegroupmanagerresizerequests$Get extends StandardParameters {
        /**
         * The name of the managed instance group. Name should conform to RFC1035 or be a resource ID.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the resize request. Name should conform to RFC1035 or be a resource ID.
         */
        resizeRequest?: string;
        /**
         * Name of the href="/compute/docs/regions-zones/#available"\>zone scoping this request. Name should conform to RFC1035.
         */
        zone?: string;
    }
    export interface Params$Resource$Instancegroupmanagerresizerequests$Insert extends StandardParameters {
        /**
         * The name of the managed instance group to which the resize request will be added. Name should conform to RFC1035 or be a resource ID.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where the managed instance group is located and where the resize request will be created. Name should conform to RFC1035.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupManagerResizeRequest;
    }
    export interface Params$Resource$Instancegroupmanagerresizerequests$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The name of the managed instance group. The name should conform to RFC1035.
         */
        instanceGroupManager?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         * The name of the zone where the managed instance group is located. The name should conform to RFC1035.
         */
        zone?: string;
    }
    export class Resource$Instancegroupmanagers {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Flags the specified instances to be removed from the managed instance group. Abandoning an instance does not delete the instance, but it does remove the instance from any target pools that are applied by the managed instance group. This method reduces the targetSize of the managed instance group by the number of instances that you abandon. This operation is marked as DONE when the action is scheduled even if the instances have not yet been removed from the group. You must separately verify the status of the abandoning action with the listmanagedinstances method. If the group is part of a backend service that has enabled connection draining, it can take up to 60 seconds after the connection draining duration has elapsed before the VM instance is removed or deleted. You can specify a maximum of 1000 instances with this method per request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        abandonInstances(params: Params$Resource$Instancegroupmanagers$Abandoninstances, options: StreamMethodOptions): GaxiosPromise<Readable>;
        abandonInstances(params?: Params$Resource$Instancegroupmanagers$Abandoninstances, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        abandonInstances(params: Params$Resource$Instancegroupmanagers$Abandoninstances, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        abandonInstances(params: Params$Resource$Instancegroupmanagers$Abandoninstances, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        abandonInstances(params: Params$Resource$Instancegroupmanagers$Abandoninstances, callback: BodyResponseCallback<Schema$Operation>): void;
        abandonInstances(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of managed instance groups and groups them by zone.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Instancegroupmanagers$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Instancegroupmanagers$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$InstanceGroupManagerAggregatedList>;
        aggregatedList(params: Params$Resource$Instancegroupmanagers$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Instancegroupmanagers$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$InstanceGroupManagerAggregatedList>, callback: BodyResponseCallback<Schema$InstanceGroupManagerAggregatedList>): void;
        aggregatedList(params: Params$Resource$Instancegroupmanagers$Aggregatedlist, callback: BodyResponseCallback<Schema$InstanceGroupManagerAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$InstanceGroupManagerAggregatedList>): void;
        /**
         * Applies changes to selected instances on the managed instance group. This method can be used to apply new overrides and/or new versions.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        applyUpdatesToInstances(params: Params$Resource$Instancegroupmanagers$Applyupdatestoinstances, options: StreamMethodOptions): GaxiosPromise<Readable>;
        applyUpdatesToInstances(params?: Params$Resource$Instancegroupmanagers$Applyupdatestoinstances, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        applyUpdatesToInstances(params: Params$Resource$Instancegroupmanagers$Applyupdatestoinstances, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        applyUpdatesToInstances(params: Params$Resource$Instancegroupmanagers$Applyupdatestoinstances, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        applyUpdatesToInstances(params: Params$Resource$Instancegroupmanagers$Applyupdatestoinstances, callback: BodyResponseCallback<Schema$Operation>): void;
        applyUpdatesToInstances(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Creates instances with per-instance configurations in this managed instance group. Instances are created using the current instance template. The create instances operation is marked DONE if the createInstances request is successful. The underlying actions take additional time. You must separately verify the status of the creating or actions with the listmanagedinstances method.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        createInstances(params: Params$Resource$Instancegroupmanagers$Createinstances, options: StreamMethodOptions): GaxiosPromise<Readable>;
        createInstances(params?: Params$Resource$Instancegroupmanagers$Createinstances, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        createInstances(params: Params$Resource$Instancegroupmanagers$Createinstances, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        createInstances(params: Params$Resource$Instancegroupmanagers$Createinstances, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        createInstances(params: Params$Resource$Instancegroupmanagers$Createinstances, callback: BodyResponseCallback<Schema$Operation>): void;
        createInstances(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Deletes the specified managed instance group and all of the instances in that group. Note that the instance group must not belong to a backend service. Read Deleting an instance group for more information.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Instancegroupmanagers$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Instancegroupmanagers$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Instancegroupmanagers$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Instancegroupmanagers$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Instancegroupmanagers$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Flags the specified instances in the managed instance group for immediate deletion. The instances are also removed from any target pools of which they were a member. This method reduces the targetSize of the managed instance group by the number of instances that you delete. This operation is marked as DONE when the action is scheduled even if the instances are still being deleted. You must separately verify the status of the deleting action with the listmanagedinstances method. If the group is part of a backend service that has enabled connection draining, it can take up to 60 seconds after the connection draining duration has elapsed before the VM instance is removed or deleted. You can specify a maximum of 1000 instances with this method per request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        deleteInstances(params: Params$Resource$Instancegroupmanagers$Deleteinstances, options: StreamMethodOptions): GaxiosPromise<Readable>;
        deleteInstances(params?: Params$Resource$Instancegroupmanagers$Deleteinstances, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        deleteInstances(params: Params$Resource$Instancegroupmanagers$Deleteinstances, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        deleteInstances(params: Params$Resource$Instancegroupmanagers$Deleteinstances, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        deleteInstances(params: Params$Resource$Instancegroupmanagers$Deleteinstances, callback: BodyResponseCallback<Schema$Operation>): void;
        deleteInstances(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Deletes selected per-instance configurations for the managed instance group.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        deletePerInstanceConfigs(params: Params$Resource$Instancegroupmanagers$Deleteperinstanceconfigs, options: StreamMethodOptions): GaxiosPromise<Readable>;
        deletePerInstanceConfigs(params?: Params$Resource$Instancegroupmanagers$Deleteperinstanceconfigs, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        deletePerInstanceConfigs(params: Params$Resource$Instancegroupmanagers$Deleteperinstanceconfigs, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        deletePerInstanceConfigs(params: Params$Resource$Instancegroupmanagers$Deleteperinstanceconfigs, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        deletePerInstanceConfigs(params: Params$Resource$Instancegroupmanagers$Deleteperinstanceconfigs, callback: BodyResponseCallback<Schema$Operation>): void;
        deletePerInstanceConfigs(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns all of the details about the specified managed instance group.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Instancegroupmanagers$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Instancegroupmanagers$Get, options?: MethodOptions): GaxiosPromise<Schema$InstanceGroupManager>;
        get(params: Params$Resource$Instancegroupmanagers$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Instancegroupmanagers$Get, options: MethodOptions | BodyResponseCallback<Schema$InstanceGroupManager>, callback: BodyResponseCallback<Schema$InstanceGroupManager>): void;
        get(params: Params$Resource$Instancegroupmanagers$Get, callback: BodyResponseCallback<Schema$InstanceGroupManager>): void;
        get(callback: BodyResponseCallback<Schema$InstanceGroupManager>): void;
        /**
         * Creates a managed instance group using the information that you specify in the request. After the group is created, instances in the group are created using the specified instance template. This operation is marked as DONE when the group is created even if the instances in the group have not yet been created. You must separately verify the status of the individual instances with the listmanagedinstances method. A managed instance group can have up to 1000 VM instances per group. Please contact Cloud Support if you need an increase in this limit.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Instancegroupmanagers$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Instancegroupmanagers$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Instancegroupmanagers$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Instancegroupmanagers$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Instancegroupmanagers$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves a list of managed instance groups that are contained within the specified project and zone.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Instancegroupmanagers$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Instancegroupmanagers$List, options?: MethodOptions): GaxiosPromise<Schema$InstanceGroupManagerList>;
        list(params: Params$Resource$Instancegroupmanagers$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Instancegroupmanagers$List, options: MethodOptions | BodyResponseCallback<Schema$InstanceGroupManagerList>, callback: BodyResponseCallback<Schema$InstanceGroupManagerList>): void;
        list(params: Params$Resource$Instancegroupmanagers$List, callback: BodyResponseCallback<Schema$InstanceGroupManagerList>): void;
        list(callback: BodyResponseCallback<Schema$InstanceGroupManagerList>): void;
        /**
         * Lists all errors thrown by actions on instances for a given managed instance group. The filter and orderBy query parameters are not supported.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        listErrors(params: Params$Resource$Instancegroupmanagers$Listerrors, options: StreamMethodOptions): GaxiosPromise<Readable>;
        listErrors(params?: Params$Resource$Instancegroupmanagers$Listerrors, options?: MethodOptions): GaxiosPromise<Schema$InstanceGroupManagersListErrorsResponse>;
        listErrors(params: Params$Resource$Instancegroupmanagers$Listerrors, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        listErrors(params: Params$Resource$Instancegroupmanagers$Listerrors, options: MethodOptions | BodyResponseCallback<Schema$InstanceGroupManagersListErrorsResponse>, callback: BodyResponseCallback<Schema$InstanceGroupManagersListErrorsResponse>): void;
        listErrors(params: Params$Resource$Instancegroupmanagers$Listerrors, callback: BodyResponseCallback<Schema$InstanceGroupManagersListErrorsResponse>): void;
        listErrors(callback: BodyResponseCallback<Schema$InstanceGroupManagersListErrorsResponse>): void;
        /**
         * Lists all of the instances in the managed instance group. Each instance in the list has a currentAction, which indicates the action that the managed instance group is performing on the instance. For example, if the group is still creating an instance, the currentAction is CREATING. If a previous action failed, the list displays the errors for that failed action. The orderBy query parameter is not supported. The `pageToken` query parameter is supported only in the alpha and beta API and only if the group's `listManagedInstancesResults` field is set to `PAGINATED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        listManagedInstances(params: Params$Resource$Instancegroupmanagers$Listmanagedinstances, options: StreamMethodOptions): GaxiosPromise<Readable>;
        listManagedInstances(params?: Params$Resource$Instancegroupmanagers$Listmanagedinstances, options?: MethodOptions): GaxiosPromise<Schema$InstanceGroupManagersListManagedInstancesResponse>;
        listManagedInstances(params: Params$Resource$Instancegroupmanagers$Listmanagedinstances, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        listManagedInstances(params: Params$Resource$Instancegroupmanagers$Listmanagedinstances, options: MethodOptions | BodyResponseCallback<Schema$InstanceGroupManagersListManagedInstancesResponse>, callback: BodyResponseCallback<Schema$InstanceGroupManagersListManagedInstancesResponse>): void;
        listManagedInstances(params: Params$Resource$Instancegroupmanagers$Listmanagedinstances, callback: BodyResponseCallback<Schema$InstanceGroupManagersListManagedInstancesResponse>): void;
        listManagedInstances(callback: BodyResponseCallback<Schema$InstanceGroupManagersListManagedInstancesResponse>): void;
        /**
         * Lists all of the per-instance configurations defined for the managed instance group. The orderBy query parameter is not supported.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        listPerInstanceConfigs(params: Params$Resource$Instancegroupmanagers$Listperinstanceconfigs, options: StreamMethodOptions): GaxiosPromise<Readable>;
        listPerInstanceConfigs(params?: Params$Resource$Instancegroupmanagers$Listperinstanceconfigs, options?: MethodOptions): GaxiosPromise<Schema$InstanceGroupManagersListPerInstanceConfigsResp>;
        listPerInstanceConfigs(params: Params$Resource$Instancegroupmanagers$Listperinstanceconfigs, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        listPerInstanceConfigs(params: Params$Resource$Instancegroupmanagers$Listperinstanceconfigs, options: MethodOptions | BodyResponseCallback<Schema$InstanceGroupManagersListPerInstanceConfigsResp>, callback: BodyResponseCallback<Schema$InstanceGroupManagersListPerInstanceConfigsResp>): void;
        listPerInstanceConfigs(params: Params$Resource$Instancegroupmanagers$Listperinstanceconfigs, callback: BodyResponseCallback<Schema$InstanceGroupManagersListPerInstanceConfigsResp>): void;
        listPerInstanceConfigs(callback: BodyResponseCallback<Schema$InstanceGroupManagersListPerInstanceConfigsResp>): void;
        /**
         * Updates a managed instance group using the information that you specify in the request. This operation is marked as DONE when the group is patched even if the instances in the group are still in the process of being patched. You must separately verify the status of the individual instances with the listManagedInstances method. This method supports PATCH semantics and uses the JSON merge patch format and processing rules. If you update your group to specify a new template or instance configuration, it's possible that your intended specification for each VM in the group is different from the current state of that VM. To learn how to apply an updated configuration to the VMs in a MIG, see Updating instances in a MIG.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Instancegroupmanagers$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Instancegroupmanagers$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Instancegroupmanagers$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Instancegroupmanagers$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Instancegroupmanagers$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Inserts or patches per-instance configurations for the managed instance group. perInstanceConfig.name serves as a key used to distinguish whether to perform insert or patch.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patchPerInstanceConfigs(params: Params$Resource$Instancegroupmanagers$Patchperinstanceconfigs, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patchPerInstanceConfigs(params?: Params$Resource$Instancegroupmanagers$Patchperinstanceconfigs, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patchPerInstanceConfigs(params: Params$Resource$Instancegroupmanagers$Patchperinstanceconfigs, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patchPerInstanceConfigs(params: Params$Resource$Instancegroupmanagers$Patchperinstanceconfigs, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patchPerInstanceConfigs(params: Params$Resource$Instancegroupmanagers$Patchperinstanceconfigs, callback: BodyResponseCallback<Schema$Operation>): void;
        patchPerInstanceConfigs(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Flags the specified VM instances in the managed instance group to be immediately recreated. Each instance is recreated using the group's current configuration. This operation is marked as DONE when the flag is set even if the instances have not yet been recreated. You must separately verify the status of each instance by checking its currentAction field; for more information, see Checking the status of managed instances. If the group is part of a backend service that has enabled connection draining, it can take up to 60 seconds after the connection draining duration has elapsed before the VM instance is removed or deleted. You can specify a maximum of 1000 instances with this method per request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        recreateInstances(params: Params$Resource$Instancegroupmanagers$Recreateinstances, options: StreamMethodOptions): GaxiosPromise<Readable>;
        recreateInstances(params?: Params$Resource$Instancegroupmanagers$Recreateinstances, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        recreateInstances(params: Params$Resource$Instancegroupmanagers$Recreateinstances, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        recreateInstances(params: Params$Resource$Instancegroupmanagers$Recreateinstances, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        recreateInstances(params: Params$Resource$Instancegroupmanagers$Recreateinstances, callback: BodyResponseCallback<Schema$Operation>): void;
        recreateInstances(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Resizes the managed instance group. If you increase the size, the group creates new instances using the current instance template. If you decrease the size, the group deletes instances. The resize operation is marked DONE when the resize actions are scheduled even if the group has not yet added or deleted any instances. You must separately verify the status of the creating or deleting actions with the listmanagedinstances method. When resizing down, the instance group arbitrarily chooses the order in which VMs are deleted. The group takes into account some VM attributes when making the selection including: + The status of the VM instance. + The health of the VM instance. + The instance template version the VM is based on. + For regional managed instance groups, the location of the VM instance. This list is subject to change. If the group is part of a backend service that has enabled connection draining, it can take up to 60 seconds after the connection draining duration has elapsed before the VM instance is removed or deleted.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        resize(params: Params$Resource$Instancegroupmanagers$Resize, options: StreamMethodOptions): GaxiosPromise<Readable>;
        resize(params?: Params$Resource$Instancegroupmanagers$Resize, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        resize(params: Params$Resource$Instancegroupmanagers$Resize, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        resize(params: Params$Resource$Instancegroupmanagers$Resize, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        resize(params: Params$Resource$Instancegroupmanagers$Resize, callback: BodyResponseCallback<Schema$Operation>): void;
        resize(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Resizes the managed instance group with advanced configuration options like disabling creation retries. This is an extended version of the resize method. If you increase the size of the instance group, the group creates new instances using the current instance template. If you decrease the size, the group deletes instances. The resize operation is marked DONE when the resize actions are scheduled even if the group has not yet added or deleted any instances. You must separately verify the status of the creating, creatingWithoutRetries, or deleting actions with the get or listmanagedinstances method. If the group is part of a backend service that has enabled connection draining, it can take up to 60 seconds after the connection draining duration has elapsed before the VM instance is removed or deleted.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        resizeAdvanced(params: Params$Resource$Instancegroupmanagers$Resizeadvanced, options: StreamMethodOptions): GaxiosPromise<Readable>;
        resizeAdvanced(params?: Params$Resource$Instancegroupmanagers$Resizeadvanced, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        resizeAdvanced(params: Params$Resource$Instancegroupmanagers$Resizeadvanced, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        resizeAdvanced(params: Params$Resource$Instancegroupmanagers$Resizeadvanced, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        resizeAdvanced(params: Params$Resource$Instancegroupmanagers$Resizeadvanced, callback: BodyResponseCallback<Schema$Operation>): void;
        resizeAdvanced(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Flags the specified instances in the managed instance group to be resumed. This method increases the targetSize and decreases the targetSuspendedSize of the managed instance group by the number of instances that you resume. The resumeInstances operation is marked DONE if the resumeInstances request is successful. The underlying actions take additional time. You must separately verify the status of the RESUMING action with the listmanagedinstances method. In this request, you can only specify instances that are suspended. For example, if an instance was previously suspended using the suspendInstances method, it can be resumed using the resumeInstances method. If a health check is attached to the managed instance group, the specified instances will be verified as healthy after they are resumed. You can specify a maximum of 1000 instances with this method per request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        resumeInstances(params: Params$Resource$Instancegroupmanagers$Resumeinstances, options: StreamMethodOptions): GaxiosPromise<Readable>;
        resumeInstances(params?: Params$Resource$Instancegroupmanagers$Resumeinstances, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        resumeInstances(params: Params$Resource$Instancegroupmanagers$Resumeinstances, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        resumeInstances(params: Params$Resource$Instancegroupmanagers$Resumeinstances, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        resumeInstances(params: Params$Resource$Instancegroupmanagers$Resumeinstances, callback: BodyResponseCallback<Schema$Operation>): void;
        resumeInstances(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Motifies the autohealing policy for the instances in this managed instance group. [Deprecated] This method is deprecated. Use instanceGroupManagers.patch instead.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setAutoHealingPolicies(params: Params$Resource$Instancegroupmanagers$Setautohealingpolicies, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setAutoHealingPolicies(params?: Params$Resource$Instancegroupmanagers$Setautohealingpolicies, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setAutoHealingPolicies(params: Params$Resource$Instancegroupmanagers$Setautohealingpolicies, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setAutoHealingPolicies(params: Params$Resource$Instancegroupmanagers$Setautohealingpolicies, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setAutoHealingPolicies(params: Params$Resource$Instancegroupmanagers$Setautohealingpolicies, callback: BodyResponseCallback<Schema$Operation>): void;
        setAutoHealingPolicies(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Specifies the instance template to use when creating new instances in this group. The templates for existing instances in the group do not change unless you run recreateInstances, run applyUpdatesToInstances, or set the group's updatePolicy.type to PROACTIVE.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setInstanceTemplate(params: Params$Resource$Instancegroupmanagers$Setinstancetemplate, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setInstanceTemplate(params?: Params$Resource$Instancegroupmanagers$Setinstancetemplate, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setInstanceTemplate(params: Params$Resource$Instancegroupmanagers$Setinstancetemplate, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setInstanceTemplate(params: Params$Resource$Instancegroupmanagers$Setinstancetemplate, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setInstanceTemplate(params: Params$Resource$Instancegroupmanagers$Setinstancetemplate, callback: BodyResponseCallback<Schema$Operation>): void;
        setInstanceTemplate(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Modifies the target pools to which all instances in this managed instance group are assigned. The target pools automatically apply to all of the instances in the managed instance group. This operation is marked DONE when you make the request even if the instances have not yet been added to their target pools. The change might take some time to apply to all of the instances in the group depending on the size of the group.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setTargetPools(params: Params$Resource$Instancegroupmanagers$Settargetpools, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setTargetPools(params?: Params$Resource$Instancegroupmanagers$Settargetpools, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setTargetPools(params: Params$Resource$Instancegroupmanagers$Settargetpools, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setTargetPools(params: Params$Resource$Instancegroupmanagers$Settargetpools, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setTargetPools(params: Params$Resource$Instancegroupmanagers$Settargetpools, callback: BodyResponseCallback<Schema$Operation>): void;
        setTargetPools(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Flags the specified instances in the managed instance group to be started. This method increases the targetSize and decreases the targetStoppedSize of the managed instance group by the number of instances that you start. The startInstances operation is marked DONE if the startInstances request is successful. The underlying actions take additional time. You must separately verify the status of the STARTING action with the listmanagedinstances method. In this request, you can only specify instances that are stopped. For example, if an instance was previously stopped using the stopInstances method, it can be started using the startInstances method. If a health check is attached to the managed instance group, the specified instances will be verified as healthy after they are started. You can specify a maximum of 1000 instances with this method per request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        startInstances(params: Params$Resource$Instancegroupmanagers$Startinstances, options: StreamMethodOptions): GaxiosPromise<Readable>;
        startInstances(params?: Params$Resource$Instancegroupmanagers$Startinstances, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        startInstances(params: Params$Resource$Instancegroupmanagers$Startinstances, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        startInstances(params: Params$Resource$Instancegroupmanagers$Startinstances, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        startInstances(params: Params$Resource$Instancegroupmanagers$Startinstances, callback: BodyResponseCallback<Schema$Operation>): void;
        startInstances(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Flags the specified instances in the managed instance group to be immediately stopped. You can only specify instances that are running in this request. This method reduces the targetSize and increases the targetStoppedSize of the managed instance group by the number of instances that you stop. The stopInstances operation is marked DONE if the stopInstances request is successful. The underlying actions take additional time. You must separately verify the status of the STOPPING action with the listmanagedinstances method. If the standbyPolicy.initialDelaySec field is set, the group delays stopping the instances until initialDelaySec have passed from instance.creationTimestamp (that is, when the instance was created). This delay gives your application time to set itself up and initialize on the instance. If more than initialDelaySec seconds have passed since instance.creationTimestamp when this method is called, there will be zero delay. If the group is part of a backend service that has enabled connection draining, it can take up to 60 seconds after the connection draining duration has elapsed before the VM instance is stopped. Stopped instances can be started using the startInstances method. You can specify a maximum of 1000 instances with this method per request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        stopInstances(params: Params$Resource$Instancegroupmanagers$Stopinstances, options: StreamMethodOptions): GaxiosPromise<Readable>;
        stopInstances(params?: Params$Resource$Instancegroupmanagers$Stopinstances, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        stopInstances(params: Params$Resource$Instancegroupmanagers$Stopinstances, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        stopInstances(params: Params$Resource$Instancegroupmanagers$Stopinstances, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        stopInstances(params: Params$Resource$Instancegroupmanagers$Stopinstances, callback: BodyResponseCallback<Schema$Operation>): void;
        stopInstances(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Flags the specified instances in the managed instance group to be immediately suspended. You can only specify instances that are running in this request. This method reduces the targetSize and increases the targetSuspendedSize of the managed instance group by the number of instances that you suspend. The suspendInstances operation is marked DONE if the suspendInstances request is successful. The underlying actions take additional time. You must separately verify the status of the SUSPENDING action with the listmanagedinstances method. If the standbyPolicy.initialDelaySec field is set, the group delays suspension of the instances until initialDelaySec have passed from instance.creationTimestamp (that is, when the instance was created). This delay gives your application time to set itself up and initialize on the instance. If more than initialDelaySec seconds have passed since instance.creationTimestamp when this method is called, there will be zero delay. If the group is part of a backend service that has enabled connection draining, it can take up to 60 seconds after the connection draining duration has elapsed before the VM instance is suspended. Suspended instances can be resumed using the resumeInstances method. You can specify a maximum of 1000 instances with this method per request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        suspendInstances(params: Params$Resource$Instancegroupmanagers$Suspendinstances, options: StreamMethodOptions): GaxiosPromise<Readable>;
        suspendInstances(params?: Params$Resource$Instancegroupmanagers$Suspendinstances, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        suspendInstances(params: Params$Resource$Instancegroupmanagers$Suspendinstances, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        suspendInstances(params: Params$Resource$Instancegroupmanagers$Suspendinstances, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        suspendInstances(params: Params$Resource$Instancegroupmanagers$Suspendinstances, callback: BodyResponseCallback<Schema$Operation>): void;
        suspendInstances(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Instancegroupmanagers$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Instancegroupmanagers$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Instancegroupmanagers$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Instancegroupmanagers$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Instancegroupmanagers$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        /**
         * Updates a managed instance group using the information that you specify in the request. This operation is marked as DONE when the group is updated even if the instances in the group have not yet been updated. You must separately verify the status of the individual instances with the listManagedInstances method. If you update your group to specify a new template or instance configuration, it's possible that your intended specification for each VM in the group is different from the current state of that VM. To learn how to apply an updated configuration to the VMs in a MIG, see Updating instances in a MIG.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        update(params: Params$Resource$Instancegroupmanagers$Update, options: StreamMethodOptions): GaxiosPromise<Readable>;
        update(params?: Params$Resource$Instancegroupmanagers$Update, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        update(params: Params$Resource$Instancegroupmanagers$Update, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        update(params: Params$Resource$Instancegroupmanagers$Update, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        update(params: Params$Resource$Instancegroupmanagers$Update, callback: BodyResponseCallback<Schema$Operation>): void;
        update(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Inserts or updates per-instance configurations for the managed instance group. perInstanceConfig.name serves as a key used to distinguish whether to perform insert or patch.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        updatePerInstanceConfigs(params: Params$Resource$Instancegroupmanagers$Updateperinstanceconfigs, options: StreamMethodOptions): GaxiosPromise<Readable>;
        updatePerInstanceConfigs(params?: Params$Resource$Instancegroupmanagers$Updateperinstanceconfigs, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        updatePerInstanceConfigs(params: Params$Resource$Instancegroupmanagers$Updateperinstanceconfigs, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        updatePerInstanceConfigs(params: Params$Resource$Instancegroupmanagers$Updateperinstanceconfigs, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        updatePerInstanceConfigs(params: Params$Resource$Instancegroupmanagers$Updateperinstanceconfigs, callback: BodyResponseCallback<Schema$Operation>): void;
        updatePerInstanceConfigs(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    export interface Params$Resource$Instancegroupmanagers$Abandoninstances extends StandardParameters {
        /**
         * The name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where the managed instance group is located.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupManagersAbandonInstancesRequest;
    }
    export interface Params$Resource$Instancegroupmanagers$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Instancegroupmanagers$Applyupdatestoinstances extends StandardParameters {
        /**
         * The name of the managed instance group, should conform to RFC1035.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone where the managed instance group is located. Should conform to RFC1035.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupManagersApplyUpdatesRequest;
    }
    export interface Params$Resource$Instancegroupmanagers$Createinstances extends StandardParameters {
        /**
         * The name of the managed instance group. It should conform to RFC1035.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where the managed instance group is located. It should conform to RFC1035.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupManagersCreateInstancesRequest;
    }
    export interface Params$Resource$Instancegroupmanagers$Delete extends StandardParameters {
        /**
         * The name of the managed instance group to delete.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where the managed instance group is located.
         */
        zone?: string;
    }
    export interface Params$Resource$Instancegroupmanagers$Deleteinstances extends StandardParameters {
        /**
         * The name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where the managed instance group is located.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupManagersDeleteInstancesRequest;
    }
    export interface Params$Resource$Instancegroupmanagers$Deleteperinstanceconfigs extends StandardParameters {
        /**
         * The name of the managed instance group. It should conform to RFC1035.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone where the managed instance group is located. It should conform to RFC1035.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupManagersDeletePerInstanceConfigsReq;
    }
    export interface Params$Resource$Instancegroupmanagers$Get extends StandardParameters {
        /**
         * The name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone where the managed instance group is located.
         */
        zone?: string;
    }
    export interface Params$Resource$Instancegroupmanagers$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where you want to create the managed instance group.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupManager;
    }
    export interface Params$Resource$Instancegroupmanagers$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         * The name of the zone where the managed instance group is located.
         */
        zone?: string;
    }
    export interface Params$Resource$Instancegroupmanagers$Listerrors extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The name of the managed instance group. It must be a string that meets the requirements in RFC1035, or an unsigned long integer: must match regexp pattern: (?:[a-z](?:[-a-z0-9]{0,61\}[a-z0-9])?)|1-9{0,19\}.
         */
        instanceGroupManager?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         * The name of the zone where the managed instance group is located. It should conform to RFC1035.
         */
        zone?: string;
    }
    export interface Params$Resource$Instancegroupmanagers$Listmanagedinstances extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         * The name of the zone where the managed instance group is located.
         */
        zone?: string;
    }
    export interface Params$Resource$Instancegroupmanagers$Listperinstanceconfigs extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The name of the managed instance group. It should conform to RFC1035.
         */
        instanceGroupManager?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         * The name of the zone where the managed instance group is located. It should conform to RFC1035.
         */
        zone?: string;
    }
    export interface Params$Resource$Instancegroupmanagers$Patch extends StandardParameters {
        /**
         * The name of the instance group manager.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where you want to create the managed instance group.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupManager;
    }
    export interface Params$Resource$Instancegroupmanagers$Patchperinstanceconfigs extends StandardParameters {
        /**
         * The name of the managed instance group. It should conform to RFC1035.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where the managed instance group is located. It should conform to RFC1035.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupManagersPatchPerInstanceConfigsReq;
    }
    export interface Params$Resource$Instancegroupmanagers$Recreateinstances extends StandardParameters {
        /**
         * The name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where the managed instance group is located.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupManagersRecreateInstancesRequest;
    }
    export interface Params$Resource$Instancegroupmanagers$Resize extends StandardParameters {
        /**
         * The name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The number of running instances that the managed instance group should maintain at any given time. The group automatically adds or removes instances to maintain the number of instances specified by this parameter.
         */
        size?: number;
        /**
         * The name of the zone where the managed instance group is located.
         */
        zone?: string;
    }
    export interface Params$Resource$Instancegroupmanagers$Resizeadvanced extends StandardParameters {
        /**
         * The name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where the managed instance group is located.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupManagersResizeAdvancedRequest;
    }
    export interface Params$Resource$Instancegroupmanagers$Resumeinstances extends StandardParameters {
        /**
         * The name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where the managed instance group is located.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupManagersResumeInstancesRequest;
    }
    export interface Params$Resource$Instancegroupmanagers$Setautohealingpolicies extends StandardParameters {
        /**
         * The name of the instance group manager.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where the managed instance group is located.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupManagersSetAutoHealingRequest;
    }
    export interface Params$Resource$Instancegroupmanagers$Setinstancetemplate extends StandardParameters {
        /**
         * The name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where the managed instance group is located.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupManagersSetInstanceTemplateRequest;
    }
    export interface Params$Resource$Instancegroupmanagers$Settargetpools extends StandardParameters {
        /**
         * The name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where the managed instance group is located.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupManagersSetTargetPoolsRequest;
    }
    export interface Params$Resource$Instancegroupmanagers$Startinstances extends StandardParameters {
        /**
         * The name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where the managed instance group is located.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupManagersStartInstancesRequest;
    }
    export interface Params$Resource$Instancegroupmanagers$Stopinstances extends StandardParameters {
        /**
         * The name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where the managed instance group is located.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupManagersStopInstancesRequest;
    }
    export interface Params$Resource$Instancegroupmanagers$Suspendinstances extends StandardParameters {
        /**
         * The name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where the managed instance group is located.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupManagersSuspendInstancesRequest;
    }
    export interface Params$Resource$Instancegroupmanagers$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export interface Params$Resource$Instancegroupmanagers$Update extends StandardParameters {
        /**
         * The name of the instance group manager.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where you want to create the managed instance group.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupManager;
    }
    export interface Params$Resource$Instancegroupmanagers$Updateperinstanceconfigs extends StandardParameters {
        /**
         * The name of the managed instance group. It should conform to RFC1035.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where the managed instance group is located. It should conform to RFC1035.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupManagersUpdatePerInstanceConfigsReq;
    }
    export class Resource$Instancegroups {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Adds a list of instances to the specified instance group. All of the instances in the instance group must be in the same network/subnetwork. Read Adding instances for more information.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        addInstances(params: Params$Resource$Instancegroups$Addinstances, options: StreamMethodOptions): GaxiosPromise<Readable>;
        addInstances(params?: Params$Resource$Instancegroups$Addinstances, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        addInstances(params: Params$Resource$Instancegroups$Addinstances, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        addInstances(params: Params$Resource$Instancegroups$Addinstances, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        addInstances(params: Params$Resource$Instancegroups$Addinstances, callback: BodyResponseCallback<Schema$Operation>): void;
        addInstances(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of instance groups and sorts them by zone.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Instancegroups$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Instancegroups$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$InstanceGroupAggregatedList>;
        aggregatedList(params: Params$Resource$Instancegroups$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Instancegroups$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$InstanceGroupAggregatedList>, callback: BodyResponseCallback<Schema$InstanceGroupAggregatedList>): void;
        aggregatedList(params: Params$Resource$Instancegroups$Aggregatedlist, callback: BodyResponseCallback<Schema$InstanceGroupAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$InstanceGroupAggregatedList>): void;
        /**
         * Deletes the specified instance group. The instances in the group are not deleted. Note that instance group must not belong to a backend service. Read Deleting an instance group for more information.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Instancegroups$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Instancegroups$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Instancegroups$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Instancegroups$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Instancegroups$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified zonal instance group. Get a list of available zonal instance groups by making a list() request. For managed instance groups, use the instanceGroupManagers or regionInstanceGroupManagers methods instead.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Instancegroups$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Instancegroups$Get, options?: MethodOptions): GaxiosPromise<Schema$InstanceGroup>;
        get(params: Params$Resource$Instancegroups$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Instancegroups$Get, options: MethodOptions | BodyResponseCallback<Schema$InstanceGroup>, callback: BodyResponseCallback<Schema$InstanceGroup>): void;
        get(params: Params$Resource$Instancegroups$Get, callback: BodyResponseCallback<Schema$InstanceGroup>): void;
        get(callback: BodyResponseCallback<Schema$InstanceGroup>): void;
        /**
         * Creates an instance group in the specified project using the parameters that are included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Instancegroups$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Instancegroups$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Instancegroups$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Instancegroups$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Instancegroups$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of zonal instance group resources contained within the specified zone. For managed instance groups, use the instanceGroupManagers or regionInstanceGroupManagers methods instead.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Instancegroups$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Instancegroups$List, options?: MethodOptions): GaxiosPromise<Schema$InstanceGroupList>;
        list(params: Params$Resource$Instancegroups$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Instancegroups$List, options: MethodOptions | BodyResponseCallback<Schema$InstanceGroupList>, callback: BodyResponseCallback<Schema$InstanceGroupList>): void;
        list(params: Params$Resource$Instancegroups$List, callback: BodyResponseCallback<Schema$InstanceGroupList>): void;
        list(callback: BodyResponseCallback<Schema$InstanceGroupList>): void;
        /**
         * Lists the instances in the specified instance group. The orderBy query parameter is not supported. The filter query parameter is supported, but only for expressions that use `eq` (equal) or `ne` (not equal) operators.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        listInstances(params: Params$Resource$Instancegroups$Listinstances, options: StreamMethodOptions): GaxiosPromise<Readable>;
        listInstances(params?: Params$Resource$Instancegroups$Listinstances, options?: MethodOptions): GaxiosPromise<Schema$InstanceGroupsListInstances>;
        listInstances(params: Params$Resource$Instancegroups$Listinstances, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        listInstances(params: Params$Resource$Instancegroups$Listinstances, options: MethodOptions | BodyResponseCallback<Schema$InstanceGroupsListInstances>, callback: BodyResponseCallback<Schema$InstanceGroupsListInstances>): void;
        listInstances(params: Params$Resource$Instancegroups$Listinstances, callback: BodyResponseCallback<Schema$InstanceGroupsListInstances>): void;
        listInstances(callback: BodyResponseCallback<Schema$InstanceGroupsListInstances>): void;
        /**
         * Removes one or more instances from the specified instance group, but does not delete those instances. If the group is part of a backend service that has enabled connection draining, it can take up to 60 seconds after the connection draining duration before the VM instance is removed or deleted.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        removeInstances(params: Params$Resource$Instancegroups$Removeinstances, options: StreamMethodOptions): GaxiosPromise<Readable>;
        removeInstances(params?: Params$Resource$Instancegroups$Removeinstances, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        removeInstances(params: Params$Resource$Instancegroups$Removeinstances, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        removeInstances(params: Params$Resource$Instancegroups$Removeinstances, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        removeInstances(params: Params$Resource$Instancegroups$Removeinstances, callback: BodyResponseCallback<Schema$Operation>): void;
        removeInstances(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the named ports for the specified instance group.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setNamedPorts(params: Params$Resource$Instancegroups$Setnamedports, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setNamedPorts(params?: Params$Resource$Instancegroups$Setnamedports, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setNamedPorts(params: Params$Resource$Instancegroups$Setnamedports, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setNamedPorts(params: Params$Resource$Instancegroups$Setnamedports, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setNamedPorts(params: Params$Resource$Instancegroups$Setnamedports, callback: BodyResponseCallback<Schema$Operation>): void;
        setNamedPorts(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Instancegroups$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Instancegroups$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Instancegroups$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Instancegroups$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Instancegroups$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Instancegroups$Addinstances extends StandardParameters {
        /**
         * The name of the instance group where you are adding instances.
         */
        instanceGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where the instance group is located.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupsAddInstancesRequest;
    }
    export interface Params$Resource$Instancegroups$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Instancegroups$Delete extends StandardParameters {
        /**
         * The name of the instance group to delete.
         */
        instanceGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where the instance group is located.
         */
        zone?: string;
    }
    export interface Params$Resource$Instancegroups$Get extends StandardParameters {
        /**
         * The name of the instance group.
         */
        instanceGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone where the instance group is located.
         */
        zone?: string;
    }
    export interface Params$Resource$Instancegroups$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where you want to create the instance group.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroup;
    }
    export interface Params$Resource$Instancegroups$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         * The name of the zone where the instance group is located.
         */
        zone?: string;
    }
    export interface Params$Resource$Instancegroups$Listinstances extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The name of the instance group from which you want to generate a list of included instances.
         */
        instanceGroup?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         * The name of the zone where the instance group is located.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupsListInstancesRequest;
    }
    export interface Params$Resource$Instancegroups$Removeinstances extends StandardParameters {
        /**
         * The name of the instance group where the specified instances will be removed.
         */
        instanceGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where the instance group is located.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupsRemoveInstancesRequest;
    }
    export interface Params$Resource$Instancegroups$Setnamedports extends StandardParameters {
        /**
         * The name of the instance group where the named ports are updated.
         */
        instanceGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where the instance group is located.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupsSetNamedPortsRequest;
    }
    export interface Params$Resource$Instancegroups$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Instances {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Adds an access config to an instance's network interface.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        addAccessConfig(params: Params$Resource$Instances$Addaccessconfig, options: StreamMethodOptions): GaxiosPromise<Readable>;
        addAccessConfig(params?: Params$Resource$Instances$Addaccessconfig, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        addAccessConfig(params: Params$Resource$Instances$Addaccessconfig, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        addAccessConfig(params: Params$Resource$Instances$Addaccessconfig, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        addAccessConfig(params: Params$Resource$Instances$Addaccessconfig, callback: BodyResponseCallback<Schema$Operation>): void;
        addAccessConfig(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Adds existing resource policies to an instance. You can only add one policy right now which will be applied to this instance for scheduling live migrations.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        addResourcePolicies(params: Params$Resource$Instances$Addresourcepolicies, options: StreamMethodOptions): GaxiosPromise<Readable>;
        addResourcePolicies(params?: Params$Resource$Instances$Addresourcepolicies, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        addResourcePolicies(params: Params$Resource$Instances$Addresourcepolicies, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        addResourcePolicies(params: Params$Resource$Instances$Addresourcepolicies, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        addResourcePolicies(params: Params$Resource$Instances$Addresourcepolicies, callback: BodyResponseCallback<Schema$Operation>): void;
        addResourcePolicies(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves an aggregated list of all of the instances in your project across all regions and zones. The performance of this method degrades when a filter is specified on a project that has a very large number of instances.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Instances$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Instances$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$InstanceAggregatedList>;
        aggregatedList(params: Params$Resource$Instances$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Instances$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$InstanceAggregatedList>, callback: BodyResponseCallback<Schema$InstanceAggregatedList>): void;
        aggregatedList(params: Params$Resource$Instances$Aggregatedlist, callback: BodyResponseCallback<Schema$InstanceAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$InstanceAggregatedList>): void;
        /**
         * Attaches an existing Disk resource to an instance. You must first create the disk before you can attach it. It is not possible to create and attach a disk at the same time. For more information, read Adding a persistent disk to your instance.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        attachDisk(params: Params$Resource$Instances$Attachdisk, options: StreamMethodOptions): GaxiosPromise<Readable>;
        attachDisk(params?: Params$Resource$Instances$Attachdisk, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        attachDisk(params: Params$Resource$Instances$Attachdisk, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        attachDisk(params: Params$Resource$Instances$Attachdisk, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        attachDisk(params: Params$Resource$Instances$Attachdisk, callback: BodyResponseCallback<Schema$Operation>): void;
        attachDisk(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Creates multiple instances. Count specifies the number of instances to create. For more information, see About bulk creation of VMs.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        bulkInsert(params: Params$Resource$Instances$Bulkinsert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        bulkInsert(params?: Params$Resource$Instances$Bulkinsert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        bulkInsert(params: Params$Resource$Instances$Bulkinsert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        bulkInsert(params: Params$Resource$Instances$Bulkinsert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        bulkInsert(params: Params$Resource$Instances$Bulkinsert, callback: BodyResponseCallback<Schema$Operation>): void;
        bulkInsert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Deletes the specified Instance resource. For more information, see Deleting an instance.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Instances$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Instances$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Instances$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Instances$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Instances$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Deletes an access config from an instance's network interface.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        deleteAccessConfig(params: Params$Resource$Instances$Deleteaccessconfig, options: StreamMethodOptions): GaxiosPromise<Readable>;
        deleteAccessConfig(params?: Params$Resource$Instances$Deleteaccessconfig, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        deleteAccessConfig(params: Params$Resource$Instances$Deleteaccessconfig, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        deleteAccessConfig(params: Params$Resource$Instances$Deleteaccessconfig, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        deleteAccessConfig(params: Params$Resource$Instances$Deleteaccessconfig, callback: BodyResponseCallback<Schema$Operation>): void;
        deleteAccessConfig(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Detaches a disk from an instance.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        detachDisk(params: Params$Resource$Instances$Detachdisk, options: StreamMethodOptions): GaxiosPromise<Readable>;
        detachDisk(params?: Params$Resource$Instances$Detachdisk, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        detachDisk(params: Params$Resource$Instances$Detachdisk, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        detachDisk(params: Params$Resource$Instances$Detachdisk, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        detachDisk(params: Params$Resource$Instances$Detachdisk, callback: BodyResponseCallback<Schema$Operation>): void;
        detachDisk(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified Instance resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Instances$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Instances$Get, options?: MethodOptions): GaxiosPromise<Schema$Instance>;
        get(params: Params$Resource$Instances$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Instances$Get, options: MethodOptions | BodyResponseCallback<Schema$Instance>, callback: BodyResponseCallback<Schema$Instance>): void;
        get(params: Params$Resource$Instances$Get, callback: BodyResponseCallback<Schema$Instance>): void;
        get(callback: BodyResponseCallback<Schema$Instance>): void;
        /**
         * Returns effective firewalls applied to an interface of the instance.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getEffectiveFirewalls(params: Params$Resource$Instances$Geteffectivefirewalls, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getEffectiveFirewalls(params?: Params$Resource$Instances$Geteffectivefirewalls, options?: MethodOptions): GaxiosPromise<Schema$InstancesGetEffectiveFirewallsResponse>;
        getEffectiveFirewalls(params: Params$Resource$Instances$Geteffectivefirewalls, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getEffectiveFirewalls(params: Params$Resource$Instances$Geteffectivefirewalls, options: MethodOptions | BodyResponseCallback<Schema$InstancesGetEffectiveFirewallsResponse>, callback: BodyResponseCallback<Schema$InstancesGetEffectiveFirewallsResponse>): void;
        getEffectiveFirewalls(params: Params$Resource$Instances$Geteffectivefirewalls, callback: BodyResponseCallback<Schema$InstancesGetEffectiveFirewallsResponse>): void;
        getEffectiveFirewalls(callback: BodyResponseCallback<Schema$InstancesGetEffectiveFirewallsResponse>): void;
        /**
         * Returns the specified guest attributes entry.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getGuestAttributes(params: Params$Resource$Instances$Getguestattributes, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getGuestAttributes(params?: Params$Resource$Instances$Getguestattributes, options?: MethodOptions): GaxiosPromise<Schema$GuestAttributes>;
        getGuestAttributes(params: Params$Resource$Instances$Getguestattributes, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getGuestAttributes(params: Params$Resource$Instances$Getguestattributes, options: MethodOptions | BodyResponseCallback<Schema$GuestAttributes>, callback: BodyResponseCallback<Schema$GuestAttributes>): void;
        getGuestAttributes(params: Params$Resource$Instances$Getguestattributes, callback: BodyResponseCallback<Schema$GuestAttributes>): void;
        getGuestAttributes(callback: BodyResponseCallback<Schema$GuestAttributes>): void;
        /**
         * Gets the access control policy for a resource. May be empty if no such policy or resource exists.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getIamPolicy(params: Params$Resource$Instances$Getiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getIamPolicy(params?: Params$Resource$Instances$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        getIamPolicy(params: Params$Resource$Instances$Getiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getIamPolicy(params: Params$Resource$Instances$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(params: Params$Resource$Instances$Getiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Gets partner metadata of the specified instance and namespaces.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getPartnerMetadata(params: Params$Resource$Instances$Getpartnermetadata, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getPartnerMetadata(params?: Params$Resource$Instances$Getpartnermetadata, options?: MethodOptions): GaxiosPromise<Schema$PartnerMetadata>;
        getPartnerMetadata(params: Params$Resource$Instances$Getpartnermetadata, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getPartnerMetadata(params: Params$Resource$Instances$Getpartnermetadata, options: MethodOptions | BodyResponseCallback<Schema$PartnerMetadata>, callback: BodyResponseCallback<Schema$PartnerMetadata>): void;
        getPartnerMetadata(params: Params$Resource$Instances$Getpartnermetadata, callback: BodyResponseCallback<Schema$PartnerMetadata>): void;
        getPartnerMetadata(callback: BodyResponseCallback<Schema$PartnerMetadata>): void;
        /**
         * Returns the screenshot from the specified instance.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getScreenshot(params: Params$Resource$Instances$Getscreenshot, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getScreenshot(params?: Params$Resource$Instances$Getscreenshot, options?: MethodOptions): GaxiosPromise<Schema$Screenshot>;
        getScreenshot(params: Params$Resource$Instances$Getscreenshot, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getScreenshot(params: Params$Resource$Instances$Getscreenshot, options: MethodOptions | BodyResponseCallback<Schema$Screenshot>, callback: BodyResponseCallback<Schema$Screenshot>): void;
        getScreenshot(params: Params$Resource$Instances$Getscreenshot, callback: BodyResponseCallback<Schema$Screenshot>): void;
        getScreenshot(callback: BodyResponseCallback<Schema$Screenshot>): void;
        /**
         * Returns the last 1 MB of serial port output from the specified instance.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getSerialPortOutput(params: Params$Resource$Instances$Getserialportoutput, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getSerialPortOutput(params?: Params$Resource$Instances$Getserialportoutput, options?: MethodOptions): GaxiosPromise<Schema$SerialPortOutput>;
        getSerialPortOutput(params: Params$Resource$Instances$Getserialportoutput, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getSerialPortOutput(params: Params$Resource$Instances$Getserialportoutput, options: MethodOptions | BodyResponseCallback<Schema$SerialPortOutput>, callback: BodyResponseCallback<Schema$SerialPortOutput>): void;
        getSerialPortOutput(params: Params$Resource$Instances$Getserialportoutput, callback: BodyResponseCallback<Schema$SerialPortOutput>): void;
        getSerialPortOutput(callback: BodyResponseCallback<Schema$SerialPortOutput>): void;
        /**
         * Returns the Shielded Instance Identity of an instance
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getShieldedInstanceIdentity(params: Params$Resource$Instances$Getshieldedinstanceidentity, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getShieldedInstanceIdentity(params?: Params$Resource$Instances$Getshieldedinstanceidentity, options?: MethodOptions): GaxiosPromise<Schema$ShieldedInstanceIdentity>;
        getShieldedInstanceIdentity(params: Params$Resource$Instances$Getshieldedinstanceidentity, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getShieldedInstanceIdentity(params: Params$Resource$Instances$Getshieldedinstanceidentity, options: MethodOptions | BodyResponseCallback<Schema$ShieldedInstanceIdentity>, callback: BodyResponseCallback<Schema$ShieldedInstanceIdentity>): void;
        getShieldedInstanceIdentity(params: Params$Resource$Instances$Getshieldedinstanceidentity, callback: BodyResponseCallback<Schema$ShieldedInstanceIdentity>): void;
        getShieldedInstanceIdentity(callback: BodyResponseCallback<Schema$ShieldedInstanceIdentity>): void;
        /**
         * Returns the Shielded VM Identity of an instance
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getShieldedVmIdentity(params: Params$Resource$Instances$Getshieldedvmidentity, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getShieldedVmIdentity(params?: Params$Resource$Instances$Getshieldedvmidentity, options?: MethodOptions): GaxiosPromise<Schema$ShieldedVmIdentity>;
        getShieldedVmIdentity(params: Params$Resource$Instances$Getshieldedvmidentity, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getShieldedVmIdentity(params: Params$Resource$Instances$Getshieldedvmidentity, options: MethodOptions | BodyResponseCallback<Schema$ShieldedVmIdentity>, callback: BodyResponseCallback<Schema$ShieldedVmIdentity>): void;
        getShieldedVmIdentity(params: Params$Resource$Instances$Getshieldedvmidentity, callback: BodyResponseCallback<Schema$ShieldedVmIdentity>): void;
        getShieldedVmIdentity(callback: BodyResponseCallback<Schema$ShieldedVmIdentity>): void;
        /**
         * Creates an instance resource in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Instances$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Instances$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Instances$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Instances$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Instances$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of instances contained within the specified zone.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Instances$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Instances$List, options?: MethodOptions): GaxiosPromise<Schema$InstanceList>;
        list(params: Params$Resource$Instances$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Instances$List, options: MethodOptions | BodyResponseCallback<Schema$InstanceList>, callback: BodyResponseCallback<Schema$InstanceList>): void;
        list(params: Params$Resource$Instances$List, callback: BodyResponseCallback<Schema$InstanceList>): void;
        list(callback: BodyResponseCallback<Schema$InstanceList>): void;
        /**
         * Retrieves a list of resources that refer to the VM instance specified in the request. For example, if the VM instance is part of a managed or unmanaged instance group, the referrers list includes the instance group. For more information, read Viewing referrers to VM instances.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        listReferrers(params: Params$Resource$Instances$Listreferrers, options: StreamMethodOptions): GaxiosPromise<Readable>;
        listReferrers(params?: Params$Resource$Instances$Listreferrers, options?: MethodOptions): GaxiosPromise<Schema$InstanceListReferrers>;
        listReferrers(params: Params$Resource$Instances$Listreferrers, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        listReferrers(params: Params$Resource$Instances$Listreferrers, options: MethodOptions | BodyResponseCallback<Schema$InstanceListReferrers>, callback: BodyResponseCallback<Schema$InstanceListReferrers>): void;
        listReferrers(params: Params$Resource$Instances$Listreferrers, callback: BodyResponseCallback<Schema$InstanceListReferrers>): void;
        listReferrers(callback: BodyResponseCallback<Schema$InstanceListReferrers>): void;
        /**
         * Patches partner metadata of the specified instance.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patchPartnerMetadata(params: Params$Resource$Instances$Patchpartnermetadata, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patchPartnerMetadata(params?: Params$Resource$Instances$Patchpartnermetadata, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patchPartnerMetadata(params: Params$Resource$Instances$Patchpartnermetadata, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patchPartnerMetadata(params: Params$Resource$Instances$Patchpartnermetadata, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patchPartnerMetadata(params: Params$Resource$Instances$Patchpartnermetadata, callback: BodyResponseCallback<Schema$Operation>): void;
        patchPartnerMetadata(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Perform a manual maintenance on the instance.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        performMaintenance(params: Params$Resource$Instances$Performmaintenance, options: StreamMethodOptions): GaxiosPromise<Readable>;
        performMaintenance(params?: Params$Resource$Instances$Performmaintenance, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        performMaintenance(params: Params$Resource$Instances$Performmaintenance, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        performMaintenance(params: Params$Resource$Instances$Performmaintenance, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        performMaintenance(params: Params$Resource$Instances$Performmaintenance, callback: BodyResponseCallback<Schema$Operation>): void;
        performMaintenance(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Removes resource policies from an instance.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        removeResourcePolicies(params: Params$Resource$Instances$Removeresourcepolicies, options: StreamMethodOptions): GaxiosPromise<Readable>;
        removeResourcePolicies(params?: Params$Resource$Instances$Removeresourcepolicies, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        removeResourcePolicies(params: Params$Resource$Instances$Removeresourcepolicies, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        removeResourcePolicies(params: Params$Resource$Instances$Removeresourcepolicies, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        removeResourcePolicies(params: Params$Resource$Instances$Removeresourcepolicies, callback: BodyResponseCallback<Schema$Operation>): void;
        removeResourcePolicies(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Performs a reset on the instance. This is a hard reset. The VM does not do a graceful shutdown. For more information, see Resetting an instance.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        reset(params: Params$Resource$Instances$Reset, options: StreamMethodOptions): GaxiosPromise<Readable>;
        reset(params?: Params$Resource$Instances$Reset, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        reset(params: Params$Resource$Instances$Reset, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        reset(params: Params$Resource$Instances$Reset, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        reset(params: Params$Resource$Instances$Reset, callback: BodyResponseCallback<Schema$Operation>): void;
        reset(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Resumes an instance that was suspended using the instances().suspend method.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        resume(params: Params$Resource$Instances$Resume, options: StreamMethodOptions): GaxiosPromise<Readable>;
        resume(params?: Params$Resource$Instances$Resume, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        resume(params: Params$Resource$Instances$Resume, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        resume(params: Params$Resource$Instances$Resume, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        resume(params: Params$Resource$Instances$Resume, callback: BodyResponseCallback<Schema$Operation>): void;
        resume(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sends diagnostic interrupt to the instance.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        sendDiagnosticInterrupt(params: Params$Resource$Instances$Senddiagnosticinterrupt, options: StreamMethodOptions): GaxiosPromise<Readable>;
        sendDiagnosticInterrupt(params?: Params$Resource$Instances$Senddiagnosticinterrupt, options?: MethodOptions): GaxiosPromise<void>;
        sendDiagnosticInterrupt(params: Params$Resource$Instances$Senddiagnosticinterrupt, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        sendDiagnosticInterrupt(params: Params$Resource$Instances$Senddiagnosticinterrupt, options: MethodOptions | BodyResponseCallback<void>, callback: BodyResponseCallback<void>): void;
        sendDiagnosticInterrupt(params: Params$Resource$Instances$Senddiagnosticinterrupt, callback: BodyResponseCallback<void>): void;
        sendDiagnosticInterrupt(callback: BodyResponseCallback<void>): void;
        /**
         * Sets deletion protection on the instance.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setDeletionProtection(params: Params$Resource$Instances$Setdeletionprotection, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setDeletionProtection(params?: Params$Resource$Instances$Setdeletionprotection, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setDeletionProtection(params: Params$Resource$Instances$Setdeletionprotection, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setDeletionProtection(params: Params$Resource$Instances$Setdeletionprotection, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setDeletionProtection(params: Params$Resource$Instances$Setdeletionprotection, callback: BodyResponseCallback<Schema$Operation>): void;
        setDeletionProtection(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the auto-delete flag for a disk attached to an instance.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setDiskAutoDelete(params: Params$Resource$Instances$Setdiskautodelete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setDiskAutoDelete(params?: Params$Resource$Instances$Setdiskautodelete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setDiskAutoDelete(params: Params$Resource$Instances$Setdiskautodelete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setDiskAutoDelete(params: Params$Resource$Instances$Setdiskautodelete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setDiskAutoDelete(params: Params$Resource$Instances$Setdiskautodelete, callback: BodyResponseCallback<Schema$Operation>): void;
        setDiskAutoDelete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the access control policy on the specified resource. Replaces any existing policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setIamPolicy(params: Params$Resource$Instances$Setiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setIamPolicy(params?: Params$Resource$Instances$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        setIamPolicy(params: Params$Resource$Instances$Setiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setIamPolicy(params: Params$Resource$Instances$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(params: Params$Resource$Instances$Setiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Sets labels on an instance. To learn more about labels, read the Labeling Resources documentation.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setLabels(params: Params$Resource$Instances$Setlabels, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setLabels(params?: Params$Resource$Instances$Setlabels, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setLabels(params: Params$Resource$Instances$Setlabels, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setLabels(params: Params$Resource$Instances$Setlabels, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(params: Params$Resource$Instances$Setlabels, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Changes the number and/or type of accelerator for a stopped instance to the values specified in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setMachineResources(params: Params$Resource$Instances$Setmachineresources, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setMachineResources(params?: Params$Resource$Instances$Setmachineresources, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setMachineResources(params: Params$Resource$Instances$Setmachineresources, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setMachineResources(params: Params$Resource$Instances$Setmachineresources, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setMachineResources(params: Params$Resource$Instances$Setmachineresources, callback: BodyResponseCallback<Schema$Operation>): void;
        setMachineResources(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Changes the machine type for a stopped instance to the machine type specified in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setMachineType(params: Params$Resource$Instances$Setmachinetype, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setMachineType(params?: Params$Resource$Instances$Setmachinetype, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setMachineType(params: Params$Resource$Instances$Setmachinetype, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setMachineType(params: Params$Resource$Instances$Setmachinetype, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setMachineType(params: Params$Resource$Instances$Setmachinetype, callback: BodyResponseCallback<Schema$Operation>): void;
        setMachineType(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets metadata for the specified instance to the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setMetadata(params: Params$Resource$Instances$Setmetadata, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setMetadata(params?: Params$Resource$Instances$Setmetadata, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setMetadata(params: Params$Resource$Instances$Setmetadata, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setMetadata(params: Params$Resource$Instances$Setmetadata, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setMetadata(params: Params$Resource$Instances$Setmetadata, callback: BodyResponseCallback<Schema$Operation>): void;
        setMetadata(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Changes the minimum CPU platform that this instance should use. This method can only be called on a stopped instance. For more information, read Specifying a Minimum CPU Platform.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setMinCpuPlatform(params: Params$Resource$Instances$Setmincpuplatform, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setMinCpuPlatform(params?: Params$Resource$Instances$Setmincpuplatform, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setMinCpuPlatform(params: Params$Resource$Instances$Setmincpuplatform, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setMinCpuPlatform(params: Params$Resource$Instances$Setmincpuplatform, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setMinCpuPlatform(params: Params$Resource$Instances$Setmincpuplatform, callback: BodyResponseCallback<Schema$Operation>): void;
        setMinCpuPlatform(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets name of an instance.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setName(params: Params$Resource$Instances$Setname, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setName(params?: Params$Resource$Instances$Setname, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setName(params: Params$Resource$Instances$Setname, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setName(params: Params$Resource$Instances$Setname, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setName(params: Params$Resource$Instances$Setname, callback: BodyResponseCallback<Schema$Operation>): void;
        setName(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets an instance's scheduling options. You can only call this method on a stopped instance, that is, a VM instance that is in a `TERMINATED` state. See Instance Life Cycle for more information on the possible instance states. For more information about setting scheduling options for a VM, see Set VM host maintenance policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setScheduling(params: Params$Resource$Instances$Setscheduling, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setScheduling(params?: Params$Resource$Instances$Setscheduling, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setScheduling(params: Params$Resource$Instances$Setscheduling, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setScheduling(params: Params$Resource$Instances$Setscheduling, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setScheduling(params: Params$Resource$Instances$Setscheduling, callback: BodyResponseCallback<Schema$Operation>): void;
        setScheduling(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the Google Cloud Armor security policy for the specified instance. For more information, see Google Cloud Armor Overview
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setSecurityPolicy(params: Params$Resource$Instances$Setsecuritypolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setSecurityPolicy(params?: Params$Resource$Instances$Setsecuritypolicy, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setSecurityPolicy(params: Params$Resource$Instances$Setsecuritypolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setSecurityPolicy(params: Params$Resource$Instances$Setsecuritypolicy, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setSecurityPolicy(params: Params$Resource$Instances$Setsecuritypolicy, callback: BodyResponseCallback<Schema$Operation>): void;
        setSecurityPolicy(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the service account on the instance. For more information, read Changing the service account and access scopes for an instance.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setServiceAccount(params: Params$Resource$Instances$Setserviceaccount, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setServiceAccount(params?: Params$Resource$Instances$Setserviceaccount, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setServiceAccount(params: Params$Resource$Instances$Setserviceaccount, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setServiceAccount(params: Params$Resource$Instances$Setserviceaccount, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setServiceAccount(params: Params$Resource$Instances$Setserviceaccount, callback: BodyResponseCallback<Schema$Operation>): void;
        setServiceAccount(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the Shielded Instance integrity policy for an instance. You can only use this method on a running instance. This method supports PATCH semantics and uses the JSON merge patch format and processing rules.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setShieldedInstanceIntegrityPolicy(params: Params$Resource$Instances$Setshieldedinstanceintegritypolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setShieldedInstanceIntegrityPolicy(params?: Params$Resource$Instances$Setshieldedinstanceintegritypolicy, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setShieldedInstanceIntegrityPolicy(params: Params$Resource$Instances$Setshieldedinstanceintegritypolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setShieldedInstanceIntegrityPolicy(params: Params$Resource$Instances$Setshieldedinstanceintegritypolicy, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setShieldedInstanceIntegrityPolicy(params: Params$Resource$Instances$Setshieldedinstanceintegritypolicy, callback: BodyResponseCallback<Schema$Operation>): void;
        setShieldedInstanceIntegrityPolicy(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the Shielded VM integrity policy for a VM instance. You can only use this method on a running VM instance. This method supports PATCH semantics and uses the JSON merge patch format and processing rules.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setShieldedVmIntegrityPolicy(params: Params$Resource$Instances$Setshieldedvmintegritypolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setShieldedVmIntegrityPolicy(params?: Params$Resource$Instances$Setshieldedvmintegritypolicy, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setShieldedVmIntegrityPolicy(params: Params$Resource$Instances$Setshieldedvmintegritypolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setShieldedVmIntegrityPolicy(params: Params$Resource$Instances$Setshieldedvmintegritypolicy, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setShieldedVmIntegrityPolicy(params: Params$Resource$Instances$Setshieldedvmintegritypolicy, callback: BodyResponseCallback<Schema$Operation>): void;
        setShieldedVmIntegrityPolicy(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets network tags for the specified instance to the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setTags(params: Params$Resource$Instances$Settags, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setTags(params?: Params$Resource$Instances$Settags, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setTags(params: Params$Resource$Instances$Settags, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setTags(params: Params$Resource$Instances$Settags, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setTags(params: Params$Resource$Instances$Settags, callback: BodyResponseCallback<Schema$Operation>): void;
        setTags(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Simulates a host maintenance event on a VM. For more information, see Simulate a host maintenance event.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        simulateMaintenanceEvent(params: Params$Resource$Instances$Simulatemaintenanceevent, options: StreamMethodOptions): GaxiosPromise<Readable>;
        simulateMaintenanceEvent(params?: Params$Resource$Instances$Simulatemaintenanceevent, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        simulateMaintenanceEvent(params: Params$Resource$Instances$Simulatemaintenanceevent, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        simulateMaintenanceEvent(params: Params$Resource$Instances$Simulatemaintenanceevent, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        simulateMaintenanceEvent(params: Params$Resource$Instances$Simulatemaintenanceevent, callback: BodyResponseCallback<Schema$Operation>): void;
        simulateMaintenanceEvent(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Starts an instance that was stopped using the instances().stop method. For more information, see Restart an instance.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        start(params: Params$Resource$Instances$Start, options: StreamMethodOptions): GaxiosPromise<Readable>;
        start(params?: Params$Resource$Instances$Start, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        start(params: Params$Resource$Instances$Start, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        start(params: Params$Resource$Instances$Start, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        start(params: Params$Resource$Instances$Start, callback: BodyResponseCallback<Schema$Operation>): void;
        start(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Starts an instance that was stopped using the instances().stop method. For more information, see Restart an instance.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        startWithEncryptionKey(params: Params$Resource$Instances$Startwithencryptionkey, options: StreamMethodOptions): GaxiosPromise<Readable>;
        startWithEncryptionKey(params?: Params$Resource$Instances$Startwithencryptionkey, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        startWithEncryptionKey(params: Params$Resource$Instances$Startwithencryptionkey, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        startWithEncryptionKey(params: Params$Resource$Instances$Startwithencryptionkey, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        startWithEncryptionKey(params: Params$Resource$Instances$Startwithencryptionkey, callback: BodyResponseCallback<Schema$Operation>): void;
        startWithEncryptionKey(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Stops a running instance, shutting it down cleanly, and allows you to restart the instance at a later time. Stopped instances do not incur VM usage charges while they are stopped. However, resources that the VM is using, such as persistent disks and static IP addresses, will continue to be charged until they are deleted. For more information, see Stopping an instance.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        stop(params: Params$Resource$Instances$Stop, options: StreamMethodOptions): GaxiosPromise<Readable>;
        stop(params?: Params$Resource$Instances$Stop, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        stop(params: Params$Resource$Instances$Stop, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        stop(params: Params$Resource$Instances$Stop, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        stop(params: Params$Resource$Instances$Stop, callback: BodyResponseCallback<Schema$Operation>): void;
        stop(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * This method suspends a running instance, saving its state to persistent storage, and allows you to resume the instance at a later time. Suspended instances have no compute costs (cores or RAM), and incur only storage charges for the saved VM memory and localSSD data. Any charged resources the virtual machine was using, such as persistent disks and static IP addresses, will continue to be charged while the instance is suspended. For more information, see Suspending and resuming an instance.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        suspend(params: Params$Resource$Instances$Suspend, options: StreamMethodOptions): GaxiosPromise<Readable>;
        suspend(params?: Params$Resource$Instances$Suspend, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        suspend(params: Params$Resource$Instances$Suspend, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        suspend(params: Params$Resource$Instances$Suspend, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        suspend(params: Params$Resource$Instances$Suspend, callback: BodyResponseCallback<Schema$Operation>): void;
        suspend(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Instances$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Instances$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Instances$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Instances$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Instances$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        /**
         * Updates an instance only if the necessary resources are available. This method can update only a specific set of instance properties. See Updating a running instance for a list of updatable instance properties.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        update(params: Params$Resource$Instances$Update, options: StreamMethodOptions): GaxiosPromise<Readable>;
        update(params?: Params$Resource$Instances$Update, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        update(params: Params$Resource$Instances$Update, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        update(params: Params$Resource$Instances$Update, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        update(params: Params$Resource$Instances$Update, callback: BodyResponseCallback<Schema$Operation>): void;
        update(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Updates the specified access config from an instance's network interface with the data included in the request. This method supports PATCH semantics and uses the JSON merge patch format and processing rules.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        updateAccessConfig(params: Params$Resource$Instances$Updateaccessconfig, options: StreamMethodOptions): GaxiosPromise<Readable>;
        updateAccessConfig(params?: Params$Resource$Instances$Updateaccessconfig, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        updateAccessConfig(params: Params$Resource$Instances$Updateaccessconfig, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        updateAccessConfig(params: Params$Resource$Instances$Updateaccessconfig, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        updateAccessConfig(params: Params$Resource$Instances$Updateaccessconfig, callback: BodyResponseCallback<Schema$Operation>): void;
        updateAccessConfig(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Updates the Display config for a VM instance. You can only use this method on a stopped VM instance. This method supports PATCH semantics and uses the JSON merge patch format and processing rules.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        updateDisplayDevice(params: Params$Resource$Instances$Updatedisplaydevice, options: StreamMethodOptions): GaxiosPromise<Readable>;
        updateDisplayDevice(params?: Params$Resource$Instances$Updatedisplaydevice, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        updateDisplayDevice(params: Params$Resource$Instances$Updatedisplaydevice, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        updateDisplayDevice(params: Params$Resource$Instances$Updatedisplaydevice, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        updateDisplayDevice(params: Params$Resource$Instances$Updatedisplaydevice, callback: BodyResponseCallback<Schema$Operation>): void;
        updateDisplayDevice(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Updates an instance's network interface. This method can only update an interface's alias IP range and attached network. See Modifying alias IP ranges for an existing instance for instructions on changing alias IP ranges. See Migrating a VM between networks for instructions on migrating an interface. This method follows PATCH semantics.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        updateNetworkInterface(params: Params$Resource$Instances$Updatenetworkinterface, options: StreamMethodOptions): GaxiosPromise<Readable>;
        updateNetworkInterface(params?: Params$Resource$Instances$Updatenetworkinterface, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        updateNetworkInterface(params: Params$Resource$Instances$Updatenetworkinterface, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        updateNetworkInterface(params: Params$Resource$Instances$Updatenetworkinterface, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        updateNetworkInterface(params: Params$Resource$Instances$Updatenetworkinterface, callback: BodyResponseCallback<Schema$Operation>): void;
        updateNetworkInterface(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Updates the Shielded Instance config for an instance. You can only use this method on a stopped instance. This method supports PATCH semantics and uses the JSON merge patch format and processing rules.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        updateShieldedInstanceConfig(params: Params$Resource$Instances$Updateshieldedinstanceconfig, options: StreamMethodOptions): GaxiosPromise<Readable>;
        updateShieldedInstanceConfig(params?: Params$Resource$Instances$Updateshieldedinstanceconfig, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        updateShieldedInstanceConfig(params: Params$Resource$Instances$Updateshieldedinstanceconfig, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        updateShieldedInstanceConfig(params: Params$Resource$Instances$Updateshieldedinstanceconfig, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        updateShieldedInstanceConfig(params: Params$Resource$Instances$Updateshieldedinstanceconfig, callback: BodyResponseCallback<Schema$Operation>): void;
        updateShieldedInstanceConfig(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Updates the Shielded VM config for a VM instance. You can only use this method on a stopped VM instance. This method supports PATCH semantics and uses the JSON merge patch format and processing rules.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        updateShieldedVmConfig(params: Params$Resource$Instances$Updateshieldedvmconfig, options: StreamMethodOptions): GaxiosPromise<Readable>;
        updateShieldedVmConfig(params?: Params$Resource$Instances$Updateshieldedvmconfig, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        updateShieldedVmConfig(params: Params$Resource$Instances$Updateshieldedvmconfig, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        updateShieldedVmConfig(params: Params$Resource$Instances$Updateshieldedvmconfig, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        updateShieldedVmConfig(params: Params$Resource$Instances$Updateshieldedvmconfig, callback: BodyResponseCallback<Schema$Operation>): void;
        updateShieldedVmConfig(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    export interface Params$Resource$Instances$Addaccessconfig extends StandardParameters {
        /**
         * The instance name for this request.
         */
        instance?: string;
        /**
         * The name of the network interface to add to this instance.
         */
        networkInterface?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$AccessConfig;
    }
    export interface Params$Resource$Instances$Addresourcepolicies extends StandardParameters {
        /**
         * The instance name for this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstancesAddResourcePoliciesRequest;
    }
    export interface Params$Resource$Instances$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Instances$Attachdisk extends StandardParameters {
        /**
         * Whether to force attach the regional disk even if it's currently attached to another instance. If you try to force attach a zonal disk to an instance, you will receive an error.
         */
        forceAttach?: boolean;
        /**
         * The instance name for this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$AttachedDisk;
    }
    export interface Params$Resource$Instances$Bulkinsert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$BulkInsertInstanceResource;
    }
    export interface Params$Resource$Instances$Delete extends StandardParameters {
        /**
         * Name of the instance resource to delete.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Instances$Deleteaccessconfig extends StandardParameters {
        /**
         * The name of the access config to delete.
         */
        accessConfig?: string;
        /**
         * The instance name for this request.
         */
        instance?: string;
        /**
         * The name of the network interface.
         */
        networkInterface?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Instances$Detachdisk extends StandardParameters {
        /**
         * The device name of the disk to detach. Make a get() request on the instance to view currently attached disks and device names.
         */
        deviceName?: string;
        /**
         * Instance name for this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Instances$Get extends StandardParameters {
        /**
         * Name of the instance resource to return.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * View of the instance.
         */
        view?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Instances$Geteffectivefirewalls extends StandardParameters {
        /**
         * Name of the instance scoping this request.
         */
        instance?: string;
        /**
         * The name of the network interface to get the effective firewalls.
         */
        networkInterface?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Instances$Getguestattributes extends StandardParameters {
        /**
         * Name of the instance scoping this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Specifies the guest attributes path to be queried.
         */
        queryPath?: string;
        /**
         * Specifies the key for the guest attributes entry.
         */
        variableKey?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Instances$Getiampolicy extends StandardParameters {
        /**
         * Requested IAM Policy version.
         */
        optionsRequestedPolicyVersion?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Instances$Getpartnermetadata extends StandardParameters {
        /**
         * Name of the instance scoping this request.
         */
        instance?: string;
        /**
         * Comma separated partner metadata namespaces.
         */
        namespaces?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Instances$Getscreenshot extends StandardParameters {
        /**
         * Name of the instance scoping this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Instances$Getserialportoutput extends StandardParameters {
        /**
         * Name of the instance for this request.
         */
        instance?: string;
        /**
         * Specifies which COM or serial port to retrieve data from.
         */
        port?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Specifies the starting byte position of the output to return. To start with the first byte of output to the specified port, omit this field or set it to `0`. If the output for that byte position is available, this field matches the `start` parameter sent with the request. If the amount of serial console output exceeds the size of the buffer (1 MB), the oldest output is discarded and is no longer available. If the requested start position refers to discarded output, the start position is adjusted to the oldest output still available, and the adjusted start position is returned as the `start` property value. You can also provide a negative start position, which translates to the most recent number of bytes written to the serial port. For example, -3 is interpreted as the most recent 3 bytes written to the serial console.
         */
        start?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Instances$Getshieldedinstanceidentity extends StandardParameters {
        /**
         * Name or id of the instance scoping this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Instances$Getshieldedvmidentity extends StandardParameters {
        /**
         * Name of the instance scoping this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Instances$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Specifies instance template to create the instance. This field is optional. It can be a full or partial URL. For example, the following are all valid URLs to an instance template: - https://www.googleapis.com/compute/v1/projects/project /global/instanceTemplates/instanceTemplate - projects/project/global/instanceTemplates/instanceTemplate - global/instanceTemplates/instanceTemplate
         */
        sourceInstanceTemplate?: string;
        /**
         * Specifies the machine image to use to create the instance. This field is optional. It can be a full or partial URL. For example, the following are all valid URLs to a machine image: - https://www.googleapis.com/compute/v1/projects/project/global/global /machineImages/machineImage - projects/project/global/global/machineImages/machineImage - global/machineImages/machineImage
         */
        sourceMachineImage?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Instance;
    }
    export interface Params$Resource$Instances$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         * View of the instance.
         */
        view?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Instances$Listreferrers extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Name of the target instance scoping this request, or '-' if the request should span over all instances in the container.
         */
        instance?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Instances$Patchpartnermetadata extends StandardParameters {
        /**
         * Name of the instance scoping this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$PartnerMetadata;
    }
    export interface Params$Resource$Instances$Performmaintenance extends StandardParameters {
        /**
         * Name of the instance scoping this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Instances$Removeresourcepolicies extends StandardParameters {
        /**
         * The instance name for this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstancesRemoveResourcePoliciesRequest;
    }
    export interface Params$Resource$Instances$Reset extends StandardParameters {
        /**
         * Name of the instance scoping this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Instances$Resume extends StandardParameters {
        /**
         * Name of the instance resource to resume.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstancesResumeRequest;
    }
    export interface Params$Resource$Instances$Senddiagnosticinterrupt extends StandardParameters {
        /**
         * Name of the instance scoping this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Instances$Setdeletionprotection extends StandardParameters {
        /**
         * Whether the resource should be protected against deletion.
         */
        deletionProtection?: boolean;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Instances$Setdiskautodelete extends StandardParameters {
        /**
         * Whether to auto-delete the disk when the instance is deleted.
         */
        autoDelete?: boolean;
        /**
         * The device name of the disk to modify. Make a get() request on the instance to view currently attached disks and device names.
         */
        deviceName?: string;
        /**
         * The instance name for this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Instances$Setiampolicy extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ZoneSetPolicyRequest;
    }
    export interface Params$Resource$Instances$Setlabels extends StandardParameters {
        /**
         * Name of the instance scoping this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstancesSetLabelsRequest;
    }
    export interface Params$Resource$Instances$Setmachineresources extends StandardParameters {
        /**
         * Name of the instance scoping this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstancesSetMachineResourcesRequest;
    }
    export interface Params$Resource$Instances$Setmachinetype extends StandardParameters {
        /**
         * Name of the instance scoping this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstancesSetMachineTypeRequest;
    }
    export interface Params$Resource$Instances$Setmetadata extends StandardParameters {
        /**
         * Name of the instance scoping this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Metadata;
    }
    export interface Params$Resource$Instances$Setmincpuplatform extends StandardParameters {
        /**
         * Name of the instance scoping this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstancesSetMinCpuPlatformRequest;
    }
    export interface Params$Resource$Instances$Setname extends StandardParameters {
        /**
         * The instance name for this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstancesSetNameRequest;
    }
    export interface Params$Resource$Instances$Setscheduling extends StandardParameters {
        /**
         * Instance name for this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Scheduling;
    }
    export interface Params$Resource$Instances$Setsecuritypolicy extends StandardParameters {
        /**
         * Name of the Instance resource to which the security policy should be set. The name should conform to RFC1035.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the zone scoping this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstancesSetSecurityPolicyRequest;
    }
    export interface Params$Resource$Instances$Setserviceaccount extends StandardParameters {
        /**
         * Name of the instance resource to start.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstancesSetServiceAccountRequest;
    }
    export interface Params$Resource$Instances$Setshieldedinstanceintegritypolicy extends StandardParameters {
        /**
         * Name or id of the instance scoping this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ShieldedInstanceIntegrityPolicy;
    }
    export interface Params$Resource$Instances$Setshieldedvmintegritypolicy extends StandardParameters {
        /**
         * Name of the instance scoping this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ShieldedVmIntegrityPolicy;
    }
    export interface Params$Resource$Instances$Settags extends StandardParameters {
        /**
         * Name of the instance scoping this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Tags;
    }
    export interface Params$Resource$Instances$Simulatemaintenanceevent extends StandardParameters {
        /**
         * Name of the instance scoping this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Determines whether the customers receive notifications before migration. Only applicable to SF vms.
         */
        withExtendedNotifications?: boolean;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Instances$Start extends StandardParameters {
        /**
         * Name of the instance resource to start.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Instances$Startwithencryptionkey extends StandardParameters {
        /**
         * Name of the instance resource to start.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstancesStartWithEncryptionKeyRequest;
    }
    export interface Params$Resource$Instances$Stop extends StandardParameters {
        /**
         * If true, discard the contents of any attached localSSD partitions. Default value is false.
         */
        discardLocalSsd?: boolean;
        /**
         * Name of the instance resource to stop.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Instances$Suspend extends StandardParameters {
        /**
         * If true, discard the contents of any attached localSSD partitions. Default value is false.
         */
        discardLocalSsd?: boolean;
        /**
         * Name of the instance resource to suspend.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Instances$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export interface Params$Resource$Instances$Update extends StandardParameters {
        /**
         * Whether to clear secure tags from the instance. This property if set to true will clear secure tags regardless of the resource.secure_tags.
         */
        clearSecureTag?: boolean;
        /**
         * Name of the instance resource to update.
         */
        instance?: string;
        /**
         * Specifies the action to take when updating an instance even if the updated properties do not require it. If not specified, then Compute Engine acts based on the minimum action that the updated properties require.
         */
        minimalAction?: string;
        /**
         * Specifies the most disruptive action that can be taken on the instance as part of the update. Compute Engine returns an error if the instance properties require a more disruptive action as part of the instance update. Valid options from lowest to highest are NO_EFFECT, REFRESH, and RESTART.
         */
        mostDisruptiveAllowedAction?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Instance;
    }
    export interface Params$Resource$Instances$Updateaccessconfig extends StandardParameters {
        /**
         * The instance name for this request.
         */
        instance?: string;
        /**
         * The name of the network interface where the access config is attached.
         */
        networkInterface?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$AccessConfig;
    }
    export interface Params$Resource$Instances$Updatedisplaydevice extends StandardParameters {
        /**
         * Name of the instance scoping this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$DisplayDevice;
    }
    export interface Params$Resource$Instances$Updatenetworkinterface extends StandardParameters {
        /**
         * The instance name for this request.
         */
        instance?: string;
        /**
         * The name of the network interface to update.
         */
        networkInterface?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$NetworkInterface;
    }
    export interface Params$Resource$Instances$Updateshieldedinstanceconfig extends StandardParameters {
        /**
         * Name or id of the instance scoping this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ShieldedInstanceConfig;
    }
    export interface Params$Resource$Instances$Updateshieldedvmconfig extends StandardParameters {
        /**
         * Name of the instance scoping this request.
         */
        instance?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ShieldedVmConfig;
    }
    export class Resource$Instancesettings {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Get Instance settings.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Instancesettings$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Instancesettings$Get, options?: MethodOptions): GaxiosPromise<Schema$InstanceSettings>;
        get(params: Params$Resource$Instancesettings$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Instancesettings$Get, options: MethodOptions | BodyResponseCallback<Schema$InstanceSettings>, callback: BodyResponseCallback<Schema$InstanceSettings>): void;
        get(params: Params$Resource$Instancesettings$Get, callback: BodyResponseCallback<Schema$InstanceSettings>): void;
        get(callback: BodyResponseCallback<Schema$InstanceSettings>): void;
        /**
         * Patch Instance settings
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Instancesettings$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Instancesettings$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Instancesettings$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Instancesettings$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Instancesettings$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    export interface Params$Resource$Instancesettings$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Instancesettings$Patch extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * update_mask indicates fields to be updated as part of this request.
         */
        updateMask?: string;
        /**
         * The zone scoping this request. It should conform to RFC1035.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceSettings;
    }
    export class Resource$Instancetemplates {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves the list of all InstanceTemplates resources, regional and global, available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Instancetemplates$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Instancetemplates$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$InstanceTemplateAggregatedList>;
        aggregatedList(params: Params$Resource$Instancetemplates$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Instancetemplates$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$InstanceTemplateAggregatedList>, callback: BodyResponseCallback<Schema$InstanceTemplateAggregatedList>): void;
        aggregatedList(params: Params$Resource$Instancetemplates$Aggregatedlist, callback: BodyResponseCallback<Schema$InstanceTemplateAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$InstanceTemplateAggregatedList>): void;
        /**
         * Deletes the specified instance template. Deleting an instance template is permanent and cannot be undone. It is not possible to delete templates that are already in use by a managed instance group.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Instancetemplates$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Instancetemplates$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Instancetemplates$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Instancetemplates$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Instancetemplates$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified instance template.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Instancetemplates$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Instancetemplates$Get, options?: MethodOptions): GaxiosPromise<Schema$InstanceTemplate>;
        get(params: Params$Resource$Instancetemplates$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Instancetemplates$Get, options: MethodOptions | BodyResponseCallback<Schema$InstanceTemplate>, callback: BodyResponseCallback<Schema$InstanceTemplate>): void;
        get(params: Params$Resource$Instancetemplates$Get, callback: BodyResponseCallback<Schema$InstanceTemplate>): void;
        get(callback: BodyResponseCallback<Schema$InstanceTemplate>): void;
        /**
         * Gets the access control policy for a resource. May be empty if no such policy or resource exists.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getIamPolicy(params: Params$Resource$Instancetemplates$Getiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getIamPolicy(params?: Params$Resource$Instancetemplates$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        getIamPolicy(params: Params$Resource$Instancetemplates$Getiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getIamPolicy(params: Params$Resource$Instancetemplates$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(params: Params$Resource$Instancetemplates$Getiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Creates an instance template in the specified project using the data that is included in the request. If you are creating a new template to update an existing instance group, your new instance template must use the same network or, if applicable, the same subnetwork as the original template.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Instancetemplates$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Instancetemplates$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Instancetemplates$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Instancetemplates$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Instancetemplates$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves a list of instance templates that are contained within the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Instancetemplates$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Instancetemplates$List, options?: MethodOptions): GaxiosPromise<Schema$InstanceTemplateList>;
        list(params: Params$Resource$Instancetemplates$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Instancetemplates$List, options: MethodOptions | BodyResponseCallback<Schema$InstanceTemplateList>, callback: BodyResponseCallback<Schema$InstanceTemplateList>): void;
        list(params: Params$Resource$Instancetemplates$List, callback: BodyResponseCallback<Schema$InstanceTemplateList>): void;
        list(callback: BodyResponseCallback<Schema$InstanceTemplateList>): void;
        /**
         * Sets the access control policy on the specified resource. Replaces any existing policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setIamPolicy(params: Params$Resource$Instancetemplates$Setiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setIamPolicy(params?: Params$Resource$Instancetemplates$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        setIamPolicy(params: Params$Resource$Instancetemplates$Setiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setIamPolicy(params: Params$Resource$Instancetemplates$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(params: Params$Resource$Instancetemplates$Setiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Instancetemplates$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Instancetemplates$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Instancetemplates$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Instancetemplates$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Instancetemplates$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Instancetemplates$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Name of the project scoping this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Instancetemplates$Delete extends StandardParameters {
        /**
         * The name of the instance template to delete.
         */
        instanceTemplate?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Instancetemplates$Get extends StandardParameters {
        /**
         * The name of the instance template.
         */
        instanceTemplate?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * View of the instance template.
         */
        view?: string;
    }
    export interface Params$Resource$Instancetemplates$Getiampolicy extends StandardParameters {
        /**
         * Requested IAM Policy version.
         */
        optionsRequestedPolicyVersion?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
    }
    export interface Params$Resource$Instancetemplates$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceTemplate;
    }
    export interface Params$Resource$Instancetemplates$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         * View of the instance template.
         */
        view?: string;
    }
    export interface Params$Resource$Instancetemplates$Setiampolicy extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GlobalSetPolicyRequest;
    }
    export interface Params$Resource$Instancetemplates$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Instantsnapshots {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves an aggregated list of instantSnapshots.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Instantsnapshots$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Instantsnapshots$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$InstantSnapshotAggregatedList>;
        aggregatedList(params: Params$Resource$Instantsnapshots$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Instantsnapshots$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$InstantSnapshotAggregatedList>, callback: BodyResponseCallback<Schema$InstantSnapshotAggregatedList>): void;
        aggregatedList(params: Params$Resource$Instantsnapshots$Aggregatedlist, callback: BodyResponseCallback<Schema$InstantSnapshotAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$InstantSnapshotAggregatedList>): void;
        /**
         * Deletes the specified InstantSnapshot resource. Keep in mind that deleting a single instantSnapshot might not necessarily delete all the data on that instantSnapshot. If any data on the instantSnapshot that is marked for deletion is needed for subsequent instantSnapshots, the data will be moved to the next corresponding instantSnapshot. For more information, see Deleting instantSnapshots.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Instantsnapshots$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Instantsnapshots$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Instantsnapshots$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Instantsnapshots$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Instantsnapshots$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Export the changed blocks between two instant snapshots to a customer's bucket in the user specified format.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        export(params: Params$Resource$Instantsnapshots$Export, options: StreamMethodOptions): GaxiosPromise<Readable>;
        export(params?: Params$Resource$Instantsnapshots$Export, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        export(params: Params$Resource$Instantsnapshots$Export, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        export(params: Params$Resource$Instantsnapshots$Export, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        export(params: Params$Resource$Instantsnapshots$Export, callback: BodyResponseCallback<Schema$Operation>): void;
        export(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified InstantSnapshot resource in the specified zone.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Instantsnapshots$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Instantsnapshots$Get, options?: MethodOptions): GaxiosPromise<Schema$InstantSnapshot>;
        get(params: Params$Resource$Instantsnapshots$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Instantsnapshots$Get, options: MethodOptions | BodyResponseCallback<Schema$InstantSnapshot>, callback: BodyResponseCallback<Schema$InstantSnapshot>): void;
        get(params: Params$Resource$Instantsnapshots$Get, callback: BodyResponseCallback<Schema$InstantSnapshot>): void;
        get(callback: BodyResponseCallback<Schema$InstantSnapshot>): void;
        /**
         * Gets the access control policy for a resource. May be empty if no such policy or resource exists.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getIamPolicy(params: Params$Resource$Instantsnapshots$Getiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getIamPolicy(params?: Params$Resource$Instantsnapshots$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        getIamPolicy(params: Params$Resource$Instantsnapshots$Getiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getIamPolicy(params: Params$Resource$Instantsnapshots$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(params: Params$Resource$Instantsnapshots$Getiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Creates an instant snapshot in the specified zone.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Instantsnapshots$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Instantsnapshots$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Instantsnapshots$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Instantsnapshots$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Instantsnapshots$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of InstantSnapshot resources contained within the specified zone.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Instantsnapshots$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Instantsnapshots$List, options?: MethodOptions): GaxiosPromise<Schema$InstantSnapshotList>;
        list(params: Params$Resource$Instantsnapshots$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Instantsnapshots$List, options: MethodOptions | BodyResponseCallback<Schema$InstantSnapshotList>, callback: BodyResponseCallback<Schema$InstantSnapshotList>): void;
        list(params: Params$Resource$Instantsnapshots$List, callback: BodyResponseCallback<Schema$InstantSnapshotList>): void;
        list(callback: BodyResponseCallback<Schema$InstantSnapshotList>): void;
        /**
         * Sets the access control policy on the specified resource. Replaces any existing policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setIamPolicy(params: Params$Resource$Instantsnapshots$Setiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setIamPolicy(params?: Params$Resource$Instantsnapshots$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        setIamPolicy(params: Params$Resource$Instantsnapshots$Setiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setIamPolicy(params: Params$Resource$Instantsnapshots$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(params: Params$Resource$Instantsnapshots$Setiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Sets the labels on a instantSnapshot in the given zone. To learn more about labels, read the Labeling Resources documentation.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setLabels(params: Params$Resource$Instantsnapshots$Setlabels, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setLabels(params?: Params$Resource$Instantsnapshots$Setlabels, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setLabels(params: Params$Resource$Instantsnapshots$Setlabels, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setLabels(params: Params$Resource$Instantsnapshots$Setlabels, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(params: Params$Resource$Instantsnapshots$Setlabels, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Instantsnapshots$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Instantsnapshots$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Instantsnapshots$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Instantsnapshots$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Instantsnapshots$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Instantsnapshots$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Instantsnapshots$Delete extends StandardParameters {
        /**
         * Name of the InstantSnapshot resource to delete.
         */
        instantSnapshot?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Instantsnapshots$Export extends StandardParameters {
        /**
         * Name of the instant snapshot to export.
         */
        instantSnapshot?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstantSnapshotsExportRequest;
    }
    export interface Params$Resource$Instantsnapshots$Get extends StandardParameters {
        /**
         * Name of the InstantSnapshot resource to return.
         */
        instantSnapshot?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Instantsnapshots$Getiampolicy extends StandardParameters {
        /**
         * Requested IAM Policy version.
         */
        optionsRequestedPolicyVersion?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Instantsnapshots$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstantSnapshot;
    }
    export interface Params$Resource$Instantsnapshots$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Instantsnapshots$Setiampolicy extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ZoneSetPolicyRequest;
    }
    export interface Params$Resource$Instantsnapshots$Setlabels extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ZoneSetLabelsRequest;
    }
    export interface Params$Resource$Instantsnapshots$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Interconnectattachments {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves an aggregated list of interconnect attachments.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Interconnectattachments$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Interconnectattachments$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$InterconnectAttachmentAggregatedList>;
        aggregatedList(params: Params$Resource$Interconnectattachments$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Interconnectattachments$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$InterconnectAttachmentAggregatedList>, callback: BodyResponseCallback<Schema$InterconnectAttachmentAggregatedList>): void;
        aggregatedList(params: Params$Resource$Interconnectattachments$Aggregatedlist, callback: BodyResponseCallback<Schema$InterconnectAttachmentAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$InterconnectAttachmentAggregatedList>): void;
        /**
         * Deletes the specified interconnect attachment.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Interconnectattachments$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Interconnectattachments$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Interconnectattachments$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Interconnectattachments$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Interconnectattachments$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified interconnect attachment.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Interconnectattachments$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Interconnectattachments$Get, options?: MethodOptions): GaxiosPromise<Schema$InterconnectAttachment>;
        get(params: Params$Resource$Interconnectattachments$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Interconnectattachments$Get, options: MethodOptions | BodyResponseCallback<Schema$InterconnectAttachment>, callback: BodyResponseCallback<Schema$InterconnectAttachment>): void;
        get(params: Params$Resource$Interconnectattachments$Get, callback: BodyResponseCallback<Schema$InterconnectAttachment>): void;
        get(callback: BodyResponseCallback<Schema$InterconnectAttachment>): void;
        /**
         * Gets the access control policy for a resource. May be empty if no such policy or resource exists.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getIamPolicy(params: Params$Resource$Interconnectattachments$Getiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getIamPolicy(params?: Params$Resource$Interconnectattachments$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        getIamPolicy(params: Params$Resource$Interconnectattachments$Getiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getIamPolicy(params: Params$Resource$Interconnectattachments$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(params: Params$Resource$Interconnectattachments$Getiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Creates an InterconnectAttachment in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Interconnectattachments$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Interconnectattachments$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Interconnectattachments$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Interconnectattachments$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Interconnectattachments$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of interconnect attachments contained within the specified region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Interconnectattachments$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Interconnectattachments$List, options?: MethodOptions): GaxiosPromise<Schema$InterconnectAttachmentList>;
        list(params: Params$Resource$Interconnectattachments$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Interconnectattachments$List, options: MethodOptions | BodyResponseCallback<Schema$InterconnectAttachmentList>, callback: BodyResponseCallback<Schema$InterconnectAttachmentList>): void;
        list(params: Params$Resource$Interconnectattachments$List, callback: BodyResponseCallback<Schema$InterconnectAttachmentList>): void;
        list(callback: BodyResponseCallback<Schema$InterconnectAttachmentList>): void;
        /**
         * Updates the specified interconnect attachment with the data included in the request. This method supports PATCH semantics and uses the JSON merge patch format and processing rules.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Interconnectattachments$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Interconnectattachments$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Interconnectattachments$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Interconnectattachments$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Interconnectattachments$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the access control policy on the specified resource. Replaces any existing policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setIamPolicy(params: Params$Resource$Interconnectattachments$Setiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setIamPolicy(params?: Params$Resource$Interconnectattachments$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        setIamPolicy(params: Params$Resource$Interconnectattachments$Setiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setIamPolicy(params: Params$Resource$Interconnectattachments$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(params: Params$Resource$Interconnectattachments$Setiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Sets the labels on an InterconnectAttachment. To learn more about labels, read the Labeling Resources documentation.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setLabels(params: Params$Resource$Interconnectattachments$Setlabels, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setLabels(params?: Params$Resource$Interconnectattachments$Setlabels, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setLabels(params: Params$Resource$Interconnectattachments$Setlabels, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setLabels(params: Params$Resource$Interconnectattachments$Setlabels, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(params: Params$Resource$Interconnectattachments$Setlabels, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Interconnectattachments$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Interconnectattachments$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Interconnectattachments$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Interconnectattachments$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Interconnectattachments$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Interconnectattachments$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Interconnectattachments$Delete extends StandardParameters {
        /**
         * Name of the interconnect attachment to delete.
         */
        interconnectAttachment?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Interconnectattachments$Get extends StandardParameters {
        /**
         * Name of the interconnect attachment to return.
         */
        interconnectAttachment?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
    }
    export interface Params$Resource$Interconnectattachments$Getiampolicy extends StandardParameters {
        /**
         * Requested IAM Policy version.
         */
        optionsRequestedPolicyVersion?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
    }
    export interface Params$Resource$Interconnectattachments$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * If true, the request will not be committed.
         */
        validateOnly?: boolean;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InterconnectAttachment;
    }
    export interface Params$Resource$Interconnectattachments$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Interconnectattachments$Patch extends StandardParameters {
        /**
         * Name of the interconnect attachment to patch.
         */
        interconnectAttachment?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InterconnectAttachment;
    }
    export interface Params$Resource$Interconnectattachments$Setiampolicy extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionSetPolicyRequest;
    }
    export interface Params$Resource$Interconnectattachments$Setlabels extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionSetLabelsRequest;
    }
    export interface Params$Resource$Interconnectattachments$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Interconnectlocations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Returns the details for the specified interconnect location. Gets a list of available interconnect locations by making a list() request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Interconnectlocations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Interconnectlocations$Get, options?: MethodOptions): GaxiosPromise<Schema$InterconnectLocation>;
        get(params: Params$Resource$Interconnectlocations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Interconnectlocations$Get, options: MethodOptions | BodyResponseCallback<Schema$InterconnectLocation>, callback: BodyResponseCallback<Schema$InterconnectLocation>): void;
        get(params: Params$Resource$Interconnectlocations$Get, callback: BodyResponseCallback<Schema$InterconnectLocation>): void;
        get(callback: BodyResponseCallback<Schema$InterconnectLocation>): void;
        /**
         * Retrieves the list of interconnect locations available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Interconnectlocations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Interconnectlocations$List, options?: MethodOptions): GaxiosPromise<Schema$InterconnectLocationList>;
        list(params: Params$Resource$Interconnectlocations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Interconnectlocations$List, options: MethodOptions | BodyResponseCallback<Schema$InterconnectLocationList>, callback: BodyResponseCallback<Schema$InterconnectLocationList>): void;
        list(params: Params$Resource$Interconnectlocations$List, callback: BodyResponseCallback<Schema$InterconnectLocationList>): void;
        list(callback: BodyResponseCallback<Schema$InterconnectLocationList>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Interconnectlocations$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Interconnectlocations$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Interconnectlocations$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Interconnectlocations$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Interconnectlocations$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Interconnectlocations$Get extends StandardParameters {
        /**
         * Name of the interconnect location to return.
         */
        interconnectLocation?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    export interface Params$Resource$Interconnectlocations$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Interconnectlocations$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Interconnectremotelocations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Returns the details for the specified interconnect remote location. Gets a list of available interconnect remote locations by making a list() request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Interconnectremotelocations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Interconnectremotelocations$Get, options?: MethodOptions): GaxiosPromise<Schema$InterconnectRemoteLocation>;
        get(params: Params$Resource$Interconnectremotelocations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Interconnectremotelocations$Get, options: MethodOptions | BodyResponseCallback<Schema$InterconnectRemoteLocation>, callback: BodyResponseCallback<Schema$InterconnectRemoteLocation>): void;
        get(params: Params$Resource$Interconnectremotelocations$Get, callback: BodyResponseCallback<Schema$InterconnectRemoteLocation>): void;
        get(callback: BodyResponseCallback<Schema$InterconnectRemoteLocation>): void;
        /**
         * Retrieves the list of interconnect remote locations available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Interconnectremotelocations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Interconnectremotelocations$List, options?: MethodOptions): GaxiosPromise<Schema$InterconnectRemoteLocationList>;
        list(params: Params$Resource$Interconnectremotelocations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Interconnectremotelocations$List, options: MethodOptions | BodyResponseCallback<Schema$InterconnectRemoteLocationList>, callback: BodyResponseCallback<Schema$InterconnectRemoteLocationList>): void;
        list(params: Params$Resource$Interconnectremotelocations$List, callback: BodyResponseCallback<Schema$InterconnectRemoteLocationList>): void;
        list(callback: BodyResponseCallback<Schema$InterconnectRemoteLocationList>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Interconnectremotelocations$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Interconnectremotelocations$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Interconnectremotelocations$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Interconnectremotelocations$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Interconnectremotelocations$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Interconnectremotelocations$Get extends StandardParameters {
        /**
         * Name of the interconnect remote location to return.
         */
        interconnectRemoteLocation?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    export interface Params$Resource$Interconnectremotelocations$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Interconnectremotelocations$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Interconnects {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Deletes the specified Interconnect.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Interconnects$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Interconnects$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Interconnects$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Interconnects$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Interconnects$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified Interconnect. Get a list of available Interconnects by making a list() request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Interconnects$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Interconnects$Get, options?: MethodOptions): GaxiosPromise<Schema$Interconnect>;
        get(params: Params$Resource$Interconnects$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Interconnects$Get, options: MethodOptions | BodyResponseCallback<Schema$Interconnect>, callback: BodyResponseCallback<Schema$Interconnect>): void;
        get(params: Params$Resource$Interconnects$Get, callback: BodyResponseCallback<Schema$Interconnect>): void;
        get(callback: BodyResponseCallback<Schema$Interconnect>): void;
        /**
         * Returns the interconnectDiagnostics for the specified Interconnect.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getDiagnostics(params: Params$Resource$Interconnects$Getdiagnostics, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getDiagnostics(params?: Params$Resource$Interconnects$Getdiagnostics, options?: MethodOptions): GaxiosPromise<Schema$InterconnectsGetDiagnosticsResponse>;
        getDiagnostics(params: Params$Resource$Interconnects$Getdiagnostics, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getDiagnostics(params: Params$Resource$Interconnects$Getdiagnostics, options: MethodOptions | BodyResponseCallback<Schema$InterconnectsGetDiagnosticsResponse>, callback: BodyResponseCallback<Schema$InterconnectsGetDiagnosticsResponse>): void;
        getDiagnostics(params: Params$Resource$Interconnects$Getdiagnostics, callback: BodyResponseCallback<Schema$InterconnectsGetDiagnosticsResponse>): void;
        getDiagnostics(callback: BodyResponseCallback<Schema$InterconnectsGetDiagnosticsResponse>): void;
        /**
         * Gets the access control policy for a resource. May be empty if no such policy or resource exists.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getIamPolicy(params: Params$Resource$Interconnects$Getiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getIamPolicy(params?: Params$Resource$Interconnects$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        getIamPolicy(params: Params$Resource$Interconnects$Getiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getIamPolicy(params: Params$Resource$Interconnects$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(params: Params$Resource$Interconnects$Getiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Returns the interconnectMacsecConfig for the specified Interconnect.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getMacsecConfig(params: Params$Resource$Interconnects$Getmacsecconfig, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getMacsecConfig(params?: Params$Resource$Interconnects$Getmacsecconfig, options?: MethodOptions): GaxiosPromise<Schema$InterconnectsGetMacsecConfigResponse>;
        getMacsecConfig(params: Params$Resource$Interconnects$Getmacsecconfig, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getMacsecConfig(params: Params$Resource$Interconnects$Getmacsecconfig, options: MethodOptions | BodyResponseCallback<Schema$InterconnectsGetMacsecConfigResponse>, callback: BodyResponseCallback<Schema$InterconnectsGetMacsecConfigResponse>): void;
        getMacsecConfig(params: Params$Resource$Interconnects$Getmacsecconfig, callback: BodyResponseCallback<Schema$InterconnectsGetMacsecConfigResponse>): void;
        getMacsecConfig(callback: BodyResponseCallback<Schema$InterconnectsGetMacsecConfigResponse>): void;
        /**
         * Creates an Interconnect in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Interconnects$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Interconnects$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Interconnects$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Interconnects$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Interconnects$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of Interconnects available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Interconnects$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Interconnects$List, options?: MethodOptions): GaxiosPromise<Schema$InterconnectList>;
        list(params: Params$Resource$Interconnects$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Interconnects$List, options: MethodOptions | BodyResponseCallback<Schema$InterconnectList>, callback: BodyResponseCallback<Schema$InterconnectList>): void;
        list(params: Params$Resource$Interconnects$List, callback: BodyResponseCallback<Schema$InterconnectList>): void;
        list(callback: BodyResponseCallback<Schema$InterconnectList>): void;
        /**
         * Updates the specified Interconnect with the data included in the request. This method supports PATCH semantics and uses the JSON merge patch format and processing rules.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Interconnects$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Interconnects$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Interconnects$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Interconnects$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Interconnects$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the access control policy on the specified resource. Replaces any existing policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setIamPolicy(params: Params$Resource$Interconnects$Setiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setIamPolicy(params?: Params$Resource$Interconnects$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        setIamPolicy(params: Params$Resource$Interconnects$Setiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setIamPolicy(params: Params$Resource$Interconnects$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(params: Params$Resource$Interconnects$Setiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Sets the labels on an Interconnect. To learn more about labels, read the Labeling Resources documentation.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setLabels(params: Params$Resource$Interconnects$Setlabels, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setLabels(params?: Params$Resource$Interconnects$Setlabels, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setLabels(params: Params$Resource$Interconnects$Setlabels, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setLabels(params: Params$Resource$Interconnects$Setlabels, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(params: Params$Resource$Interconnects$Setlabels, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Interconnects$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Interconnects$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Interconnects$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Interconnects$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Interconnects$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Interconnects$Delete extends StandardParameters {
        /**
         * Name of the interconnect to delete.
         */
        interconnect?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Interconnects$Get extends StandardParameters {
        /**
         * Name of the interconnect to return.
         */
        interconnect?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    export interface Params$Resource$Interconnects$Getdiagnostics extends StandardParameters {
        /**
         * Name of the interconnect resource to query.
         */
        interconnect?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    export interface Params$Resource$Interconnects$Getiampolicy extends StandardParameters {
        /**
         * Requested IAM Policy version.
         */
        optionsRequestedPolicyVersion?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
    }
    export interface Params$Resource$Interconnects$Getmacsecconfig extends StandardParameters {
        /**
         * Name of the interconnect resource to query.
         */
        interconnect?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    export interface Params$Resource$Interconnects$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Interconnect;
    }
    export interface Params$Resource$Interconnects$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Interconnects$Patch extends StandardParameters {
        /**
         * Name of the interconnect to update.
         */
        interconnect?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Interconnect;
    }
    export interface Params$Resource$Interconnects$Setiampolicy extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GlobalSetPolicyRequest;
    }
    export interface Params$Resource$Interconnects$Setlabels extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GlobalSetLabelsRequest;
    }
    export interface Params$Resource$Interconnects$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Licensecodes {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Return a specified license code. License codes are mirrored across all projects that have permissions to read the License Code. *Caution* This resource is intended for use only by third-party partners who are creating Cloud Marketplace images.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Licensecodes$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Licensecodes$Get, options?: MethodOptions): GaxiosPromise<Schema$LicenseCode>;
        get(params: Params$Resource$Licensecodes$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Licensecodes$Get, options: MethodOptions | BodyResponseCallback<Schema$LicenseCode>, callback: BodyResponseCallback<Schema$LicenseCode>): void;
        get(params: Params$Resource$Licensecodes$Get, callback: BodyResponseCallback<Schema$LicenseCode>): void;
        get(callback: BodyResponseCallback<Schema$LicenseCode>): void;
        /**
         * Gets the access control policy for a resource. May be empty if no such policy or resource exists. *Caution* This resource is intended for use only by third-party partners who are creating Cloud Marketplace images.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getIamPolicy(params: Params$Resource$Licensecodes$Getiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getIamPolicy(params?: Params$Resource$Licensecodes$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        getIamPolicy(params: Params$Resource$Licensecodes$Getiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getIamPolicy(params: Params$Resource$Licensecodes$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(params: Params$Resource$Licensecodes$Getiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Sets the access control policy on the specified resource. Replaces any existing policy. *Caution* This resource is intended for use only by third-party partners who are creating Cloud Marketplace images.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setIamPolicy(params: Params$Resource$Licensecodes$Setiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setIamPolicy(params?: Params$Resource$Licensecodes$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        setIamPolicy(params: Params$Resource$Licensecodes$Setiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setIamPolicy(params: Params$Resource$Licensecodes$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(params: Params$Resource$Licensecodes$Setiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Returns permissions that a caller has on the specified resource. *Caution* This resource is intended for use only by third-party partners who are creating Cloud Marketplace images.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Licensecodes$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Licensecodes$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Licensecodes$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Licensecodes$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Licensecodes$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Licensecodes$Get extends StandardParameters {
        /**
         * Number corresponding to the License code resource to return.
         */
        licenseCode?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    export interface Params$Resource$Licensecodes$Getiampolicy extends StandardParameters {
        /**
         * Requested IAM Policy version.
         */
        optionsRequestedPolicyVersion?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
    }
    export interface Params$Resource$Licensecodes$Setiampolicy extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GlobalSetPolicyRequest;
    }
    export interface Params$Resource$Licensecodes$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Licenses {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Deletes the specified license. *Caution* This resource is intended for use only by third-party partners who are creating Cloud Marketplace images.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Licenses$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Licenses$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Licenses$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Licenses$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Licenses$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified License resource. *Caution* This resource is intended for use only by third-party partners who are creating Cloud Marketplace images.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Licenses$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Licenses$Get, options?: MethodOptions): GaxiosPromise<Schema$License>;
        get(params: Params$Resource$Licenses$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Licenses$Get, options: MethodOptions | BodyResponseCallback<Schema$License>, callback: BodyResponseCallback<Schema$License>): void;
        get(params: Params$Resource$Licenses$Get, callback: BodyResponseCallback<Schema$License>): void;
        get(callback: BodyResponseCallback<Schema$License>): void;
        /**
         * Gets the access control policy for a resource. May be empty if no such policy or resource exists. *Caution* This resource is intended for use only by third-party partners who are creating Cloud Marketplace images.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getIamPolicy(params: Params$Resource$Licenses$Getiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getIamPolicy(params?: Params$Resource$Licenses$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        getIamPolicy(params: Params$Resource$Licenses$Getiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getIamPolicy(params: Params$Resource$Licenses$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(params: Params$Resource$Licenses$Getiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Create a License resource in the specified project. *Caution* This resource is intended for use only by third-party partners who are creating Cloud Marketplace images.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Licenses$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Licenses$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Licenses$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Licenses$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Licenses$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of licenses available in the specified project. This method does not get any licenses that belong to other projects, including licenses attached to publicly-available images, like Debian 9. If you want to get a list of publicly-available licenses, use this method to make a request to the respective image project, such as debian-cloud or windows-cloud. *Caution* This resource is intended for use only by third-party partners who are creating Cloud Marketplace images.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Licenses$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Licenses$List, options?: MethodOptions): GaxiosPromise<Schema$LicensesListResponse>;
        list(params: Params$Resource$Licenses$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Licenses$List, options: MethodOptions | BodyResponseCallback<Schema$LicensesListResponse>, callback: BodyResponseCallback<Schema$LicensesListResponse>): void;
        list(params: Params$Resource$Licenses$List, callback: BodyResponseCallback<Schema$LicensesListResponse>): void;
        list(callback: BodyResponseCallback<Schema$LicensesListResponse>): void;
        /**
         * Sets the access control policy on the specified resource. Replaces any existing policy. *Caution* This resource is intended for use only by third-party partners who are creating Cloud Marketplace images.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setIamPolicy(params: Params$Resource$Licenses$Setiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setIamPolicy(params?: Params$Resource$Licenses$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        setIamPolicy(params: Params$Resource$Licenses$Setiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setIamPolicy(params: Params$Resource$Licenses$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(params: Params$Resource$Licenses$Setiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Returns permissions that a caller has on the specified resource. *Caution* This resource is intended for use only by third-party partners who are creating Cloud Marketplace images.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Licenses$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Licenses$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Licenses$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Licenses$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Licenses$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Licenses$Delete extends StandardParameters {
        /**
         * Name of the license resource to delete.
         */
        license?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Licenses$Get extends StandardParameters {
        /**
         * Name of the License resource to return.
         */
        license?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    export interface Params$Resource$Licenses$Getiampolicy extends StandardParameters {
        /**
         * Requested IAM Policy version.
         */
        optionsRequestedPolicyVersion?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
    }
    export interface Params$Resource$Licenses$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$License;
    }
    export interface Params$Resource$Licenses$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Licenses$Setiampolicy extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GlobalSetPolicyRequest;
    }
    export interface Params$Resource$Licenses$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Machineimages {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Deletes the specified machine image. Deleting a machine image is permanent and cannot be undone.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Machineimages$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Machineimages$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Machineimages$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Machineimages$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Machineimages$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified machine image.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Machineimages$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Machineimages$Get, options?: MethodOptions): GaxiosPromise<Schema$MachineImage>;
        get(params: Params$Resource$Machineimages$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Machineimages$Get, options: MethodOptions | BodyResponseCallback<Schema$MachineImage>, callback: BodyResponseCallback<Schema$MachineImage>): void;
        get(params: Params$Resource$Machineimages$Get, callback: BodyResponseCallback<Schema$MachineImage>): void;
        get(callback: BodyResponseCallback<Schema$MachineImage>): void;
        /**
         * Gets the access control policy for a resource. May be empty if no such policy or resource exists.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getIamPolicy(params: Params$Resource$Machineimages$Getiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getIamPolicy(params?: Params$Resource$Machineimages$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        getIamPolicy(params: Params$Resource$Machineimages$Getiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getIamPolicy(params: Params$Resource$Machineimages$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(params: Params$Resource$Machineimages$Getiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Creates a machine image in the specified project using the data that is included in the request. If you are creating a new machine image to update an existing instance, your new machine image should use the same network or, if applicable, the same subnetwork as the original instance.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Machineimages$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Machineimages$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Machineimages$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Machineimages$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Machineimages$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves a list of machine images that are contained within the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Machineimages$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Machineimages$List, options?: MethodOptions): GaxiosPromise<Schema$MachineImageList>;
        list(params: Params$Resource$Machineimages$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Machineimages$List, options: MethodOptions | BodyResponseCallback<Schema$MachineImageList>, callback: BodyResponseCallback<Schema$MachineImageList>): void;
        list(params: Params$Resource$Machineimages$List, callback: BodyResponseCallback<Schema$MachineImageList>): void;
        list(callback: BodyResponseCallback<Schema$MachineImageList>): void;
        /**
         * Sets the access control policy on the specified resource. Replaces any existing policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setIamPolicy(params: Params$Resource$Machineimages$Setiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setIamPolicy(params?: Params$Resource$Machineimages$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        setIamPolicy(params: Params$Resource$Machineimages$Setiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setIamPolicy(params: Params$Resource$Machineimages$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(params: Params$Resource$Machineimages$Setiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Machineimages$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Machineimages$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Machineimages$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Machineimages$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Machineimages$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Machineimages$Delete extends StandardParameters {
        /**
         * The name of the machine image to delete.
         */
        machineImage?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Machineimages$Get extends StandardParameters {
        /**
         * The name of the machine image.
         */
        machineImage?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    export interface Params$Resource$Machineimages$Getiampolicy extends StandardParameters {
        /**
         * Requested IAM Policy version.
         */
        optionsRequestedPolicyVersion?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
    }
    export interface Params$Resource$Machineimages$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Required. Source instance that is used to create the machine image from.
         */
        sourceInstance?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$MachineImage;
    }
    export interface Params$Resource$Machineimages$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Machineimages$Setiampolicy extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GlobalSetPolicyRequest;
    }
    export interface Params$Resource$Machineimages$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Machinetypes {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves an aggregated list of machine types.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Machinetypes$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Machinetypes$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$MachineTypeAggregatedList>;
        aggregatedList(params: Params$Resource$Machinetypes$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Machinetypes$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$MachineTypeAggregatedList>, callback: BodyResponseCallback<Schema$MachineTypeAggregatedList>): void;
        aggregatedList(params: Params$Resource$Machinetypes$Aggregatedlist, callback: BodyResponseCallback<Schema$MachineTypeAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$MachineTypeAggregatedList>): void;
        /**
         * Returns the specified machine type.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Machinetypes$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Machinetypes$Get, options?: MethodOptions): GaxiosPromise<Schema$MachineType>;
        get(params: Params$Resource$Machinetypes$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Machinetypes$Get, options: MethodOptions | BodyResponseCallback<Schema$MachineType>, callback: BodyResponseCallback<Schema$MachineType>): void;
        get(params: Params$Resource$Machinetypes$Get, callback: BodyResponseCallback<Schema$MachineType>): void;
        get(callback: BodyResponseCallback<Schema$MachineType>): void;
        /**
         * Retrieves a list of machine types available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Machinetypes$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Machinetypes$List, options?: MethodOptions): GaxiosPromise<Schema$MachineTypeList>;
        list(params: Params$Resource$Machinetypes$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Machinetypes$List, options: MethodOptions | BodyResponseCallback<Schema$MachineTypeList>, callback: BodyResponseCallback<Schema$MachineTypeList>): void;
        list(params: Params$Resource$Machinetypes$List, callback: BodyResponseCallback<Schema$MachineTypeList>): void;
        list(callback: BodyResponseCallback<Schema$MachineTypeList>): void;
    }
    export interface Params$Resource$Machinetypes$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Machinetypes$Get extends StandardParameters {
        /**
         * Name of the machine type to return.
         */
        machineType?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Machinetypes$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export class Resource$Networkattachments {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves the list of all NetworkAttachment resources, regional and global, available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Networkattachments$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Networkattachments$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$NetworkAttachmentAggregatedList>;
        aggregatedList(params: Params$Resource$Networkattachments$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Networkattachments$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$NetworkAttachmentAggregatedList>, callback: BodyResponseCallback<Schema$NetworkAttachmentAggregatedList>): void;
        aggregatedList(params: Params$Resource$Networkattachments$Aggregatedlist, callback: BodyResponseCallback<Schema$NetworkAttachmentAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$NetworkAttachmentAggregatedList>): void;
        /**
         * Deletes the specified NetworkAttachment in the given scope
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Networkattachments$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Networkattachments$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Networkattachments$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Networkattachments$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Networkattachments$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified NetworkAttachment resource in the given scope.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Networkattachments$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Networkattachments$Get, options?: MethodOptions): GaxiosPromise<Schema$NetworkAttachment>;
        get(params: Params$Resource$Networkattachments$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Networkattachments$Get, options: MethodOptions | BodyResponseCallback<Schema$NetworkAttachment>, callback: BodyResponseCallback<Schema$NetworkAttachment>): void;
        get(params: Params$Resource$Networkattachments$Get, callback: BodyResponseCallback<Schema$NetworkAttachment>): void;
        get(callback: BodyResponseCallback<Schema$NetworkAttachment>): void;
        /**
         * Gets the access control policy for a resource. May be empty if no such policy or resource exists.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getIamPolicy(params: Params$Resource$Networkattachments$Getiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getIamPolicy(params?: Params$Resource$Networkattachments$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        getIamPolicy(params: Params$Resource$Networkattachments$Getiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getIamPolicy(params: Params$Resource$Networkattachments$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(params: Params$Resource$Networkattachments$Getiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Creates a NetworkAttachment in the specified project in the given scope using the parameters that are included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Networkattachments$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Networkattachments$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Networkattachments$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Networkattachments$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Networkattachments$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Lists the NetworkAttachments for a project in the given scope.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Networkattachments$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Networkattachments$List, options?: MethodOptions): GaxiosPromise<Schema$NetworkAttachmentList>;
        list(params: Params$Resource$Networkattachments$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Networkattachments$List, options: MethodOptions | BodyResponseCallback<Schema$NetworkAttachmentList>, callback: BodyResponseCallback<Schema$NetworkAttachmentList>): void;
        list(params: Params$Resource$Networkattachments$List, callback: BodyResponseCallback<Schema$NetworkAttachmentList>): void;
        list(callback: BodyResponseCallback<Schema$NetworkAttachmentList>): void;
        /**
         * Patches the specified NetworkAttachment resource with the data included in the request. This method supports PATCH semantics and uses JSON merge patch format and processing rules.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Networkattachments$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Networkattachments$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Networkattachments$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Networkattachments$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Networkattachments$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the access control policy on the specified resource. Replaces any existing policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setIamPolicy(params: Params$Resource$Networkattachments$Setiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setIamPolicy(params?: Params$Resource$Networkattachments$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        setIamPolicy(params: Params$Resource$Networkattachments$Setiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setIamPolicy(params: Params$Resource$Networkattachments$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(params: Params$Resource$Networkattachments$Setiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Networkattachments$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Networkattachments$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Networkattachments$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Networkattachments$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Networkattachments$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Networkattachments$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Networkattachments$Delete extends StandardParameters {
        /**
         * Name of the NetworkAttachment resource to delete.
         */
        networkAttachment?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region of this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000). end_interface: MixerMutationRequestBuilder
         */
        requestId?: string;
    }
    export interface Params$Resource$Networkattachments$Get extends StandardParameters {
        /**
         * Name of the NetworkAttachment resource to return.
         */
        networkAttachment?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region of this request.
         */
        region?: string;
    }
    export interface Params$Resource$Networkattachments$Getiampolicy extends StandardParameters {
        /**
         * Requested IAM Policy version.
         */
        optionsRequestedPolicyVersion?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
    }
    export interface Params$Resource$Networkattachments$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region of this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000). end_interface: MixerMutationRequestBuilder
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$NetworkAttachment;
    }
    export interface Params$Resource$Networkattachments$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region of this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Networkattachments$Patch extends StandardParameters {
        /**
         * Name of the NetworkAttachment resource to patch.
         */
        networkAttachment?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000). end_interface: MixerMutationRequestBuilder
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$NetworkAttachment;
    }
    export interface Params$Resource$Networkattachments$Setiampolicy extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionSetPolicyRequest;
    }
    export interface Params$Resource$Networkattachments$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Networkedgesecurityservices {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves the list of all NetworkEdgeSecurityService resources available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Networkedgesecurityservices$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Networkedgesecurityservices$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$NetworkEdgeSecurityServiceAggregatedList>;
        aggregatedList(params: Params$Resource$Networkedgesecurityservices$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Networkedgesecurityservices$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$NetworkEdgeSecurityServiceAggregatedList>, callback: BodyResponseCallback<Schema$NetworkEdgeSecurityServiceAggregatedList>): void;
        aggregatedList(params: Params$Resource$Networkedgesecurityservices$Aggregatedlist, callback: BodyResponseCallback<Schema$NetworkEdgeSecurityServiceAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$NetworkEdgeSecurityServiceAggregatedList>): void;
        /**
         * Deletes the specified service.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Networkedgesecurityservices$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Networkedgesecurityservices$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Networkedgesecurityservices$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Networkedgesecurityservices$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Networkedgesecurityservices$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Gets a specified NetworkEdgeSecurityService.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Networkedgesecurityservices$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Networkedgesecurityservices$Get, options?: MethodOptions): GaxiosPromise<Schema$NetworkEdgeSecurityService>;
        get(params: Params$Resource$Networkedgesecurityservices$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Networkedgesecurityservices$Get, options: MethodOptions | BodyResponseCallback<Schema$NetworkEdgeSecurityService>, callback: BodyResponseCallback<Schema$NetworkEdgeSecurityService>): void;
        get(params: Params$Resource$Networkedgesecurityservices$Get, callback: BodyResponseCallback<Schema$NetworkEdgeSecurityService>): void;
        get(callback: BodyResponseCallback<Schema$NetworkEdgeSecurityService>): void;
        /**
         * Creates a new service in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Networkedgesecurityservices$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Networkedgesecurityservices$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Networkedgesecurityservices$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Networkedgesecurityservices$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Networkedgesecurityservices$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Patches the specified policy with the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Networkedgesecurityservices$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Networkedgesecurityservices$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Networkedgesecurityservices$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Networkedgesecurityservices$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Networkedgesecurityservices$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    export interface Params$Resource$Networkedgesecurityservices$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Name of the project scoping this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Networkedgesecurityservices$Delete extends StandardParameters {
        /**
         * Name of the network edge security service to delete.
         */
        networkEdgeSecurityService?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Networkedgesecurityservices$Get extends StandardParameters {
        /**
         * Name of the network edge security service to get.
         */
        networkEdgeSecurityService?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
    }
    export interface Params$Resource$Networkedgesecurityservices$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * If true, the request will not be committed.
         */
        validateOnly?: boolean;
        /**
         * Request body metadata
         */
        requestBody?: Schema$NetworkEdgeSecurityService;
    }
    export interface Params$Resource$Networkedgesecurityservices$Patch extends StandardParameters {
        /**
         * Name of the network edge security service to update.
         */
        networkEdgeSecurityService?: string;
        /**
         *
         */
        paths?: string[];
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Indicates fields to be updated as part of this request.
         */
        updateMask?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$NetworkEdgeSecurityService;
    }
    export class Resource$Networkendpointgroups {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves the list of network endpoint groups and sorts them by zone.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Networkendpointgroups$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Networkendpointgroups$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$NetworkEndpointGroupAggregatedList>;
        aggregatedList(params: Params$Resource$Networkendpointgroups$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Networkendpointgroups$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$NetworkEndpointGroupAggregatedList>, callback: BodyResponseCallback<Schema$NetworkEndpointGroupAggregatedList>): void;
        aggregatedList(params: Params$Resource$Networkendpointgroups$Aggregatedlist, callback: BodyResponseCallback<Schema$NetworkEndpointGroupAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$NetworkEndpointGroupAggregatedList>): void;
        /**
         * Attach a list of network endpoints to the specified network endpoint group.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        attachNetworkEndpoints(params: Params$Resource$Networkendpointgroups$Attachnetworkendpoints, options: StreamMethodOptions): GaxiosPromise<Readable>;
        attachNetworkEndpoints(params?: Params$Resource$Networkendpointgroups$Attachnetworkendpoints, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        attachNetworkEndpoints(params: Params$Resource$Networkendpointgroups$Attachnetworkendpoints, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        attachNetworkEndpoints(params: Params$Resource$Networkendpointgroups$Attachnetworkendpoints, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        attachNetworkEndpoints(params: Params$Resource$Networkendpointgroups$Attachnetworkendpoints, callback: BodyResponseCallback<Schema$Operation>): void;
        attachNetworkEndpoints(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Deletes the specified network endpoint group. The network endpoints in the NEG and the VM instances they belong to are not terminated when the NEG is deleted. Note that the NEG cannot be deleted if there are backend services referencing it.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Networkendpointgroups$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Networkendpointgroups$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Networkendpointgroups$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Networkendpointgroups$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Networkendpointgroups$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Detach a list of network endpoints from the specified network endpoint group.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        detachNetworkEndpoints(params: Params$Resource$Networkendpointgroups$Detachnetworkendpoints, options: StreamMethodOptions): GaxiosPromise<Readable>;
        detachNetworkEndpoints(params?: Params$Resource$Networkendpointgroups$Detachnetworkendpoints, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        detachNetworkEndpoints(params: Params$Resource$Networkendpointgroups$Detachnetworkendpoints, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        detachNetworkEndpoints(params: Params$Resource$Networkendpointgroups$Detachnetworkendpoints, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        detachNetworkEndpoints(params: Params$Resource$Networkendpointgroups$Detachnetworkendpoints, callback: BodyResponseCallback<Schema$Operation>): void;
        detachNetworkEndpoints(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified network endpoint group.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Networkendpointgroups$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Networkendpointgroups$Get, options?: MethodOptions): GaxiosPromise<Schema$NetworkEndpointGroup>;
        get(params: Params$Resource$Networkendpointgroups$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Networkendpointgroups$Get, options: MethodOptions | BodyResponseCallback<Schema$NetworkEndpointGroup>, callback: BodyResponseCallback<Schema$NetworkEndpointGroup>): void;
        get(params: Params$Resource$Networkendpointgroups$Get, callback: BodyResponseCallback<Schema$NetworkEndpointGroup>): void;
        get(callback: BodyResponseCallback<Schema$NetworkEndpointGroup>): void;
        /**
         * Creates a network endpoint group in the specified project using the parameters that are included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Networkendpointgroups$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Networkendpointgroups$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Networkendpointgroups$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Networkendpointgroups$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Networkendpointgroups$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of network endpoint groups that are located in the specified project and zone.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Networkendpointgroups$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Networkendpointgroups$List, options?: MethodOptions): GaxiosPromise<Schema$NetworkEndpointGroupList>;
        list(params: Params$Resource$Networkendpointgroups$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Networkendpointgroups$List, options: MethodOptions | BodyResponseCallback<Schema$NetworkEndpointGroupList>, callback: BodyResponseCallback<Schema$NetworkEndpointGroupList>): void;
        list(params: Params$Resource$Networkendpointgroups$List, callback: BodyResponseCallback<Schema$NetworkEndpointGroupList>): void;
        list(callback: BodyResponseCallback<Schema$NetworkEndpointGroupList>): void;
        /**
         * Lists the network endpoints in the specified network endpoint group.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        listNetworkEndpoints(params: Params$Resource$Networkendpointgroups$Listnetworkendpoints, options: StreamMethodOptions): GaxiosPromise<Readable>;
        listNetworkEndpoints(params?: Params$Resource$Networkendpointgroups$Listnetworkendpoints, options?: MethodOptions): GaxiosPromise<Schema$NetworkEndpointGroupsListNetworkEndpoints>;
        listNetworkEndpoints(params: Params$Resource$Networkendpointgroups$Listnetworkendpoints, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        listNetworkEndpoints(params: Params$Resource$Networkendpointgroups$Listnetworkendpoints, options: MethodOptions | BodyResponseCallback<Schema$NetworkEndpointGroupsListNetworkEndpoints>, callback: BodyResponseCallback<Schema$NetworkEndpointGroupsListNetworkEndpoints>): void;
        listNetworkEndpoints(params: Params$Resource$Networkendpointgroups$Listnetworkendpoints, callback: BodyResponseCallback<Schema$NetworkEndpointGroupsListNetworkEndpoints>): void;
        listNetworkEndpoints(callback: BodyResponseCallback<Schema$NetworkEndpointGroupsListNetworkEndpoints>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Networkendpointgroups$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Networkendpointgroups$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Networkendpointgroups$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Networkendpointgroups$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Networkendpointgroups$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Networkendpointgroups$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Networkendpointgroups$Attachnetworkendpoints extends StandardParameters {
        /**
         * The name of the network endpoint group where you are attaching network endpoints to. It should comply with RFC1035.
         */
        networkEndpointGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where the network endpoint group is located. It should comply with RFC1035.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$NetworkEndpointGroupsAttachEndpointsRequest;
    }
    export interface Params$Resource$Networkendpointgroups$Delete extends StandardParameters {
        /**
         * The name of the network endpoint group to delete. It should comply with RFC1035.
         */
        networkEndpointGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where the network endpoint group is located. It should comply with RFC1035.
         */
        zone?: string;
    }
    export interface Params$Resource$Networkendpointgroups$Detachnetworkendpoints extends StandardParameters {
        /**
         * The name of the network endpoint group where you are removing network endpoints. It should comply with RFC1035.
         */
        networkEndpointGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where the network endpoint group is located. It should comply with RFC1035.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$NetworkEndpointGroupsDetachEndpointsRequest;
    }
    export interface Params$Resource$Networkendpointgroups$Get extends StandardParameters {
        /**
         * The name of the network endpoint group. It should comply with RFC1035.
         */
        networkEndpointGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone where the network endpoint group is located. It should comply with RFC1035.
         */
        zone?: string;
    }
    export interface Params$Resource$Networkendpointgroups$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone where you want to create the network endpoint group. It should comply with RFC1035.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$NetworkEndpointGroup;
    }
    export interface Params$Resource$Networkendpointgroups$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         * The name of the zone where the network endpoint group is located. It should comply with RFC1035.
         */
        zone?: string;
    }
    export interface Params$Resource$Networkendpointgroups$Listnetworkendpoints extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * The name of the network endpoint group from which you want to generate a list of included network endpoints. It should comply with RFC1035.
         */
        networkEndpointGroup?: string;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         * The name of the zone where the network endpoint group is located. It should comply with RFC1035.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$NetworkEndpointGroupsListEndpointsRequest;
    }
    export interface Params$Resource$Networkendpointgroups$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Networkfirewallpolicies {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Inserts an association for the specified firewall policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        addAssociation(params: Params$Resource$Networkfirewallpolicies$Addassociation, options: StreamMethodOptions): GaxiosPromise<Readable>;
        addAssociation(params?: Params$Resource$Networkfirewallpolicies$Addassociation, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        addAssociation(params: Params$Resource$Networkfirewallpolicies$Addassociation, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        addAssociation(params: Params$Resource$Networkfirewallpolicies$Addassociation, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        addAssociation(params: Params$Resource$Networkfirewallpolicies$Addassociation, callback: BodyResponseCallback<Schema$Operation>): void;
        addAssociation(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Inserts a rule into a firewall policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        addRule(params: Params$Resource$Networkfirewallpolicies$Addrule, options: StreamMethodOptions): GaxiosPromise<Readable>;
        addRule(params?: Params$Resource$Networkfirewallpolicies$Addrule, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        addRule(params: Params$Resource$Networkfirewallpolicies$Addrule, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        addRule(params: Params$Resource$Networkfirewallpolicies$Addrule, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        addRule(params: Params$Resource$Networkfirewallpolicies$Addrule, callback: BodyResponseCallback<Schema$Operation>): void;
        addRule(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Copies rules to the specified firewall policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cloneRules(params: Params$Resource$Networkfirewallpolicies$Clonerules, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cloneRules(params?: Params$Resource$Networkfirewallpolicies$Clonerules, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        cloneRules(params: Params$Resource$Networkfirewallpolicies$Clonerules, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cloneRules(params: Params$Resource$Networkfirewallpolicies$Clonerules, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        cloneRules(params: Params$Resource$Networkfirewallpolicies$Clonerules, callback: BodyResponseCallback<Schema$Operation>): void;
        cloneRules(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Deletes the specified policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Networkfirewallpolicies$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Networkfirewallpolicies$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Networkfirewallpolicies$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Networkfirewallpolicies$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Networkfirewallpolicies$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified network firewall policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Networkfirewallpolicies$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Networkfirewallpolicies$Get, options?: MethodOptions): GaxiosPromise<Schema$FirewallPolicy>;
        get(params: Params$Resource$Networkfirewallpolicies$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Networkfirewallpolicies$Get, options: MethodOptions | BodyResponseCallback<Schema$FirewallPolicy>, callback: BodyResponseCallback<Schema$FirewallPolicy>): void;
        get(params: Params$Resource$Networkfirewallpolicies$Get, callback: BodyResponseCallback<Schema$FirewallPolicy>): void;
        get(callback: BodyResponseCallback<Schema$FirewallPolicy>): void;
        /**
         * Gets an association with the specified name.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getAssociation(params: Params$Resource$Networkfirewallpolicies$Getassociation, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getAssociation(params?: Params$Resource$Networkfirewallpolicies$Getassociation, options?: MethodOptions): GaxiosPromise<Schema$FirewallPolicyAssociation>;
        getAssociation(params: Params$Resource$Networkfirewallpolicies$Getassociation, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getAssociation(params: Params$Resource$Networkfirewallpolicies$Getassociation, options: MethodOptions | BodyResponseCallback<Schema$FirewallPolicyAssociation>, callback: BodyResponseCallback<Schema$FirewallPolicyAssociation>): void;
        getAssociation(params: Params$Resource$Networkfirewallpolicies$Getassociation, callback: BodyResponseCallback<Schema$FirewallPolicyAssociation>): void;
        getAssociation(callback: BodyResponseCallback<Schema$FirewallPolicyAssociation>): void;
        /**
         * Gets the access control policy for a resource. May be empty if no such policy or resource exists.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getIamPolicy(params: Params$Resource$Networkfirewallpolicies$Getiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getIamPolicy(params?: Params$Resource$Networkfirewallpolicies$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        getIamPolicy(params: Params$Resource$Networkfirewallpolicies$Getiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getIamPolicy(params: Params$Resource$Networkfirewallpolicies$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(params: Params$Resource$Networkfirewallpolicies$Getiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Gets a rule of the specified priority.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getRule(params: Params$Resource$Networkfirewallpolicies$Getrule, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getRule(params?: Params$Resource$Networkfirewallpolicies$Getrule, options?: MethodOptions): GaxiosPromise<Schema$FirewallPolicyRule>;
        getRule(params: Params$Resource$Networkfirewallpolicies$Getrule, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getRule(params: Params$Resource$Networkfirewallpolicies$Getrule, options: MethodOptions | BodyResponseCallback<Schema$FirewallPolicyRule>, callback: BodyResponseCallback<Schema$FirewallPolicyRule>): void;
        getRule(params: Params$Resource$Networkfirewallpolicies$Getrule, callback: BodyResponseCallback<Schema$FirewallPolicyRule>): void;
        getRule(callback: BodyResponseCallback<Schema$FirewallPolicyRule>): void;
        /**
         * Creates a new policy in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Networkfirewallpolicies$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Networkfirewallpolicies$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Networkfirewallpolicies$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Networkfirewallpolicies$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Networkfirewallpolicies$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Lists all the policies that have been configured for the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Networkfirewallpolicies$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Networkfirewallpolicies$List, options?: MethodOptions): GaxiosPromise<Schema$FirewallPolicyList>;
        list(params: Params$Resource$Networkfirewallpolicies$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Networkfirewallpolicies$List, options: MethodOptions | BodyResponseCallback<Schema$FirewallPolicyList>, callback: BodyResponseCallback<Schema$FirewallPolicyList>): void;
        list(params: Params$Resource$Networkfirewallpolicies$List, callback: BodyResponseCallback<Schema$FirewallPolicyList>): void;
        list(callback: BodyResponseCallback<Schema$FirewallPolicyList>): void;
        /**
         * Patches the specified policy with the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Networkfirewallpolicies$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Networkfirewallpolicies$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Networkfirewallpolicies$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Networkfirewallpolicies$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Networkfirewallpolicies$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Updates an association for the specified network firewall policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patchAssociation(params: Params$Resource$Networkfirewallpolicies$Patchassociation, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patchAssociation(params?: Params$Resource$Networkfirewallpolicies$Patchassociation, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patchAssociation(params: Params$Resource$Networkfirewallpolicies$Patchassociation, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patchAssociation(params: Params$Resource$Networkfirewallpolicies$Patchassociation, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patchAssociation(params: Params$Resource$Networkfirewallpolicies$Patchassociation, callback: BodyResponseCallback<Schema$Operation>): void;
        patchAssociation(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Patches a rule of the specified priority.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patchRule(params: Params$Resource$Networkfirewallpolicies$Patchrule, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patchRule(params?: Params$Resource$Networkfirewallpolicies$Patchrule, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patchRule(params: Params$Resource$Networkfirewallpolicies$Patchrule, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patchRule(params: Params$Resource$Networkfirewallpolicies$Patchrule, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patchRule(params: Params$Resource$Networkfirewallpolicies$Patchrule, callback: BodyResponseCallback<Schema$Operation>): void;
        patchRule(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Removes an association for the specified firewall policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        removeAssociation(params: Params$Resource$Networkfirewallpolicies$Removeassociation, options: StreamMethodOptions): GaxiosPromise<Readable>;
        removeAssociation(params?: Params$Resource$Networkfirewallpolicies$Removeassociation, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        removeAssociation(params: Params$Resource$Networkfirewallpolicies$Removeassociation, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        removeAssociation(params: Params$Resource$Networkfirewallpolicies$Removeassociation, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        removeAssociation(params: Params$Resource$Networkfirewallpolicies$Removeassociation, callback: BodyResponseCallback<Schema$Operation>): void;
        removeAssociation(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Deletes a rule of the specified priority.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        removeRule(params: Params$Resource$Networkfirewallpolicies$Removerule, options: StreamMethodOptions): GaxiosPromise<Readable>;
        removeRule(params?: Params$Resource$Networkfirewallpolicies$Removerule, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        removeRule(params: Params$Resource$Networkfirewallpolicies$Removerule, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        removeRule(params: Params$Resource$Networkfirewallpolicies$Removerule, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        removeRule(params: Params$Resource$Networkfirewallpolicies$Removerule, callback: BodyResponseCallback<Schema$Operation>): void;
        removeRule(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the access control policy on the specified resource. Replaces any existing policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setIamPolicy(params: Params$Resource$Networkfirewallpolicies$Setiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setIamPolicy(params?: Params$Resource$Networkfirewallpolicies$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        setIamPolicy(params: Params$Resource$Networkfirewallpolicies$Setiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setIamPolicy(params: Params$Resource$Networkfirewallpolicies$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(params: Params$Resource$Networkfirewallpolicies$Setiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Networkfirewallpolicies$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Networkfirewallpolicies$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Networkfirewallpolicies$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Networkfirewallpolicies$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Networkfirewallpolicies$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Networkfirewallpolicies$Addassociation extends StandardParameters {
        /**
         * Name of the firewall policy associated with the target network to swap association with. This field is mutually exclusive with 'replace_existing_association'.
         */
        associatedPolicyToBeReplaced?: string;
        /**
         * Name of the firewall policy to update.
         */
        firewallPolicy?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Indicates whether or not to replace it if an association of the attachment already exists. This is false by default, in which case an error will be returned if an association already exists.
         */
        replaceExistingAssociation?: boolean;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$FirewallPolicyAssociation;
    }
    export interface Params$Resource$Networkfirewallpolicies$Addrule extends StandardParameters {
        /**
         * Name of the firewall policy to update.
         */
        firewallPolicy?: string;
        /**
         * When rule.priority is not specified, auto choose a unused priority between minPriority and maxPriority\>. This field is exclusive with rule.priority.
         */
        maxPriority?: number;
        /**
         * When rule.priority is not specified, auto choose a unused priority between minPriority and maxPriority\>. This field is exclusive with rule.priority.
         */
        minPriority?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$FirewallPolicyRule;
    }
    export interface Params$Resource$Networkfirewallpolicies$Clonerules extends StandardParameters {
        /**
         * Name of the firewall policy to update.
         */
        firewallPolicy?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The firewall policy from which to copy rules.
         */
        sourceFirewallPolicy?: string;
    }
    export interface Params$Resource$Networkfirewallpolicies$Delete extends StandardParameters {
        /**
         * Name of the firewall policy to delete.
         */
        firewallPolicy?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Networkfirewallpolicies$Get extends StandardParameters {
        /**
         * Name of the firewall policy to get.
         */
        firewallPolicy?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    export interface Params$Resource$Networkfirewallpolicies$Getassociation extends StandardParameters {
        /**
         * Name of the firewall policy to which the queried association belongs.
         */
        firewallPolicy?: string;
        /**
         * The name of the association to get from the firewall policy.
         */
        name?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    export interface Params$Resource$Networkfirewallpolicies$Getiampolicy extends StandardParameters {
        /**
         * Requested IAM Policy version.
         */
        optionsRequestedPolicyVersion?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
    }
    export interface Params$Resource$Networkfirewallpolicies$Getrule extends StandardParameters {
        /**
         * Name of the firewall policy to which the queried rule belongs.
         */
        firewallPolicy?: string;
        /**
         * The priority of the rule to get from the firewall policy.
         */
        priority?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    export interface Params$Resource$Networkfirewallpolicies$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$FirewallPolicy;
    }
    export interface Params$Resource$Networkfirewallpolicies$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Networkfirewallpolicies$Patch extends StandardParameters {
        /**
         * Name of the firewall policy to update.
         */
        firewallPolicy?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$FirewallPolicy;
    }
    export interface Params$Resource$Networkfirewallpolicies$Patchassociation extends StandardParameters {
        /**
         * Name of the firewall policy to update.
         */
        firewallPolicy?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$FirewallPolicyAssociation;
    }
    export interface Params$Resource$Networkfirewallpolicies$Patchrule extends StandardParameters {
        /**
         * Name of the firewall policy to update.
         */
        firewallPolicy?: string;
        /**
         * The priority of the rule to patch.
         */
        priority?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$FirewallPolicyRule;
    }
    export interface Params$Resource$Networkfirewallpolicies$Removeassociation extends StandardParameters {
        /**
         * Name of the firewall policy to update.
         */
        firewallPolicy?: string;
        /**
         * Name for the attachment that will be removed.
         */
        name?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Networkfirewallpolicies$Removerule extends StandardParameters {
        /**
         * Name of the firewall policy to update.
         */
        firewallPolicy?: string;
        /**
         * The priority of the rule to remove from the firewall policy.
         */
        priority?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Networkfirewallpolicies$Setiampolicy extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GlobalSetPolicyRequest;
    }
    export interface Params$Resource$Networkfirewallpolicies$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Networks {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Adds a peering to the specified network.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        addPeering(params: Params$Resource$Networks$Addpeering, options: StreamMethodOptions): GaxiosPromise<Readable>;
        addPeering(params?: Params$Resource$Networks$Addpeering, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        addPeering(params: Params$Resource$Networks$Addpeering, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        addPeering(params: Params$Resource$Networks$Addpeering, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        addPeering(params: Params$Resource$Networks$Addpeering, callback: BodyResponseCallback<Schema$Operation>): void;
        addPeering(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Deletes the specified network.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Networks$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Networks$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Networks$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Networks$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Networks$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified network.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Networks$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Networks$Get, options?: MethodOptions): GaxiosPromise<Schema$Network>;
        get(params: Params$Resource$Networks$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Networks$Get, options: MethodOptions | BodyResponseCallback<Schema$Network>, callback: BodyResponseCallback<Schema$Network>): void;
        get(params: Params$Resource$Networks$Get, callback: BodyResponseCallback<Schema$Network>): void;
        get(callback: BodyResponseCallback<Schema$Network>): void;
        /**
         * Returns the effective firewalls on a given network.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getEffectiveFirewalls(params: Params$Resource$Networks$Geteffectivefirewalls, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getEffectiveFirewalls(params?: Params$Resource$Networks$Geteffectivefirewalls, options?: MethodOptions): GaxiosPromise<Schema$NetworksGetEffectiveFirewallsResponse>;
        getEffectiveFirewalls(params: Params$Resource$Networks$Geteffectivefirewalls, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getEffectiveFirewalls(params: Params$Resource$Networks$Geteffectivefirewalls, options: MethodOptions | BodyResponseCallback<Schema$NetworksGetEffectiveFirewallsResponse>, callback: BodyResponseCallback<Schema$NetworksGetEffectiveFirewallsResponse>): void;
        getEffectiveFirewalls(params: Params$Resource$Networks$Geteffectivefirewalls, callback: BodyResponseCallback<Schema$NetworksGetEffectiveFirewallsResponse>): void;
        getEffectiveFirewalls(callback: BodyResponseCallback<Schema$NetworksGetEffectiveFirewallsResponse>): void;
        /**
         * Creates a network in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Networks$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Networks$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Networks$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Networks$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Networks$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of networks available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Networks$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Networks$List, options?: MethodOptions): GaxiosPromise<Schema$NetworkList>;
        list(params: Params$Resource$Networks$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Networks$List, options: MethodOptions | BodyResponseCallback<Schema$NetworkList>, callback: BodyResponseCallback<Schema$NetworkList>): void;
        list(params: Params$Resource$Networks$List, callback: BodyResponseCallback<Schema$NetworkList>): void;
        list(callback: BodyResponseCallback<Schema$NetworkList>): void;
        /**
         * Lists the internal IP addresses in the specified network.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        listIpAddresses(params: Params$Resource$Networks$Listipaddresses, options: StreamMethodOptions): GaxiosPromise<Readable>;
        listIpAddresses(params?: Params$Resource$Networks$Listipaddresses, options?: MethodOptions): GaxiosPromise<Schema$IpAddressesList>;
        listIpAddresses(params: Params$Resource$Networks$Listipaddresses, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        listIpAddresses(params: Params$Resource$Networks$Listipaddresses, options: MethodOptions | BodyResponseCallback<Schema$IpAddressesList>, callback: BodyResponseCallback<Schema$IpAddressesList>): void;
        listIpAddresses(params: Params$Resource$Networks$Listipaddresses, callback: BodyResponseCallback<Schema$IpAddressesList>): void;
        listIpAddresses(callback: BodyResponseCallback<Schema$IpAddressesList>): void;
        /**
         * Lists the internal IP owners in the specified network.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        listIpOwners(params: Params$Resource$Networks$Listipowners, options: StreamMethodOptions): GaxiosPromise<Readable>;
        listIpOwners(params?: Params$Resource$Networks$Listipowners, options?: MethodOptions): GaxiosPromise<Schema$IpOwnerList>;
        listIpOwners(params: Params$Resource$Networks$Listipowners, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        listIpOwners(params: Params$Resource$Networks$Listipowners, options: MethodOptions | BodyResponseCallback<Schema$IpOwnerList>, callback: BodyResponseCallback<Schema$IpOwnerList>): void;
        listIpOwners(params: Params$Resource$Networks$Listipowners, callback: BodyResponseCallback<Schema$IpOwnerList>): void;
        listIpOwners(callback: BodyResponseCallback<Schema$IpOwnerList>): void;
        /**
         * Lists the peering routes exchanged over peering connection.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        listPeeringRoutes(params: Params$Resource$Networks$Listpeeringroutes, options: StreamMethodOptions): GaxiosPromise<Readable>;
        listPeeringRoutes(params?: Params$Resource$Networks$Listpeeringroutes, options?: MethodOptions): GaxiosPromise<Schema$ExchangedPeeringRoutesList>;
        listPeeringRoutes(params: Params$Resource$Networks$Listpeeringroutes, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        listPeeringRoutes(params: Params$Resource$Networks$Listpeeringroutes, options: MethodOptions | BodyResponseCallback<Schema$ExchangedPeeringRoutesList>, callback: BodyResponseCallback<Schema$ExchangedPeeringRoutesList>): void;
        listPeeringRoutes(params: Params$Resource$Networks$Listpeeringroutes, callback: BodyResponseCallback<Schema$ExchangedPeeringRoutesList>): void;
        listPeeringRoutes(callback: BodyResponseCallback<Schema$ExchangedPeeringRoutesList>): void;
        /**
         * Patches the specified network with the data included in the request. Only the following fields can be modified: routingConfig.routingMode.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Networks$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Networks$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Networks$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Networks$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Networks$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Removes a peering from the specified network.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        removePeering(params: Params$Resource$Networks$Removepeering, options: StreamMethodOptions): GaxiosPromise<Readable>;
        removePeering(params?: Params$Resource$Networks$Removepeering, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        removePeering(params: Params$Resource$Networks$Removepeering, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        removePeering(params: Params$Resource$Networks$Removepeering, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        removePeering(params: Params$Resource$Networks$Removepeering, callback: BodyResponseCallback<Schema$Operation>): void;
        removePeering(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Switches the network mode from auto subnet mode to custom subnet mode.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        switchToCustomMode(params: Params$Resource$Networks$Switchtocustommode, options: StreamMethodOptions): GaxiosPromise<Readable>;
        switchToCustomMode(params?: Params$Resource$Networks$Switchtocustommode, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        switchToCustomMode(params: Params$Resource$Networks$Switchtocustommode, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        switchToCustomMode(params: Params$Resource$Networks$Switchtocustommode, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        switchToCustomMode(params: Params$Resource$Networks$Switchtocustommode, callback: BodyResponseCallback<Schema$Operation>): void;
        switchToCustomMode(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Networks$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Networks$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Networks$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Networks$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Networks$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        /**
         * Updates the specified network peering with the data included in the request. You can only modify the NetworkPeering.export_custom_routes field and the NetworkPeering.import_custom_routes field.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        updatePeering(params: Params$Resource$Networks$Updatepeering, options: StreamMethodOptions): GaxiosPromise<Readable>;
        updatePeering(params?: Params$Resource$Networks$Updatepeering, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        updatePeering(params: Params$Resource$Networks$Updatepeering, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        updatePeering(params: Params$Resource$Networks$Updatepeering, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        updatePeering(params: Params$Resource$Networks$Updatepeering, callback: BodyResponseCallback<Schema$Operation>): void;
        updatePeering(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    export interface Params$Resource$Networks$Addpeering extends StandardParameters {
        /**
         * Name of the network resource to add peering to.
         */
        network?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$NetworksAddPeeringRequest;
    }
    export interface Params$Resource$Networks$Delete extends StandardParameters {
        /**
         * Name of the network to delete.
         */
        network?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Networks$Get extends StandardParameters {
        /**
         * Name of the network to return.
         */
        network?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    export interface Params$Resource$Networks$Geteffectivefirewalls extends StandardParameters {
        /**
         * Name of the network for this request.
         */
        network?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    export interface Params$Resource$Networks$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Network;
    }
    export interface Params$Resource$Networks$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Networks$Listipaddresses extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Name of the network for this request.
         */
        network?: string;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         * (Optional) types filter separate by comma, valid values are: SUBNETWORK, RESERVED, PEER_USED, PEER_RESERVED, REMOTE_USED, REMOTE_RESERVED.
         */
        types?: string;
    }
    export interface Params$Resource$Networks$Listipowners extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * (Optional) IP CIDR range filter, example: "10.128.10.0/30".
         */
        ipCidrRange?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Name of the network to return.
         */
        network?: string;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * (Optional) Project IDs filter, example: "project-1,project-2".
         */
        ownerProjects?: string;
        /**
         * (Optional) Owner types filter, example: "instance,forwardingRule".
         */
        ownerTypes?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         * (Optional) Subnetwork name filter.
         */
        subnetName?: string;
        /**
         * (Optional) Subnetwork region filter.
         */
        subnetRegion?: string;
    }
    export interface Params$Resource$Networks$Listpeeringroutes extends StandardParameters {
        /**
         * The direction of the exchanged routes.
         */
        direction?: string;
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Name of the network for this request.
         */
        network?: string;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * The response will show routes exchanged over the given peering connection.
         */
        peeringName?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The region of the request. The response will include all subnet routes, static routes and dynamic routes in the region.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Networks$Patch extends StandardParameters {
        /**
         * Name of the network to update.
         */
        network?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Network;
    }
    export interface Params$Resource$Networks$Removepeering extends StandardParameters {
        /**
         * Name of the network resource to remove peering from.
         */
        network?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$NetworksRemovePeeringRequest;
    }
    export interface Params$Resource$Networks$Switchtocustommode extends StandardParameters {
        /**
         * Name of the network to be updated.
         */
        network?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Networks$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export interface Params$Resource$Networks$Updatepeering extends StandardParameters {
        /**
         * Name of the network resource which the updated peering is belonging to.
         */
        network?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$NetworksUpdatePeeringRequest;
    }
    export class Resource$Nodegroups {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Adds specified number of nodes to the node group.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        addNodes(params: Params$Resource$Nodegroups$Addnodes, options: StreamMethodOptions): GaxiosPromise<Readable>;
        addNodes(params?: Params$Resource$Nodegroups$Addnodes, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        addNodes(params: Params$Resource$Nodegroups$Addnodes, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        addNodes(params: Params$Resource$Nodegroups$Addnodes, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        addNodes(params: Params$Resource$Nodegroups$Addnodes, callback: BodyResponseCallback<Schema$Operation>): void;
        addNodes(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves an aggregated list of node groups. Note: use nodeGroups.listNodes for more details about each group.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Nodegroups$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Nodegroups$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$NodeGroupAggregatedList>;
        aggregatedList(params: Params$Resource$Nodegroups$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Nodegroups$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$NodeGroupAggregatedList>, callback: BodyResponseCallback<Schema$NodeGroupAggregatedList>): void;
        aggregatedList(params: Params$Resource$Nodegroups$Aggregatedlist, callback: BodyResponseCallback<Schema$NodeGroupAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$NodeGroupAggregatedList>): void;
        /**
         * Deletes the specified NodeGroup resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Nodegroups$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Nodegroups$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Nodegroups$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Nodegroups$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Nodegroups$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Deletes specified nodes from the node group.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        deleteNodes(params: Params$Resource$Nodegroups$Deletenodes, options: StreamMethodOptions): GaxiosPromise<Readable>;
        deleteNodes(params?: Params$Resource$Nodegroups$Deletenodes, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        deleteNodes(params: Params$Resource$Nodegroups$Deletenodes, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        deleteNodes(params: Params$Resource$Nodegroups$Deletenodes, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        deleteNodes(params: Params$Resource$Nodegroups$Deletenodes, callback: BodyResponseCallback<Schema$Operation>): void;
        deleteNodes(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified NodeGroup. Get a list of available NodeGroups by making a list() request. Note: the "nodes" field should not be used. Use nodeGroups.listNodes instead.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Nodegroups$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Nodegroups$Get, options?: MethodOptions): GaxiosPromise<Schema$NodeGroup>;
        get(params: Params$Resource$Nodegroups$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Nodegroups$Get, options: MethodOptions | BodyResponseCallback<Schema$NodeGroup>, callback: BodyResponseCallback<Schema$NodeGroup>): void;
        get(params: Params$Resource$Nodegroups$Get, callback: BodyResponseCallback<Schema$NodeGroup>): void;
        get(callback: BodyResponseCallback<Schema$NodeGroup>): void;
        /**
         * Gets the access control policy for a resource. May be empty if no such policy or resource exists.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getIamPolicy(params: Params$Resource$Nodegroups$Getiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getIamPolicy(params?: Params$Resource$Nodegroups$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        getIamPolicy(params: Params$Resource$Nodegroups$Getiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getIamPolicy(params: Params$Resource$Nodegroups$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(params: Params$Resource$Nodegroups$Getiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Creates a NodeGroup resource in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Nodegroups$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Nodegroups$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Nodegroups$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Nodegroups$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Nodegroups$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves a list of node groups available to the specified project. Note: use nodeGroups.listNodes for more details about each group.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Nodegroups$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Nodegroups$List, options?: MethodOptions): GaxiosPromise<Schema$NodeGroupList>;
        list(params: Params$Resource$Nodegroups$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Nodegroups$List, options: MethodOptions | BodyResponseCallback<Schema$NodeGroupList>, callback: BodyResponseCallback<Schema$NodeGroupList>): void;
        list(params: Params$Resource$Nodegroups$List, callback: BodyResponseCallback<Schema$NodeGroupList>): void;
        list(callback: BodyResponseCallback<Schema$NodeGroupList>): void;
        /**
         * Lists nodes in the node group.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        listNodes(params: Params$Resource$Nodegroups$Listnodes, options: StreamMethodOptions): GaxiosPromise<Readable>;
        listNodes(params?: Params$Resource$Nodegroups$Listnodes, options?: MethodOptions): GaxiosPromise<Schema$NodeGroupsListNodes>;
        listNodes(params: Params$Resource$Nodegroups$Listnodes, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        listNodes(params: Params$Resource$Nodegroups$Listnodes, options: MethodOptions | BodyResponseCallback<Schema$NodeGroupsListNodes>, callback: BodyResponseCallback<Schema$NodeGroupsListNodes>): void;
        listNodes(params: Params$Resource$Nodegroups$Listnodes, callback: BodyResponseCallback<Schema$NodeGroupsListNodes>): void;
        listNodes(callback: BodyResponseCallback<Schema$NodeGroupsListNodes>): void;
        /**
         * Updates the specified node group.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Nodegroups$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Nodegroups$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Nodegroups$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Nodegroups$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Nodegroups$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Perform maintenance on a subset of nodes in the node group.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        performMaintenance(params: Params$Resource$Nodegroups$Performmaintenance, options: StreamMethodOptions): GaxiosPromise<Readable>;
        performMaintenance(params?: Params$Resource$Nodegroups$Performmaintenance, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        performMaintenance(params: Params$Resource$Nodegroups$Performmaintenance, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        performMaintenance(params: Params$Resource$Nodegroups$Performmaintenance, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        performMaintenance(params: Params$Resource$Nodegroups$Performmaintenance, callback: BodyResponseCallback<Schema$Operation>): void;
        performMaintenance(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the access control policy on the specified resource. Replaces any existing policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setIamPolicy(params: Params$Resource$Nodegroups$Setiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setIamPolicy(params?: Params$Resource$Nodegroups$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        setIamPolicy(params: Params$Resource$Nodegroups$Setiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setIamPolicy(params: Params$Resource$Nodegroups$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(params: Params$Resource$Nodegroups$Setiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Updates the node template of the node group.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setNodeTemplate(params: Params$Resource$Nodegroups$Setnodetemplate, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setNodeTemplate(params?: Params$Resource$Nodegroups$Setnodetemplate, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setNodeTemplate(params: Params$Resource$Nodegroups$Setnodetemplate, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setNodeTemplate(params: Params$Resource$Nodegroups$Setnodetemplate, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setNodeTemplate(params: Params$Resource$Nodegroups$Setnodetemplate, callback: BodyResponseCallback<Schema$Operation>): void;
        setNodeTemplate(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Simulates maintenance event on specified nodes from the node group.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        simulateMaintenanceEvent(params: Params$Resource$Nodegroups$Simulatemaintenanceevent, options: StreamMethodOptions): GaxiosPromise<Readable>;
        simulateMaintenanceEvent(params?: Params$Resource$Nodegroups$Simulatemaintenanceevent, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        simulateMaintenanceEvent(params: Params$Resource$Nodegroups$Simulatemaintenanceevent, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        simulateMaintenanceEvent(params: Params$Resource$Nodegroups$Simulatemaintenanceevent, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        simulateMaintenanceEvent(params: Params$Resource$Nodegroups$Simulatemaintenanceevent, callback: BodyResponseCallback<Schema$Operation>): void;
        simulateMaintenanceEvent(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Nodegroups$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Nodegroups$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Nodegroups$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Nodegroups$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Nodegroups$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Nodegroups$Addnodes extends StandardParameters {
        /**
         * Name of the NodeGroup resource.
         */
        nodeGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$NodeGroupsAddNodesRequest;
    }
    export interface Params$Resource$Nodegroups$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Nodegroups$Delete extends StandardParameters {
        /**
         * Name of the NodeGroup resource to delete.
         */
        nodeGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Nodegroups$Deletenodes extends StandardParameters {
        /**
         * Name of the NodeGroup resource whose nodes will be deleted.
         */
        nodeGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$NodeGroupsDeleteNodesRequest;
    }
    export interface Params$Resource$Nodegroups$Get extends StandardParameters {
        /**
         * Name of the node group to return.
         */
        nodeGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Nodegroups$Getiampolicy extends StandardParameters {
        /**
         * Requested IAM Policy version.
         */
        optionsRequestedPolicyVersion?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Nodegroups$Insert extends StandardParameters {
        /**
         * Initial count of nodes in the node group.
         */
        initialNodeCount?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$NodeGroup;
    }
    export interface Params$Resource$Nodegroups$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Nodegroups$Listnodes extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Name of the NodeGroup resource whose nodes you want to list.
         */
        nodeGroup?: string;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Nodegroups$Patch extends StandardParameters {
        /**
         * Name of the NodeGroup resource to update.
         */
        nodeGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$NodeGroup;
    }
    export interface Params$Resource$Nodegroups$Performmaintenance extends StandardParameters {
        /**
         * Name of the node group scoping this request.
         */
        nodeGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$NodeGroupsPerformMaintenanceRequest;
    }
    export interface Params$Resource$Nodegroups$Setiampolicy extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ZoneSetPolicyRequest;
    }
    export interface Params$Resource$Nodegroups$Setnodetemplate extends StandardParameters {
        /**
         * Name of the NodeGroup resource to update.
         */
        nodeGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$NodeGroupsSetNodeTemplateRequest;
    }
    export interface Params$Resource$Nodegroups$Simulatemaintenanceevent extends StandardParameters {
        /**
         * Name of the NodeGroup resource whose nodes will go under maintenance simulation.
         */
        nodeGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$NodeGroupsSimulateMaintenanceEventRequest;
    }
    export interface Params$Resource$Nodegroups$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Nodetemplates {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves an aggregated list of node templates.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Nodetemplates$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Nodetemplates$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$NodeTemplateAggregatedList>;
        aggregatedList(params: Params$Resource$Nodetemplates$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Nodetemplates$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$NodeTemplateAggregatedList>, callback: BodyResponseCallback<Schema$NodeTemplateAggregatedList>): void;
        aggregatedList(params: Params$Resource$Nodetemplates$Aggregatedlist, callback: BodyResponseCallback<Schema$NodeTemplateAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$NodeTemplateAggregatedList>): void;
        /**
         * Deletes the specified NodeTemplate resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Nodetemplates$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Nodetemplates$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Nodetemplates$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Nodetemplates$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Nodetemplates$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified node template.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Nodetemplates$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Nodetemplates$Get, options?: MethodOptions): GaxiosPromise<Schema$NodeTemplate>;
        get(params: Params$Resource$Nodetemplates$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Nodetemplates$Get, options: MethodOptions | BodyResponseCallback<Schema$NodeTemplate>, callback: BodyResponseCallback<Schema$NodeTemplate>): void;
        get(params: Params$Resource$Nodetemplates$Get, callback: BodyResponseCallback<Schema$NodeTemplate>): void;
        get(callback: BodyResponseCallback<Schema$NodeTemplate>): void;
        /**
         * Gets the access control policy for a resource. May be empty if no such policy or resource exists.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getIamPolicy(params: Params$Resource$Nodetemplates$Getiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getIamPolicy(params?: Params$Resource$Nodetemplates$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        getIamPolicy(params: Params$Resource$Nodetemplates$Getiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getIamPolicy(params: Params$Resource$Nodetemplates$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(params: Params$Resource$Nodetemplates$Getiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Creates a NodeTemplate resource in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Nodetemplates$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Nodetemplates$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Nodetemplates$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Nodetemplates$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Nodetemplates$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves a list of node templates available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Nodetemplates$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Nodetemplates$List, options?: MethodOptions): GaxiosPromise<Schema$NodeTemplateList>;
        list(params: Params$Resource$Nodetemplates$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Nodetemplates$List, options: MethodOptions | BodyResponseCallback<Schema$NodeTemplateList>, callback: BodyResponseCallback<Schema$NodeTemplateList>): void;
        list(params: Params$Resource$Nodetemplates$List, callback: BodyResponseCallback<Schema$NodeTemplateList>): void;
        list(callback: BodyResponseCallback<Schema$NodeTemplateList>): void;
        /**
         * Sets the access control policy on the specified resource. Replaces any existing policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setIamPolicy(params: Params$Resource$Nodetemplates$Setiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setIamPolicy(params?: Params$Resource$Nodetemplates$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        setIamPolicy(params: Params$Resource$Nodetemplates$Setiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setIamPolicy(params: Params$Resource$Nodetemplates$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(params: Params$Resource$Nodetemplates$Setiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Nodetemplates$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Nodetemplates$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Nodetemplates$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Nodetemplates$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Nodetemplates$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Nodetemplates$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Nodetemplates$Delete extends StandardParameters {
        /**
         * Name of the NodeTemplate resource to delete.
         */
        nodeTemplate?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Nodetemplates$Get extends StandardParameters {
        /**
         * Name of the node template to return.
         */
        nodeTemplate?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
    }
    export interface Params$Resource$Nodetemplates$Getiampolicy extends StandardParameters {
        /**
         * Requested IAM Policy version.
         */
        optionsRequestedPolicyVersion?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
    }
    export interface Params$Resource$Nodetemplates$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$NodeTemplate;
    }
    export interface Params$Resource$Nodetemplates$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Nodetemplates$Setiampolicy extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionSetPolicyRequest;
    }
    export interface Params$Resource$Nodetemplates$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Nodetypes {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves an aggregated list of node types.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Nodetypes$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Nodetypes$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$NodeTypeAggregatedList>;
        aggregatedList(params: Params$Resource$Nodetypes$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Nodetypes$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$NodeTypeAggregatedList>, callback: BodyResponseCallback<Schema$NodeTypeAggregatedList>): void;
        aggregatedList(params: Params$Resource$Nodetypes$Aggregatedlist, callback: BodyResponseCallback<Schema$NodeTypeAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$NodeTypeAggregatedList>): void;
        /**
         * Returns the specified node type.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Nodetypes$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Nodetypes$Get, options?: MethodOptions): GaxiosPromise<Schema$NodeType>;
        get(params: Params$Resource$Nodetypes$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Nodetypes$Get, options: MethodOptions | BodyResponseCallback<Schema$NodeType>, callback: BodyResponseCallback<Schema$NodeType>): void;
        get(params: Params$Resource$Nodetypes$Get, callback: BodyResponseCallback<Schema$NodeType>): void;
        get(callback: BodyResponseCallback<Schema$NodeType>): void;
        /**
         * Retrieves a list of node types available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Nodetypes$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Nodetypes$List, options?: MethodOptions): GaxiosPromise<Schema$NodeTypeList>;
        list(params: Params$Resource$Nodetypes$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Nodetypes$List, options: MethodOptions | BodyResponseCallback<Schema$NodeTypeList>, callback: BodyResponseCallback<Schema$NodeTypeList>): void;
        list(params: Params$Resource$Nodetypes$List, callback: BodyResponseCallback<Schema$NodeTypeList>): void;
        list(callback: BodyResponseCallback<Schema$NodeTypeList>): void;
    }
    export interface Params$Resource$Nodetypes$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Nodetypes$Get extends StandardParameters {
        /**
         * Name of the node type to return.
         */
        nodeType?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Nodetypes$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export class Resource$Organizationsecuritypolicies {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Inserts an association for the specified security policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        addAssociation(params: Params$Resource$Organizationsecuritypolicies$Addassociation, options: StreamMethodOptions): GaxiosPromise<Readable>;
        addAssociation(params?: Params$Resource$Organizationsecuritypolicies$Addassociation, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        addAssociation(params: Params$Resource$Organizationsecuritypolicies$Addassociation, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        addAssociation(params: Params$Resource$Organizationsecuritypolicies$Addassociation, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        addAssociation(params: Params$Resource$Organizationsecuritypolicies$Addassociation, callback: BodyResponseCallback<Schema$Operation>): void;
        addAssociation(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Inserts a rule into a security policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        addRule(params: Params$Resource$Organizationsecuritypolicies$Addrule, options: StreamMethodOptions): GaxiosPromise<Readable>;
        addRule(params?: Params$Resource$Organizationsecuritypolicies$Addrule, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        addRule(params: Params$Resource$Organizationsecuritypolicies$Addrule, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        addRule(params: Params$Resource$Organizationsecuritypolicies$Addrule, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        addRule(params: Params$Resource$Organizationsecuritypolicies$Addrule, callback: BodyResponseCallback<Schema$Operation>): void;
        addRule(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Copies rules to the specified security policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        copyRules(params: Params$Resource$Organizationsecuritypolicies$Copyrules, options: StreamMethodOptions): GaxiosPromise<Readable>;
        copyRules(params?: Params$Resource$Organizationsecuritypolicies$Copyrules, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        copyRules(params: Params$Resource$Organizationsecuritypolicies$Copyrules, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        copyRules(params: Params$Resource$Organizationsecuritypolicies$Copyrules, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        copyRules(params: Params$Resource$Organizationsecuritypolicies$Copyrules, callback: BodyResponseCallback<Schema$Operation>): void;
        copyRules(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Deletes the specified policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Organizationsecuritypolicies$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Organizationsecuritypolicies$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Organizationsecuritypolicies$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Organizationsecuritypolicies$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Organizationsecuritypolicies$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * List all of the ordered rules present in a single specified policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Organizationsecuritypolicies$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Organizationsecuritypolicies$Get, options?: MethodOptions): GaxiosPromise<Schema$SecurityPolicy>;
        get(params: Params$Resource$Organizationsecuritypolicies$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Organizationsecuritypolicies$Get, options: MethodOptions | BodyResponseCallback<Schema$SecurityPolicy>, callback: BodyResponseCallback<Schema$SecurityPolicy>): void;
        get(params: Params$Resource$Organizationsecuritypolicies$Get, callback: BodyResponseCallback<Schema$SecurityPolicy>): void;
        get(callback: BodyResponseCallback<Schema$SecurityPolicy>): void;
        /**
         * Gets an association with the specified name.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getAssociation(params: Params$Resource$Organizationsecuritypolicies$Getassociation, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getAssociation(params?: Params$Resource$Organizationsecuritypolicies$Getassociation, options?: MethodOptions): GaxiosPromise<Schema$SecurityPolicyAssociation>;
        getAssociation(params: Params$Resource$Organizationsecuritypolicies$Getassociation, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getAssociation(params: Params$Resource$Organizationsecuritypolicies$Getassociation, options: MethodOptions | BodyResponseCallback<Schema$SecurityPolicyAssociation>, callback: BodyResponseCallback<Schema$SecurityPolicyAssociation>): void;
        getAssociation(params: Params$Resource$Organizationsecuritypolicies$Getassociation, callback: BodyResponseCallback<Schema$SecurityPolicyAssociation>): void;
        getAssociation(callback: BodyResponseCallback<Schema$SecurityPolicyAssociation>): void;
        /**
         * Gets a rule at the specified priority.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getRule(params: Params$Resource$Organizationsecuritypolicies$Getrule, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getRule(params?: Params$Resource$Organizationsecuritypolicies$Getrule, options?: MethodOptions): GaxiosPromise<Schema$SecurityPolicyRule>;
        getRule(params: Params$Resource$Organizationsecuritypolicies$Getrule, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getRule(params: Params$Resource$Organizationsecuritypolicies$Getrule, options: MethodOptions | BodyResponseCallback<Schema$SecurityPolicyRule>, callback: BodyResponseCallback<Schema$SecurityPolicyRule>): void;
        getRule(params: Params$Resource$Organizationsecuritypolicies$Getrule, callback: BodyResponseCallback<Schema$SecurityPolicyRule>): void;
        getRule(callback: BodyResponseCallback<Schema$SecurityPolicyRule>): void;
        /**
         * Creates a new policy in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Organizationsecuritypolicies$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Organizationsecuritypolicies$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Organizationsecuritypolicies$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Organizationsecuritypolicies$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Organizationsecuritypolicies$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * List all the policies that have been configured for the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Organizationsecuritypolicies$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Organizationsecuritypolicies$List, options?: MethodOptions): GaxiosPromise<Schema$SecurityPolicyList>;
        list(params: Params$Resource$Organizationsecuritypolicies$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Organizationsecuritypolicies$List, options: MethodOptions | BodyResponseCallback<Schema$SecurityPolicyList>, callback: BodyResponseCallback<Schema$SecurityPolicyList>): void;
        list(params: Params$Resource$Organizationsecuritypolicies$List, callback: BodyResponseCallback<Schema$SecurityPolicyList>): void;
        list(callback: BodyResponseCallback<Schema$SecurityPolicyList>): void;
        /**
         * Lists associations of a specified target, i.e., organization or folder.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        listAssociations(params: Params$Resource$Organizationsecuritypolicies$Listassociations, options: StreamMethodOptions): GaxiosPromise<Readable>;
        listAssociations(params?: Params$Resource$Organizationsecuritypolicies$Listassociations, options?: MethodOptions): GaxiosPromise<Schema$OrganizationSecurityPoliciesListAssociationsResponse>;
        listAssociations(params: Params$Resource$Organizationsecuritypolicies$Listassociations, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        listAssociations(params: Params$Resource$Organizationsecuritypolicies$Listassociations, options: MethodOptions | BodyResponseCallback<Schema$OrganizationSecurityPoliciesListAssociationsResponse>, callback: BodyResponseCallback<Schema$OrganizationSecurityPoliciesListAssociationsResponse>): void;
        listAssociations(params: Params$Resource$Organizationsecuritypolicies$Listassociations, callback: BodyResponseCallback<Schema$OrganizationSecurityPoliciesListAssociationsResponse>): void;
        listAssociations(callback: BodyResponseCallback<Schema$OrganizationSecurityPoliciesListAssociationsResponse>): void;
        /**
         * Moves the specified security policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        move(params: Params$Resource$Organizationsecuritypolicies$Move, options: StreamMethodOptions): GaxiosPromise<Readable>;
        move(params?: Params$Resource$Organizationsecuritypolicies$Move, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        move(params: Params$Resource$Organizationsecuritypolicies$Move, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        move(params: Params$Resource$Organizationsecuritypolicies$Move, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        move(params: Params$Resource$Organizationsecuritypolicies$Move, callback: BodyResponseCallback<Schema$Operation>): void;
        move(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Patches the specified policy with the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Organizationsecuritypolicies$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Organizationsecuritypolicies$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Organizationsecuritypolicies$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Organizationsecuritypolicies$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Organizationsecuritypolicies$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Patches a rule at the specified priority.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patchRule(params: Params$Resource$Organizationsecuritypolicies$Patchrule, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patchRule(params?: Params$Resource$Organizationsecuritypolicies$Patchrule, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patchRule(params: Params$Resource$Organizationsecuritypolicies$Patchrule, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patchRule(params: Params$Resource$Organizationsecuritypolicies$Patchrule, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patchRule(params: Params$Resource$Organizationsecuritypolicies$Patchrule, callback: BodyResponseCallback<Schema$Operation>): void;
        patchRule(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Removes an association for the specified security policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        removeAssociation(params: Params$Resource$Organizationsecuritypolicies$Removeassociation, options: StreamMethodOptions): GaxiosPromise<Readable>;
        removeAssociation(params?: Params$Resource$Organizationsecuritypolicies$Removeassociation, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        removeAssociation(params: Params$Resource$Organizationsecuritypolicies$Removeassociation, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        removeAssociation(params: Params$Resource$Organizationsecuritypolicies$Removeassociation, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        removeAssociation(params: Params$Resource$Organizationsecuritypolicies$Removeassociation, callback: BodyResponseCallback<Schema$Operation>): void;
        removeAssociation(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Deletes a rule at the specified priority.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        removeRule(params: Params$Resource$Organizationsecuritypolicies$Removerule, options: StreamMethodOptions): GaxiosPromise<Readable>;
        removeRule(params?: Params$Resource$Organizationsecuritypolicies$Removerule, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        removeRule(params: Params$Resource$Organizationsecuritypolicies$Removerule, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        removeRule(params: Params$Resource$Organizationsecuritypolicies$Removerule, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        removeRule(params: Params$Resource$Organizationsecuritypolicies$Removerule, callback: BodyResponseCallback<Schema$Operation>): void;
        removeRule(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    export interface Params$Resource$Organizationsecuritypolicies$Addassociation extends StandardParameters {
        /**
         * Indicates whether or not to replace it if an association of the attachment already exists. This is false by default, in which case an error will be returned if an association already exists.
         */
        replaceExistingAssociation?: boolean;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the security policy to update.
         */
        securityPolicy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SecurityPolicyAssociation;
    }
    export interface Params$Resource$Organizationsecuritypolicies$Addrule extends StandardParameters {
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the security policy to update.
         */
        securityPolicy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SecurityPolicyRule;
    }
    export interface Params$Resource$Organizationsecuritypolicies$Copyrules extends StandardParameters {
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the security policy to update.
         */
        securityPolicy?: string;
        /**
         * The security policy from which to copy rules.
         */
        sourceSecurityPolicy?: string;
    }
    export interface Params$Resource$Organizationsecuritypolicies$Delete extends StandardParameters {
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the security policy to delete.
         */
        securityPolicy?: string;
    }
    export interface Params$Resource$Organizationsecuritypolicies$Get extends StandardParameters {
        /**
         * Name of the security policy to get.
         */
        securityPolicy?: string;
    }
    export interface Params$Resource$Organizationsecuritypolicies$Getassociation extends StandardParameters {
        /**
         * The name of the association to get from the security policy.
         */
        name?: string;
        /**
         * Name of the security policy to which the queried rule belongs.
         */
        securityPolicy?: string;
    }
    export interface Params$Resource$Organizationsecuritypolicies$Getrule extends StandardParameters {
        /**
         * The priority of the rule to get from the security policy.
         */
        priority?: number;
        /**
         * Name of the security policy to which the queried rule belongs.
         */
        securityPolicy?: string;
    }
    export interface Params$Resource$Organizationsecuritypolicies$Insert extends StandardParameters {
        /**
         * Parent ID for this request. The ID can be either be "folders/[FOLDER_ID]" if the parent is a folder or "organizations/[ORGANIZATION_ID]" if the parent is an organization.
         */
        parentId?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SecurityPolicy;
    }
    export interface Params$Resource$Organizationsecuritypolicies$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Parent ID for this request.
         */
        parentId?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Organizationsecuritypolicies$Listassociations extends StandardParameters {
        /**
         * The target resource to list associations. It is an organization, or a folder.
         */
        targetResource?: string;
    }
    export interface Params$Resource$Organizationsecuritypolicies$Move extends StandardParameters {
        /**
         * The new parent of the security policy.
         */
        parentId?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the security policy to update.
         */
        securityPolicy?: string;
    }
    export interface Params$Resource$Organizationsecuritypolicies$Patch extends StandardParameters {
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the security policy to update.
         */
        securityPolicy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SecurityPolicy;
    }
    export interface Params$Resource$Organizationsecuritypolicies$Patchrule extends StandardParameters {
        /**
         * The priority of the rule to patch.
         */
        priority?: number;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the security policy to update.
         */
        securityPolicy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SecurityPolicyRule;
    }
    export interface Params$Resource$Organizationsecuritypolicies$Removeassociation extends StandardParameters {
        /**
         * Name for the attachment that will be removed.
         */
        name?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the security policy to update.
         */
        securityPolicy?: string;
    }
    export interface Params$Resource$Organizationsecuritypolicies$Removerule extends StandardParameters {
        /**
         * The priority of the rule to remove from the security policy.
         */
        priority?: number;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the security policy to update.
         */
        securityPolicy?: string;
    }
    export class Resource$Packetmirrorings {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves an aggregated list of packetMirrorings.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Packetmirrorings$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Packetmirrorings$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$PacketMirroringAggregatedList>;
        aggregatedList(params: Params$Resource$Packetmirrorings$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Packetmirrorings$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$PacketMirroringAggregatedList>, callback: BodyResponseCallback<Schema$PacketMirroringAggregatedList>): void;
        aggregatedList(params: Params$Resource$Packetmirrorings$Aggregatedlist, callback: BodyResponseCallback<Schema$PacketMirroringAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$PacketMirroringAggregatedList>): void;
        /**
         * Deletes the specified PacketMirroring resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Packetmirrorings$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Packetmirrorings$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Packetmirrorings$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Packetmirrorings$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Packetmirrorings$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified PacketMirroring resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Packetmirrorings$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Packetmirrorings$Get, options?: MethodOptions): GaxiosPromise<Schema$PacketMirroring>;
        get(params: Params$Resource$Packetmirrorings$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Packetmirrorings$Get, options: MethodOptions | BodyResponseCallback<Schema$PacketMirroring>, callback: BodyResponseCallback<Schema$PacketMirroring>): void;
        get(params: Params$Resource$Packetmirrorings$Get, callback: BodyResponseCallback<Schema$PacketMirroring>): void;
        get(callback: BodyResponseCallback<Schema$PacketMirroring>): void;
        /**
         * Creates a PacketMirroring resource in the specified project and region using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Packetmirrorings$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Packetmirrorings$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Packetmirrorings$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Packetmirrorings$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Packetmirrorings$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves a list of PacketMirroring resources available to the specified project and region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Packetmirrorings$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Packetmirrorings$List, options?: MethodOptions): GaxiosPromise<Schema$PacketMirroringList>;
        list(params: Params$Resource$Packetmirrorings$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Packetmirrorings$List, options: MethodOptions | BodyResponseCallback<Schema$PacketMirroringList>, callback: BodyResponseCallback<Schema$PacketMirroringList>): void;
        list(params: Params$Resource$Packetmirrorings$List, callback: BodyResponseCallback<Schema$PacketMirroringList>): void;
        list(callback: BodyResponseCallback<Schema$PacketMirroringList>): void;
        /**
         * Patches the specified PacketMirroring resource with the data included in the request. This method supports PATCH semantics and uses JSON merge patch format and processing rules.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Packetmirrorings$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Packetmirrorings$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Packetmirrorings$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Packetmirrorings$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Packetmirrorings$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Packetmirrorings$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Packetmirrorings$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Packetmirrorings$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Packetmirrorings$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Packetmirrorings$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Packetmirrorings$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Packetmirrorings$Delete extends StandardParameters {
        /**
         * Name of the PacketMirroring resource to delete.
         */
        packetMirroring?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Packetmirrorings$Get extends StandardParameters {
        /**
         * Name of the PacketMirroring resource to return.
         */
        packetMirroring?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
    }
    export interface Params$Resource$Packetmirrorings$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$PacketMirroring;
    }
    export interface Params$Resource$Packetmirrorings$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Packetmirrorings$Patch extends StandardParameters {
        /**
         * Name of the PacketMirroring resource to patch.
         */
        packetMirroring?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$PacketMirroring;
    }
    export interface Params$Resource$Packetmirrorings$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Projects {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Disable this project as a shared VPC host project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        disableXpnHost(params: Params$Resource$Projects$Disablexpnhost, options: StreamMethodOptions): GaxiosPromise<Readable>;
        disableXpnHost(params?: Params$Resource$Projects$Disablexpnhost, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        disableXpnHost(params: Params$Resource$Projects$Disablexpnhost, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        disableXpnHost(params: Params$Resource$Projects$Disablexpnhost, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        disableXpnHost(params: Params$Resource$Projects$Disablexpnhost, callback: BodyResponseCallback<Schema$Operation>): void;
        disableXpnHost(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Disable a service resource (also known as service project) associated with this host project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        disableXpnResource(params: Params$Resource$Projects$Disablexpnresource, options: StreamMethodOptions): GaxiosPromise<Readable>;
        disableXpnResource(params?: Params$Resource$Projects$Disablexpnresource, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        disableXpnResource(params: Params$Resource$Projects$Disablexpnresource, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        disableXpnResource(params: Params$Resource$Projects$Disablexpnresource, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        disableXpnResource(params: Params$Resource$Projects$Disablexpnresource, callback: BodyResponseCallback<Schema$Operation>): void;
        disableXpnResource(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Enable this project as a shared VPC host project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        enableXpnHost(params: Params$Resource$Projects$Enablexpnhost, options: StreamMethodOptions): GaxiosPromise<Readable>;
        enableXpnHost(params?: Params$Resource$Projects$Enablexpnhost, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        enableXpnHost(params: Params$Resource$Projects$Enablexpnhost, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        enableXpnHost(params: Params$Resource$Projects$Enablexpnhost, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        enableXpnHost(params: Params$Resource$Projects$Enablexpnhost, callback: BodyResponseCallback<Schema$Operation>): void;
        enableXpnHost(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Enable service resource (a.k.a service project) for a host project, so that subnets in the host project can be used by instances in the service project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        enableXpnResource(params: Params$Resource$Projects$Enablexpnresource, options: StreamMethodOptions): GaxiosPromise<Readable>;
        enableXpnResource(params?: Params$Resource$Projects$Enablexpnresource, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        enableXpnResource(params: Params$Resource$Projects$Enablexpnresource, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        enableXpnResource(params: Params$Resource$Projects$Enablexpnresource, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        enableXpnResource(params: Params$Resource$Projects$Enablexpnresource, callback: BodyResponseCallback<Schema$Operation>): void;
        enableXpnResource(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified Project resource. To decrease latency for this method, you can optionally omit any unneeded information from the response by using a field mask. This practice is especially recommended for unused quota information (the `quotas` field). To exclude one or more fields, set your request's `fields` query parameter to only include the fields you need. For example, to only include the `id` and `selfLink` fields, add the query parameter `?fields=id,selfLink` to your request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Projects$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Projects$Get, options?: MethodOptions): GaxiosPromise<Schema$Project>;
        get(params: Params$Resource$Projects$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Projects$Get, options: MethodOptions | BodyResponseCallback<Schema$Project>, callback: BodyResponseCallback<Schema$Project>): void;
        get(params: Params$Resource$Projects$Get, callback: BodyResponseCallback<Schema$Project>): void;
        get(callback: BodyResponseCallback<Schema$Project>): void;
        /**
         * Gets the shared VPC host project that this project links to. May be empty if no link exists.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getXpnHost(params: Params$Resource$Projects$Getxpnhost, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getXpnHost(params?: Params$Resource$Projects$Getxpnhost, options?: MethodOptions): GaxiosPromise<Schema$Project>;
        getXpnHost(params: Params$Resource$Projects$Getxpnhost, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getXpnHost(params: Params$Resource$Projects$Getxpnhost, options: MethodOptions | BodyResponseCallback<Schema$Project>, callback: BodyResponseCallback<Schema$Project>): void;
        getXpnHost(params: Params$Resource$Projects$Getxpnhost, callback: BodyResponseCallback<Schema$Project>): void;
        getXpnHost(callback: BodyResponseCallback<Schema$Project>): void;
        /**
         * Gets service resources (a.k.a service project) associated with this host project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getXpnResources(params: Params$Resource$Projects$Getxpnresources, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getXpnResources(params?: Params$Resource$Projects$Getxpnresources, options?: MethodOptions): GaxiosPromise<Schema$ProjectsGetXpnResources>;
        getXpnResources(params: Params$Resource$Projects$Getxpnresources, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getXpnResources(params: Params$Resource$Projects$Getxpnresources, options: MethodOptions | BodyResponseCallback<Schema$ProjectsGetXpnResources>, callback: BodyResponseCallback<Schema$ProjectsGetXpnResources>): void;
        getXpnResources(params: Params$Resource$Projects$Getxpnresources, callback: BodyResponseCallback<Schema$ProjectsGetXpnResources>): void;
        getXpnResources(callback: BodyResponseCallback<Schema$ProjectsGetXpnResources>): void;
        /**
         * Lists all shared VPC host projects visible to the user in an organization.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        listXpnHosts(params: Params$Resource$Projects$Listxpnhosts, options: StreamMethodOptions): GaxiosPromise<Readable>;
        listXpnHosts(params?: Params$Resource$Projects$Listxpnhosts, options?: MethodOptions): GaxiosPromise<Schema$XpnHostList>;
        listXpnHosts(params: Params$Resource$Projects$Listxpnhosts, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        listXpnHosts(params: Params$Resource$Projects$Listxpnhosts, options: MethodOptions | BodyResponseCallback<Schema$XpnHostList>, callback: BodyResponseCallback<Schema$XpnHostList>): void;
        listXpnHosts(params: Params$Resource$Projects$Listxpnhosts, callback: BodyResponseCallback<Schema$XpnHostList>): void;
        listXpnHosts(callback: BodyResponseCallback<Schema$XpnHostList>): void;
        /**
         * Moves a persistent disk from one zone to another.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        moveDisk(params: Params$Resource$Projects$Movedisk, options: StreamMethodOptions): GaxiosPromise<Readable>;
        moveDisk(params?: Params$Resource$Projects$Movedisk, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        moveDisk(params: Params$Resource$Projects$Movedisk, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        moveDisk(params: Params$Resource$Projects$Movedisk, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        moveDisk(params: Params$Resource$Projects$Movedisk, callback: BodyResponseCallback<Schema$Operation>): void;
        moveDisk(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Moves an instance and its attached persistent disks from one zone to another. *Note*: Moving VMs or disks by using this method might cause unexpected behavior. For more information, see the [known issue](/compute/docs/troubleshooting/known-issues#moving_vms_or_disks_using_the_moveinstance_api_or_the_causes_unexpected_behavior). [Deprecated] This method is deprecated. See [moving instance across zones](/compute/docs/instances/moving-instance-across-zones) instead.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        moveInstance(params: Params$Resource$Projects$Moveinstance, options: StreamMethodOptions): GaxiosPromise<Readable>;
        moveInstance(params?: Params$Resource$Projects$Moveinstance, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        moveInstance(params: Params$Resource$Projects$Moveinstance, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        moveInstance(params: Params$Resource$Projects$Moveinstance, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        moveInstance(params: Params$Resource$Projects$Moveinstance, callback: BodyResponseCallback<Schema$Operation>): void;
        moveInstance(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets metadata common to all instances within the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setCommonInstanceMetadata(params: Params$Resource$Projects$Setcommoninstancemetadata, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setCommonInstanceMetadata(params?: Params$Resource$Projects$Setcommoninstancemetadata, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setCommonInstanceMetadata(params: Params$Resource$Projects$Setcommoninstancemetadata, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setCommonInstanceMetadata(params: Params$Resource$Projects$Setcommoninstancemetadata, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setCommonInstanceMetadata(params: Params$Resource$Projects$Setcommoninstancemetadata, callback: BodyResponseCallback<Schema$Operation>): void;
        setCommonInstanceMetadata(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the default network tier of the project. The default network tier is used when an address/forwardingRule/instance is created without specifying the network tier field.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setDefaultNetworkTier(params: Params$Resource$Projects$Setdefaultnetworktier, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setDefaultNetworkTier(params?: Params$Resource$Projects$Setdefaultnetworktier, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setDefaultNetworkTier(params: Params$Resource$Projects$Setdefaultnetworktier, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setDefaultNetworkTier(params: Params$Resource$Projects$Setdefaultnetworktier, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setDefaultNetworkTier(params: Params$Resource$Projects$Setdefaultnetworktier, callback: BodyResponseCallback<Schema$Operation>): void;
        setDefaultNetworkTier(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the default service account of the project. The default service account is used when a VM instance is created with the service account email address set to "default".
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setDefaultServiceAccount(params: Params$Resource$Projects$Setdefaultserviceaccount, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setDefaultServiceAccount(params?: Params$Resource$Projects$Setdefaultserviceaccount, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setDefaultServiceAccount(params: Params$Resource$Projects$Setdefaultserviceaccount, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setDefaultServiceAccount(params: Params$Resource$Projects$Setdefaultserviceaccount, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setDefaultServiceAccount(params: Params$Resource$Projects$Setdefaultserviceaccount, callback: BodyResponseCallback<Schema$Operation>): void;
        setDefaultServiceAccount(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the Cloud Armor Managed Protection (CAMP) tier of the project. To set PLUS or above the billing account of the project must be subscribed to Managed Protection Plus. See Subscribing to Managed Protection Plus for more information.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setManagedProtectionTier(params: Params$Resource$Projects$Setmanagedprotectiontier, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setManagedProtectionTier(params?: Params$Resource$Projects$Setmanagedprotectiontier, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setManagedProtectionTier(params: Params$Resource$Projects$Setmanagedprotectiontier, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setManagedProtectionTier(params: Params$Resource$Projects$Setmanagedprotectiontier, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setManagedProtectionTier(params: Params$Resource$Projects$Setmanagedprotectiontier, callback: BodyResponseCallback<Schema$Operation>): void;
        setManagedProtectionTier(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Enables the usage export feature and sets the usage export bucket where reports are stored. If you provide an empty request body using this method, the usage export feature will be disabled.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setUsageExportBucket(params: Params$Resource$Projects$Setusageexportbucket, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setUsageExportBucket(params?: Params$Resource$Projects$Setusageexportbucket, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setUsageExportBucket(params: Params$Resource$Projects$Setusageexportbucket, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setUsageExportBucket(params: Params$Resource$Projects$Setusageexportbucket, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setUsageExportBucket(params: Params$Resource$Projects$Setusageexportbucket, callback: BodyResponseCallback<Schema$Operation>): void;
        setUsageExportBucket(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    export interface Params$Resource$Projects$Disablexpnhost extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Projects$Disablexpnresource extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ProjectsDisableXpnResourceRequest;
    }
    export interface Params$Resource$Projects$Enablexpnhost extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Projects$Enablexpnresource extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ProjectsEnableXpnResourceRequest;
    }
    export interface Params$Resource$Projects$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    export interface Params$Resource$Projects$Getxpnhost extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    export interface Params$Resource$Projects$Getxpnresources extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Projects$Listxpnhosts extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ProjectsListXpnHostsRequest;
    }
    export interface Params$Resource$Projects$Movedisk extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$DiskMoveRequest;
    }
    export interface Params$Resource$Projects$Moveinstance extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceMoveRequest;
    }
    export interface Params$Resource$Projects$Setcommoninstancemetadata extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Metadata;
    }
    export interface Params$Resource$Projects$Setdefaultnetworktier extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ProjectsSetDefaultNetworkTierRequest;
    }
    export interface Params$Resource$Projects$Setdefaultserviceaccount extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ProjectsSetDefaultServiceAccountRequest;
    }
    export interface Params$Resource$Projects$Setmanagedprotectiontier extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ProjectsSetManagedProtectionTierRequest;
    }
    export interface Params$Resource$Projects$Setusageexportbucket extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$UsageExportLocation;
    }
    export class Resource$Publicadvertisedprefixes {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Announces the specified PublicAdvertisedPrefix
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        announce(params: Params$Resource$Publicadvertisedprefixes$Announce, options: StreamMethodOptions): GaxiosPromise<Readable>;
        announce(params?: Params$Resource$Publicadvertisedprefixes$Announce, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        announce(params: Params$Resource$Publicadvertisedprefixes$Announce, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        announce(params: Params$Resource$Publicadvertisedprefixes$Announce, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        announce(params: Params$Resource$Publicadvertisedprefixes$Announce, callback: BodyResponseCallback<Schema$Operation>): void;
        announce(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Deletes the specified PublicAdvertisedPrefix
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Publicadvertisedprefixes$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Publicadvertisedprefixes$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Publicadvertisedprefixes$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Publicadvertisedprefixes$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Publicadvertisedprefixes$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified PublicAdvertisedPrefix resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Publicadvertisedprefixes$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Publicadvertisedprefixes$Get, options?: MethodOptions): GaxiosPromise<Schema$PublicAdvertisedPrefix>;
        get(params: Params$Resource$Publicadvertisedprefixes$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Publicadvertisedprefixes$Get, options: MethodOptions | BodyResponseCallback<Schema$PublicAdvertisedPrefix>, callback: BodyResponseCallback<Schema$PublicAdvertisedPrefix>): void;
        get(params: Params$Resource$Publicadvertisedprefixes$Get, callback: BodyResponseCallback<Schema$PublicAdvertisedPrefix>): void;
        get(callback: BodyResponseCallback<Schema$PublicAdvertisedPrefix>): void;
        /**
         * Creates a PublicAdvertisedPrefix in the specified project using the parameters that are included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Publicadvertisedprefixes$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Publicadvertisedprefixes$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Publicadvertisedprefixes$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Publicadvertisedprefixes$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Publicadvertisedprefixes$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Lists the PublicAdvertisedPrefixes for a project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Publicadvertisedprefixes$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Publicadvertisedprefixes$List, options?: MethodOptions): GaxiosPromise<Schema$PublicAdvertisedPrefixList>;
        list(params: Params$Resource$Publicadvertisedprefixes$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Publicadvertisedprefixes$List, options: MethodOptions | BodyResponseCallback<Schema$PublicAdvertisedPrefixList>, callback: BodyResponseCallback<Schema$PublicAdvertisedPrefixList>): void;
        list(params: Params$Resource$Publicadvertisedprefixes$List, callback: BodyResponseCallback<Schema$PublicAdvertisedPrefixList>): void;
        list(callback: BodyResponseCallback<Schema$PublicAdvertisedPrefixList>): void;
        /**
         * Patches the specified Router resource with the data included in the request. This method supports PATCH semantics and uses JSON merge patch format and processing rules.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Publicadvertisedprefixes$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Publicadvertisedprefixes$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Publicadvertisedprefixes$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Publicadvertisedprefixes$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Publicadvertisedprefixes$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Withdraws the specified PublicAdvertisedPrefix
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        withdraw(params: Params$Resource$Publicadvertisedprefixes$Withdraw, options: StreamMethodOptions): GaxiosPromise<Readable>;
        withdraw(params?: Params$Resource$Publicadvertisedprefixes$Withdraw, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        withdraw(params: Params$Resource$Publicadvertisedprefixes$Withdraw, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        withdraw(params: Params$Resource$Publicadvertisedprefixes$Withdraw, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        withdraw(params: Params$Resource$Publicadvertisedprefixes$Withdraw, callback: BodyResponseCallback<Schema$Operation>): void;
        withdraw(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    export interface Params$Resource$Publicadvertisedprefixes$Announce extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the public advertised prefix. It should comply with RFC1035.
         */
        publicAdvertisedPrefix?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Publicadvertisedprefixes$Delete extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the PublicAdvertisedPrefix resource to delete.
         */
        publicAdvertisedPrefix?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Publicadvertisedprefixes$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the PublicAdvertisedPrefix resource to return.
         */
        publicAdvertisedPrefix?: string;
    }
    export interface Params$Resource$Publicadvertisedprefixes$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$PublicAdvertisedPrefix;
    }
    export interface Params$Resource$Publicadvertisedprefixes$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Publicadvertisedprefixes$Patch extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the PublicAdvertisedPrefix resource to patch.
         */
        publicAdvertisedPrefix?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$PublicAdvertisedPrefix;
    }
    export interface Params$Resource$Publicadvertisedprefixes$Withdraw extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the public advertised prefix. It should comply with RFC1035.
         */
        publicAdvertisedPrefix?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export class Resource$Publicdelegatedprefixes {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Lists all PublicDelegatedPrefix resources owned by the specific project across all scopes.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Publicdelegatedprefixes$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Publicdelegatedprefixes$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$PublicDelegatedPrefixAggregatedList>;
        aggregatedList(params: Params$Resource$Publicdelegatedprefixes$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Publicdelegatedprefixes$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$PublicDelegatedPrefixAggregatedList>, callback: BodyResponseCallback<Schema$PublicDelegatedPrefixAggregatedList>): void;
        aggregatedList(params: Params$Resource$Publicdelegatedprefixes$Aggregatedlist, callback: BodyResponseCallback<Schema$PublicDelegatedPrefixAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$PublicDelegatedPrefixAggregatedList>): void;
        /**
         * Announces the specified PublicDelegatedPrefix in the given region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        announce(params: Params$Resource$Publicdelegatedprefixes$Announce, options: StreamMethodOptions): GaxiosPromise<Readable>;
        announce(params?: Params$Resource$Publicdelegatedprefixes$Announce, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        announce(params: Params$Resource$Publicdelegatedprefixes$Announce, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        announce(params: Params$Resource$Publicdelegatedprefixes$Announce, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        announce(params: Params$Resource$Publicdelegatedprefixes$Announce, callback: BodyResponseCallback<Schema$Operation>): void;
        announce(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Deletes the specified PublicDelegatedPrefix in the given region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Publicdelegatedprefixes$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Publicdelegatedprefixes$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Publicdelegatedprefixes$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Publicdelegatedprefixes$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Publicdelegatedprefixes$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified PublicDelegatedPrefix resource in the given region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Publicdelegatedprefixes$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Publicdelegatedprefixes$Get, options?: MethodOptions): GaxiosPromise<Schema$PublicDelegatedPrefix>;
        get(params: Params$Resource$Publicdelegatedprefixes$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Publicdelegatedprefixes$Get, options: MethodOptions | BodyResponseCallback<Schema$PublicDelegatedPrefix>, callback: BodyResponseCallback<Schema$PublicDelegatedPrefix>): void;
        get(params: Params$Resource$Publicdelegatedprefixes$Get, callback: BodyResponseCallback<Schema$PublicDelegatedPrefix>): void;
        get(callback: BodyResponseCallback<Schema$PublicDelegatedPrefix>): void;
        /**
         * Creates a PublicDelegatedPrefix in the specified project in the given region using the parameters that are included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Publicdelegatedprefixes$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Publicdelegatedprefixes$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Publicdelegatedprefixes$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Publicdelegatedprefixes$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Publicdelegatedprefixes$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Lists the PublicDelegatedPrefixes for a project in the given region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Publicdelegatedprefixes$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Publicdelegatedprefixes$List, options?: MethodOptions): GaxiosPromise<Schema$PublicDelegatedPrefixList>;
        list(params: Params$Resource$Publicdelegatedprefixes$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Publicdelegatedprefixes$List, options: MethodOptions | BodyResponseCallback<Schema$PublicDelegatedPrefixList>, callback: BodyResponseCallback<Schema$PublicDelegatedPrefixList>): void;
        list(params: Params$Resource$Publicdelegatedprefixes$List, callback: BodyResponseCallback<Schema$PublicDelegatedPrefixList>): void;
        list(callback: BodyResponseCallback<Schema$PublicDelegatedPrefixList>): void;
        /**
         * Patches the specified PublicDelegatedPrefix resource with the data included in the request. This method supports PATCH semantics and uses JSON merge patch format and processing rules.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Publicdelegatedprefixes$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Publicdelegatedprefixes$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Publicdelegatedprefixes$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Publicdelegatedprefixes$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Publicdelegatedprefixes$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Withdraws the specified PublicDelegatedPrefix in the given region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        withdraw(params: Params$Resource$Publicdelegatedprefixes$Withdraw, options: StreamMethodOptions): GaxiosPromise<Readable>;
        withdraw(params?: Params$Resource$Publicdelegatedprefixes$Withdraw, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        withdraw(params: Params$Resource$Publicdelegatedprefixes$Withdraw, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        withdraw(params: Params$Resource$Publicdelegatedprefixes$Withdraw, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        withdraw(params: Params$Resource$Publicdelegatedprefixes$Withdraw, callback: BodyResponseCallback<Schema$Operation>): void;
        withdraw(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    export interface Params$Resource$Publicdelegatedprefixes$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Name of the project scoping this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Publicdelegatedprefixes$Announce extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the public delegated prefix. It should comply with RFC1035.
         */
        publicDelegatedPrefix?: string;
        /**
         * The name of the region where the public delegated prefix is located. It should comply with RFC1035.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Publicdelegatedprefixes$Delete extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the PublicDelegatedPrefix resource to delete.
         */
        publicDelegatedPrefix?: string;
        /**
         * Name of the region of this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Publicdelegatedprefixes$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the PublicDelegatedPrefix resource to return.
         */
        publicDelegatedPrefix?: string;
        /**
         * Name of the region of this request.
         */
        region?: string;
    }
    export interface Params$Resource$Publicdelegatedprefixes$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region of this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$PublicDelegatedPrefix;
    }
    export interface Params$Resource$Publicdelegatedprefixes$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region of this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Publicdelegatedprefixes$Patch extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the PublicDelegatedPrefix resource to patch.
         */
        publicDelegatedPrefix?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$PublicDelegatedPrefix;
    }
    export interface Params$Resource$Publicdelegatedprefixes$Withdraw extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the public delegated prefix. It should comply with RFC1035.
         */
        publicDelegatedPrefix?: string;
        /**
         * The name of the region where the public delegated prefix is located. It should comply with RFC1035.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export class Resource$Regionautoscalers {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Deletes the specified autoscaler.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Regionautoscalers$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Regionautoscalers$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Regionautoscalers$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Regionautoscalers$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Regionautoscalers$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified autoscaler.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Regionautoscalers$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Regionautoscalers$Get, options?: MethodOptions): GaxiosPromise<Schema$Autoscaler>;
        get(params: Params$Resource$Regionautoscalers$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Regionautoscalers$Get, options: MethodOptions | BodyResponseCallback<Schema$Autoscaler>, callback: BodyResponseCallback<Schema$Autoscaler>): void;
        get(params: Params$Resource$Regionautoscalers$Get, callback: BodyResponseCallback<Schema$Autoscaler>): void;
        get(callback: BodyResponseCallback<Schema$Autoscaler>): void;
        /**
         * Creates an autoscaler in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Regionautoscalers$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Regionautoscalers$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Regionautoscalers$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Regionautoscalers$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Regionautoscalers$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves a list of autoscalers contained within the specified region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Regionautoscalers$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Regionautoscalers$List, options?: MethodOptions): GaxiosPromise<Schema$RegionAutoscalerList>;
        list(params: Params$Resource$Regionautoscalers$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Regionautoscalers$List, options: MethodOptions | BodyResponseCallback<Schema$RegionAutoscalerList>, callback: BodyResponseCallback<Schema$RegionAutoscalerList>): void;
        list(params: Params$Resource$Regionautoscalers$List, callback: BodyResponseCallback<Schema$RegionAutoscalerList>): void;
        list(callback: BodyResponseCallback<Schema$RegionAutoscalerList>): void;
        /**
         * Updates an autoscaler in the specified project using the data included in the request. This method supports PATCH semantics and uses the JSON merge patch format and processing rules.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Regionautoscalers$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Regionautoscalers$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Regionautoscalers$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Regionautoscalers$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Regionautoscalers$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Regionautoscalers$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Regionautoscalers$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Regionautoscalers$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Regionautoscalers$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Regionautoscalers$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        /**
         * Updates an autoscaler in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        update(params: Params$Resource$Regionautoscalers$Update, options: StreamMethodOptions): GaxiosPromise<Readable>;
        update(params?: Params$Resource$Regionautoscalers$Update, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        update(params: Params$Resource$Regionautoscalers$Update, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        update(params: Params$Resource$Regionautoscalers$Update, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        update(params: Params$Resource$Regionautoscalers$Update, callback: BodyResponseCallback<Schema$Operation>): void;
        update(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    export interface Params$Resource$Regionautoscalers$Delete extends StandardParameters {
        /**
         * Name of the autoscaler to delete.
         */
        autoscaler?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Regionautoscalers$Get extends StandardParameters {
        /**
         * Name of the autoscaler to return.
         */
        autoscaler?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
    }
    export interface Params$Resource$Regionautoscalers$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Autoscaler;
    }
    export interface Params$Resource$Regionautoscalers$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Regionautoscalers$Patch extends StandardParameters {
        /**
         * Name of the autoscaler to patch.
         */
        autoscaler?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Autoscaler;
    }
    export interface Params$Resource$Regionautoscalers$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export interface Params$Resource$Regionautoscalers$Update extends StandardParameters {
        /**
         * Name of the autoscaler to update.
         */
        autoscaler?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Autoscaler;
    }
    export class Resource$Regionbackendservices {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Deletes the specified regional BackendService resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Regionbackendservices$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Regionbackendservices$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Regionbackendservices$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Regionbackendservices$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Regionbackendservices$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified regional BackendService resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Regionbackendservices$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Regionbackendservices$Get, options?: MethodOptions): GaxiosPromise<Schema$BackendService>;
        get(params: Params$Resource$Regionbackendservices$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Regionbackendservices$Get, options: MethodOptions | BodyResponseCallback<Schema$BackendService>, callback: BodyResponseCallback<Schema$BackendService>): void;
        get(params: Params$Resource$Regionbackendservices$Get, callback: BodyResponseCallback<Schema$BackendService>): void;
        get(callback: BodyResponseCallback<Schema$BackendService>): void;
        /**
         * Gets the most recent health check results for this regional BackendService.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getHealth(params: Params$Resource$Regionbackendservices$Gethealth, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getHealth(params?: Params$Resource$Regionbackendservices$Gethealth, options?: MethodOptions): GaxiosPromise<Schema$BackendServiceGroupHealth>;
        getHealth(params: Params$Resource$Regionbackendservices$Gethealth, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getHealth(params: Params$Resource$Regionbackendservices$Gethealth, options: MethodOptions | BodyResponseCallback<Schema$BackendServiceGroupHealth>, callback: BodyResponseCallback<Schema$BackendServiceGroupHealth>): void;
        getHealth(params: Params$Resource$Regionbackendservices$Gethealth, callback: BodyResponseCallback<Schema$BackendServiceGroupHealth>): void;
        getHealth(callback: BodyResponseCallback<Schema$BackendServiceGroupHealth>): void;
        /**
         * Gets the access control policy for a resource. May be empty if no such policy or resource exists.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getIamPolicy(params: Params$Resource$Regionbackendservices$Getiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getIamPolicy(params?: Params$Resource$Regionbackendservices$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        getIamPolicy(params: Params$Resource$Regionbackendservices$Getiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getIamPolicy(params: Params$Resource$Regionbackendservices$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(params: Params$Resource$Regionbackendservices$Getiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Creates a regional BackendService resource in the specified project using the data included in the request. For more information, see Backend services overview.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Regionbackendservices$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Regionbackendservices$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Regionbackendservices$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Regionbackendservices$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Regionbackendservices$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of regional BackendService resources available to the specified project in the given region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Regionbackendservices$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Regionbackendservices$List, options?: MethodOptions): GaxiosPromise<Schema$BackendServiceList>;
        list(params: Params$Resource$Regionbackendservices$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Regionbackendservices$List, options: MethodOptions | BodyResponseCallback<Schema$BackendServiceList>, callback: BodyResponseCallback<Schema$BackendServiceList>): void;
        list(params: Params$Resource$Regionbackendservices$List, callback: BodyResponseCallback<Schema$BackendServiceList>): void;
        list(callback: BodyResponseCallback<Schema$BackendServiceList>): void;
        /**
         * Retrieves an aggregated list of all usable backend services in the specified project in the given region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        listUsable(params: Params$Resource$Regionbackendservices$Listusable, options: StreamMethodOptions): GaxiosPromise<Readable>;
        listUsable(params?: Params$Resource$Regionbackendservices$Listusable, options?: MethodOptions): GaxiosPromise<Schema$BackendServiceListUsable>;
        listUsable(params: Params$Resource$Regionbackendservices$Listusable, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        listUsable(params: Params$Resource$Regionbackendservices$Listusable, options: MethodOptions | BodyResponseCallback<Schema$BackendServiceListUsable>, callback: BodyResponseCallback<Schema$BackendServiceListUsable>): void;
        listUsable(params: Params$Resource$Regionbackendservices$Listusable, callback: BodyResponseCallback<Schema$BackendServiceListUsable>): void;
        listUsable(callback: BodyResponseCallback<Schema$BackendServiceListUsable>): void;
        /**
         * Updates the specified regional BackendService resource with the data included in the request. For more information, see Understanding backend services This method supports PATCH semantics and uses the JSON merge patch format and processing rules.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Regionbackendservices$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Regionbackendservices$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Regionbackendservices$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Regionbackendservices$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Regionbackendservices$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the access control policy on the specified resource. Replaces any existing policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setIamPolicy(params: Params$Resource$Regionbackendservices$Setiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setIamPolicy(params?: Params$Resource$Regionbackendservices$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        setIamPolicy(params: Params$Resource$Regionbackendservices$Setiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setIamPolicy(params: Params$Resource$Regionbackendservices$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(params: Params$Resource$Regionbackendservices$Setiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Sets the Google Cloud Armor security policy for the specified backend service. For more information, see Google Cloud Armor Overview
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setSecurityPolicy(params: Params$Resource$Regionbackendservices$Setsecuritypolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setSecurityPolicy(params?: Params$Resource$Regionbackendservices$Setsecuritypolicy, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setSecurityPolicy(params: Params$Resource$Regionbackendservices$Setsecuritypolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setSecurityPolicy(params: Params$Resource$Regionbackendservices$Setsecuritypolicy, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setSecurityPolicy(params: Params$Resource$Regionbackendservices$Setsecuritypolicy, callback: BodyResponseCallback<Schema$Operation>): void;
        setSecurityPolicy(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Regionbackendservices$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Regionbackendservices$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Regionbackendservices$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Regionbackendservices$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Regionbackendservices$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        /**
         * Updates the specified regional BackendService resource with the data included in the request. For more information, see Backend services overview .
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        update(params: Params$Resource$Regionbackendservices$Update, options: StreamMethodOptions): GaxiosPromise<Readable>;
        update(params?: Params$Resource$Regionbackendservices$Update, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        update(params: Params$Resource$Regionbackendservices$Update, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        update(params: Params$Resource$Regionbackendservices$Update, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        update(params: Params$Resource$Regionbackendservices$Update, callback: BodyResponseCallback<Schema$Operation>): void;
        update(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    export interface Params$Resource$Regionbackendservices$Delete extends StandardParameters {
        /**
         * Name of the BackendService resource to delete.
         */
        backendService?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Regionbackendservices$Get extends StandardParameters {
        /**
         * Name of the BackendService resource to return.
         */
        backendService?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
    }
    export interface Params$Resource$Regionbackendservices$Gethealth extends StandardParameters {
        /**
         * Name of the BackendService resource for which to get health.
         */
        backendService?: string;
        /**
         *
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ResourceGroupReference;
    }
    export interface Params$Resource$Regionbackendservices$Getiampolicy extends StandardParameters {
        /**
         * Requested IAM Policy version.
         */
        optionsRequestedPolicyVersion?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
    }
    export interface Params$Resource$Regionbackendservices$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$BackendService;
    }
    export interface Params$Resource$Regionbackendservices$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Regionbackendservices$Listusable extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request. It must be a string that meets the requirements in RFC1035.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Regionbackendservices$Patch extends StandardParameters {
        /**
         * Name of the BackendService resource to patch.
         */
        backendService?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$BackendService;
    }
    export interface Params$Resource$Regionbackendservices$Setiampolicy extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionSetPolicyRequest;
    }
    export interface Params$Resource$Regionbackendservices$Setsecuritypolicy extends StandardParameters {
        /**
         * Name of the BackendService resource to which the security policy should be set. The name should conform to RFC1035.
         */
        backendService?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SecurityPolicyReference;
    }
    export interface Params$Resource$Regionbackendservices$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export interface Params$Resource$Regionbackendservices$Update extends StandardParameters {
        /**
         * Name of the BackendService resource to update.
         */
        backendService?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$BackendService;
    }
    export class Resource$Regioncommitments {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves an aggregated list of commitments by region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Regioncommitments$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Regioncommitments$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$CommitmentAggregatedList>;
        aggregatedList(params: Params$Resource$Regioncommitments$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Regioncommitments$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$CommitmentAggregatedList>, callback: BodyResponseCallback<Schema$CommitmentAggregatedList>): void;
        aggregatedList(params: Params$Resource$Regioncommitments$Aggregatedlist, callback: BodyResponseCallback<Schema$CommitmentAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$CommitmentAggregatedList>): void;
        /**
         * Calculate cancellation fee for the specified commitment.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        calculateCancellationFee(params: Params$Resource$Regioncommitments$Calculatecancellationfee, options: StreamMethodOptions): GaxiosPromise<Readable>;
        calculateCancellationFee(params?: Params$Resource$Regioncommitments$Calculatecancellationfee, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        calculateCancellationFee(params: Params$Resource$Regioncommitments$Calculatecancellationfee, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        calculateCancellationFee(params: Params$Resource$Regioncommitments$Calculatecancellationfee, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        calculateCancellationFee(params: Params$Resource$Regioncommitments$Calculatecancellationfee, callback: BodyResponseCallback<Schema$Operation>): void;
        calculateCancellationFee(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Cancel the specified commitment.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Regioncommitments$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Regioncommitments$Cancel, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        cancel(params: Params$Resource$Regioncommitments$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Regioncommitments$Cancel, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        cancel(params: Params$Resource$Regioncommitments$Cancel, callback: BodyResponseCallback<Schema$Operation>): void;
        cancel(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified commitment resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Regioncommitments$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Regioncommitments$Get, options?: MethodOptions): GaxiosPromise<Schema$Commitment>;
        get(params: Params$Resource$Regioncommitments$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Regioncommitments$Get, options: MethodOptions | BodyResponseCallback<Schema$Commitment>, callback: BodyResponseCallback<Schema$Commitment>): void;
        get(params: Params$Resource$Regioncommitments$Get, callback: BodyResponseCallback<Schema$Commitment>): void;
        get(callback: BodyResponseCallback<Schema$Commitment>): void;
        /**
         * Creates a commitment in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Regioncommitments$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Regioncommitments$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Regioncommitments$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Regioncommitments$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Regioncommitments$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves a list of commitments contained within the specified region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Regioncommitments$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Regioncommitments$List, options?: MethodOptions): GaxiosPromise<Schema$CommitmentList>;
        list(params: Params$Resource$Regioncommitments$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Regioncommitments$List, options: MethodOptions | BodyResponseCallback<Schema$CommitmentList>, callback: BodyResponseCallback<Schema$CommitmentList>): void;
        list(params: Params$Resource$Regioncommitments$List, callback: BodyResponseCallback<Schema$CommitmentList>): void;
        list(callback: BodyResponseCallback<Schema$CommitmentList>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Regioncommitments$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Regioncommitments$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Regioncommitments$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Regioncommitments$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Regioncommitments$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        /**
         * Updates the specified commitment with the data included in the request. Update is performed only on selected fields included as part of update-mask. Only the following fields can be modified: auto_renew.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        update(params: Params$Resource$Regioncommitments$Update, options: StreamMethodOptions): GaxiosPromise<Readable>;
        update(params?: Params$Resource$Regioncommitments$Update, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        update(params: Params$Resource$Regioncommitments$Update, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        update(params: Params$Resource$Regioncommitments$Update, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        update(params: Params$Resource$Regioncommitments$Update, callback: BodyResponseCallback<Schema$Operation>): void;
        update(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Transfers GPUs or local SSDs between reservations within commitments.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        updateReservations(params: Params$Resource$Regioncommitments$Updatereservations, options: StreamMethodOptions): GaxiosPromise<Readable>;
        updateReservations(params?: Params$Resource$Regioncommitments$Updatereservations, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        updateReservations(params: Params$Resource$Regioncommitments$Updatereservations, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        updateReservations(params: Params$Resource$Regioncommitments$Updatereservations, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        updateReservations(params: Params$Resource$Regioncommitments$Updatereservations, callback: BodyResponseCallback<Schema$Operation>): void;
        updateReservations(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    export interface Params$Resource$Regioncommitments$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Regioncommitments$Calculatecancellationfee extends StandardParameters {
        /**
         * Name of the commitment to delete.
         */
        commitment?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Regioncommitments$Cancel extends StandardParameters {
        /**
         * Name of the commitment to delete.
         */
        commitment?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Regioncommitments$Get extends StandardParameters {
        /**
         * Name of the commitment to return.
         */
        commitment?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
    }
    export interface Params$Resource$Regioncommitments$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Commitment;
    }
    export interface Params$Resource$Regioncommitments$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Regioncommitments$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export interface Params$Resource$Regioncommitments$Update extends StandardParameters {
        /**
         * Name of the commitment for which auto renew is being updated.
         */
        commitment?: string;
        /**
         *
         */
        paths?: string[];
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * update_mask indicates fields to be updated as part of this request.
         */
        updateMask?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Commitment;
    }
    export interface Params$Resource$Regioncommitments$Updatereservations extends StandardParameters {
        /**
         * Name of the commitment for which the reservation is being updated.
         */
        commitment?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionCommitmentsUpdateReservationsRequest;
    }
    export class Resource$Regiondisks {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Adds existing resource policies to a regional disk. You can only add one policy which will be applied to this disk for scheduling snapshot creation.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        addResourcePolicies(params: Params$Resource$Regiondisks$Addresourcepolicies, options: StreamMethodOptions): GaxiosPromise<Readable>;
        addResourcePolicies(params?: Params$Resource$Regiondisks$Addresourcepolicies, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        addResourcePolicies(params: Params$Resource$Regiondisks$Addresourcepolicies, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        addResourcePolicies(params: Params$Resource$Regiondisks$Addresourcepolicies, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        addResourcePolicies(params: Params$Resource$Regiondisks$Addresourcepolicies, callback: BodyResponseCallback<Schema$Operation>): void;
        addResourcePolicies(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Bulk create a set of disks.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        bulkInsert(params: Params$Resource$Regiondisks$Bulkinsert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        bulkInsert(params?: Params$Resource$Regiondisks$Bulkinsert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        bulkInsert(params: Params$Resource$Regiondisks$Bulkinsert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        bulkInsert(params: Params$Resource$Regiondisks$Bulkinsert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        bulkInsert(params: Params$Resource$Regiondisks$Bulkinsert, callback: BodyResponseCallback<Schema$Operation>): void;
        bulkInsert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Creates a snapshot of a specified persistent disk. For regular snapshot creation, consider using snapshots.insert instead, as that method supports more features, such as creating snapshots in a project different from the source disk project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        createSnapshot(params: Params$Resource$Regiondisks$Createsnapshot, options: StreamMethodOptions): GaxiosPromise<Readable>;
        createSnapshot(params?: Params$Resource$Regiondisks$Createsnapshot, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        createSnapshot(params: Params$Resource$Regiondisks$Createsnapshot, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        createSnapshot(params: Params$Resource$Regiondisks$Createsnapshot, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        createSnapshot(params: Params$Resource$Regiondisks$Createsnapshot, callback: BodyResponseCallback<Schema$Operation>): void;
        createSnapshot(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Deletes the specified regional persistent disk. Deleting a regional disk removes all the replicas of its data permanently and is irreversible. However, deleting a disk does not delete any snapshots previously made from the disk. You must separately delete snapshots.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Regiondisks$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Regiondisks$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Regiondisks$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Regiondisks$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Regiondisks$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns a specified regional persistent disk.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Regiondisks$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Regiondisks$Get, options?: MethodOptions): GaxiosPromise<Schema$Disk>;
        get(params: Params$Resource$Regiondisks$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Regiondisks$Get, options: MethodOptions | BodyResponseCallback<Schema$Disk>, callback: BodyResponseCallback<Schema$Disk>): void;
        get(params: Params$Resource$Regiondisks$Get, callback: BodyResponseCallback<Schema$Disk>): void;
        get(callback: BodyResponseCallback<Schema$Disk>): void;
        /**
         * Gets the access control policy for a resource. May be empty if no such policy or resource exists.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getIamPolicy(params: Params$Resource$Regiondisks$Getiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getIamPolicy(params?: Params$Resource$Regiondisks$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        getIamPolicy(params: Params$Resource$Regiondisks$Getiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getIamPolicy(params: Params$Resource$Regiondisks$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(params: Params$Resource$Regiondisks$Getiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Creates a persistent regional disk in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Regiondisks$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Regiondisks$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Regiondisks$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Regiondisks$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Regiondisks$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of persistent disks contained within the specified region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Regiondisks$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Regiondisks$List, options?: MethodOptions): GaxiosPromise<Schema$DiskList>;
        list(params: Params$Resource$Regiondisks$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Regiondisks$List, options: MethodOptions | BodyResponseCallback<Schema$DiskList>, callback: BodyResponseCallback<Schema$DiskList>): void;
        list(params: Params$Resource$Regiondisks$List, callback: BodyResponseCallback<Schema$DiskList>): void;
        list(callback: BodyResponseCallback<Schema$DiskList>): void;
        /**
         * Removes resource policies from a regional disk.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        removeResourcePolicies(params: Params$Resource$Regiondisks$Removeresourcepolicies, options: StreamMethodOptions): GaxiosPromise<Readable>;
        removeResourcePolicies(params?: Params$Resource$Regiondisks$Removeresourcepolicies, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        removeResourcePolicies(params: Params$Resource$Regiondisks$Removeresourcepolicies, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        removeResourcePolicies(params: Params$Resource$Regiondisks$Removeresourcepolicies, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        removeResourcePolicies(params: Params$Resource$Regiondisks$Removeresourcepolicies, callback: BodyResponseCallback<Schema$Operation>): void;
        removeResourcePolicies(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Resizes the specified regional persistent disk.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        resize(params: Params$Resource$Regiondisks$Resize, options: StreamMethodOptions): GaxiosPromise<Readable>;
        resize(params?: Params$Resource$Regiondisks$Resize, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        resize(params: Params$Resource$Regiondisks$Resize, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        resize(params: Params$Resource$Regiondisks$Resize, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        resize(params: Params$Resource$Regiondisks$Resize, callback: BodyResponseCallback<Schema$Operation>): void;
        resize(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the access control policy on the specified resource. Replaces any existing policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setIamPolicy(params: Params$Resource$Regiondisks$Setiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setIamPolicy(params?: Params$Resource$Regiondisks$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        setIamPolicy(params: Params$Resource$Regiondisks$Setiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setIamPolicy(params: Params$Resource$Regiondisks$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(params: Params$Resource$Regiondisks$Setiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Sets the labels on the target regional disk.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setLabels(params: Params$Resource$Regiondisks$Setlabels, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setLabels(params?: Params$Resource$Regiondisks$Setlabels, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setLabels(params: Params$Resource$Regiondisks$Setlabels, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setLabels(params: Params$Resource$Regiondisks$Setlabels, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(params: Params$Resource$Regiondisks$Setlabels, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Starts asynchronous replication. Must be invoked on the primary disk.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        startAsyncReplication(params: Params$Resource$Regiondisks$Startasyncreplication, options: StreamMethodOptions): GaxiosPromise<Readable>;
        startAsyncReplication(params?: Params$Resource$Regiondisks$Startasyncreplication, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        startAsyncReplication(params: Params$Resource$Regiondisks$Startasyncreplication, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        startAsyncReplication(params: Params$Resource$Regiondisks$Startasyncreplication, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        startAsyncReplication(params: Params$Resource$Regiondisks$Startasyncreplication, callback: BodyResponseCallback<Schema$Operation>): void;
        startAsyncReplication(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Stops asynchronous replication. Can be invoked either on the primary or on the secondary disk.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        stopAsyncReplication(params: Params$Resource$Regiondisks$Stopasyncreplication, options: StreamMethodOptions): GaxiosPromise<Readable>;
        stopAsyncReplication(params?: Params$Resource$Regiondisks$Stopasyncreplication, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        stopAsyncReplication(params: Params$Resource$Regiondisks$Stopasyncreplication, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        stopAsyncReplication(params: Params$Resource$Regiondisks$Stopasyncreplication, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        stopAsyncReplication(params: Params$Resource$Regiondisks$Stopasyncreplication, callback: BodyResponseCallback<Schema$Operation>): void;
        stopAsyncReplication(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Stops asynchronous replication for a consistency group of disks. Can be invoked either in the primary or secondary scope.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        stopGroupAsyncReplication(params: Params$Resource$Regiondisks$Stopgroupasyncreplication, options: StreamMethodOptions): GaxiosPromise<Readable>;
        stopGroupAsyncReplication(params?: Params$Resource$Regiondisks$Stopgroupasyncreplication, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        stopGroupAsyncReplication(params: Params$Resource$Regiondisks$Stopgroupasyncreplication, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        stopGroupAsyncReplication(params: Params$Resource$Regiondisks$Stopgroupasyncreplication, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        stopGroupAsyncReplication(params: Params$Resource$Regiondisks$Stopgroupasyncreplication, callback: BodyResponseCallback<Schema$Operation>): void;
        stopGroupAsyncReplication(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Regiondisks$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Regiondisks$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Regiondisks$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Regiondisks$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Regiondisks$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        /**
         * Update the specified disk with the data included in the request. Update is performed only on selected fields included as part of update-mask. Only the following fields can be modified: user_license.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        update(params: Params$Resource$Regiondisks$Update, options: StreamMethodOptions): GaxiosPromise<Readable>;
        update(params?: Params$Resource$Regiondisks$Update, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        update(params: Params$Resource$Regiondisks$Update, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        update(params: Params$Resource$Regiondisks$Update, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        update(params: Params$Resource$Regiondisks$Update, callback: BodyResponseCallback<Schema$Operation>): void;
        update(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    export interface Params$Resource$Regiondisks$Addresourcepolicies extends StandardParameters {
        /**
         * The disk name for this request.
         */
        disk?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionDisksAddResourcePoliciesRequest;
    }
    export interface Params$Resource$Regiondisks$Bulkinsert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$BulkInsertDiskResource;
    }
    export interface Params$Resource$Regiondisks$Createsnapshot extends StandardParameters {
        /**
         * Name of the regional persistent disk to snapshot.
         */
        disk?: string;
        /**
         * [Input Only] Specifies to create an application consistent snapshot by informing the OS to prepare for the snapshot process.
         */
        guestFlush?: boolean;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Snapshot;
    }
    export interface Params$Resource$Regiondisks$Delete extends StandardParameters {
        /**
         * Name of the regional persistent disk to delete.
         */
        disk?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Regiondisks$Get extends StandardParameters {
        /**
         * Name of the regional persistent disk to return.
         */
        disk?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
    }
    export interface Params$Resource$Regiondisks$Getiampolicy extends StandardParameters {
        /**
         * Requested IAM Policy version.
         */
        optionsRequestedPolicyVersion?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
    }
    export interface Params$Resource$Regiondisks$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Source image to restore onto a disk. This field is optional.
         */
        sourceImage?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Disk;
    }
    export interface Params$Resource$Regiondisks$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Regiondisks$Removeresourcepolicies extends StandardParameters {
        /**
         * The disk name for this request.
         */
        disk?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionDisksRemoveResourcePoliciesRequest;
    }
    export interface Params$Resource$Regiondisks$Resize extends StandardParameters {
        /**
         * Name of the regional persistent disk.
         */
        disk?: string;
        /**
         * The project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionDisksResizeRequest;
    }
    export interface Params$Resource$Regiondisks$Setiampolicy extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionSetPolicyRequest;
    }
    export interface Params$Resource$Regiondisks$Setlabels extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionSetLabelsRequest;
    }
    export interface Params$Resource$Regiondisks$Startasyncreplication extends StandardParameters {
        /**
         * The name of the persistent disk.
         */
        disk?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionDisksStartAsyncReplicationRequest;
    }
    export interface Params$Resource$Regiondisks$Stopasyncreplication extends StandardParameters {
        /**
         * The name of the persistent disk.
         */
        disk?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Regiondisks$Stopgroupasyncreplication extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request. This must be the region of the primary or secondary disks in the consistency group.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$DisksStopGroupAsyncReplicationResource;
    }
    export interface Params$Resource$Regiondisks$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export interface Params$Resource$Regiondisks$Update extends StandardParameters {
        /**
         * The disk name for this request.
         */
        disk?: string;
        /**
         *
         */
        paths?: string[];
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * update_mask indicates fields to be updated as part of this request.
         */
        updateMask?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Disk;
    }
    export class Resource$Regiondisksettings {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Get Regional Disk Settings.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Regiondisksettings$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Regiondisksettings$Get, options?: MethodOptions): GaxiosPromise<Schema$DiskSettings>;
        get(params: Params$Resource$Regiondisksettings$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Regiondisksettings$Get, options: MethodOptions | BodyResponseCallback<Schema$DiskSettings>, callback: BodyResponseCallback<Schema$DiskSettings>): void;
        get(params: Params$Resource$Regiondisksettings$Get, callback: BodyResponseCallback<Schema$DiskSettings>): void;
        get(callback: BodyResponseCallback<Schema$DiskSettings>): void;
        /**
         * Patch Regional Disk Settings
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Regiondisksettings$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Regiondisksettings$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Regiondisksettings$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Regiondisksettings$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Regiondisksettings$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    export interface Params$Resource$Regiondisksettings$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
    }
    export interface Params$Resource$Regiondisksettings$Patch extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * update_mask indicates fields to be updated as part of this request.
         */
        updateMask?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$DiskSettings;
    }
    export class Resource$Regiondisktypes {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Returns the specified regional disk type.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Regiondisktypes$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Regiondisktypes$Get, options?: MethodOptions): GaxiosPromise<Schema$DiskType>;
        get(params: Params$Resource$Regiondisktypes$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Regiondisktypes$Get, options: MethodOptions | BodyResponseCallback<Schema$DiskType>, callback: BodyResponseCallback<Schema$DiskType>): void;
        get(params: Params$Resource$Regiondisktypes$Get, callback: BodyResponseCallback<Schema$DiskType>): void;
        get(callback: BodyResponseCallback<Schema$DiskType>): void;
        /**
         * Retrieves a list of regional disk types available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Regiondisktypes$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Regiondisktypes$List, options?: MethodOptions): GaxiosPromise<Schema$RegionDiskTypeList>;
        list(params: Params$Resource$Regiondisktypes$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Regiondisktypes$List, options: MethodOptions | BodyResponseCallback<Schema$RegionDiskTypeList>, callback: BodyResponseCallback<Schema$RegionDiskTypeList>): void;
        list(params: Params$Resource$Regiondisktypes$List, callback: BodyResponseCallback<Schema$RegionDiskTypeList>): void;
        list(callback: BodyResponseCallback<Schema$RegionDiskTypeList>): void;
    }
    export interface Params$Resource$Regiondisktypes$Get extends StandardParameters {
        /**
         * Name of the disk type to return.
         */
        diskType?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
    }
    export interface Params$Resource$Regiondisktypes$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export class Resource$Regionhealthchecks {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Deletes the specified HealthCheck resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Regionhealthchecks$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Regionhealthchecks$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Regionhealthchecks$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Regionhealthchecks$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Regionhealthchecks$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified HealthCheck resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Regionhealthchecks$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Regionhealthchecks$Get, options?: MethodOptions): GaxiosPromise<Schema$HealthCheck>;
        get(params: Params$Resource$Regionhealthchecks$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Regionhealthchecks$Get, options: MethodOptions | BodyResponseCallback<Schema$HealthCheck>, callback: BodyResponseCallback<Schema$HealthCheck>): void;
        get(params: Params$Resource$Regionhealthchecks$Get, callback: BodyResponseCallback<Schema$HealthCheck>): void;
        get(callback: BodyResponseCallback<Schema$HealthCheck>): void;
        /**
         * Creates a HealthCheck resource in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Regionhealthchecks$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Regionhealthchecks$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Regionhealthchecks$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Regionhealthchecks$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Regionhealthchecks$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of HealthCheck resources available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Regionhealthchecks$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Regionhealthchecks$List, options?: MethodOptions): GaxiosPromise<Schema$HealthCheckList>;
        list(params: Params$Resource$Regionhealthchecks$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Regionhealthchecks$List, options: MethodOptions | BodyResponseCallback<Schema$HealthCheckList>, callback: BodyResponseCallback<Schema$HealthCheckList>): void;
        list(params: Params$Resource$Regionhealthchecks$List, callback: BodyResponseCallback<Schema$HealthCheckList>): void;
        list(callback: BodyResponseCallback<Schema$HealthCheckList>): void;
        /**
         * Updates a HealthCheck resource in the specified project using the data included in the request. This method supports PATCH semantics and uses the JSON merge patch format and processing rules.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Regionhealthchecks$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Regionhealthchecks$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Regionhealthchecks$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Regionhealthchecks$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Regionhealthchecks$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Regionhealthchecks$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Regionhealthchecks$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Regionhealthchecks$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Regionhealthchecks$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Regionhealthchecks$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        /**
         * Updates a HealthCheck resource in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        update(params: Params$Resource$Regionhealthchecks$Update, options: StreamMethodOptions): GaxiosPromise<Readable>;
        update(params?: Params$Resource$Regionhealthchecks$Update, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        update(params: Params$Resource$Regionhealthchecks$Update, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        update(params: Params$Resource$Regionhealthchecks$Update, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        update(params: Params$Resource$Regionhealthchecks$Update, callback: BodyResponseCallback<Schema$Operation>): void;
        update(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    export interface Params$Resource$Regionhealthchecks$Delete extends StandardParameters {
        /**
         * Name of the HealthCheck resource to delete.
         */
        healthCheck?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Regionhealthchecks$Get extends StandardParameters {
        /**
         * Name of the HealthCheck resource to return.
         */
        healthCheck?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
    }
    export interface Params$Resource$Regionhealthchecks$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$HealthCheck;
    }
    export interface Params$Resource$Regionhealthchecks$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Regionhealthchecks$Patch extends StandardParameters {
        /**
         * Name of the HealthCheck resource to patch.
         */
        healthCheck?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$HealthCheck;
    }
    export interface Params$Resource$Regionhealthchecks$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export interface Params$Resource$Regionhealthchecks$Update extends StandardParameters {
        /**
         * Name of the HealthCheck resource to update.
         */
        healthCheck?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$HealthCheck;
    }
    export class Resource$Regionhealthcheckservices {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves the list of all HealthCheckService resources, regional and global, available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Regionhealthcheckservices$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Regionhealthcheckservices$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$HealthCheckServiceAggregatedList>;
        aggregatedList(params: Params$Resource$Regionhealthcheckservices$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Regionhealthcheckservices$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$HealthCheckServiceAggregatedList>, callback: BodyResponseCallback<Schema$HealthCheckServiceAggregatedList>): void;
        aggregatedList(params: Params$Resource$Regionhealthcheckservices$Aggregatedlist, callback: BodyResponseCallback<Schema$HealthCheckServiceAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$HealthCheckServiceAggregatedList>): void;
        /**
         * Deletes the specified regional HealthCheckService.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Regionhealthcheckservices$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Regionhealthcheckservices$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Regionhealthcheckservices$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Regionhealthcheckservices$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Regionhealthcheckservices$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified regional HealthCheckService resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Regionhealthcheckservices$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Regionhealthcheckservices$Get, options?: MethodOptions): GaxiosPromise<Schema$HealthCheckService>;
        get(params: Params$Resource$Regionhealthcheckservices$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Regionhealthcheckservices$Get, options: MethodOptions | BodyResponseCallback<Schema$HealthCheckService>, callback: BodyResponseCallback<Schema$HealthCheckService>): void;
        get(params: Params$Resource$Regionhealthcheckservices$Get, callback: BodyResponseCallback<Schema$HealthCheckService>): void;
        get(callback: BodyResponseCallback<Schema$HealthCheckService>): void;
        /**
         * Creates a regional HealthCheckService resource in the specified project and region using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Regionhealthcheckservices$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Regionhealthcheckservices$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Regionhealthcheckservices$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Regionhealthcheckservices$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Regionhealthcheckservices$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Lists all the HealthCheckService resources that have been configured for the specified project in the given region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Regionhealthcheckservices$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Regionhealthcheckservices$List, options?: MethodOptions): GaxiosPromise<Schema$HealthCheckServicesList>;
        list(params: Params$Resource$Regionhealthcheckservices$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Regionhealthcheckservices$List, options: MethodOptions | BodyResponseCallback<Schema$HealthCheckServicesList>, callback: BodyResponseCallback<Schema$HealthCheckServicesList>): void;
        list(params: Params$Resource$Regionhealthcheckservices$List, callback: BodyResponseCallback<Schema$HealthCheckServicesList>): void;
        list(callback: BodyResponseCallback<Schema$HealthCheckServicesList>): void;
        /**
         * Updates the specified regional HealthCheckService resource with the data included in the request. This method supports PATCH semantics and uses the JSON merge patch format and processing rules.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Regionhealthcheckservices$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Regionhealthcheckservices$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Regionhealthcheckservices$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Regionhealthcheckservices$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Regionhealthcheckservices$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Regionhealthcheckservices$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Regionhealthcheckservices$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Regionhealthcheckservices$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Regionhealthcheckservices$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Regionhealthcheckservices$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Regionhealthcheckservices$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Name of the project scoping this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Regionhealthcheckservices$Delete extends StandardParameters {
        /**
         * Name of the HealthCheckService to delete. The name must be 1-63 characters long, and comply with RFC1035.
         */
        healthCheckService?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Regionhealthcheckservices$Get extends StandardParameters {
        /**
         * Name of the HealthCheckService to update. The name must be 1-63 characters long, and comply with RFC1035.
         */
        healthCheckService?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
    }
    export interface Params$Resource$Regionhealthcheckservices$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$HealthCheckService;
    }
    export interface Params$Resource$Regionhealthcheckservices$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Regionhealthcheckservices$Patch extends StandardParameters {
        /**
         * Name of the HealthCheckService to update. The name must be 1-63 characters long, and comply with RFC1035.
         */
        healthCheckService?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$HealthCheckService;
    }
    export interface Params$Resource$Regionhealthcheckservices$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Regioninstancegroupmanagers {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Flags the specified instances to be immediately removed from the managed instance group. Abandoning an instance does not delete the instance, but it does remove the instance from any target pools that are applied by the managed instance group. This method reduces the targetSize of the managed instance group by the number of instances that you abandon. This operation is marked as DONE when the action is scheduled even if the instances have not yet been removed from the group. You must separately verify the status of the abandoning action with the listmanagedinstances method. If the group is part of a backend service that has enabled connection draining, it can take up to 60 seconds after the connection draining duration has elapsed before the VM instance is removed or deleted. You can specify a maximum of 1000 instances with this method per request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        abandonInstances(params: Params$Resource$Regioninstancegroupmanagers$Abandoninstances, options: StreamMethodOptions): GaxiosPromise<Readable>;
        abandonInstances(params?: Params$Resource$Regioninstancegroupmanagers$Abandoninstances, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        abandonInstances(params: Params$Resource$Regioninstancegroupmanagers$Abandoninstances, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        abandonInstances(params: Params$Resource$Regioninstancegroupmanagers$Abandoninstances, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        abandonInstances(params: Params$Resource$Regioninstancegroupmanagers$Abandoninstances, callback: BodyResponseCallback<Schema$Operation>): void;
        abandonInstances(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Apply updates to selected instances the managed instance group.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        applyUpdatesToInstances(params: Params$Resource$Regioninstancegroupmanagers$Applyupdatestoinstances, options: StreamMethodOptions): GaxiosPromise<Readable>;
        applyUpdatesToInstances(params?: Params$Resource$Regioninstancegroupmanagers$Applyupdatestoinstances, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        applyUpdatesToInstances(params: Params$Resource$Regioninstancegroupmanagers$Applyupdatestoinstances, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        applyUpdatesToInstances(params: Params$Resource$Regioninstancegroupmanagers$Applyupdatestoinstances, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        applyUpdatesToInstances(params: Params$Resource$Regioninstancegroupmanagers$Applyupdatestoinstances, callback: BodyResponseCallback<Schema$Operation>): void;
        applyUpdatesToInstances(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Creates instances with per-instance configurations in this regional managed instance group. Instances are created using the current instance template. The create instances operation is marked DONE if the createInstances request is successful. The underlying actions take additional time. You must separately verify the status of the creating or actions with the listmanagedinstances method.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        createInstances(params: Params$Resource$Regioninstancegroupmanagers$Createinstances, options: StreamMethodOptions): GaxiosPromise<Readable>;
        createInstances(params?: Params$Resource$Regioninstancegroupmanagers$Createinstances, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        createInstances(params: Params$Resource$Regioninstancegroupmanagers$Createinstances, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        createInstances(params: Params$Resource$Regioninstancegroupmanagers$Createinstances, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        createInstances(params: Params$Resource$Regioninstancegroupmanagers$Createinstances, callback: BodyResponseCallback<Schema$Operation>): void;
        createInstances(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Deletes the specified managed instance group and all of the instances in that group.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Regioninstancegroupmanagers$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Regioninstancegroupmanagers$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Regioninstancegroupmanagers$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Regioninstancegroupmanagers$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Regioninstancegroupmanagers$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Flags the specified instances in the managed instance group to be immediately deleted. The instances are also removed from any target pools of which they were a member. This method reduces the targetSize of the managed instance group by the number of instances that you delete. The deleteInstances operation is marked DONE if the deleteInstances request is successful. The underlying actions take additional time. You must separately verify the status of the deleting action with the listmanagedinstances method. If the group is part of a backend service that has enabled connection draining, it can take up to 60 seconds after the connection draining duration has elapsed before the VM instance is removed or deleted. You can specify a maximum of 1000 instances with this method per request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        deleteInstances(params: Params$Resource$Regioninstancegroupmanagers$Deleteinstances, options: StreamMethodOptions): GaxiosPromise<Readable>;
        deleteInstances(params?: Params$Resource$Regioninstancegroupmanagers$Deleteinstances, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        deleteInstances(params: Params$Resource$Regioninstancegroupmanagers$Deleteinstances, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        deleteInstances(params: Params$Resource$Regioninstancegroupmanagers$Deleteinstances, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        deleteInstances(params: Params$Resource$Regioninstancegroupmanagers$Deleteinstances, callback: BodyResponseCallback<Schema$Operation>): void;
        deleteInstances(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Deletes selected per-instance configurations for the managed instance group.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        deletePerInstanceConfigs(params: Params$Resource$Regioninstancegroupmanagers$Deleteperinstanceconfigs, options: StreamMethodOptions): GaxiosPromise<Readable>;
        deletePerInstanceConfigs(params?: Params$Resource$Regioninstancegroupmanagers$Deleteperinstanceconfigs, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        deletePerInstanceConfigs(params: Params$Resource$Regioninstancegroupmanagers$Deleteperinstanceconfigs, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        deletePerInstanceConfigs(params: Params$Resource$Regioninstancegroupmanagers$Deleteperinstanceconfigs, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        deletePerInstanceConfigs(params: Params$Resource$Regioninstancegroupmanagers$Deleteperinstanceconfigs, callback: BodyResponseCallback<Schema$Operation>): void;
        deletePerInstanceConfigs(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns all of the details about the specified managed instance group.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Regioninstancegroupmanagers$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Regioninstancegroupmanagers$Get, options?: MethodOptions): GaxiosPromise<Schema$InstanceGroupManager>;
        get(params: Params$Resource$Regioninstancegroupmanagers$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Regioninstancegroupmanagers$Get, options: MethodOptions | BodyResponseCallback<Schema$InstanceGroupManager>, callback: BodyResponseCallback<Schema$InstanceGroupManager>): void;
        get(params: Params$Resource$Regioninstancegroupmanagers$Get, callback: BodyResponseCallback<Schema$InstanceGroupManager>): void;
        get(callback: BodyResponseCallback<Schema$InstanceGroupManager>): void;
        /**
         * Creates a managed instance group using the information that you specify in the request. After the group is created, instances in the group are created using the specified instance template. This operation is marked as DONE when the group is created even if the instances in the group have not yet been created. You must separately verify the status of the individual instances with the listmanagedinstances method. A regional managed instance group can contain up to 2000 instances.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Regioninstancegroupmanagers$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Regioninstancegroupmanagers$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Regioninstancegroupmanagers$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Regioninstancegroupmanagers$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Regioninstancegroupmanagers$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of managed instance groups that are contained within the specified region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Regioninstancegroupmanagers$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Regioninstancegroupmanagers$List, options?: MethodOptions): GaxiosPromise<Schema$RegionInstanceGroupManagerList>;
        list(params: Params$Resource$Regioninstancegroupmanagers$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Regioninstancegroupmanagers$List, options: MethodOptions | BodyResponseCallback<Schema$RegionInstanceGroupManagerList>, callback: BodyResponseCallback<Schema$RegionInstanceGroupManagerList>): void;
        list(params: Params$Resource$Regioninstancegroupmanagers$List, callback: BodyResponseCallback<Schema$RegionInstanceGroupManagerList>): void;
        list(callback: BodyResponseCallback<Schema$RegionInstanceGroupManagerList>): void;
        /**
         * Lists all errors thrown by actions on instances for a given regional managed instance group. The filter and orderBy query parameters are not supported.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        listErrors(params: Params$Resource$Regioninstancegroupmanagers$Listerrors, options: StreamMethodOptions): GaxiosPromise<Readable>;
        listErrors(params?: Params$Resource$Regioninstancegroupmanagers$Listerrors, options?: MethodOptions): GaxiosPromise<Schema$RegionInstanceGroupManagersListErrorsResponse>;
        listErrors(params: Params$Resource$Regioninstancegroupmanagers$Listerrors, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        listErrors(params: Params$Resource$Regioninstancegroupmanagers$Listerrors, options: MethodOptions | BodyResponseCallback<Schema$RegionInstanceGroupManagersListErrorsResponse>, callback: BodyResponseCallback<Schema$RegionInstanceGroupManagersListErrorsResponse>): void;
        listErrors(params: Params$Resource$Regioninstancegroupmanagers$Listerrors, callback: BodyResponseCallback<Schema$RegionInstanceGroupManagersListErrorsResponse>): void;
        listErrors(callback: BodyResponseCallback<Schema$RegionInstanceGroupManagersListErrorsResponse>): void;
        /**
         * Lists the instances in the managed instance group and instances that are scheduled to be created. The list includes any current actions that the group has scheduled for its instances. The orderBy query parameter is not supported. The `pageToken` query parameter is supported only in the alpha and beta API and only if the group's `listManagedInstancesResults` field is set to `PAGINATED`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        listManagedInstances(params: Params$Resource$Regioninstancegroupmanagers$Listmanagedinstances, options: StreamMethodOptions): GaxiosPromise<Readable>;
        listManagedInstances(params?: Params$Resource$Regioninstancegroupmanagers$Listmanagedinstances, options?: MethodOptions): GaxiosPromise<Schema$RegionInstanceGroupManagersListInstancesResponse>;
        listManagedInstances(params: Params$Resource$Regioninstancegroupmanagers$Listmanagedinstances, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        listManagedInstances(params: Params$Resource$Regioninstancegroupmanagers$Listmanagedinstances, options: MethodOptions | BodyResponseCallback<Schema$RegionInstanceGroupManagersListInstancesResponse>, callback: BodyResponseCallback<Schema$RegionInstanceGroupManagersListInstancesResponse>): void;
        listManagedInstances(params: Params$Resource$Regioninstancegroupmanagers$Listmanagedinstances, callback: BodyResponseCallback<Schema$RegionInstanceGroupManagersListInstancesResponse>): void;
        listManagedInstances(callback: BodyResponseCallback<Schema$RegionInstanceGroupManagersListInstancesResponse>): void;
        /**
         * Lists all of the per-instance configurations defined for the managed instance group. The orderBy query parameter is not supported.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        listPerInstanceConfigs(params: Params$Resource$Regioninstancegroupmanagers$Listperinstanceconfigs, options: StreamMethodOptions): GaxiosPromise<Readable>;
        listPerInstanceConfigs(params?: Params$Resource$Regioninstancegroupmanagers$Listperinstanceconfigs, options?: MethodOptions): GaxiosPromise<Schema$RegionInstanceGroupManagersListInstanceConfigsResp>;
        listPerInstanceConfigs(params: Params$Resource$Regioninstancegroupmanagers$Listperinstanceconfigs, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        listPerInstanceConfigs(params: Params$Resource$Regioninstancegroupmanagers$Listperinstanceconfigs, options: MethodOptions | BodyResponseCallback<Schema$RegionInstanceGroupManagersListInstanceConfigsResp>, callback: BodyResponseCallback<Schema$RegionInstanceGroupManagersListInstanceConfigsResp>): void;
        listPerInstanceConfigs(params: Params$Resource$Regioninstancegroupmanagers$Listperinstanceconfigs, callback: BodyResponseCallback<Schema$RegionInstanceGroupManagersListInstanceConfigsResp>): void;
        listPerInstanceConfigs(callback: BodyResponseCallback<Schema$RegionInstanceGroupManagersListInstanceConfigsResp>): void;
        /**
         * Updates a managed instance group using the information that you specify in the request. This operation is marked as DONE when the group is patched even if the instances in the group are still in the process of being patched. You must separately verify the status of the individual instances with the listmanagedinstances method. This method supports PATCH semantics and uses the JSON merge patch format and processing rules. If you update your group to specify a new template or instance configuration, it's possible that your intended specification for each VM in the group is different from the current state of that VM. To learn how to apply an updated configuration to the VMs in a MIG, see Updating instances in a MIG.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Regioninstancegroupmanagers$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Regioninstancegroupmanagers$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Regioninstancegroupmanagers$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Regioninstancegroupmanagers$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Regioninstancegroupmanagers$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Inserts or patches per-instance configurations for the managed instance group. perInstanceConfig.name serves as a key used to distinguish whether to perform insert or patch.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patchPerInstanceConfigs(params: Params$Resource$Regioninstancegroupmanagers$Patchperinstanceconfigs, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patchPerInstanceConfigs(params?: Params$Resource$Regioninstancegroupmanagers$Patchperinstanceconfigs, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patchPerInstanceConfigs(params: Params$Resource$Regioninstancegroupmanagers$Patchperinstanceconfigs, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patchPerInstanceConfigs(params: Params$Resource$Regioninstancegroupmanagers$Patchperinstanceconfigs, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patchPerInstanceConfigs(params: Params$Resource$Regioninstancegroupmanagers$Patchperinstanceconfigs, callback: BodyResponseCallback<Schema$Operation>): void;
        patchPerInstanceConfigs(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Flags the specified VM instances in the managed instance group to be immediately recreated. Each instance is recreated using the group's current configuration. This operation is marked as DONE when the flag is set even if the instances have not yet been recreated. You must separately verify the status of each instance by checking its currentAction field; for more information, see Checking the status of managed instances. If the group is part of a backend service that has enabled connection draining, it can take up to 60 seconds after the connection draining duration has elapsed before the VM instance is removed or deleted. You can specify a maximum of 1000 instances with this method per request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        recreateInstances(params: Params$Resource$Regioninstancegroupmanagers$Recreateinstances, options: StreamMethodOptions): GaxiosPromise<Readable>;
        recreateInstances(params?: Params$Resource$Regioninstancegroupmanagers$Recreateinstances, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        recreateInstances(params: Params$Resource$Regioninstancegroupmanagers$Recreateinstances, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        recreateInstances(params: Params$Resource$Regioninstancegroupmanagers$Recreateinstances, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        recreateInstances(params: Params$Resource$Regioninstancegroupmanagers$Recreateinstances, callback: BodyResponseCallback<Schema$Operation>): void;
        recreateInstances(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Changes the intended size of the managed instance group. If you increase the size, the group creates new instances using the current instance template. If you decrease the size, the group deletes one or more instances. The resize operation is marked DONE if the resize request is successful. The underlying actions take additional time. You must separately verify the status of the creating or deleting actions with the listmanagedinstances method. If the group is part of a backend service that has enabled connection draining, it can take up to 60 seconds after the connection draining duration has elapsed before the VM instance is removed or deleted.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        resize(params: Params$Resource$Regioninstancegroupmanagers$Resize, options: StreamMethodOptions): GaxiosPromise<Readable>;
        resize(params?: Params$Resource$Regioninstancegroupmanagers$Resize, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        resize(params: Params$Resource$Regioninstancegroupmanagers$Resize, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        resize(params: Params$Resource$Regioninstancegroupmanagers$Resize, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        resize(params: Params$Resource$Regioninstancegroupmanagers$Resize, callback: BodyResponseCallback<Schema$Operation>): void;
        resize(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Resizes the regional managed instance group with advanced configuration options like disabling creation retries. This is an extended version of the resize method. If you increase the size, the group creates new instances using the current instance template. If you decrease the size, the group deletes one or more instances. The resize operation is marked DONE if the resize request is successful. The underlying actions take additional time. You must separately verify the status of the creating or deleting actions with the get or listmanagedinstances method. If the group is part of a backend service that has enabled connection draining, it can take up to 60 seconds after the connection draining duration has elapsed before the VM instance is removed or deleted.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        resizeAdvanced(params: Params$Resource$Regioninstancegroupmanagers$Resizeadvanced, options: StreamMethodOptions): GaxiosPromise<Readable>;
        resizeAdvanced(params?: Params$Resource$Regioninstancegroupmanagers$Resizeadvanced, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        resizeAdvanced(params: Params$Resource$Regioninstancegroupmanagers$Resizeadvanced, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        resizeAdvanced(params: Params$Resource$Regioninstancegroupmanagers$Resizeadvanced, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        resizeAdvanced(params: Params$Resource$Regioninstancegroupmanagers$Resizeadvanced, callback: BodyResponseCallback<Schema$Operation>): void;
        resizeAdvanced(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Flags the specified instances in the managed instance group to be resumed. This method increases the targetSize and decreases the targetSuspendedSize of the managed instance group by the number of instances that you resume. The resumeInstances operation is marked DONE if the resumeInstances request is successful. The underlying actions take additional time. You must separately verify the status of the RESUMING action with the listmanagedinstances method. In this request, you can only specify instances that are suspended. For example, if an instance was previously suspended using the suspendInstances method, it can be resumed using the resumeInstances method. If a health check is attached to the managed instance group, the specified instances will be verified as healthy after they are resumed. You can specify a maximum of 1000 instances with this method per request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        resumeInstances(params: Params$Resource$Regioninstancegroupmanagers$Resumeinstances, options: StreamMethodOptions): GaxiosPromise<Readable>;
        resumeInstances(params?: Params$Resource$Regioninstancegroupmanagers$Resumeinstances, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        resumeInstances(params: Params$Resource$Regioninstancegroupmanagers$Resumeinstances, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        resumeInstances(params: Params$Resource$Regioninstancegroupmanagers$Resumeinstances, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        resumeInstances(params: Params$Resource$Regioninstancegroupmanagers$Resumeinstances, callback: BodyResponseCallback<Schema$Operation>): void;
        resumeInstances(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Modifies the autohealing policy for the instances in this managed instance group. [Deprecated] This method is deprecated. Use regionInstanceGroupManagers.patch instead.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setAutoHealingPolicies(params: Params$Resource$Regioninstancegroupmanagers$Setautohealingpolicies, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setAutoHealingPolicies(params?: Params$Resource$Regioninstancegroupmanagers$Setautohealingpolicies, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setAutoHealingPolicies(params: Params$Resource$Regioninstancegroupmanagers$Setautohealingpolicies, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setAutoHealingPolicies(params: Params$Resource$Regioninstancegroupmanagers$Setautohealingpolicies, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setAutoHealingPolicies(params: Params$Resource$Regioninstancegroupmanagers$Setautohealingpolicies, callback: BodyResponseCallback<Schema$Operation>): void;
        setAutoHealingPolicies(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the instance template to use when creating new instances or recreating instances in this group. Existing instances are not affected.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setInstanceTemplate(params: Params$Resource$Regioninstancegroupmanagers$Setinstancetemplate, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setInstanceTemplate(params?: Params$Resource$Regioninstancegroupmanagers$Setinstancetemplate, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setInstanceTemplate(params: Params$Resource$Regioninstancegroupmanagers$Setinstancetemplate, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setInstanceTemplate(params: Params$Resource$Regioninstancegroupmanagers$Setinstancetemplate, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setInstanceTemplate(params: Params$Resource$Regioninstancegroupmanagers$Setinstancetemplate, callback: BodyResponseCallback<Schema$Operation>): void;
        setInstanceTemplate(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Modifies the target pools to which all new instances in this group are assigned. Existing instances in the group are not affected.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setTargetPools(params: Params$Resource$Regioninstancegroupmanagers$Settargetpools, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setTargetPools(params?: Params$Resource$Regioninstancegroupmanagers$Settargetpools, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setTargetPools(params: Params$Resource$Regioninstancegroupmanagers$Settargetpools, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setTargetPools(params: Params$Resource$Regioninstancegroupmanagers$Settargetpools, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setTargetPools(params: Params$Resource$Regioninstancegroupmanagers$Settargetpools, callback: BodyResponseCallback<Schema$Operation>): void;
        setTargetPools(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Flags the specified instances in the managed instance group to be started. This method increases the targetSize and decreases the targetStoppedSize of the managed instance group by the number of instances that you start. The startInstances operation is marked DONE if the startInstances request is successful. The underlying actions take additional time. You must separately verify the status of the STARTING action with the listmanagedinstances method. In this request, you can only specify instances that are stopped. For example, if an instance was previously stopped using the stopInstances method, it can be started using the startInstances method. If a health check is attached to the managed instance group, the specified instances will be verified as healthy after they are started. You can specify a maximum of 1000 instances with this method per request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        startInstances(params: Params$Resource$Regioninstancegroupmanagers$Startinstances, options: StreamMethodOptions): GaxiosPromise<Readable>;
        startInstances(params?: Params$Resource$Regioninstancegroupmanagers$Startinstances, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        startInstances(params: Params$Resource$Regioninstancegroupmanagers$Startinstances, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        startInstances(params: Params$Resource$Regioninstancegroupmanagers$Startinstances, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        startInstances(params: Params$Resource$Regioninstancegroupmanagers$Startinstances, callback: BodyResponseCallback<Schema$Operation>): void;
        startInstances(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Flags the specified instances in the managed instance group to be immediately stopped. You can only specify instances that are running in this request. This method reduces the targetSize and increases the targetStoppedSize of the managed instance group by the number of instances that you stop. The stopInstances operation is marked DONE if the stopInstances request is successful. The underlying actions take additional time. You must separately verify the status of the STOPPING action with the listmanagedinstances method. If the standbyPolicy.initialDelaySec field is set, the group delays stopping the instances until initialDelaySec have passed from instance.creationTimestamp (that is, when the instance was created). This delay gives your application time to set itself up and initialize on the instance. If more than initialDelaySec seconds have passed since instance.creationTimestamp when this method is called, there will be zero delay. If the group is part of a backend service that has enabled connection draining, it can take up to 60 seconds after the connection draining duration has elapsed before the VM instance is stopped. Stopped instances can be started using the startInstances method. You can specify a maximum of 1000 instances with this method per request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        stopInstances(params: Params$Resource$Regioninstancegroupmanagers$Stopinstances, options: StreamMethodOptions): GaxiosPromise<Readable>;
        stopInstances(params?: Params$Resource$Regioninstancegroupmanagers$Stopinstances, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        stopInstances(params: Params$Resource$Regioninstancegroupmanagers$Stopinstances, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        stopInstances(params: Params$Resource$Regioninstancegroupmanagers$Stopinstances, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        stopInstances(params: Params$Resource$Regioninstancegroupmanagers$Stopinstances, callback: BodyResponseCallback<Schema$Operation>): void;
        stopInstances(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Flags the specified instances in the managed instance group to be immediately suspended. You can only specify instances that are running in this request. This method reduces the targetSize and increases the targetSuspendedSize of the managed instance group by the number of instances that you suspend. The suspendInstances operation is marked DONE if the suspendInstances request is successful. The underlying actions take additional time. You must separately verify the status of the SUSPENDING action with the listmanagedinstances method. If the standbyPolicy.initialDelaySec field is set, the group delays suspension of the instances until initialDelaySec have passed from instance.creationTimestamp (that is, when the instance was created). This delay gives your application time to set itself up and initialize on the instance. If more than initialDelaySec seconds have passed since instance.creationTimestamp when this method is called, there will be zero delay. If the group is part of a backend service that has enabled connection draining, it can take up to 60 seconds after the connection draining duration has elapsed before the VM instance is suspended. Suspended instances can be resumed using the resumeInstances method. You can specify a maximum of 1000 instances with this method per request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        suspendInstances(params: Params$Resource$Regioninstancegroupmanagers$Suspendinstances, options: StreamMethodOptions): GaxiosPromise<Readable>;
        suspendInstances(params?: Params$Resource$Regioninstancegroupmanagers$Suspendinstances, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        suspendInstances(params: Params$Resource$Regioninstancegroupmanagers$Suspendinstances, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        suspendInstances(params: Params$Resource$Regioninstancegroupmanagers$Suspendinstances, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        suspendInstances(params: Params$Resource$Regioninstancegroupmanagers$Suspendinstances, callback: BodyResponseCallback<Schema$Operation>): void;
        suspendInstances(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Regioninstancegroupmanagers$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Regioninstancegroupmanagers$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Regioninstancegroupmanagers$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Regioninstancegroupmanagers$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Regioninstancegroupmanagers$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        /**
         * Updates a managed instance group using the information that you specify in the request. This operation is marked as DONE when the group is updated even if the instances in the group have not yet been updated. You must separately verify the status of the individual instances with the listmanagedinstances method. If you update your group to specify a new template or instance configuration, it's possible that your intended specification for each VM in the group is different from the current state of that VM. To learn how to apply an updated configuration to the VMs in a MIG, see Updating instances in a MIG.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        update(params: Params$Resource$Regioninstancegroupmanagers$Update, options: StreamMethodOptions): GaxiosPromise<Readable>;
        update(params?: Params$Resource$Regioninstancegroupmanagers$Update, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        update(params: Params$Resource$Regioninstancegroupmanagers$Update, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        update(params: Params$Resource$Regioninstancegroupmanagers$Update, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        update(params: Params$Resource$Regioninstancegroupmanagers$Update, callback: BodyResponseCallback<Schema$Operation>): void;
        update(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Inserts or updates per-instance configurations for the managed instance group. perInstanceConfig.name serves as a key used to distinguish whether to perform insert or patch.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        updatePerInstanceConfigs(params: Params$Resource$Regioninstancegroupmanagers$Updateperinstanceconfigs, options: StreamMethodOptions): GaxiosPromise<Readable>;
        updatePerInstanceConfigs(params?: Params$Resource$Regioninstancegroupmanagers$Updateperinstanceconfigs, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        updatePerInstanceConfigs(params: Params$Resource$Regioninstancegroupmanagers$Updateperinstanceconfigs, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        updatePerInstanceConfigs(params: Params$Resource$Regioninstancegroupmanagers$Updateperinstanceconfigs, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        updatePerInstanceConfigs(params: Params$Resource$Regioninstancegroupmanagers$Updateperinstanceconfigs, callback: BodyResponseCallback<Schema$Operation>): void;
        updatePerInstanceConfigs(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    export interface Params$Resource$Regioninstancegroupmanagers$Abandoninstances extends StandardParameters {
        /**
         * Name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionInstanceGroupManagersAbandonInstancesRequest;
    }
    export interface Params$Resource$Regioninstancegroupmanagers$Applyupdatestoinstances extends StandardParameters {
        /**
         * The name of the managed instance group, should conform to RFC1035.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request, should conform to RFC1035.
         */
        region?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionInstanceGroupManagersApplyUpdatesRequest;
    }
    export interface Params$Resource$Regioninstancegroupmanagers$Createinstances extends StandardParameters {
        /**
         * The name of the managed instance group. It should conform to RFC1035.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region where the managed instance group is located. It should conform to RFC1035.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionInstanceGroupManagersCreateInstancesRequest;
    }
    export interface Params$Resource$Regioninstancegroupmanagers$Delete extends StandardParameters {
        /**
         * Name of the managed instance group to delete.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Regioninstancegroupmanagers$Deleteinstances extends StandardParameters {
        /**
         * Name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionInstanceGroupManagersDeleteInstancesRequest;
    }
    export interface Params$Resource$Regioninstancegroupmanagers$Deleteperinstanceconfigs extends StandardParameters {
        /**
         * The name of the managed instance group. It should conform to RFC1035.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request, should conform to RFC1035.
         */
        region?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionInstanceGroupManagerDeleteInstanceConfigReq;
    }
    export interface Params$Resource$Regioninstancegroupmanagers$Get extends StandardParameters {
        /**
         * Name of the managed instance group to return.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
    }
    export interface Params$Resource$Regioninstancegroupmanagers$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupManager;
    }
    export interface Params$Resource$Regioninstancegroupmanagers$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Regioninstancegroupmanagers$Listerrors extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The name of the managed instance group. It must be a string that meets the requirements in RFC1035, or an unsigned long integer: must match regexp pattern: (?:[a-z](?:[-a-z0-9]{0,61\}[a-z0-9])?)|1-9{0,19\}.
         */
        instanceGroupManager?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request. This should conform to RFC1035.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Regioninstancegroupmanagers$Listmanagedinstances extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Regioninstancegroupmanagers$Listperinstanceconfigs extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The name of the managed instance group. It should conform to RFC1035.
         */
        instanceGroupManager?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request, should conform to RFC1035.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Regioninstancegroupmanagers$Patch extends StandardParameters {
        /**
         * The name of the instance group manager.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupManager;
    }
    export interface Params$Resource$Regioninstancegroupmanagers$Patchperinstanceconfigs extends StandardParameters {
        /**
         * The name of the managed instance group. It should conform to RFC1035.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request, should conform to RFC1035.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionInstanceGroupManagerPatchInstanceConfigReq;
    }
    export interface Params$Resource$Regioninstancegroupmanagers$Recreateinstances extends StandardParameters {
        /**
         * Name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionInstanceGroupManagersRecreateRequest;
    }
    export interface Params$Resource$Regioninstancegroupmanagers$Resize extends StandardParameters {
        /**
         * Name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Number of instances that should exist in this instance group manager.
         */
        size?: number;
    }
    export interface Params$Resource$Regioninstancegroupmanagers$Resizeadvanced extends StandardParameters {
        /**
         * The name of the managed instance group. It must be a string that meets the requirements in RFC1035.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request. It must be a string that meets the requirements in RFC1035.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionInstanceGroupManagersResizeAdvancedRequest;
    }
    export interface Params$Resource$Regioninstancegroupmanagers$Resumeinstances extends StandardParameters {
        /**
         * Name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionInstanceGroupManagersResumeInstancesRequest;
    }
    export interface Params$Resource$Regioninstancegroupmanagers$Setautohealingpolicies extends StandardParameters {
        /**
         * Name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionInstanceGroupManagersSetAutoHealingRequest;
    }
    export interface Params$Resource$Regioninstancegroupmanagers$Setinstancetemplate extends StandardParameters {
        /**
         * The name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionInstanceGroupManagersSetTemplateRequest;
    }
    export interface Params$Resource$Regioninstancegroupmanagers$Settargetpools extends StandardParameters {
        /**
         * Name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionInstanceGroupManagersSetTargetPoolsRequest;
    }
    export interface Params$Resource$Regioninstancegroupmanagers$Startinstances extends StandardParameters {
        /**
         * Name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionInstanceGroupManagersStartInstancesRequest;
    }
    export interface Params$Resource$Regioninstancegroupmanagers$Stopinstances extends StandardParameters {
        /**
         * The name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionInstanceGroupManagersStopInstancesRequest;
    }
    export interface Params$Resource$Regioninstancegroupmanagers$Suspendinstances extends StandardParameters {
        /**
         * Name of the managed instance group.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionInstanceGroupManagersSuspendInstancesRequest;
    }
    export interface Params$Resource$Regioninstancegroupmanagers$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export interface Params$Resource$Regioninstancegroupmanagers$Update extends StandardParameters {
        /**
         * The name of the instance group manager.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceGroupManager;
    }
    export interface Params$Resource$Regioninstancegroupmanagers$Updateperinstanceconfigs extends StandardParameters {
        /**
         * The name of the managed instance group. It should conform to RFC1035.
         */
        instanceGroupManager?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request, should conform to RFC1035.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionInstanceGroupManagerUpdateInstanceConfigReq;
    }
    export class Resource$Regioninstancegroups {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Returns the specified instance group resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Regioninstancegroups$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Regioninstancegroups$Get, options?: MethodOptions): GaxiosPromise<Schema$InstanceGroup>;
        get(params: Params$Resource$Regioninstancegroups$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Regioninstancegroups$Get, options: MethodOptions | BodyResponseCallback<Schema$InstanceGroup>, callback: BodyResponseCallback<Schema$InstanceGroup>): void;
        get(params: Params$Resource$Regioninstancegroups$Get, callback: BodyResponseCallback<Schema$InstanceGroup>): void;
        get(callback: BodyResponseCallback<Schema$InstanceGroup>): void;
        /**
         * Retrieves the list of instance group resources contained within the specified region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Regioninstancegroups$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Regioninstancegroups$List, options?: MethodOptions): GaxiosPromise<Schema$RegionInstanceGroupList>;
        list(params: Params$Resource$Regioninstancegroups$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Regioninstancegroups$List, options: MethodOptions | BodyResponseCallback<Schema$RegionInstanceGroupList>, callback: BodyResponseCallback<Schema$RegionInstanceGroupList>): void;
        list(params: Params$Resource$Regioninstancegroups$List, callback: BodyResponseCallback<Schema$RegionInstanceGroupList>): void;
        list(callback: BodyResponseCallback<Schema$RegionInstanceGroupList>): void;
        /**
         * Lists the instances in the specified instance group and displays information about the named ports. Depending on the specified options, this method can list all instances or only the instances that are running. The orderBy query parameter is not supported.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        listInstances(params: Params$Resource$Regioninstancegroups$Listinstances, options: StreamMethodOptions): GaxiosPromise<Readable>;
        listInstances(params?: Params$Resource$Regioninstancegroups$Listinstances, options?: MethodOptions): GaxiosPromise<Schema$RegionInstanceGroupsListInstances>;
        listInstances(params: Params$Resource$Regioninstancegroups$Listinstances, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        listInstances(params: Params$Resource$Regioninstancegroups$Listinstances, options: MethodOptions | BodyResponseCallback<Schema$RegionInstanceGroupsListInstances>, callback: BodyResponseCallback<Schema$RegionInstanceGroupsListInstances>): void;
        listInstances(params: Params$Resource$Regioninstancegroups$Listinstances, callback: BodyResponseCallback<Schema$RegionInstanceGroupsListInstances>): void;
        listInstances(callback: BodyResponseCallback<Schema$RegionInstanceGroupsListInstances>): void;
        /**
         * Sets the named ports for the specified regional instance group.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setNamedPorts(params: Params$Resource$Regioninstancegroups$Setnamedports, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setNamedPorts(params?: Params$Resource$Regioninstancegroups$Setnamedports, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setNamedPorts(params: Params$Resource$Regioninstancegroups$Setnamedports, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setNamedPorts(params: Params$Resource$Regioninstancegroups$Setnamedports, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setNamedPorts(params: Params$Resource$Regioninstancegroups$Setnamedports, callback: BodyResponseCallback<Schema$Operation>): void;
        setNamedPorts(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Regioninstancegroups$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Regioninstancegroups$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Regioninstancegroups$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Regioninstancegroups$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Regioninstancegroups$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Regioninstancegroups$Get extends StandardParameters {
        /**
         * Name of the instance group resource to return.
         */
        instanceGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
    }
    export interface Params$Resource$Regioninstancegroups$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Regioninstancegroups$Listinstances extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Name of the regional instance group for which we want to list the instances.
         */
        instanceGroup?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionInstanceGroupsListInstancesRequest;
    }
    export interface Params$Resource$Regioninstancegroups$Setnamedports extends StandardParameters {
        /**
         * The name of the regional instance group where the named ports are updated.
         */
        instanceGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionInstanceGroupsSetNamedPortsRequest;
    }
    export interface Params$Resource$Regioninstancegroups$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Regioninstances {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Creates multiple instances in a given region. Count specifies the number of instances to create.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        bulkInsert(params: Params$Resource$Regioninstances$Bulkinsert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        bulkInsert(params?: Params$Resource$Regioninstances$Bulkinsert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        bulkInsert(params: Params$Resource$Regioninstances$Bulkinsert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        bulkInsert(params: Params$Resource$Regioninstances$Bulkinsert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        bulkInsert(params: Params$Resource$Regioninstances$Bulkinsert, callback: BodyResponseCallback<Schema$Operation>): void;
        bulkInsert(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    export interface Params$Resource$Regioninstances$Bulkinsert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$BulkInsertInstanceResource;
    }
    export class Resource$Regioninstancetemplates {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Deletes the specified instance template. Deleting an instance template is permanent and cannot be undone.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Regioninstancetemplates$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Regioninstancetemplates$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Regioninstancetemplates$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Regioninstancetemplates$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Regioninstancetemplates$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified instance template.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Regioninstancetemplates$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Regioninstancetemplates$Get, options?: MethodOptions): GaxiosPromise<Schema$InstanceTemplate>;
        get(params: Params$Resource$Regioninstancetemplates$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Regioninstancetemplates$Get, options: MethodOptions | BodyResponseCallback<Schema$InstanceTemplate>, callback: BodyResponseCallback<Schema$InstanceTemplate>): void;
        get(params: Params$Resource$Regioninstancetemplates$Get, callback: BodyResponseCallback<Schema$InstanceTemplate>): void;
        get(callback: BodyResponseCallback<Schema$InstanceTemplate>): void;
        /**
         * Creates an instance template in the specified project and region using the global instance template whose URL is included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Regioninstancetemplates$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Regioninstancetemplates$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Regioninstancetemplates$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Regioninstancetemplates$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Regioninstancetemplates$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves a list of instance templates that are contained within the specified project and region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Regioninstancetemplates$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Regioninstancetemplates$List, options?: MethodOptions): GaxiosPromise<Schema$InstanceTemplateList>;
        list(params: Params$Resource$Regioninstancetemplates$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Regioninstancetemplates$List, options: MethodOptions | BodyResponseCallback<Schema$InstanceTemplateList>, callback: BodyResponseCallback<Schema$InstanceTemplateList>): void;
        list(params: Params$Resource$Regioninstancetemplates$List, callback: BodyResponseCallback<Schema$InstanceTemplateList>): void;
        list(callback: BodyResponseCallback<Schema$InstanceTemplateList>): void;
    }
    export interface Params$Resource$Regioninstancetemplates$Delete extends StandardParameters {
        /**
         * The name of the instance template to delete.
         */
        instanceTemplate?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Regioninstancetemplates$Get extends StandardParameters {
        /**
         * The name of the instance template.
         */
        instanceTemplate?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * View of the instance template.
         */
        view?: string;
    }
    export interface Params$Resource$Regioninstancetemplates$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceTemplate;
    }
    export interface Params$Resource$Regioninstancetemplates$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the regions for this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         * View of the instance template.
         */
        view?: string;
    }
    export class Resource$Regioninstantsnapshots {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Deletes the specified InstantSnapshot resource. Keep in mind that deleting a single instantSnapshot might not necessarily delete all the data on that instantSnapshot. If any data on the instantSnapshot that is marked for deletion is needed for subsequent instantSnapshots, the data will be moved to the next corresponding instantSnapshot. For more information, see Deleting instantSnapshots.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Regioninstantsnapshots$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Regioninstantsnapshots$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Regioninstantsnapshots$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Regioninstantsnapshots$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Regioninstantsnapshots$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Export the changed blocks between two instant snapshots to a customer's bucket in the user specified format.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        export(params: Params$Resource$Regioninstantsnapshots$Export, options: StreamMethodOptions): GaxiosPromise<Readable>;
        export(params?: Params$Resource$Regioninstantsnapshots$Export, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        export(params: Params$Resource$Regioninstantsnapshots$Export, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        export(params: Params$Resource$Regioninstantsnapshots$Export, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        export(params: Params$Resource$Regioninstantsnapshots$Export, callback: BodyResponseCallback<Schema$Operation>): void;
        export(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified InstantSnapshot resource in the specified region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Regioninstantsnapshots$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Regioninstantsnapshots$Get, options?: MethodOptions): GaxiosPromise<Schema$InstantSnapshot>;
        get(params: Params$Resource$Regioninstantsnapshots$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Regioninstantsnapshots$Get, options: MethodOptions | BodyResponseCallback<Schema$InstantSnapshot>, callback: BodyResponseCallback<Schema$InstantSnapshot>): void;
        get(params: Params$Resource$Regioninstantsnapshots$Get, callback: BodyResponseCallback<Schema$InstantSnapshot>): void;
        get(callback: BodyResponseCallback<Schema$InstantSnapshot>): void;
        /**
         * Gets the access control policy for a resource. May be empty if no such policy or resource exists.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getIamPolicy(params: Params$Resource$Regioninstantsnapshots$Getiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getIamPolicy(params?: Params$Resource$Regioninstantsnapshots$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        getIamPolicy(params: Params$Resource$Regioninstantsnapshots$Getiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getIamPolicy(params: Params$Resource$Regioninstantsnapshots$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(params: Params$Resource$Regioninstantsnapshots$Getiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Creates an instant snapshot in the specified region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Regioninstantsnapshots$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Regioninstantsnapshots$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Regioninstantsnapshots$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Regioninstantsnapshots$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Regioninstantsnapshots$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of InstantSnapshot resources contained within the specified region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Regioninstantsnapshots$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Regioninstantsnapshots$List, options?: MethodOptions): GaxiosPromise<Schema$InstantSnapshotList>;
        list(params: Params$Resource$Regioninstantsnapshots$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Regioninstantsnapshots$List, options: MethodOptions | BodyResponseCallback<Schema$InstantSnapshotList>, callback: BodyResponseCallback<Schema$InstantSnapshotList>): void;
        list(params: Params$Resource$Regioninstantsnapshots$List, callback: BodyResponseCallback<Schema$InstantSnapshotList>): void;
        list(callback: BodyResponseCallback<Schema$InstantSnapshotList>): void;
        /**
         * Sets the access control policy on the specified resource. Replaces any existing policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setIamPolicy(params: Params$Resource$Regioninstantsnapshots$Setiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setIamPolicy(params?: Params$Resource$Regioninstantsnapshots$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        setIamPolicy(params: Params$Resource$Regioninstantsnapshots$Setiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setIamPolicy(params: Params$Resource$Regioninstantsnapshots$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(params: Params$Resource$Regioninstantsnapshots$Setiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Sets the labels on a instantSnapshot in the given region. To learn more about labels, read the Labeling Resources documentation.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setLabels(params: Params$Resource$Regioninstantsnapshots$Setlabels, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setLabels(params?: Params$Resource$Regioninstantsnapshots$Setlabels, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setLabels(params: Params$Resource$Regioninstantsnapshots$Setlabels, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setLabels(params: Params$Resource$Regioninstantsnapshots$Setlabels, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(params: Params$Resource$Regioninstantsnapshots$Setlabels, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Regioninstantsnapshots$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Regioninstantsnapshots$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Regioninstantsnapshots$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Regioninstantsnapshots$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Regioninstantsnapshots$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Regioninstantsnapshots$Delete extends StandardParameters {
        /**
         * Name of the InstantSnapshot resource to delete.
         */
        instantSnapshot?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Regioninstantsnapshots$Export extends StandardParameters {
        /**
         * Name of the instant snapshot to export.
         */
        instantSnapshot?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the zone for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionInstantSnapshotsExportRequest;
    }
    export interface Params$Resource$Regioninstantsnapshots$Get extends StandardParameters {
        /**
         * Name of the InstantSnapshot resource to return.
         */
        instantSnapshot?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
    }
    export interface Params$Resource$Regioninstantsnapshots$Getiampolicy extends StandardParameters {
        /**
         * Requested IAM Policy version.
         */
        optionsRequestedPolicyVersion?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
    }
    export interface Params$Resource$Regioninstantsnapshots$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstantSnapshot;
    }
    export interface Params$Resource$Regioninstantsnapshots$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Regioninstantsnapshots$Setiampolicy extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionSetPolicyRequest;
    }
    export interface Params$Resource$Regioninstantsnapshots$Setlabels extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionSetLabelsRequest;
    }
    export interface Params$Resource$Regioninstantsnapshots$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Regionnetworkendpointgroups {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Attach a list of network endpoints to the specified network endpoint group.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        attachNetworkEndpoints(params: Params$Resource$Regionnetworkendpointgroups$Attachnetworkendpoints, options: StreamMethodOptions): GaxiosPromise<Readable>;
        attachNetworkEndpoints(params?: Params$Resource$Regionnetworkendpointgroups$Attachnetworkendpoints, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        attachNetworkEndpoints(params: Params$Resource$Regionnetworkendpointgroups$Attachnetworkendpoints, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        attachNetworkEndpoints(params: Params$Resource$Regionnetworkendpointgroups$Attachnetworkendpoints, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        attachNetworkEndpoints(params: Params$Resource$Regionnetworkendpointgroups$Attachnetworkendpoints, callback: BodyResponseCallback<Schema$Operation>): void;
        attachNetworkEndpoints(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Deletes the specified network endpoint group. Note that the NEG cannot be deleted if it is configured as a backend of a backend service.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Regionnetworkendpointgroups$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Regionnetworkendpointgroups$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Regionnetworkendpointgroups$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Regionnetworkendpointgroups$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Regionnetworkendpointgroups$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Detach the network endpoint from the specified network endpoint group.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        detachNetworkEndpoints(params: Params$Resource$Regionnetworkendpointgroups$Detachnetworkendpoints, options: StreamMethodOptions): GaxiosPromise<Readable>;
        detachNetworkEndpoints(params?: Params$Resource$Regionnetworkendpointgroups$Detachnetworkendpoints, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        detachNetworkEndpoints(params: Params$Resource$Regionnetworkendpointgroups$Detachnetworkendpoints, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        detachNetworkEndpoints(params: Params$Resource$Regionnetworkendpointgroups$Detachnetworkendpoints, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        detachNetworkEndpoints(params: Params$Resource$Regionnetworkendpointgroups$Detachnetworkendpoints, callback: BodyResponseCallback<Schema$Operation>): void;
        detachNetworkEndpoints(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified network endpoint group.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Regionnetworkendpointgroups$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Regionnetworkendpointgroups$Get, options?: MethodOptions): GaxiosPromise<Schema$NetworkEndpointGroup>;
        get(params: Params$Resource$Regionnetworkendpointgroups$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Regionnetworkendpointgroups$Get, options: MethodOptions | BodyResponseCallback<Schema$NetworkEndpointGroup>, callback: BodyResponseCallback<Schema$NetworkEndpointGroup>): void;
        get(params: Params$Resource$Regionnetworkendpointgroups$Get, callback: BodyResponseCallback<Schema$NetworkEndpointGroup>): void;
        get(callback: BodyResponseCallback<Schema$NetworkEndpointGroup>): void;
        /**
         * Creates a network endpoint group in the specified project using the parameters that are included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Regionnetworkendpointgroups$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Regionnetworkendpointgroups$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Regionnetworkendpointgroups$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Regionnetworkendpointgroups$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Regionnetworkendpointgroups$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of regional network endpoint groups available to the specified project in the given region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Regionnetworkendpointgroups$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Regionnetworkendpointgroups$List, options?: MethodOptions): GaxiosPromise<Schema$NetworkEndpointGroupList>;
        list(params: Params$Resource$Regionnetworkendpointgroups$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Regionnetworkendpointgroups$List, options: MethodOptions | BodyResponseCallback<Schema$NetworkEndpointGroupList>, callback: BodyResponseCallback<Schema$NetworkEndpointGroupList>): void;
        list(params: Params$Resource$Regionnetworkendpointgroups$List, callback: BodyResponseCallback<Schema$NetworkEndpointGroupList>): void;
        list(callback: BodyResponseCallback<Schema$NetworkEndpointGroupList>): void;
        /**
         * Lists the network endpoints in the specified network endpoint group.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        listNetworkEndpoints(params: Params$Resource$Regionnetworkendpointgroups$Listnetworkendpoints, options: StreamMethodOptions): GaxiosPromise<Readable>;
        listNetworkEndpoints(params?: Params$Resource$Regionnetworkendpointgroups$Listnetworkendpoints, options?: MethodOptions): GaxiosPromise<Schema$NetworkEndpointGroupsListNetworkEndpoints>;
        listNetworkEndpoints(params: Params$Resource$Regionnetworkendpointgroups$Listnetworkendpoints, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        listNetworkEndpoints(params: Params$Resource$Regionnetworkendpointgroups$Listnetworkendpoints, options: MethodOptions | BodyResponseCallback<Schema$NetworkEndpointGroupsListNetworkEndpoints>, callback: BodyResponseCallback<Schema$NetworkEndpointGroupsListNetworkEndpoints>): void;
        listNetworkEndpoints(params: Params$Resource$Regionnetworkendpointgroups$Listnetworkendpoints, callback: BodyResponseCallback<Schema$NetworkEndpointGroupsListNetworkEndpoints>): void;
        listNetworkEndpoints(callback: BodyResponseCallback<Schema$NetworkEndpointGroupsListNetworkEndpoints>): void;
    }
    export interface Params$Resource$Regionnetworkendpointgroups$Attachnetworkendpoints extends StandardParameters {
        /**
         * The name of the network endpoint group where you are attaching network endpoints to. It should comply with RFC1035.
         */
        networkEndpointGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region where you want to create the network endpoint group. It should comply with RFC1035.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionNetworkEndpointGroupsAttachEndpointsRequest;
    }
    export interface Params$Resource$Regionnetworkendpointgroups$Delete extends StandardParameters {
        /**
         * The name of the network endpoint group to delete. It should comply with RFC1035.
         */
        networkEndpointGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region where the network endpoint group is located. It should comply with RFC1035.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Regionnetworkendpointgroups$Detachnetworkendpoints extends StandardParameters {
        /**
         * The name of the network endpoint group you are detaching network endpoints from. It should comply with RFC1035.
         */
        networkEndpointGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region where the network endpoint group is located. It should comply with RFC1035.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000). end_interface: MixerMutationRequestBuilder
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionNetworkEndpointGroupsDetachEndpointsRequest;
    }
    export interface Params$Resource$Regionnetworkendpointgroups$Get extends StandardParameters {
        /**
         * The name of the network endpoint group. It should comply with RFC1035.
         */
        networkEndpointGroup?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region where the network endpoint group is located. It should comply with RFC1035.
         */
        region?: string;
    }
    export interface Params$Resource$Regionnetworkendpointgroups$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region where you want to create the network endpoint group. It should comply with RFC1035.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$NetworkEndpointGroup;
    }
    export interface Params$Resource$Regionnetworkendpointgroups$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region where the network endpoint group is located. It should comply with RFC1035.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Regionnetworkendpointgroups$Listnetworkendpoints extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * The name of the network endpoint group from which you want to generate a list of included network endpoints. It should comply with RFC1035.
         */
        networkEndpointGroup?: string;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region where the network endpoint group is located. It should comply with RFC1035.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export class Resource$Regionnetworkfirewallpolicies {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Inserts an association for the specified network firewall policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        addAssociation(params: Params$Resource$Regionnetworkfirewallpolicies$Addassociation, options: StreamMethodOptions): GaxiosPromise<Readable>;
        addAssociation(params?: Params$Resource$Regionnetworkfirewallpolicies$Addassociation, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        addAssociation(params: Params$Resource$Regionnetworkfirewallpolicies$Addassociation, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        addAssociation(params: Params$Resource$Regionnetworkfirewallpolicies$Addassociation, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        addAssociation(params: Params$Resource$Regionnetworkfirewallpolicies$Addassociation, callback: BodyResponseCallback<Schema$Operation>): void;
        addAssociation(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Inserts a rule into a network firewall policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        addRule(params: Params$Resource$Regionnetworkfirewallpolicies$Addrule, options: StreamMethodOptions): GaxiosPromise<Readable>;
        addRule(params?: Params$Resource$Regionnetworkfirewallpolicies$Addrule, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        addRule(params: Params$Resource$Regionnetworkfirewallpolicies$Addrule, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        addRule(params: Params$Resource$Regionnetworkfirewallpolicies$Addrule, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        addRule(params: Params$Resource$Regionnetworkfirewallpolicies$Addrule, callback: BodyResponseCallback<Schema$Operation>): void;
        addRule(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Copies rules to the specified network firewall policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cloneRules(params: Params$Resource$Regionnetworkfirewallpolicies$Clonerules, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cloneRules(params?: Params$Resource$Regionnetworkfirewallpolicies$Clonerules, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        cloneRules(params: Params$Resource$Regionnetworkfirewallpolicies$Clonerules, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cloneRules(params: Params$Resource$Regionnetworkfirewallpolicies$Clonerules, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        cloneRules(params: Params$Resource$Regionnetworkfirewallpolicies$Clonerules, callback: BodyResponseCallback<Schema$Operation>): void;
        cloneRules(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Deletes the specified network firewall policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Regionnetworkfirewallpolicies$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Regionnetworkfirewallpolicies$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Regionnetworkfirewallpolicies$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Regionnetworkfirewallpolicies$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Regionnetworkfirewallpolicies$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified network firewall policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Regionnetworkfirewallpolicies$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Regionnetworkfirewallpolicies$Get, options?: MethodOptions): GaxiosPromise<Schema$FirewallPolicy>;
        get(params: Params$Resource$Regionnetworkfirewallpolicies$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Regionnetworkfirewallpolicies$Get, options: MethodOptions | BodyResponseCallback<Schema$FirewallPolicy>, callback: BodyResponseCallback<Schema$FirewallPolicy>): void;
        get(params: Params$Resource$Regionnetworkfirewallpolicies$Get, callback: BodyResponseCallback<Schema$FirewallPolicy>): void;
        get(callback: BodyResponseCallback<Schema$FirewallPolicy>): void;
        /**
         * Gets an association with the specified name.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getAssociation(params: Params$Resource$Regionnetworkfirewallpolicies$Getassociation, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getAssociation(params?: Params$Resource$Regionnetworkfirewallpolicies$Getassociation, options?: MethodOptions): GaxiosPromise<Schema$FirewallPolicyAssociation>;
        getAssociation(params: Params$Resource$Regionnetworkfirewallpolicies$Getassociation, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getAssociation(params: Params$Resource$Regionnetworkfirewallpolicies$Getassociation, options: MethodOptions | BodyResponseCallback<Schema$FirewallPolicyAssociation>, callback: BodyResponseCallback<Schema$FirewallPolicyAssociation>): void;
        getAssociation(params: Params$Resource$Regionnetworkfirewallpolicies$Getassociation, callback: BodyResponseCallback<Schema$FirewallPolicyAssociation>): void;
        getAssociation(callback: BodyResponseCallback<Schema$FirewallPolicyAssociation>): void;
        /**
         * Returns the effective firewalls on a given network.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getEffectiveFirewalls(params: Params$Resource$Regionnetworkfirewallpolicies$Geteffectivefirewalls, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getEffectiveFirewalls(params?: Params$Resource$Regionnetworkfirewallpolicies$Geteffectivefirewalls, options?: MethodOptions): GaxiosPromise<Schema$RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse>;
        getEffectiveFirewalls(params: Params$Resource$Regionnetworkfirewallpolicies$Geteffectivefirewalls, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getEffectiveFirewalls(params: Params$Resource$Regionnetworkfirewallpolicies$Geteffectivefirewalls, options: MethodOptions | BodyResponseCallback<Schema$RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse>, callback: BodyResponseCallback<Schema$RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse>): void;
        getEffectiveFirewalls(params: Params$Resource$Regionnetworkfirewallpolicies$Geteffectivefirewalls, callback: BodyResponseCallback<Schema$RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse>): void;
        getEffectiveFirewalls(callback: BodyResponseCallback<Schema$RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse>): void;
        /**
         * Gets the access control policy for a resource. May be empty if no such policy or resource exists.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getIamPolicy(params: Params$Resource$Regionnetworkfirewallpolicies$Getiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getIamPolicy(params?: Params$Resource$Regionnetworkfirewallpolicies$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        getIamPolicy(params: Params$Resource$Regionnetworkfirewallpolicies$Getiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getIamPolicy(params: Params$Resource$Regionnetworkfirewallpolicies$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(params: Params$Resource$Regionnetworkfirewallpolicies$Getiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Gets a rule of the specified priority.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getRule(params: Params$Resource$Regionnetworkfirewallpolicies$Getrule, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getRule(params?: Params$Resource$Regionnetworkfirewallpolicies$Getrule, options?: MethodOptions): GaxiosPromise<Schema$FirewallPolicyRule>;
        getRule(params: Params$Resource$Regionnetworkfirewallpolicies$Getrule, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getRule(params: Params$Resource$Regionnetworkfirewallpolicies$Getrule, options: MethodOptions | BodyResponseCallback<Schema$FirewallPolicyRule>, callback: BodyResponseCallback<Schema$FirewallPolicyRule>): void;
        getRule(params: Params$Resource$Regionnetworkfirewallpolicies$Getrule, callback: BodyResponseCallback<Schema$FirewallPolicyRule>): void;
        getRule(callback: BodyResponseCallback<Schema$FirewallPolicyRule>): void;
        /**
         * Creates a new network firewall policy in the specified project and region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Regionnetworkfirewallpolicies$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Regionnetworkfirewallpolicies$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Regionnetworkfirewallpolicies$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Regionnetworkfirewallpolicies$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Regionnetworkfirewallpolicies$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Lists all the network firewall policies that have been configured for the specified project in the given region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Regionnetworkfirewallpolicies$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Regionnetworkfirewallpolicies$List, options?: MethodOptions): GaxiosPromise<Schema$FirewallPolicyList>;
        list(params: Params$Resource$Regionnetworkfirewallpolicies$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Regionnetworkfirewallpolicies$List, options: MethodOptions | BodyResponseCallback<Schema$FirewallPolicyList>, callback: BodyResponseCallback<Schema$FirewallPolicyList>): void;
        list(params: Params$Resource$Regionnetworkfirewallpolicies$List, callback: BodyResponseCallback<Schema$FirewallPolicyList>): void;
        list(callback: BodyResponseCallback<Schema$FirewallPolicyList>): void;
        /**
         * Patches the specified network firewall policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Regionnetworkfirewallpolicies$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Regionnetworkfirewallpolicies$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Regionnetworkfirewallpolicies$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Regionnetworkfirewallpolicies$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Regionnetworkfirewallpolicies$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Updates an association for the specified network firewall policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patchAssociation(params: Params$Resource$Regionnetworkfirewallpolicies$Patchassociation, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patchAssociation(params?: Params$Resource$Regionnetworkfirewallpolicies$Patchassociation, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patchAssociation(params: Params$Resource$Regionnetworkfirewallpolicies$Patchassociation, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patchAssociation(params: Params$Resource$Regionnetworkfirewallpolicies$Patchassociation, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patchAssociation(params: Params$Resource$Regionnetworkfirewallpolicies$Patchassociation, callback: BodyResponseCallback<Schema$Operation>): void;
        patchAssociation(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Patches a rule of the specified priority.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patchRule(params: Params$Resource$Regionnetworkfirewallpolicies$Patchrule, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patchRule(params?: Params$Resource$Regionnetworkfirewallpolicies$Patchrule, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patchRule(params: Params$Resource$Regionnetworkfirewallpolicies$Patchrule, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patchRule(params: Params$Resource$Regionnetworkfirewallpolicies$Patchrule, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patchRule(params: Params$Resource$Regionnetworkfirewallpolicies$Patchrule, callback: BodyResponseCallback<Schema$Operation>): void;
        patchRule(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Removes an association for the specified network firewall policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        removeAssociation(params: Params$Resource$Regionnetworkfirewallpolicies$Removeassociation, options: StreamMethodOptions): GaxiosPromise<Readable>;
        removeAssociation(params?: Params$Resource$Regionnetworkfirewallpolicies$Removeassociation, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        removeAssociation(params: Params$Resource$Regionnetworkfirewallpolicies$Removeassociation, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        removeAssociation(params: Params$Resource$Regionnetworkfirewallpolicies$Removeassociation, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        removeAssociation(params: Params$Resource$Regionnetworkfirewallpolicies$Removeassociation, callback: BodyResponseCallback<Schema$Operation>): void;
        removeAssociation(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Deletes a rule of the specified priority.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        removeRule(params: Params$Resource$Regionnetworkfirewallpolicies$Removerule, options: StreamMethodOptions): GaxiosPromise<Readable>;
        removeRule(params?: Params$Resource$Regionnetworkfirewallpolicies$Removerule, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        removeRule(params: Params$Resource$Regionnetworkfirewallpolicies$Removerule, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        removeRule(params: Params$Resource$Regionnetworkfirewallpolicies$Removerule, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        removeRule(params: Params$Resource$Regionnetworkfirewallpolicies$Removerule, callback: BodyResponseCallback<Schema$Operation>): void;
        removeRule(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the access control policy on the specified resource. Replaces any existing policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setIamPolicy(params: Params$Resource$Regionnetworkfirewallpolicies$Setiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setIamPolicy(params?: Params$Resource$Regionnetworkfirewallpolicies$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        setIamPolicy(params: Params$Resource$Regionnetworkfirewallpolicies$Setiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setIamPolicy(params: Params$Resource$Regionnetworkfirewallpolicies$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(params: Params$Resource$Regionnetworkfirewallpolicies$Setiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Regionnetworkfirewallpolicies$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Regionnetworkfirewallpolicies$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Regionnetworkfirewallpolicies$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Regionnetworkfirewallpolicies$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Regionnetworkfirewallpolicies$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Regionnetworkfirewallpolicies$Addassociation extends StandardParameters {
        /**
         * Name of the firewall policy associated with the target network to swap association with. This field is mutually exclusive with 'replace_existing_association'.
         */
        associatedPolicyToBeReplaced?: string;
        /**
         * Name of the firewall policy to update.
         */
        firewallPolicy?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Indicates whether or not to replace it if an association already exists. This is false by default, in which case an error will be returned if an association already exists.
         */
        replaceExistingAssociation?: boolean;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$FirewallPolicyAssociation;
    }
    export interface Params$Resource$Regionnetworkfirewallpolicies$Addrule extends StandardParameters {
        /**
         * Name of the firewall policy to update.
         */
        firewallPolicy?: string;
        /**
         * When rule.priority is not specified, auto choose a unused priority between minPriority and maxPriority\>. This field is exclusive with rule.priority.
         */
        maxPriority?: number;
        /**
         * When rule.priority is not specified, auto choose a unused priority between minPriority and maxPriority\>. This field is exclusive with rule.priority.
         */
        minPriority?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$FirewallPolicyRule;
    }
    export interface Params$Resource$Regionnetworkfirewallpolicies$Clonerules extends StandardParameters {
        /**
         * Name of the firewall policy to update.
         */
        firewallPolicy?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The firewall policy from which to copy rules.
         */
        sourceFirewallPolicy?: string;
    }
    export interface Params$Resource$Regionnetworkfirewallpolicies$Delete extends StandardParameters {
        /**
         * Name of the firewall policy to delete.
         */
        firewallPolicy?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Regionnetworkfirewallpolicies$Get extends StandardParameters {
        /**
         * Name of the firewall policy to get.
         */
        firewallPolicy?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
    }
    export interface Params$Resource$Regionnetworkfirewallpolicies$Getassociation extends StandardParameters {
        /**
         * Name of the firewall policy to which the queried association belongs.
         */
        firewallPolicy?: string;
        /**
         * The name of the association to get from the firewall policy.
         */
        name?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
    }
    export interface Params$Resource$Regionnetworkfirewallpolicies$Geteffectivefirewalls extends StandardParameters {
        /**
         * Network reference
         */
        network?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
    }
    export interface Params$Resource$Regionnetworkfirewallpolicies$Getiampolicy extends StandardParameters {
        /**
         * Requested IAM Policy version.
         */
        optionsRequestedPolicyVersion?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
    }
    export interface Params$Resource$Regionnetworkfirewallpolicies$Getrule extends StandardParameters {
        /**
         * Name of the firewall policy to which the queried rule belongs.
         */
        firewallPolicy?: string;
        /**
         * The priority of the rule to get from the firewall policy.
         */
        priority?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
    }
    export interface Params$Resource$Regionnetworkfirewallpolicies$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$FirewallPolicy;
    }
    export interface Params$Resource$Regionnetworkfirewallpolicies$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Regionnetworkfirewallpolicies$Patch extends StandardParameters {
        /**
         * Name of the firewall policy to update.
         */
        firewallPolicy?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$FirewallPolicy;
    }
    export interface Params$Resource$Regionnetworkfirewallpolicies$Patchassociation extends StandardParameters {
        /**
         * Name of the firewall policy to update.
         */
        firewallPolicy?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$FirewallPolicyAssociation;
    }
    export interface Params$Resource$Regionnetworkfirewallpolicies$Patchrule extends StandardParameters {
        /**
         * Name of the firewall policy to update.
         */
        firewallPolicy?: string;
        /**
         * The priority of the rule to patch.
         */
        priority?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$FirewallPolicyRule;
    }
    export interface Params$Resource$Regionnetworkfirewallpolicies$Removeassociation extends StandardParameters {
        /**
         * Name of the firewall policy to update.
         */
        firewallPolicy?: string;
        /**
         * Name for the association that will be removed.
         */
        name?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Regionnetworkfirewallpolicies$Removerule extends StandardParameters {
        /**
         * Name of the firewall policy to update.
         */
        firewallPolicy?: string;
        /**
         * The priority of the rule to remove from the firewall policy.
         */
        priority?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Regionnetworkfirewallpolicies$Setiampolicy extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionSetPolicyRequest;
    }
    export interface Params$Resource$Regionnetworkfirewallpolicies$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Regionnotificationendpoints {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves the list of all NotificationEndpoint resources, regional and global, available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Regionnotificationendpoints$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Regionnotificationendpoints$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$NotificationEndpointAggregatedList>;
        aggregatedList(params: Params$Resource$Regionnotificationendpoints$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Regionnotificationendpoints$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$NotificationEndpointAggregatedList>, callback: BodyResponseCallback<Schema$NotificationEndpointAggregatedList>): void;
        aggregatedList(params: Params$Resource$Regionnotificationendpoints$Aggregatedlist, callback: BodyResponseCallback<Schema$NotificationEndpointAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$NotificationEndpointAggregatedList>): void;
        /**
         * Deletes the specified NotificationEndpoint in the given region
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Regionnotificationendpoints$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Regionnotificationendpoints$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Regionnotificationendpoints$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Regionnotificationendpoints$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Regionnotificationendpoints$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified NotificationEndpoint resource in the given region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Regionnotificationendpoints$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Regionnotificationendpoints$Get, options?: MethodOptions): GaxiosPromise<Schema$NotificationEndpoint>;
        get(params: Params$Resource$Regionnotificationendpoints$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Regionnotificationendpoints$Get, options: MethodOptions | BodyResponseCallback<Schema$NotificationEndpoint>, callback: BodyResponseCallback<Schema$NotificationEndpoint>): void;
        get(params: Params$Resource$Regionnotificationendpoints$Get, callback: BodyResponseCallback<Schema$NotificationEndpoint>): void;
        get(callback: BodyResponseCallback<Schema$NotificationEndpoint>): void;
        /**
         * Create a NotificationEndpoint in the specified project in the given region using the parameters that are included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Regionnotificationendpoints$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Regionnotificationendpoints$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Regionnotificationendpoints$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Regionnotificationendpoints$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Regionnotificationendpoints$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Lists the NotificationEndpoints for a project in the given region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Regionnotificationendpoints$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Regionnotificationendpoints$List, options?: MethodOptions): GaxiosPromise<Schema$NotificationEndpointList>;
        list(params: Params$Resource$Regionnotificationendpoints$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Regionnotificationendpoints$List, options: MethodOptions | BodyResponseCallback<Schema$NotificationEndpointList>, callback: BodyResponseCallback<Schema$NotificationEndpointList>): void;
        list(params: Params$Resource$Regionnotificationendpoints$List, callback: BodyResponseCallback<Schema$NotificationEndpointList>): void;
        list(callback: BodyResponseCallback<Schema$NotificationEndpointList>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Regionnotificationendpoints$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Regionnotificationendpoints$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Regionnotificationendpoints$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Regionnotificationendpoints$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Regionnotificationendpoints$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Regionnotificationendpoints$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Name of the project scoping this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Regionnotificationendpoints$Delete extends StandardParameters {
        /**
         * Name of the NotificationEndpoint resource to delete.
         */
        notificationEndpoint?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
    }
    export interface Params$Resource$Regionnotificationendpoints$Get extends StandardParameters {
        /**
         * Name of the NotificationEndpoint resource to return.
         */
        notificationEndpoint?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
    }
    export interface Params$Resource$Regionnotificationendpoints$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$NotificationEndpoint;
    }
    export interface Params$Resource$Regionnotificationendpoints$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Regionnotificationendpoints$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Regionoperations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Deletes the specified region-specific Operations resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Regionoperations$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Regionoperations$Delete, options?: MethodOptions): GaxiosPromise<void>;
        delete(params: Params$Resource$Regionoperations$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Regionoperations$Delete, options: MethodOptions | BodyResponseCallback<void>, callback: BodyResponseCallback<void>): void;
        delete(params: Params$Resource$Regionoperations$Delete, callback: BodyResponseCallback<void>): void;
        delete(callback: BodyResponseCallback<void>): void;
        /**
         * Retrieves the specified region-specific Operations resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Regionoperations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Regionoperations$Get, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        get(params: Params$Resource$Regionoperations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Regionoperations$Get, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        get(params: Params$Resource$Regionoperations$Get, callback: BodyResponseCallback<Schema$Operation>): void;
        get(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves a list of Operation resources contained within the specified region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Regionoperations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Regionoperations$List, options?: MethodOptions): GaxiosPromise<Schema$OperationList>;
        list(params: Params$Resource$Regionoperations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Regionoperations$List, options: MethodOptions | BodyResponseCallback<Schema$OperationList>, callback: BodyResponseCallback<Schema$OperationList>): void;
        list(params: Params$Resource$Regionoperations$List, callback: BodyResponseCallback<Schema$OperationList>): void;
        list(callback: BodyResponseCallback<Schema$OperationList>): void;
        /**
         * Waits for the specified Operation resource to return as `DONE` or for the request to approach the 2 minute deadline, and retrieves the specified Operation resource. This method differs from the `GET` method in that it waits for no more than the default deadline (2 minutes) and then returns the current state of the operation, which might be `DONE` or still in progress. This method is called on a best-effort basis. Specifically: - In uncommon cases, when the server is overloaded, the request might return before the default deadline is reached, or might return after zero seconds. - If the default deadline is reached, there is no guarantee that the operation is actually done when the method returns. Be prepared to retry if the operation is not `DONE`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        wait(params: Params$Resource$Regionoperations$Wait, options: StreamMethodOptions): GaxiosPromise<Readable>;
        wait(params?: Params$Resource$Regionoperations$Wait, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        wait(params: Params$Resource$Regionoperations$Wait, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        wait(params: Params$Resource$Regionoperations$Wait, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        wait(params: Params$Resource$Regionoperations$Wait, callback: BodyResponseCallback<Schema$Operation>): void;
        wait(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    export interface Params$Resource$Regionoperations$Delete extends StandardParameters {
        /**
         * Name of the Operations resource to delete.
         */
        operation?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
    }
    export interface Params$Resource$Regionoperations$Get extends StandardParameters {
        /**
         * Name of the Operations resource to return.
         */
        operation?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
    }
    export interface Params$Resource$Regionoperations$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Regionoperations$Wait extends StandardParameters {
        /**
         * Name of the Operations resource to return.
         */
        operation?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
    }
    export class Resource$Regions {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Returns the specified Region resource. To decrease latency for this method, you can optionally omit any unneeded information from the response by using a field mask. This practice is especially recommended for unused quota information (the `quotas` field). To exclude one or more fields, set your request's `fields` query parameter to only include the fields you need. For example, to only include the `id` and `selfLink` fields, add the query parameter `?fields=id,selfLink` to your request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Regions$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Regions$Get, options?: MethodOptions): GaxiosPromise<Schema$Region>;
        get(params: Params$Resource$Regions$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Regions$Get, options: MethodOptions | BodyResponseCallback<Schema$Region>, callback: BodyResponseCallback<Schema$Region>): void;
        get(params: Params$Resource$Regions$Get, callback: BodyResponseCallback<Schema$Region>): void;
        get(callback: BodyResponseCallback<Schema$Region>): void;
        /**
         * Retrieves the list of region resources available to the specified project. To decrease latency for this method, you can optionally omit any unneeded information from the response by using a field mask. This practice is especially recommended for unused quota information (the `items.quotas` field). To exclude one or more fields, set your request's `fields` query parameter to only include the fields you need. For example, to only include the `id` and `selfLink` fields, add the query parameter `?fields=id,selfLink` to your request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Regions$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Regions$List, options?: MethodOptions): GaxiosPromise<Schema$RegionList>;
        list(params: Params$Resource$Regions$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Regions$List, options: MethodOptions | BodyResponseCallback<Schema$RegionList>, callback: BodyResponseCallback<Schema$RegionList>): void;
        list(params: Params$Resource$Regions$List, callback: BodyResponseCallback<Schema$RegionList>): void;
        list(callback: BodyResponseCallback<Schema$RegionList>): void;
    }
    export interface Params$Resource$Regions$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region resource to return.
         */
        region?: string;
    }
    export interface Params$Resource$Regions$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export class Resource$Regionsecuritypolicies {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Inserts a rule into a security policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        addRule(params: Params$Resource$Regionsecuritypolicies$Addrule, options: StreamMethodOptions): GaxiosPromise<Readable>;
        addRule(params?: Params$Resource$Regionsecuritypolicies$Addrule, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        addRule(params: Params$Resource$Regionsecuritypolicies$Addrule, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        addRule(params: Params$Resource$Regionsecuritypolicies$Addrule, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        addRule(params: Params$Resource$Regionsecuritypolicies$Addrule, callback: BodyResponseCallback<Schema$Operation>): void;
        addRule(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Deletes the specified policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Regionsecuritypolicies$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Regionsecuritypolicies$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Regionsecuritypolicies$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Regionsecuritypolicies$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Regionsecuritypolicies$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * List all of the ordered rules present in a single specified policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Regionsecuritypolicies$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Regionsecuritypolicies$Get, options?: MethodOptions): GaxiosPromise<Schema$SecurityPolicy>;
        get(params: Params$Resource$Regionsecuritypolicies$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Regionsecuritypolicies$Get, options: MethodOptions | BodyResponseCallback<Schema$SecurityPolicy>, callback: BodyResponseCallback<Schema$SecurityPolicy>): void;
        get(params: Params$Resource$Regionsecuritypolicies$Get, callback: BodyResponseCallback<Schema$SecurityPolicy>): void;
        get(callback: BodyResponseCallback<Schema$SecurityPolicy>): void;
        /**
         * Gets a rule at the specified priority.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getRule(params: Params$Resource$Regionsecuritypolicies$Getrule, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getRule(params?: Params$Resource$Regionsecuritypolicies$Getrule, options?: MethodOptions): GaxiosPromise<Schema$SecurityPolicyRule>;
        getRule(params: Params$Resource$Regionsecuritypolicies$Getrule, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getRule(params: Params$Resource$Regionsecuritypolicies$Getrule, options: MethodOptions | BodyResponseCallback<Schema$SecurityPolicyRule>, callback: BodyResponseCallback<Schema$SecurityPolicyRule>): void;
        getRule(params: Params$Resource$Regionsecuritypolicies$Getrule, callback: BodyResponseCallback<Schema$SecurityPolicyRule>): void;
        getRule(callback: BodyResponseCallback<Schema$SecurityPolicyRule>): void;
        /**
         * Creates a new policy in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Regionsecuritypolicies$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Regionsecuritypolicies$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Regionsecuritypolicies$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Regionsecuritypolicies$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Regionsecuritypolicies$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * List all the policies that have been configured for the specified project and region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Regionsecuritypolicies$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Regionsecuritypolicies$List, options?: MethodOptions): GaxiosPromise<Schema$SecurityPolicyList>;
        list(params: Params$Resource$Regionsecuritypolicies$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Regionsecuritypolicies$List, options: MethodOptions | BodyResponseCallback<Schema$SecurityPolicyList>, callback: BodyResponseCallback<Schema$SecurityPolicyList>): void;
        list(params: Params$Resource$Regionsecuritypolicies$List, callback: BodyResponseCallback<Schema$SecurityPolicyList>): void;
        list(callback: BodyResponseCallback<Schema$SecurityPolicyList>): void;
        /**
         * Patches the specified policy with the data included in the request. To clear fields in the policy, leave the fields empty and specify them in the updateMask. This cannot be used to be update the rules in the policy. Please use the per rule methods like addRule, patchRule, and removeRule instead.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Regionsecuritypolicies$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Regionsecuritypolicies$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Regionsecuritypolicies$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Regionsecuritypolicies$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Regionsecuritypolicies$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Patches a rule at the specified priority. To clear fields in the rule, leave the fields empty and specify them in the updateMask.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patchRule(params: Params$Resource$Regionsecuritypolicies$Patchrule, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patchRule(params?: Params$Resource$Regionsecuritypolicies$Patchrule, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patchRule(params: Params$Resource$Regionsecuritypolicies$Patchrule, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patchRule(params: Params$Resource$Regionsecuritypolicies$Patchrule, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patchRule(params: Params$Resource$Regionsecuritypolicies$Patchrule, callback: BodyResponseCallback<Schema$Operation>): void;
        patchRule(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Deletes a rule at the specified priority.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        removeRule(params: Params$Resource$Regionsecuritypolicies$Removerule, options: StreamMethodOptions): GaxiosPromise<Readable>;
        removeRule(params?: Params$Resource$Regionsecuritypolicies$Removerule, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        removeRule(params: Params$Resource$Regionsecuritypolicies$Removerule, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        removeRule(params: Params$Resource$Regionsecuritypolicies$Removerule, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        removeRule(params: Params$Resource$Regionsecuritypolicies$Removerule, callback: BodyResponseCallback<Schema$Operation>): void;
        removeRule(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    export interface Params$Resource$Regionsecuritypolicies$Addrule extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Name of the security policy to update.
         */
        securityPolicy?: string;
        /**
         * If true, the request will not be committed.
         */
        validateOnly?: boolean;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SecurityPolicyRule;
    }
    export interface Params$Resource$Regionsecuritypolicies$Delete extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the security policy to delete.
         */
        securityPolicy?: string;
    }
    export interface Params$Resource$Regionsecuritypolicies$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Name of the security policy to get.
         */
        securityPolicy?: string;
    }
    export interface Params$Resource$Regionsecuritypolicies$Getrule extends StandardParameters {
        /**
         * The priority of the rule to get from the security policy.
         */
        priority?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Name of the security policy to which the queried rule belongs.
         */
        securityPolicy?: string;
    }
    export interface Params$Resource$Regionsecuritypolicies$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * If true, the request will not be committed.
         */
        validateOnly?: boolean;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SecurityPolicy;
    }
    export interface Params$Resource$Regionsecuritypolicies$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Regionsecuritypolicies$Patch extends StandardParameters {
        /**
         *
         */
        paths?: string[];
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the security policy to update.
         */
        securityPolicy?: string;
        /**
         * Indicates fields to be cleared as part of this request.
         */
        updateMask?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SecurityPolicy;
    }
    export interface Params$Resource$Regionsecuritypolicies$Patchrule extends StandardParameters {
        /**
         * The priority of the rule to patch.
         */
        priority?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Name of the security policy to update.
         */
        securityPolicy?: string;
        /**
         * Indicates fields to be cleared as part of this request.
         */
        updateMask?: string;
        /**
         * If true, the request will not be committed.
         */
        validateOnly?: boolean;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SecurityPolicyRule;
    }
    export interface Params$Resource$Regionsecuritypolicies$Removerule extends StandardParameters {
        /**
         * The priority of the rule to remove from the security policy.
         */
        priority?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Name of the security policy to update.
         */
        securityPolicy?: string;
    }
    export class Resource$Regionsnapshots {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Deletes the specified Snapshot resource. Keep in mind that deleting a single snapshot might not necessarily delete all the data on that snapshot. If any data on the snapshot that is marked for deletion is needed for subsequent snapshots, the data will be moved to the next corresponding snapshot. For more information, see Deleting snapshots.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Regionsnapshots$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Regionsnapshots$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Regionsnapshots$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Regionsnapshots$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Regionsnapshots$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified Snapshot resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Regionsnapshots$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Regionsnapshots$Get, options?: MethodOptions): GaxiosPromise<Schema$Snapshot>;
        get(params: Params$Resource$Regionsnapshots$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Regionsnapshots$Get, options: MethodOptions | BodyResponseCallback<Schema$Snapshot>, callback: BodyResponseCallback<Schema$Snapshot>): void;
        get(params: Params$Resource$Regionsnapshots$Get, callback: BodyResponseCallback<Schema$Snapshot>): void;
        get(callback: BodyResponseCallback<Schema$Snapshot>): void;
        /**
         * Gets the access control policy for a resource. May be empty if no such policy or resource exists.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getIamPolicy(params: Params$Resource$Regionsnapshots$Getiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getIamPolicy(params?: Params$Resource$Regionsnapshots$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        getIamPolicy(params: Params$Resource$Regionsnapshots$Getiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getIamPolicy(params: Params$Resource$Regionsnapshots$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(params: Params$Resource$Regionsnapshots$Getiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Creates a snapshot in the specified region using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Regionsnapshots$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Regionsnapshots$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Regionsnapshots$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Regionsnapshots$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Regionsnapshots$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of Snapshot resources contained within the specified region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Regionsnapshots$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Regionsnapshots$List, options?: MethodOptions): GaxiosPromise<Schema$SnapshotList>;
        list(params: Params$Resource$Regionsnapshots$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Regionsnapshots$List, options: MethodOptions | BodyResponseCallback<Schema$SnapshotList>, callback: BodyResponseCallback<Schema$SnapshotList>): void;
        list(params: Params$Resource$Regionsnapshots$List, callback: BodyResponseCallback<Schema$SnapshotList>): void;
        list(callback: BodyResponseCallback<Schema$SnapshotList>): void;
        /**
         * Sets the access control policy on the specified resource. Replaces any existing policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setIamPolicy(params: Params$Resource$Regionsnapshots$Setiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setIamPolicy(params?: Params$Resource$Regionsnapshots$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        setIamPolicy(params: Params$Resource$Regionsnapshots$Setiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setIamPolicy(params: Params$Resource$Regionsnapshots$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(params: Params$Resource$Regionsnapshots$Setiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Sets the labels on a regional snapshot. To learn more about labels, read the Labeling Resources documentation.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setLabels(params: Params$Resource$Regionsnapshots$Setlabels, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setLabels(params?: Params$Resource$Regionsnapshots$Setlabels, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setLabels(params: Params$Resource$Regionsnapshots$Setlabels, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setLabels(params: Params$Resource$Regionsnapshots$Setlabels, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(params: Params$Resource$Regionsnapshots$Setlabels, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Regionsnapshots$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Regionsnapshots$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Regionsnapshots$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Regionsnapshots$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Regionsnapshots$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Regionsnapshots$Delete extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the snapshot resource to delete.
         */
        snapshot?: string;
    }
    export interface Params$Resource$Regionsnapshots$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * Name of the Snapshot resource to return.
         */
        snapshot?: string;
    }
    export interface Params$Resource$Regionsnapshots$Getiampolicy extends StandardParameters {
        /**
         * Requested IAM Policy version.
         */
        optionsRequestedPolicyVersion?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
    }
    export interface Params$Resource$Regionsnapshots$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Snapshot;
    }
    export interface Params$Resource$Regionsnapshots$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Regionsnapshots$Setiampolicy extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionSetPolicyRequest;
    }
    export interface Params$Resource$Regionsnapshots$Setlabels extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionSetLabelsRequest;
    }
    export interface Params$Resource$Regionsnapshots$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Regionsslcertificates {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Deletes the specified SslCertificate resource in the region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Regionsslcertificates$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Regionsslcertificates$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Regionsslcertificates$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Regionsslcertificates$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Regionsslcertificates$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified SslCertificate resource in the specified region. Get a list of available SSL certificates by making a list() request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Regionsslcertificates$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Regionsslcertificates$Get, options?: MethodOptions): GaxiosPromise<Schema$SslCertificate>;
        get(params: Params$Resource$Regionsslcertificates$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Regionsslcertificates$Get, options: MethodOptions | BodyResponseCallback<Schema$SslCertificate>, callback: BodyResponseCallback<Schema$SslCertificate>): void;
        get(params: Params$Resource$Regionsslcertificates$Get, callback: BodyResponseCallback<Schema$SslCertificate>): void;
        get(callback: BodyResponseCallback<Schema$SslCertificate>): void;
        /**
         * Creates a SslCertificate resource in the specified project and region using the data included in the request
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Regionsslcertificates$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Regionsslcertificates$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Regionsslcertificates$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Regionsslcertificates$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Regionsslcertificates$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of SslCertificate resources available to the specified project in the specified region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Regionsslcertificates$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Regionsslcertificates$List, options?: MethodOptions): GaxiosPromise<Schema$SslCertificateList>;
        list(params: Params$Resource$Regionsslcertificates$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Regionsslcertificates$List, options: MethodOptions | BodyResponseCallback<Schema$SslCertificateList>, callback: BodyResponseCallback<Schema$SslCertificateList>): void;
        list(params: Params$Resource$Regionsslcertificates$List, callback: BodyResponseCallback<Schema$SslCertificateList>): void;
        list(callback: BodyResponseCallback<Schema$SslCertificateList>): void;
        /**
         * Returns permissions that a caller has on the specified resource and region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Regionsslcertificates$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Regionsslcertificates$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Regionsslcertificates$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Regionsslcertificates$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Regionsslcertificates$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Regionsslcertificates$Delete extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the SslCertificate resource to delete.
         */
        sslCertificate?: string;
    }
    export interface Params$Resource$Regionsslcertificates$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Name of the SslCertificate resource to return.
         */
        sslCertificate?: string;
    }
    export interface Params$Resource$Regionsslcertificates$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SslCertificate;
    }
    export interface Params$Resource$Regionsslcertificates$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Regionsslcertificates$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Regionsslpolicies {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Deletes the specified SSL policy. The SSL policy resource can be deleted only if it is not in use by any TargetHttpsProxy or TargetSslProxy resources.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Regionsslpolicies$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Regionsslpolicies$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Regionsslpolicies$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Regionsslpolicies$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Regionsslpolicies$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Lists all of the ordered rules present in a single specified policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Regionsslpolicies$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Regionsslpolicies$Get, options?: MethodOptions): GaxiosPromise<Schema$SslPolicy>;
        get(params: Params$Resource$Regionsslpolicies$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Regionsslpolicies$Get, options: MethodOptions | BodyResponseCallback<Schema$SslPolicy>, callback: BodyResponseCallback<Schema$SslPolicy>): void;
        get(params: Params$Resource$Regionsslpolicies$Get, callback: BodyResponseCallback<Schema$SslPolicy>): void;
        get(callback: BodyResponseCallback<Schema$SslPolicy>): void;
        /**
         * Creates a new policy in the specified project and region using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Regionsslpolicies$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Regionsslpolicies$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Regionsslpolicies$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Regionsslpolicies$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Regionsslpolicies$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Lists all the SSL policies that have been configured for the specified project and region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Regionsslpolicies$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Regionsslpolicies$List, options?: MethodOptions): GaxiosPromise<Schema$SslPoliciesList>;
        list(params: Params$Resource$Regionsslpolicies$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Regionsslpolicies$List, options: MethodOptions | BodyResponseCallback<Schema$SslPoliciesList>, callback: BodyResponseCallback<Schema$SslPoliciesList>): void;
        list(params: Params$Resource$Regionsslpolicies$List, callback: BodyResponseCallback<Schema$SslPoliciesList>): void;
        list(callback: BodyResponseCallback<Schema$SslPoliciesList>): void;
        /**
         * Lists all features that can be specified in the SSL policy when using custom profile.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        listAvailableFeatures(params: Params$Resource$Regionsslpolicies$Listavailablefeatures, options: StreamMethodOptions): GaxiosPromise<Readable>;
        listAvailableFeatures(params?: Params$Resource$Regionsslpolicies$Listavailablefeatures, options?: MethodOptions): GaxiosPromise<Schema$SslPoliciesListAvailableFeaturesResponse>;
        listAvailableFeatures(params: Params$Resource$Regionsslpolicies$Listavailablefeatures, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        listAvailableFeatures(params: Params$Resource$Regionsslpolicies$Listavailablefeatures, options: MethodOptions | BodyResponseCallback<Schema$SslPoliciesListAvailableFeaturesResponse>, callback: BodyResponseCallback<Schema$SslPoliciesListAvailableFeaturesResponse>): void;
        listAvailableFeatures(params: Params$Resource$Regionsslpolicies$Listavailablefeatures, callback: BodyResponseCallback<Schema$SslPoliciesListAvailableFeaturesResponse>): void;
        listAvailableFeatures(callback: BodyResponseCallback<Schema$SslPoliciesListAvailableFeaturesResponse>): void;
        /**
         * Patches the specified SSL policy with the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Regionsslpolicies$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Regionsslpolicies$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Regionsslpolicies$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Regionsslpolicies$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Regionsslpolicies$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Regionsslpolicies$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Regionsslpolicies$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Regionsslpolicies$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Regionsslpolicies$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Regionsslpolicies$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Regionsslpolicies$Delete extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the SSL policy to delete. The name must be 1-63 characters long, and comply with RFC1035.
         */
        sslPolicy?: string;
    }
    export interface Params$Resource$Regionsslpolicies$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Name of the SSL policy to update. The name must be 1-63 characters long, and comply with RFC1035.
         */
        sslPolicy?: string;
    }
    export interface Params$Resource$Regionsslpolicies$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SslPolicy;
    }
    export interface Params$Resource$Regionsslpolicies$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Regionsslpolicies$Listavailablefeatures extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Regionsslpolicies$Patch extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the SSL policy to update. The name must be 1-63 characters long, and comply with RFC1035.
         */
        sslPolicy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SslPolicy;
    }
    export interface Params$Resource$Regionsslpolicies$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Regiontargethttpproxies {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Deletes the specified TargetHttpProxy resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Regiontargethttpproxies$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Regiontargethttpproxies$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Regiontargethttpproxies$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Regiontargethttpproxies$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Regiontargethttpproxies$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified TargetHttpProxy resource in the specified region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Regiontargethttpproxies$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Regiontargethttpproxies$Get, options?: MethodOptions): GaxiosPromise<Schema$TargetHttpProxy>;
        get(params: Params$Resource$Regiontargethttpproxies$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Regiontargethttpproxies$Get, options: MethodOptions | BodyResponseCallback<Schema$TargetHttpProxy>, callback: BodyResponseCallback<Schema$TargetHttpProxy>): void;
        get(params: Params$Resource$Regiontargethttpproxies$Get, callback: BodyResponseCallback<Schema$TargetHttpProxy>): void;
        get(callback: BodyResponseCallback<Schema$TargetHttpProxy>): void;
        /**
         * Creates a TargetHttpProxy resource in the specified project and region using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Regiontargethttpproxies$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Regiontargethttpproxies$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Regiontargethttpproxies$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Regiontargethttpproxies$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Regiontargethttpproxies$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of TargetHttpProxy resources available to the specified project in the specified region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Regiontargethttpproxies$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Regiontargethttpproxies$List, options?: MethodOptions): GaxiosPromise<Schema$TargetHttpProxyList>;
        list(params: Params$Resource$Regiontargethttpproxies$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Regiontargethttpproxies$List, options: MethodOptions | BodyResponseCallback<Schema$TargetHttpProxyList>, callback: BodyResponseCallback<Schema$TargetHttpProxyList>): void;
        list(params: Params$Resource$Regiontargethttpproxies$List, callback: BodyResponseCallback<Schema$TargetHttpProxyList>): void;
        list(callback: BodyResponseCallback<Schema$TargetHttpProxyList>): void;
        /**
         * Changes the URL map for TargetHttpProxy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setUrlMap(params: Params$Resource$Regiontargethttpproxies$Seturlmap, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setUrlMap(params?: Params$Resource$Regiontargethttpproxies$Seturlmap, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setUrlMap(params: Params$Resource$Regiontargethttpproxies$Seturlmap, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setUrlMap(params: Params$Resource$Regiontargethttpproxies$Seturlmap, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setUrlMap(params: Params$Resource$Regiontargethttpproxies$Seturlmap, callback: BodyResponseCallback<Schema$Operation>): void;
        setUrlMap(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Regiontargethttpproxies$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Regiontargethttpproxies$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Regiontargethttpproxies$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Regiontargethttpproxies$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Regiontargethttpproxies$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Regiontargethttpproxies$Delete extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetHttpProxy resource to delete.
         */
        targetHttpProxy?: string;
    }
    export interface Params$Resource$Regiontargethttpproxies$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Name of the TargetHttpProxy resource to return.
         */
        targetHttpProxy?: string;
    }
    export interface Params$Resource$Regiontargethttpproxies$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetHttpProxy;
    }
    export interface Params$Resource$Regiontargethttpproxies$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Regiontargethttpproxies$Seturlmap extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetHttpProxy to set a URL map for.
         */
        targetHttpProxy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$UrlMapReference;
    }
    export interface Params$Resource$Regiontargethttpproxies$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Regiontargethttpsproxies {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Deletes the specified TargetHttpsProxy resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Regiontargethttpsproxies$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Regiontargethttpsproxies$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Regiontargethttpsproxies$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Regiontargethttpsproxies$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Regiontargethttpsproxies$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified TargetHttpsProxy resource in the specified region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Regiontargethttpsproxies$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Regiontargethttpsproxies$Get, options?: MethodOptions): GaxiosPromise<Schema$TargetHttpsProxy>;
        get(params: Params$Resource$Regiontargethttpsproxies$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Regiontargethttpsproxies$Get, options: MethodOptions | BodyResponseCallback<Schema$TargetHttpsProxy>, callback: BodyResponseCallback<Schema$TargetHttpsProxy>): void;
        get(params: Params$Resource$Regiontargethttpsproxies$Get, callback: BodyResponseCallback<Schema$TargetHttpsProxy>): void;
        get(callback: BodyResponseCallback<Schema$TargetHttpsProxy>): void;
        /**
         * Creates a TargetHttpsProxy resource in the specified project and region using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Regiontargethttpsproxies$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Regiontargethttpsproxies$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Regiontargethttpsproxies$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Regiontargethttpsproxies$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Regiontargethttpsproxies$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of TargetHttpsProxy resources available to the specified project in the specified region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Regiontargethttpsproxies$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Regiontargethttpsproxies$List, options?: MethodOptions): GaxiosPromise<Schema$TargetHttpsProxyList>;
        list(params: Params$Resource$Regiontargethttpsproxies$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Regiontargethttpsproxies$List, options: MethodOptions | BodyResponseCallback<Schema$TargetHttpsProxyList>, callback: BodyResponseCallback<Schema$TargetHttpsProxyList>): void;
        list(params: Params$Resource$Regiontargethttpsproxies$List, callback: BodyResponseCallback<Schema$TargetHttpsProxyList>): void;
        list(callback: BodyResponseCallback<Schema$TargetHttpsProxyList>): void;
        /**
         * Patches the specified regional TargetHttpsProxy resource with the data included in the request. This method supports PATCH semantics and uses JSON merge patch format and processing rules.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Regiontargethttpsproxies$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Regiontargethttpsproxies$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Regiontargethttpsproxies$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Regiontargethttpsproxies$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Regiontargethttpsproxies$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Replaces SslCertificates for TargetHttpsProxy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setSslCertificates(params: Params$Resource$Regiontargethttpsproxies$Setsslcertificates, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setSslCertificates(params?: Params$Resource$Regiontargethttpsproxies$Setsslcertificates, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setSslCertificates(params: Params$Resource$Regiontargethttpsproxies$Setsslcertificates, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setSslCertificates(params: Params$Resource$Regiontargethttpsproxies$Setsslcertificates, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setSslCertificates(params: Params$Resource$Regiontargethttpsproxies$Setsslcertificates, callback: BodyResponseCallback<Schema$Operation>): void;
        setSslCertificates(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Changes the URL map for TargetHttpsProxy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setUrlMap(params: Params$Resource$Regiontargethttpsproxies$Seturlmap, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setUrlMap(params?: Params$Resource$Regiontargethttpsproxies$Seturlmap, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setUrlMap(params: Params$Resource$Regiontargethttpsproxies$Seturlmap, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setUrlMap(params: Params$Resource$Regiontargethttpsproxies$Seturlmap, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setUrlMap(params: Params$Resource$Regiontargethttpsproxies$Seturlmap, callback: BodyResponseCallback<Schema$Operation>): void;
        setUrlMap(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Regiontargethttpsproxies$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Regiontargethttpsproxies$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Regiontargethttpsproxies$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Regiontargethttpsproxies$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Regiontargethttpsproxies$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Regiontargethttpsproxies$Delete extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetHttpsProxy resource to delete.
         */
        targetHttpsProxy?: string;
    }
    export interface Params$Resource$Regiontargethttpsproxies$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Name of the TargetHttpsProxy resource to return.
         */
        targetHttpsProxy?: string;
    }
    export interface Params$Resource$Regiontargethttpsproxies$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetHttpsProxy;
    }
    export interface Params$Resource$Regiontargethttpsproxies$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Regiontargethttpsproxies$Patch extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetHttpsProxy resource to patch.
         */
        targetHttpsProxy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetHttpsProxy;
    }
    export interface Params$Resource$Regiontargethttpsproxies$Setsslcertificates extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetHttpsProxy resource to set an SslCertificates resource for.
         */
        targetHttpsProxy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionTargetHttpsProxiesSetSslCertificatesRequest;
    }
    export interface Params$Resource$Regiontargethttpsproxies$Seturlmap extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetHttpsProxy to set a URL map for.
         */
        targetHttpsProxy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$UrlMapReference;
    }
    export interface Params$Resource$Regiontargethttpsproxies$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Regiontargettcpproxies {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Deletes the specified TargetTcpProxy resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Regiontargettcpproxies$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Regiontargettcpproxies$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Regiontargettcpproxies$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Regiontargettcpproxies$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Regiontargettcpproxies$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified TargetTcpProxy resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Regiontargettcpproxies$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Regiontargettcpproxies$Get, options?: MethodOptions): GaxiosPromise<Schema$TargetTcpProxy>;
        get(params: Params$Resource$Regiontargettcpproxies$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Regiontargettcpproxies$Get, options: MethodOptions | BodyResponseCallback<Schema$TargetTcpProxy>, callback: BodyResponseCallback<Schema$TargetTcpProxy>): void;
        get(params: Params$Resource$Regiontargettcpproxies$Get, callback: BodyResponseCallback<Schema$TargetTcpProxy>): void;
        get(callback: BodyResponseCallback<Schema$TargetTcpProxy>): void;
        /**
         * Creates a TargetTcpProxy resource in the specified project and region using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Regiontargettcpproxies$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Regiontargettcpproxies$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Regiontargettcpproxies$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Regiontargettcpproxies$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Regiontargettcpproxies$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves a list of TargetTcpProxy resources available to the specified project in a given region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Regiontargettcpproxies$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Regiontargettcpproxies$List, options?: MethodOptions): GaxiosPromise<Schema$TargetTcpProxyList>;
        list(params: Params$Resource$Regiontargettcpproxies$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Regiontargettcpproxies$List, options: MethodOptions | BodyResponseCallback<Schema$TargetTcpProxyList>, callback: BodyResponseCallback<Schema$TargetTcpProxyList>): void;
        list(params: Params$Resource$Regiontargettcpproxies$List, callback: BodyResponseCallback<Schema$TargetTcpProxyList>): void;
        list(callback: BodyResponseCallback<Schema$TargetTcpProxyList>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Regiontargettcpproxies$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Regiontargettcpproxies$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Regiontargettcpproxies$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Regiontargettcpproxies$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Regiontargettcpproxies$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Regiontargettcpproxies$Delete extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetTcpProxy resource to delete.
         */
        targetTcpProxy?: string;
    }
    export interface Params$Resource$Regiontargettcpproxies$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Name of the TargetTcpProxy resource to return.
         */
        targetTcpProxy?: string;
    }
    export interface Params$Resource$Regiontargettcpproxies$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetTcpProxy;
    }
    export interface Params$Resource$Regiontargettcpproxies$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Regiontargettcpproxies$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Regionurlmaps {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Deletes the specified UrlMap resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Regionurlmaps$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Regionurlmaps$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Regionurlmaps$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Regionurlmaps$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Regionurlmaps$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified UrlMap resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Regionurlmaps$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Regionurlmaps$Get, options?: MethodOptions): GaxiosPromise<Schema$UrlMap>;
        get(params: Params$Resource$Regionurlmaps$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Regionurlmaps$Get, options: MethodOptions | BodyResponseCallback<Schema$UrlMap>, callback: BodyResponseCallback<Schema$UrlMap>): void;
        get(params: Params$Resource$Regionurlmaps$Get, callback: BodyResponseCallback<Schema$UrlMap>): void;
        get(callback: BodyResponseCallback<Schema$UrlMap>): void;
        /**
         * Creates a UrlMap resource in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Regionurlmaps$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Regionurlmaps$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Regionurlmaps$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Regionurlmaps$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Regionurlmaps$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Initiates a cache invalidation operation, invalidating the specified path, scoped to the specified UrlMap. For more information, see [Invalidating cached content](/cdn/docs/invalidating-cached-content).
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        invalidateCache(params: Params$Resource$Regionurlmaps$Invalidatecache, options: StreamMethodOptions): GaxiosPromise<Readable>;
        invalidateCache(params?: Params$Resource$Regionurlmaps$Invalidatecache, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        invalidateCache(params: Params$Resource$Regionurlmaps$Invalidatecache, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        invalidateCache(params: Params$Resource$Regionurlmaps$Invalidatecache, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        invalidateCache(params: Params$Resource$Regionurlmaps$Invalidatecache, callback: BodyResponseCallback<Schema$Operation>): void;
        invalidateCache(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of UrlMap resources available to the specified project in the specified region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Regionurlmaps$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Regionurlmaps$List, options?: MethodOptions): GaxiosPromise<Schema$UrlMapList>;
        list(params: Params$Resource$Regionurlmaps$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Regionurlmaps$List, options: MethodOptions | BodyResponseCallback<Schema$UrlMapList>, callback: BodyResponseCallback<Schema$UrlMapList>): void;
        list(params: Params$Resource$Regionurlmaps$List, callback: BodyResponseCallback<Schema$UrlMapList>): void;
        list(callback: BodyResponseCallback<Schema$UrlMapList>): void;
        /**
         * Patches the specified UrlMap resource with the data included in the request. This method supports PATCH semantics and uses JSON merge patch format and processing rules.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Regionurlmaps$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Regionurlmaps$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Regionurlmaps$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Regionurlmaps$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Regionurlmaps$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Regionurlmaps$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Regionurlmaps$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Regionurlmaps$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Regionurlmaps$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Regionurlmaps$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        /**
         * Updates the specified UrlMap resource with the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        update(params: Params$Resource$Regionurlmaps$Update, options: StreamMethodOptions): GaxiosPromise<Readable>;
        update(params?: Params$Resource$Regionurlmaps$Update, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        update(params: Params$Resource$Regionurlmaps$Update, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        update(params: Params$Resource$Regionurlmaps$Update, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        update(params: Params$Resource$Regionurlmaps$Update, callback: BodyResponseCallback<Schema$Operation>): void;
        update(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Runs static validation for the UrlMap. In particular, the tests of the provided UrlMap will be run. Calling this method does NOT create the UrlMap.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        validate(params: Params$Resource$Regionurlmaps$Validate, options: StreamMethodOptions): GaxiosPromise<Readable>;
        validate(params?: Params$Resource$Regionurlmaps$Validate, options?: MethodOptions): GaxiosPromise<Schema$UrlMapsValidateResponse>;
        validate(params: Params$Resource$Regionurlmaps$Validate, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        validate(params: Params$Resource$Regionurlmaps$Validate, options: MethodOptions | BodyResponseCallback<Schema$UrlMapsValidateResponse>, callback: BodyResponseCallback<Schema$UrlMapsValidateResponse>): void;
        validate(params: Params$Resource$Regionurlmaps$Validate, callback: BodyResponseCallback<Schema$UrlMapsValidateResponse>): void;
        validate(callback: BodyResponseCallback<Schema$UrlMapsValidateResponse>): void;
    }
    export interface Params$Resource$Regionurlmaps$Delete extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * begin_interface: MixerMutationRequestBuilder Request ID to support idempotency.
         */
        requestId?: string;
        /**
         * Name of the UrlMap resource to delete.
         */
        urlMap?: string;
    }
    export interface Params$Resource$Regionurlmaps$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Name of the UrlMap resource to return.
         */
        urlMap?: string;
    }
    export interface Params$Resource$Regionurlmaps$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * begin_interface: MixerMutationRequestBuilder Request ID to support idempotency.
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$UrlMap;
    }
    export interface Params$Resource$Regionurlmaps$Invalidatecache extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * begin_interface: MixerMutationRequestBuilder Request ID to support idempotency.
         */
        requestId?: string;
        /**
         * Name of the UrlMap scoping this request.
         */
        urlMap?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$CacheInvalidationRule;
    }
    export interface Params$Resource$Regionurlmaps$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Regionurlmaps$Patch extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * begin_interface: MixerMutationRequestBuilder Request ID to support idempotency.
         */
        requestId?: string;
        /**
         * Name of the UrlMap resource to patch.
         */
        urlMap?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$UrlMap;
    }
    export interface Params$Resource$Regionurlmaps$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export interface Params$Resource$Regionurlmaps$Update extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * begin_interface: MixerMutationRequestBuilder Request ID to support idempotency.
         */
        requestId?: string;
        /**
         * Name of the UrlMap resource to update.
         */
        urlMap?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$UrlMap;
    }
    export interface Params$Resource$Regionurlmaps$Validate extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Name of the UrlMap resource to be validated as.
         */
        urlMap?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionUrlMapsValidateRequest;
    }
    export class Resource$Regionzones {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves the list of Zone resources under the specific region available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Regionzones$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Regionzones$List, options?: MethodOptions): GaxiosPromise<Schema$ZoneList>;
        list(params: Params$Resource$Regionzones$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Regionzones$List, options: MethodOptions | BodyResponseCallback<Schema$ZoneList>, callback: BodyResponseCallback<Schema$ZoneList>): void;
        list(params: Params$Resource$Regionzones$List, callback: BodyResponseCallback<Schema$ZoneList>): void;
        list(callback: BodyResponseCallback<Schema$ZoneList>): void;
    }
    export interface Params$Resource$Regionzones$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Region for this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export class Resource$Reservations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves an aggregated list of reservations.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Reservations$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Reservations$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$ReservationAggregatedList>;
        aggregatedList(params: Params$Resource$Reservations$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Reservations$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$ReservationAggregatedList>, callback: BodyResponseCallback<Schema$ReservationAggregatedList>): void;
        aggregatedList(params: Params$Resource$Reservations$Aggregatedlist, callback: BodyResponseCallback<Schema$ReservationAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$ReservationAggregatedList>): void;
        /**
         * Deletes the specified reservation.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Reservations$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Reservations$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Reservations$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Reservations$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Reservations$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves information about the specified reservation.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Reservations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Reservations$Get, options?: MethodOptions): GaxiosPromise<Schema$Reservation>;
        get(params: Params$Resource$Reservations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Reservations$Get, options: MethodOptions | BodyResponseCallback<Schema$Reservation>, callback: BodyResponseCallback<Schema$Reservation>): void;
        get(params: Params$Resource$Reservations$Get, callback: BodyResponseCallback<Schema$Reservation>): void;
        get(callback: BodyResponseCallback<Schema$Reservation>): void;
        /**
         * Gets the access control policy for a resource. May be empty if no such policy or resource exists.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getIamPolicy(params: Params$Resource$Reservations$Getiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getIamPolicy(params?: Params$Resource$Reservations$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        getIamPolicy(params: Params$Resource$Reservations$Getiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getIamPolicy(params: Params$Resource$Reservations$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(params: Params$Resource$Reservations$Getiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Creates a new reservation. For more information, read Reserving zonal resources.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Reservations$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Reservations$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Reservations$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Reservations$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Reservations$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * A list of all the reservations that have been configured for the specified project in specified zone.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Reservations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Reservations$List, options?: MethodOptions): GaxiosPromise<Schema$ReservationList>;
        list(params: Params$Resource$Reservations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Reservations$List, options: MethodOptions | BodyResponseCallback<Schema$ReservationList>, callback: BodyResponseCallback<Schema$ReservationList>): void;
        list(params: Params$Resource$Reservations$List, callback: BodyResponseCallback<Schema$ReservationList>): void;
        list(callback: BodyResponseCallback<Schema$ReservationList>): void;
        /**
         * Resizes the reservation (applicable to standalone reservations only). For more information, read Modifying reservations.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        resize(params: Params$Resource$Reservations$Resize, options: StreamMethodOptions): GaxiosPromise<Readable>;
        resize(params?: Params$Resource$Reservations$Resize, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        resize(params: Params$Resource$Reservations$Resize, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        resize(params: Params$Resource$Reservations$Resize, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        resize(params: Params$Resource$Reservations$Resize, callback: BodyResponseCallback<Schema$Operation>): void;
        resize(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the access control policy on the specified resource. Replaces any existing policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setIamPolicy(params: Params$Resource$Reservations$Setiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setIamPolicy(params?: Params$Resource$Reservations$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        setIamPolicy(params: Params$Resource$Reservations$Setiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setIamPolicy(params: Params$Resource$Reservations$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(params: Params$Resource$Reservations$Setiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Reservations$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Reservations$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Reservations$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Reservations$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Reservations$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        /**
         * Update share settings of the reservation.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        update(params: Params$Resource$Reservations$Update, options: StreamMethodOptions): GaxiosPromise<Readable>;
        update(params?: Params$Resource$Reservations$Update, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        update(params: Params$Resource$Reservations$Update, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        update(params: Params$Resource$Reservations$Update, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        update(params: Params$Resource$Reservations$Update, callback: BodyResponseCallback<Schema$Operation>): void;
        update(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    export interface Params$Resource$Reservations$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Reservations$Delete extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the reservation to delete.
         */
        reservation?: string;
        /**
         * Name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Reservations$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the reservation to retrieve.
         */
        reservation?: string;
        /**
         * Name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Reservations$Getiampolicy extends StandardParameters {
        /**
         * Requested IAM Policy version.
         */
        optionsRequestedPolicyVersion?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Reservations$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Reservation;
    }
    export interface Params$Resource$Reservations$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         * Name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Reservations$Resize extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the reservation to update.
         */
        reservation?: string;
        /**
         * Name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ReservationsResizeRequest;
    }
    export interface Params$Resource$Reservations$Setiampolicy extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ZoneSetPolicyRequest;
    }
    export interface Params$Resource$Reservations$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export interface Params$Resource$Reservations$Update extends StandardParameters {
        /**
         *
         */
        paths?: string[];
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the reservation to update.
         */
        reservation?: string;
        /**
         * Update_mask indicates fields to be updated as part of this request.
         */
        updateMask?: string;
        /**
         * Name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Reservation;
    }
    export class Resource$Resourcepolicies {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves an aggregated list of resource policies.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Resourcepolicies$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Resourcepolicies$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$ResourcePolicyAggregatedList>;
        aggregatedList(params: Params$Resource$Resourcepolicies$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Resourcepolicies$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$ResourcePolicyAggregatedList>, callback: BodyResponseCallback<Schema$ResourcePolicyAggregatedList>): void;
        aggregatedList(params: Params$Resource$Resourcepolicies$Aggregatedlist, callback: BodyResponseCallback<Schema$ResourcePolicyAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$ResourcePolicyAggregatedList>): void;
        /**
         * Deletes the specified resource policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Resourcepolicies$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Resourcepolicies$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Resourcepolicies$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Resourcepolicies$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Resourcepolicies$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves all information of the specified resource policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Resourcepolicies$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Resourcepolicies$Get, options?: MethodOptions): GaxiosPromise<Schema$ResourcePolicy>;
        get(params: Params$Resource$Resourcepolicies$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Resourcepolicies$Get, options: MethodOptions | BodyResponseCallback<Schema$ResourcePolicy>, callback: BodyResponseCallback<Schema$ResourcePolicy>): void;
        get(params: Params$Resource$Resourcepolicies$Get, callback: BodyResponseCallback<Schema$ResourcePolicy>): void;
        get(callback: BodyResponseCallback<Schema$ResourcePolicy>): void;
        /**
         * Gets the access control policy for a resource. May be empty if no such policy or resource exists.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getIamPolicy(params: Params$Resource$Resourcepolicies$Getiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getIamPolicy(params?: Params$Resource$Resourcepolicies$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        getIamPolicy(params: Params$Resource$Resourcepolicies$Getiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getIamPolicy(params: Params$Resource$Resourcepolicies$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(params: Params$Resource$Resourcepolicies$Getiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Creates a new resource policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Resourcepolicies$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Resourcepolicies$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Resourcepolicies$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Resourcepolicies$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Resourcepolicies$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * A list all the resource policies that have been configured for the specified project in specified region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Resourcepolicies$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Resourcepolicies$List, options?: MethodOptions): GaxiosPromise<Schema$ResourcePolicyList>;
        list(params: Params$Resource$Resourcepolicies$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Resourcepolicies$List, options: MethodOptions | BodyResponseCallback<Schema$ResourcePolicyList>, callback: BodyResponseCallback<Schema$ResourcePolicyList>): void;
        list(params: Params$Resource$Resourcepolicies$List, callback: BodyResponseCallback<Schema$ResourcePolicyList>): void;
        list(callback: BodyResponseCallback<Schema$ResourcePolicyList>): void;
        /**
         * Modify the specified resource policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Resourcepolicies$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Resourcepolicies$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Resourcepolicies$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Resourcepolicies$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Resourcepolicies$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the access control policy on the specified resource. Replaces any existing policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setIamPolicy(params: Params$Resource$Resourcepolicies$Setiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setIamPolicy(params?: Params$Resource$Resourcepolicies$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        setIamPolicy(params: Params$Resource$Resourcepolicies$Setiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setIamPolicy(params: Params$Resource$Resourcepolicies$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(params: Params$Resource$Resourcepolicies$Setiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Resourcepolicies$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Resourcepolicies$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Resourcepolicies$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Resourcepolicies$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Resourcepolicies$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Resourcepolicies$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Resourcepolicies$Delete extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the resource policy to delete.
         */
        resourcePolicy?: string;
    }
    export interface Params$Resource$Resourcepolicies$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * Name of the resource policy to retrieve.
         */
        resourcePolicy?: string;
    }
    export interface Params$Resource$Resourcepolicies$Getiampolicy extends StandardParameters {
        /**
         * Requested IAM Policy version.
         */
        optionsRequestedPolicyVersion?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
    }
    export interface Params$Resource$Resourcepolicies$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ResourcePolicy;
    }
    export interface Params$Resource$Resourcepolicies$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Resourcepolicies$Patch extends StandardParameters {
        /**
         *
         */
        paths?: string[];
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Id of the resource policy to patch.
         */
        resourcePolicy?: string;
        /**
         * update_mask indicates fields to be updated as part of this request.
         */
        updateMask?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ResourcePolicy;
    }
    export interface Params$Resource$Resourcepolicies$Setiampolicy extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionSetPolicyRequest;
    }
    export interface Params$Resource$Resourcepolicies$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Routers {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves an aggregated list of routers.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Routers$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Routers$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$RouterAggregatedList>;
        aggregatedList(params: Params$Resource$Routers$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Routers$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$RouterAggregatedList>, callback: BodyResponseCallback<Schema$RouterAggregatedList>): void;
        aggregatedList(params: Params$Resource$Routers$Aggregatedlist, callback: BodyResponseCallback<Schema$RouterAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$RouterAggregatedList>): void;
        /**
         * Deletes the specified Router resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Routers$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Routers$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Routers$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Routers$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Routers$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Deletes Route Policy
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        deleteRoutePolicy(params: Params$Resource$Routers$Deleteroutepolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        deleteRoutePolicy(params?: Params$Resource$Routers$Deleteroutepolicy, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        deleteRoutePolicy(params: Params$Resource$Routers$Deleteroutepolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        deleteRoutePolicy(params: Params$Resource$Routers$Deleteroutepolicy, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        deleteRoutePolicy(params: Params$Resource$Routers$Deleteroutepolicy, callback: BodyResponseCallback<Schema$Operation>): void;
        deleteRoutePolicy(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified Router resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Routers$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Routers$Get, options?: MethodOptions): GaxiosPromise<Schema$Router>;
        get(params: Params$Resource$Routers$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Routers$Get, options: MethodOptions | BodyResponseCallback<Schema$Router>, callback: BodyResponseCallback<Schema$Router>): void;
        get(params: Params$Resource$Routers$Get, callback: BodyResponseCallback<Schema$Router>): void;
        get(callback: BodyResponseCallback<Schema$Router>): void;
        /**
         * Retrieves runtime NAT IP information.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getNatIpInfo(params: Params$Resource$Routers$Getnatipinfo, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getNatIpInfo(params?: Params$Resource$Routers$Getnatipinfo, options?: MethodOptions): GaxiosPromise<Schema$NatIpInfoResponse>;
        getNatIpInfo(params: Params$Resource$Routers$Getnatipinfo, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getNatIpInfo(params: Params$Resource$Routers$Getnatipinfo, options: MethodOptions | BodyResponseCallback<Schema$NatIpInfoResponse>, callback: BodyResponseCallback<Schema$NatIpInfoResponse>): void;
        getNatIpInfo(params: Params$Resource$Routers$Getnatipinfo, callback: BodyResponseCallback<Schema$NatIpInfoResponse>): void;
        getNatIpInfo(callback: BodyResponseCallback<Schema$NatIpInfoResponse>): void;
        /**
         * Retrieves runtime Nat mapping information of VM endpoints.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getNatMappingInfo(params: Params$Resource$Routers$Getnatmappinginfo, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getNatMappingInfo(params?: Params$Resource$Routers$Getnatmappinginfo, options?: MethodOptions): GaxiosPromise<Schema$VmEndpointNatMappingsList>;
        getNatMappingInfo(params: Params$Resource$Routers$Getnatmappinginfo, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getNatMappingInfo(params: Params$Resource$Routers$Getnatmappinginfo, options: MethodOptions | BodyResponseCallback<Schema$VmEndpointNatMappingsList>, callback: BodyResponseCallback<Schema$VmEndpointNatMappingsList>): void;
        getNatMappingInfo(params: Params$Resource$Routers$Getnatmappinginfo, callback: BodyResponseCallback<Schema$VmEndpointNatMappingsList>): void;
        getNatMappingInfo(callback: BodyResponseCallback<Schema$VmEndpointNatMappingsList>): void;
        /**
         * Returns specified Route Policy
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getRoutePolicy(params: Params$Resource$Routers$Getroutepolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getRoutePolicy(params?: Params$Resource$Routers$Getroutepolicy, options?: MethodOptions): GaxiosPromise<Schema$RoutersGetRoutePolicyResponse>;
        getRoutePolicy(params: Params$Resource$Routers$Getroutepolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getRoutePolicy(params: Params$Resource$Routers$Getroutepolicy, options: MethodOptions | BodyResponseCallback<Schema$RoutersGetRoutePolicyResponse>, callback: BodyResponseCallback<Schema$RoutersGetRoutePolicyResponse>): void;
        getRoutePolicy(params: Params$Resource$Routers$Getroutepolicy, callback: BodyResponseCallback<Schema$RoutersGetRoutePolicyResponse>): void;
        getRoutePolicy(callback: BodyResponseCallback<Schema$RoutersGetRoutePolicyResponse>): void;
        /**
         * Retrieves runtime information of the specified router.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getRouterStatus(params: Params$Resource$Routers$Getrouterstatus, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getRouterStatus(params?: Params$Resource$Routers$Getrouterstatus, options?: MethodOptions): GaxiosPromise<Schema$RouterStatusResponse>;
        getRouterStatus(params: Params$Resource$Routers$Getrouterstatus, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getRouterStatus(params: Params$Resource$Routers$Getrouterstatus, options: MethodOptions | BodyResponseCallback<Schema$RouterStatusResponse>, callback: BodyResponseCallback<Schema$RouterStatusResponse>): void;
        getRouterStatus(params: Params$Resource$Routers$Getrouterstatus, callback: BodyResponseCallback<Schema$RouterStatusResponse>): void;
        getRouterStatus(callback: BodyResponseCallback<Schema$RouterStatusResponse>): void;
        /**
         * Creates a Router resource in the specified project and region using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Routers$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Routers$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Routers$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Routers$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Routers$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves a list of Router resources available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Routers$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Routers$List, options?: MethodOptions): GaxiosPromise<Schema$RouterList>;
        list(params: Params$Resource$Routers$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Routers$List, options: MethodOptions | BodyResponseCallback<Schema$RouterList>, callback: BodyResponseCallback<Schema$RouterList>): void;
        list(params: Params$Resource$Routers$List, callback: BodyResponseCallback<Schema$RouterList>): void;
        list(callback: BodyResponseCallback<Schema$RouterList>): void;
        /**
         * Retrieves a list of router bgp routes available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        listBgpRoutes(params: Params$Resource$Routers$Listbgproutes, options: StreamMethodOptions): GaxiosPromise<Readable>;
        listBgpRoutes(params?: Params$Resource$Routers$Listbgproutes, options?: MethodOptions): GaxiosPromise<Schema$RoutersListBgpRoutes>;
        listBgpRoutes(params: Params$Resource$Routers$Listbgproutes, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        listBgpRoutes(params: Params$Resource$Routers$Listbgproutes, options: MethodOptions | BodyResponseCallback<Schema$RoutersListBgpRoutes>, callback: BodyResponseCallback<Schema$RoutersListBgpRoutes>): void;
        listBgpRoutes(params: Params$Resource$Routers$Listbgproutes, callback: BodyResponseCallback<Schema$RoutersListBgpRoutes>): void;
        listBgpRoutes(callback: BodyResponseCallback<Schema$RoutersListBgpRoutes>): void;
        /**
         * Retrieves a list of router route policy subresources available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        listRoutePolicies(params: Params$Resource$Routers$Listroutepolicies, options: StreamMethodOptions): GaxiosPromise<Readable>;
        listRoutePolicies(params?: Params$Resource$Routers$Listroutepolicies, options?: MethodOptions): GaxiosPromise<Schema$RoutersListRoutePolicies>;
        listRoutePolicies(params: Params$Resource$Routers$Listroutepolicies, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        listRoutePolicies(params: Params$Resource$Routers$Listroutepolicies, options: MethodOptions | BodyResponseCallback<Schema$RoutersListRoutePolicies>, callback: BodyResponseCallback<Schema$RoutersListRoutePolicies>): void;
        listRoutePolicies(params: Params$Resource$Routers$Listroutepolicies, callback: BodyResponseCallback<Schema$RoutersListRoutePolicies>): void;
        listRoutePolicies(callback: BodyResponseCallback<Schema$RoutersListRoutePolicies>): void;
        /**
         * Patches the specified Router resource with the data included in the request. This method supports PATCH semantics and uses JSON merge patch format and processing rules.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Routers$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Routers$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Routers$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Routers$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Routers$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Preview fields auto-generated during router create and update operations. Calling this method does NOT create or update the router.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        preview(params: Params$Resource$Routers$Preview, options: StreamMethodOptions): GaxiosPromise<Readable>;
        preview(params?: Params$Resource$Routers$Preview, options?: MethodOptions): GaxiosPromise<Schema$RoutersPreviewResponse>;
        preview(params: Params$Resource$Routers$Preview, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        preview(params: Params$Resource$Routers$Preview, options: MethodOptions | BodyResponseCallback<Schema$RoutersPreviewResponse>, callback: BodyResponseCallback<Schema$RoutersPreviewResponse>): void;
        preview(params: Params$Resource$Routers$Preview, callback: BodyResponseCallback<Schema$RoutersPreviewResponse>): void;
        preview(callback: BodyResponseCallback<Schema$RoutersPreviewResponse>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Routers$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Routers$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Routers$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Routers$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Routers$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        /**
         * Updates the specified Router resource with the data included in the request. This method conforms to PUT semantics, which requests that the state of the target resource be created or replaced with the state defined by the representation enclosed in the request message payload.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        update(params: Params$Resource$Routers$Update, options: StreamMethodOptions): GaxiosPromise<Readable>;
        update(params?: Params$Resource$Routers$Update, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        update(params: Params$Resource$Routers$Update, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        update(params: Params$Resource$Routers$Update, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        update(params: Params$Resource$Routers$Update, callback: BodyResponseCallback<Schema$Operation>): void;
        update(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Updates or creates new Route Policy
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        updateRoutePolicy(params: Params$Resource$Routers$Updateroutepolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        updateRoutePolicy(params?: Params$Resource$Routers$Updateroutepolicy, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        updateRoutePolicy(params: Params$Resource$Routers$Updateroutepolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        updateRoutePolicy(params: Params$Resource$Routers$Updateroutepolicy, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        updateRoutePolicy(params: Params$Resource$Routers$Updateroutepolicy, callback: BodyResponseCallback<Schema$Operation>): void;
        updateRoutePolicy(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    export interface Params$Resource$Routers$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Routers$Delete extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the Router resource to delete.
         */
        router?: string;
    }
    export interface Params$Resource$Routers$Deleteroutepolicy extends StandardParameters {
        /**
         * The Policy name for this request. Name must conform to RFC1035
         */
        policy?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the Router resource where Route Policy is defined.
         */
        router?: string;
    }
    export interface Params$Resource$Routers$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * Name of the Router resource to return.
         */
        router?: string;
    }
    export interface Params$Resource$Routers$Getnatipinfo extends StandardParameters {
        /**
         * Name of the nat service to filter the NAT IP information. If it is omitted, all nats for this router will be returned. Name should conform to RFC1035.
         */
        natName?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * Name of the Router resource to query for Nat IP information. The name should conform to RFC1035.
         */
        router?: string;
    }
    export interface Params$Resource$Routers$Getnatmappinginfo extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Name of the nat service to filter the Nat Mapping information. If it is omitted, all nats for this router will be returned. Name should conform to RFC1035.
         */
        natName?: string;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         * Name of the Router resource to query for Nat Mapping information of VM endpoints.
         */
        router?: string;
    }
    export interface Params$Resource$Routers$Getroutepolicy extends StandardParameters {
        /**
         * The Policy name for this request. Name must conform to RFC1035
         */
        policy?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * Name of the Router resource to query for Nat IP information. The name should conform to RFC1035.
         */
        router?: string;
    }
    export interface Params$Resource$Routers$Getrouterstatus extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * Name of the Router resource to query.
         */
        router?: string;
    }
    export interface Params$Resource$Routers$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Router;
    }
    export interface Params$Resource$Routers$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Routers$Listbgproutes extends StandardParameters {
        /**
         * (Required) limit results to this address family (either IPv4 or IPv6)
         */
        addressFamily?: string;
        /**
         * Limit results to destinations that are subnets of this CIDR range
         */
        destinationPrefix?: string;
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * (Required) limit results to the BGP peer with the given name. Name should conform to RFC1035.
         */
        peer?: string;
        /**
         * When true, the method returns post-policy routes. Otherwise, it returns pre-policy routes.
         */
        policyApplied?: boolean;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         * Name or id of the resource for this request. Name should conform to RFC1035.
         */
        router?: string;
        /**
         * (Required) limit results to this type of route (either LEARNED or ADVERTISED)
         */
        routeType?: string;
    }
    export interface Params$Resource$Routers$Listroutepolicies extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         * Name or id of the resource for this request. Name should conform to RFC1035.
         */
        router?: string;
    }
    export interface Params$Resource$Routers$Patch extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the Router resource to patch.
         */
        router?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Router;
    }
    export interface Params$Resource$Routers$Preview extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * Name of the Router resource to query.
         */
        router?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Router;
    }
    export interface Params$Resource$Routers$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export interface Params$Resource$Routers$Update extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the Router resource to update.
         */
        router?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Router;
    }
    export interface Params$Resource$Routers$Updateroutepolicy extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the Router resource where Route Policy is defined.
         */
        router?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RoutePolicy;
    }
    export class Resource$Routes {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Deletes the specified Route resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Routes$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Routes$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Routes$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Routes$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Routes$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified Route resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Routes$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Routes$Get, options?: MethodOptions): GaxiosPromise<Schema$Route>;
        get(params: Params$Resource$Routes$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Routes$Get, options: MethodOptions | BodyResponseCallback<Schema$Route>, callback: BodyResponseCallback<Schema$Route>): void;
        get(params: Params$Resource$Routes$Get, callback: BodyResponseCallback<Schema$Route>): void;
        get(callback: BodyResponseCallback<Schema$Route>): void;
        /**
         * Creates a Route resource in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Routes$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Routes$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Routes$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Routes$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Routes$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of Route resources available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Routes$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Routes$List, options?: MethodOptions): GaxiosPromise<Schema$RouteList>;
        list(params: Params$Resource$Routes$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Routes$List, options: MethodOptions | BodyResponseCallback<Schema$RouteList>, callback: BodyResponseCallback<Schema$RouteList>): void;
        list(params: Params$Resource$Routes$List, callback: BodyResponseCallback<Schema$RouteList>): void;
        list(callback: BodyResponseCallback<Schema$RouteList>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Routes$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Routes$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Routes$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Routes$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Routes$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Routes$Delete extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the Route resource to delete.
         */
        route?: string;
    }
    export interface Params$Resource$Routes$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the Route resource to return.
         */
        route?: string;
    }
    export interface Params$Resource$Routes$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Route;
    }
    export interface Params$Resource$Routes$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Routes$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Securitypolicies {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Inserts a rule into a security policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        addRule(params: Params$Resource$Securitypolicies$Addrule, options: StreamMethodOptions): GaxiosPromise<Readable>;
        addRule(params?: Params$Resource$Securitypolicies$Addrule, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        addRule(params: Params$Resource$Securitypolicies$Addrule, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        addRule(params: Params$Resource$Securitypolicies$Addrule, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        addRule(params: Params$Resource$Securitypolicies$Addrule, callback: BodyResponseCallback<Schema$Operation>): void;
        addRule(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of all SecurityPolicy resources, regional and global, available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Securitypolicies$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Securitypolicies$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$SecurityPoliciesAggregatedList>;
        aggregatedList(params: Params$Resource$Securitypolicies$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Securitypolicies$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$SecurityPoliciesAggregatedList>, callback: BodyResponseCallback<Schema$SecurityPoliciesAggregatedList>): void;
        aggregatedList(params: Params$Resource$Securitypolicies$Aggregatedlist, callback: BodyResponseCallback<Schema$SecurityPoliciesAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$SecurityPoliciesAggregatedList>): void;
        /**
         * Deletes the specified policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Securitypolicies$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Securitypolicies$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Securitypolicies$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Securitypolicies$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Securitypolicies$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * List all of the ordered rules present in a single specified policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Securitypolicies$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Securitypolicies$Get, options?: MethodOptions): GaxiosPromise<Schema$SecurityPolicy>;
        get(params: Params$Resource$Securitypolicies$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Securitypolicies$Get, options: MethodOptions | BodyResponseCallback<Schema$SecurityPolicy>, callback: BodyResponseCallback<Schema$SecurityPolicy>): void;
        get(params: Params$Resource$Securitypolicies$Get, callback: BodyResponseCallback<Schema$SecurityPolicy>): void;
        get(callback: BodyResponseCallback<Schema$SecurityPolicy>): void;
        /**
         * Gets a rule at the specified priority.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getRule(params: Params$Resource$Securitypolicies$Getrule, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getRule(params?: Params$Resource$Securitypolicies$Getrule, options?: MethodOptions): GaxiosPromise<Schema$SecurityPolicyRule>;
        getRule(params: Params$Resource$Securitypolicies$Getrule, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getRule(params: Params$Resource$Securitypolicies$Getrule, options: MethodOptions | BodyResponseCallback<Schema$SecurityPolicyRule>, callback: BodyResponseCallback<Schema$SecurityPolicyRule>): void;
        getRule(params: Params$Resource$Securitypolicies$Getrule, callback: BodyResponseCallback<Schema$SecurityPolicyRule>): void;
        getRule(callback: BodyResponseCallback<Schema$SecurityPolicyRule>): void;
        /**
         * Creates a new policy in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Securitypolicies$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Securitypolicies$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Securitypolicies$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Securitypolicies$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Securitypolicies$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * List all the policies that have been configured for the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Securitypolicies$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Securitypolicies$List, options?: MethodOptions): GaxiosPromise<Schema$SecurityPolicyList>;
        list(params: Params$Resource$Securitypolicies$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Securitypolicies$List, options: MethodOptions | BodyResponseCallback<Schema$SecurityPolicyList>, callback: BodyResponseCallback<Schema$SecurityPolicyList>): void;
        list(params: Params$Resource$Securitypolicies$List, callback: BodyResponseCallback<Schema$SecurityPolicyList>): void;
        list(callback: BodyResponseCallback<Schema$SecurityPolicyList>): void;
        /**
         * Gets the current list of preconfigured Web Application Firewall (WAF) expressions.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        listPreconfiguredExpressionSets(params: Params$Resource$Securitypolicies$Listpreconfiguredexpressionsets, options: StreamMethodOptions): GaxiosPromise<Readable>;
        listPreconfiguredExpressionSets(params?: Params$Resource$Securitypolicies$Listpreconfiguredexpressionsets, options?: MethodOptions): GaxiosPromise<Schema$SecurityPoliciesListPreconfiguredExpressionSetsResponse>;
        listPreconfiguredExpressionSets(params: Params$Resource$Securitypolicies$Listpreconfiguredexpressionsets, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        listPreconfiguredExpressionSets(params: Params$Resource$Securitypolicies$Listpreconfiguredexpressionsets, options: MethodOptions | BodyResponseCallback<Schema$SecurityPoliciesListPreconfiguredExpressionSetsResponse>, callback: BodyResponseCallback<Schema$SecurityPoliciesListPreconfiguredExpressionSetsResponse>): void;
        listPreconfiguredExpressionSets(params: Params$Resource$Securitypolicies$Listpreconfiguredexpressionsets, callback: BodyResponseCallback<Schema$SecurityPoliciesListPreconfiguredExpressionSetsResponse>): void;
        listPreconfiguredExpressionSets(callback: BodyResponseCallback<Schema$SecurityPoliciesListPreconfiguredExpressionSetsResponse>): void;
        /**
         * Patches the specified policy with the data included in the request. To clear fields in the policy, leave the fields empty and specify them in the updateMask. This cannot be used to be update the rules in the policy. Please use the per rule methods like addRule, patchRule, and removeRule instead.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Securitypolicies$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Securitypolicies$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Securitypolicies$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Securitypolicies$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Securitypolicies$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Patches a rule at the specified priority. To clear fields in the rule, leave the fields empty and specify them in the updateMask.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patchRule(params: Params$Resource$Securitypolicies$Patchrule, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patchRule(params?: Params$Resource$Securitypolicies$Patchrule, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patchRule(params: Params$Resource$Securitypolicies$Patchrule, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patchRule(params: Params$Resource$Securitypolicies$Patchrule, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patchRule(params: Params$Resource$Securitypolicies$Patchrule, callback: BodyResponseCallback<Schema$Operation>): void;
        patchRule(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Deletes a rule at the specified priority.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        removeRule(params: Params$Resource$Securitypolicies$Removerule, options: StreamMethodOptions): GaxiosPromise<Readable>;
        removeRule(params?: Params$Resource$Securitypolicies$Removerule, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        removeRule(params: Params$Resource$Securitypolicies$Removerule, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        removeRule(params: Params$Resource$Securitypolicies$Removerule, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        removeRule(params: Params$Resource$Securitypolicies$Removerule, callback: BodyResponseCallback<Schema$Operation>): void;
        removeRule(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the labels on a security policy. To learn more about labels, read the Labeling Resources documentation.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setLabels(params: Params$Resource$Securitypolicies$Setlabels, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setLabels(params?: Params$Resource$Securitypolicies$Setlabels, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setLabels(params: Params$Resource$Securitypolicies$Setlabels, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setLabels(params: Params$Resource$Securitypolicies$Setlabels, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(params: Params$Resource$Securitypolicies$Setlabels, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Securitypolicies$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Securitypolicies$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Securitypolicies$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Securitypolicies$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Securitypolicies$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Securitypolicies$Addrule extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the security policy to update.
         */
        securityPolicy?: string;
        /**
         * If true, the request will not be committed.
         */
        validateOnly?: boolean;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SecurityPolicyRule;
    }
    export interface Params$Resource$Securitypolicies$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Name of the project scoping this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Securitypolicies$Delete extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the security policy to delete.
         */
        securityPolicy?: string;
    }
    export interface Params$Resource$Securitypolicies$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the security policy to get.
         */
        securityPolicy?: string;
    }
    export interface Params$Resource$Securitypolicies$Getrule extends StandardParameters {
        /**
         * The priority of the rule to get from the security policy.
         */
        priority?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the security policy to which the queried rule belongs.
         */
        securityPolicy?: string;
    }
    export interface Params$Resource$Securitypolicies$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * If true, the request will not be committed.
         */
        validateOnly?: boolean;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SecurityPolicy;
    }
    export interface Params$Resource$Securitypolicies$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Securitypolicies$Listpreconfiguredexpressionsets extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Securitypolicies$Patch extends StandardParameters {
        /**
         *
         */
        paths?: string[];
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the security policy to update.
         */
        securityPolicy?: string;
        /**
         * Indicates fields to be cleared as part of this request.
         */
        updateMask?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SecurityPolicy;
    }
    export interface Params$Resource$Securitypolicies$Patchrule extends StandardParameters {
        /**
         * The priority of the rule to patch.
         */
        priority?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the security policy to update.
         */
        securityPolicy?: string;
        /**
         * Indicates fields to be cleared as part of this request.
         */
        updateMask?: string;
        /**
         * If true, the request will not be committed.
         */
        validateOnly?: boolean;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SecurityPolicyRule;
    }
    export interface Params$Resource$Securitypolicies$Removerule extends StandardParameters {
        /**
         * The priority of the rule to remove from the security policy.
         */
        priority?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the security policy to update.
         */
        securityPolicy?: string;
    }
    export interface Params$Resource$Securitypolicies$Setlabels extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GlobalSetLabelsRequest;
    }
    export interface Params$Resource$Securitypolicies$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Serviceattachments {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves the list of all ServiceAttachment resources, regional and global, available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Serviceattachments$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Serviceattachments$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$ServiceAttachmentAggregatedList>;
        aggregatedList(params: Params$Resource$Serviceattachments$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Serviceattachments$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$ServiceAttachmentAggregatedList>, callback: BodyResponseCallback<Schema$ServiceAttachmentAggregatedList>): void;
        aggregatedList(params: Params$Resource$Serviceattachments$Aggregatedlist, callback: BodyResponseCallback<Schema$ServiceAttachmentAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$ServiceAttachmentAggregatedList>): void;
        /**
         * Deletes the specified ServiceAttachment in the given scope
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Serviceattachments$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Serviceattachments$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Serviceattachments$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Serviceattachments$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Serviceattachments$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified ServiceAttachment resource in the given scope.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Serviceattachments$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Serviceattachments$Get, options?: MethodOptions): GaxiosPromise<Schema$ServiceAttachment>;
        get(params: Params$Resource$Serviceattachments$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Serviceattachments$Get, options: MethodOptions | BodyResponseCallback<Schema$ServiceAttachment>, callback: BodyResponseCallback<Schema$ServiceAttachment>): void;
        get(params: Params$Resource$Serviceattachments$Get, callback: BodyResponseCallback<Schema$ServiceAttachment>): void;
        get(callback: BodyResponseCallback<Schema$ServiceAttachment>): void;
        /**
         * Gets the access control policy for a resource. May be empty if no such policy or resource exists.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getIamPolicy(params: Params$Resource$Serviceattachments$Getiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getIamPolicy(params?: Params$Resource$Serviceattachments$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        getIamPolicy(params: Params$Resource$Serviceattachments$Getiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getIamPolicy(params: Params$Resource$Serviceattachments$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(params: Params$Resource$Serviceattachments$Getiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Creates a ServiceAttachment in the specified project in the given scope using the parameters that are included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Serviceattachments$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Serviceattachments$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Serviceattachments$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Serviceattachments$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Serviceattachments$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Lists the ServiceAttachments for a project in the given scope.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Serviceattachments$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Serviceattachments$List, options?: MethodOptions): GaxiosPromise<Schema$ServiceAttachmentList>;
        list(params: Params$Resource$Serviceattachments$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Serviceattachments$List, options: MethodOptions | BodyResponseCallback<Schema$ServiceAttachmentList>, callback: BodyResponseCallback<Schema$ServiceAttachmentList>): void;
        list(params: Params$Resource$Serviceattachments$List, callback: BodyResponseCallback<Schema$ServiceAttachmentList>): void;
        list(callback: BodyResponseCallback<Schema$ServiceAttachmentList>): void;
        /**
         * Patches the specified ServiceAttachment resource with the data included in the request. This method supports PATCH semantics and uses JSON merge patch format and processing rules.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Serviceattachments$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Serviceattachments$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Serviceattachments$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Serviceattachments$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Serviceattachments$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the access control policy on the specified resource. Replaces any existing policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setIamPolicy(params: Params$Resource$Serviceattachments$Setiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setIamPolicy(params?: Params$Resource$Serviceattachments$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        setIamPolicy(params: Params$Resource$Serviceattachments$Setiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setIamPolicy(params: Params$Resource$Serviceattachments$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(params: Params$Resource$Serviceattachments$Setiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Serviceattachments$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Serviceattachments$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Serviceattachments$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Serviceattachments$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Serviceattachments$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Serviceattachments$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Name of the project scoping this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Serviceattachments$Delete extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region of this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the ServiceAttachment resource to delete.
         */
        serviceAttachment?: string;
    }
    export interface Params$Resource$Serviceattachments$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region of this request.
         */
        region?: string;
        /**
         * Name of the ServiceAttachment resource to return.
         */
        serviceAttachment?: string;
    }
    export interface Params$Resource$Serviceattachments$Getiampolicy extends StandardParameters {
        /**
         * Requested IAM Policy version.
         */
        optionsRequestedPolicyVersion?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
    }
    export interface Params$Resource$Serviceattachments$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region of this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ServiceAttachment;
    }
    export interface Params$Resource$Serviceattachments$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region of this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Serviceattachments$Patch extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The region scoping this request and should conform to RFC1035.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The resource id of the ServiceAttachment to patch. It should conform to RFC1035 resource name or be a string form on an unsigned long number.
         */
        serviceAttachment?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ServiceAttachment;
    }
    export interface Params$Resource$Serviceattachments$Setiampolicy extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionSetPolicyRequest;
    }
    export interface Params$Resource$Serviceattachments$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Snapshots {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Deletes the specified Snapshot resource. Keep in mind that deleting a single snapshot might not necessarily delete all the data on that snapshot. If any data on the snapshot that is marked for deletion is needed for subsequent snapshots, the data will be moved to the next corresponding snapshot. For more information, see Deleting snapshots.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Snapshots$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Snapshots$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Snapshots$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Snapshots$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Snapshots$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified Snapshot resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Snapshots$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Snapshots$Get, options?: MethodOptions): GaxiosPromise<Schema$Snapshot>;
        get(params: Params$Resource$Snapshots$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Snapshots$Get, options: MethodOptions | BodyResponseCallback<Schema$Snapshot>, callback: BodyResponseCallback<Schema$Snapshot>): void;
        get(params: Params$Resource$Snapshots$Get, callback: BodyResponseCallback<Schema$Snapshot>): void;
        get(callback: BodyResponseCallback<Schema$Snapshot>): void;
        /**
         * Gets the access control policy for a resource. May be empty if no such policy or resource exists.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getIamPolicy(params: Params$Resource$Snapshots$Getiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getIamPolicy(params?: Params$Resource$Snapshots$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        getIamPolicy(params: Params$Resource$Snapshots$Getiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getIamPolicy(params: Params$Resource$Snapshots$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(params: Params$Resource$Snapshots$Getiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Creates a snapshot in the specified project using the data included in the request. For regular snapshot creation, consider using this method instead of disks.createSnapshot, as this method supports more features, such as creating snapshots in a project different from the source disk project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Snapshots$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Snapshots$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Snapshots$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Snapshots$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Snapshots$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of Snapshot resources contained within the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Snapshots$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Snapshots$List, options?: MethodOptions): GaxiosPromise<Schema$SnapshotList>;
        list(params: Params$Resource$Snapshots$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Snapshots$List, options: MethodOptions | BodyResponseCallback<Schema$SnapshotList>, callback: BodyResponseCallback<Schema$SnapshotList>): void;
        list(params: Params$Resource$Snapshots$List, callback: BodyResponseCallback<Schema$SnapshotList>): void;
        list(callback: BodyResponseCallback<Schema$SnapshotList>): void;
        /**
         * Sets the access control policy on the specified resource. Replaces any existing policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setIamPolicy(params: Params$Resource$Snapshots$Setiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setIamPolicy(params?: Params$Resource$Snapshots$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        setIamPolicy(params: Params$Resource$Snapshots$Setiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setIamPolicy(params: Params$Resource$Snapshots$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(params: Params$Resource$Snapshots$Setiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Sets the labels on a snapshot. To learn more about labels, read the Labeling Resources documentation.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setLabels(params: Params$Resource$Snapshots$Setlabels, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setLabels(params?: Params$Resource$Snapshots$Setlabels, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setLabels(params: Params$Resource$Snapshots$Setlabels, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setLabels(params: Params$Resource$Snapshots$Setlabels, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(params: Params$Resource$Snapshots$Setlabels, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Snapshots$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Snapshots$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Snapshots$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Snapshots$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Snapshots$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Snapshots$Delete extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the Snapshot resource to delete.
         */
        snapshot?: string;
    }
    export interface Params$Resource$Snapshots$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the Snapshot resource to return.
         */
        snapshot?: string;
    }
    export interface Params$Resource$Snapshots$Getiampolicy extends StandardParameters {
        /**
         * Requested IAM Policy version.
         */
        optionsRequestedPolicyVersion?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
    }
    export interface Params$Resource$Snapshots$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Snapshot;
    }
    export interface Params$Resource$Snapshots$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Snapshots$Setiampolicy extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GlobalSetPolicyRequest;
    }
    export interface Params$Resource$Snapshots$Setlabels extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$GlobalSetLabelsRequest;
    }
    export interface Params$Resource$Snapshots$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Snapshotsettings {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Get snapshot settings.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Snapshotsettings$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Snapshotsettings$Get, options?: MethodOptions): GaxiosPromise<Schema$SnapshotSettings>;
        get(params: Params$Resource$Snapshotsettings$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Snapshotsettings$Get, options: MethodOptions | BodyResponseCallback<Schema$SnapshotSettings>, callback: BodyResponseCallback<Schema$SnapshotSettings>): void;
        get(params: Params$Resource$Snapshotsettings$Get, callback: BodyResponseCallback<Schema$SnapshotSettings>): void;
        get(callback: BodyResponseCallback<Schema$SnapshotSettings>): void;
        /**
         * Patch snapshot settings.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Snapshotsettings$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Snapshotsettings$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Snapshotsettings$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Snapshotsettings$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Snapshotsettings$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    export interface Params$Resource$Snapshotsettings$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
    }
    export interface Params$Resource$Snapshotsettings$Patch extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * update_mask indicates fields to be updated as part of this request.
         */
        updateMask?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SnapshotSettings;
    }
    export class Resource$Sslcertificates {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves the list of all SslCertificate resources, regional and global, available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Sslcertificates$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Sslcertificates$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$SslCertificateAggregatedList>;
        aggregatedList(params: Params$Resource$Sslcertificates$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Sslcertificates$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$SslCertificateAggregatedList>, callback: BodyResponseCallback<Schema$SslCertificateAggregatedList>): void;
        aggregatedList(params: Params$Resource$Sslcertificates$Aggregatedlist, callback: BodyResponseCallback<Schema$SslCertificateAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$SslCertificateAggregatedList>): void;
        /**
         * Deletes the specified SslCertificate resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Sslcertificates$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Sslcertificates$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Sslcertificates$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Sslcertificates$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Sslcertificates$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified SslCertificate resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Sslcertificates$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Sslcertificates$Get, options?: MethodOptions): GaxiosPromise<Schema$SslCertificate>;
        get(params: Params$Resource$Sslcertificates$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Sslcertificates$Get, options: MethodOptions | BodyResponseCallback<Schema$SslCertificate>, callback: BodyResponseCallback<Schema$SslCertificate>): void;
        get(params: Params$Resource$Sslcertificates$Get, callback: BodyResponseCallback<Schema$SslCertificate>): void;
        get(callback: BodyResponseCallback<Schema$SslCertificate>): void;
        /**
         * Creates a SslCertificate resource in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Sslcertificates$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Sslcertificates$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Sslcertificates$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Sslcertificates$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Sslcertificates$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of SslCertificate resources available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Sslcertificates$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Sslcertificates$List, options?: MethodOptions): GaxiosPromise<Schema$SslCertificateList>;
        list(params: Params$Resource$Sslcertificates$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Sslcertificates$List, options: MethodOptions | BodyResponseCallback<Schema$SslCertificateList>, callback: BodyResponseCallback<Schema$SslCertificateList>): void;
        list(params: Params$Resource$Sslcertificates$List, callback: BodyResponseCallback<Schema$SslCertificateList>): void;
        list(callback: BodyResponseCallback<Schema$SslCertificateList>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Sslcertificates$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Sslcertificates$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Sslcertificates$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Sslcertificates$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Sslcertificates$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Sslcertificates$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Name of the project scoping this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Sslcertificates$Delete extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the SslCertificate resource to delete.
         */
        sslCertificate?: string;
    }
    export interface Params$Resource$Sslcertificates$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the SslCertificate resource to return.
         */
        sslCertificate?: string;
    }
    export interface Params$Resource$Sslcertificates$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SslCertificate;
    }
    export interface Params$Resource$Sslcertificates$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Sslcertificates$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Sslpolicies {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves the list of all SslPolicy resources, regional and global, available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Sslpolicies$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Sslpolicies$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$SslPoliciesAggregatedList>;
        aggregatedList(params: Params$Resource$Sslpolicies$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Sslpolicies$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$SslPoliciesAggregatedList>, callback: BodyResponseCallback<Schema$SslPoliciesAggregatedList>): void;
        aggregatedList(params: Params$Resource$Sslpolicies$Aggregatedlist, callback: BodyResponseCallback<Schema$SslPoliciesAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$SslPoliciesAggregatedList>): void;
        /**
         * Deletes the specified SSL policy. The SSL policy resource can be deleted only if it is not in use by any TargetHttpsProxy or TargetSslProxy resources.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Sslpolicies$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Sslpolicies$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Sslpolicies$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Sslpolicies$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Sslpolicies$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Lists all of the ordered rules present in a single specified policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Sslpolicies$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Sslpolicies$Get, options?: MethodOptions): GaxiosPromise<Schema$SslPolicy>;
        get(params: Params$Resource$Sslpolicies$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Sslpolicies$Get, options: MethodOptions | BodyResponseCallback<Schema$SslPolicy>, callback: BodyResponseCallback<Schema$SslPolicy>): void;
        get(params: Params$Resource$Sslpolicies$Get, callback: BodyResponseCallback<Schema$SslPolicy>): void;
        get(callback: BodyResponseCallback<Schema$SslPolicy>): void;
        /**
         * Returns the specified SSL policy resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Sslpolicies$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Sslpolicies$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Sslpolicies$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Sslpolicies$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Sslpolicies$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Lists all the SSL policies that have been configured for the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Sslpolicies$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Sslpolicies$List, options?: MethodOptions): GaxiosPromise<Schema$SslPoliciesList>;
        list(params: Params$Resource$Sslpolicies$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Sslpolicies$List, options: MethodOptions | BodyResponseCallback<Schema$SslPoliciesList>, callback: BodyResponseCallback<Schema$SslPoliciesList>): void;
        list(params: Params$Resource$Sslpolicies$List, callback: BodyResponseCallback<Schema$SslPoliciesList>): void;
        list(callback: BodyResponseCallback<Schema$SslPoliciesList>): void;
        /**
         * Lists all features that can be specified in the SSL policy when using custom profile.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        listAvailableFeatures(params: Params$Resource$Sslpolicies$Listavailablefeatures, options: StreamMethodOptions): GaxiosPromise<Readable>;
        listAvailableFeatures(params?: Params$Resource$Sslpolicies$Listavailablefeatures, options?: MethodOptions): GaxiosPromise<Schema$SslPoliciesListAvailableFeaturesResponse>;
        listAvailableFeatures(params: Params$Resource$Sslpolicies$Listavailablefeatures, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        listAvailableFeatures(params: Params$Resource$Sslpolicies$Listavailablefeatures, options: MethodOptions | BodyResponseCallback<Schema$SslPoliciesListAvailableFeaturesResponse>, callback: BodyResponseCallback<Schema$SslPoliciesListAvailableFeaturesResponse>): void;
        listAvailableFeatures(params: Params$Resource$Sslpolicies$Listavailablefeatures, callback: BodyResponseCallback<Schema$SslPoliciesListAvailableFeaturesResponse>): void;
        listAvailableFeatures(callback: BodyResponseCallback<Schema$SslPoliciesListAvailableFeaturesResponse>): void;
        /**
         * Patches the specified SSL policy with the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Sslpolicies$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Sslpolicies$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Sslpolicies$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Sslpolicies$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Sslpolicies$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Sslpolicies$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Sslpolicies$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Sslpolicies$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Sslpolicies$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Sslpolicies$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Sslpolicies$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Name of the project scoping this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Sslpolicies$Delete extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the SSL policy to delete. The name must be 1-63 characters long, and comply with RFC1035.
         */
        sslPolicy?: string;
    }
    export interface Params$Resource$Sslpolicies$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the SSL policy to update. The name must be 1-63 characters long, and comply with RFC1035.
         */
        sslPolicy?: string;
    }
    export interface Params$Resource$Sslpolicies$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SslPolicy;
    }
    export interface Params$Resource$Sslpolicies$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Sslpolicies$Listavailablefeatures extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Sslpolicies$Patch extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the SSL policy to update. The name must be 1-63 characters long, and comply with RFC1035.
         */
        sslPolicy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SslPolicy;
    }
    export interface Params$Resource$Sslpolicies$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Storagepools {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves an aggregated list of storage pools.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Storagepools$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Storagepools$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$StoragePoolAggregatedList>;
        aggregatedList(params: Params$Resource$Storagepools$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Storagepools$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$StoragePoolAggregatedList>, callback: BodyResponseCallback<Schema$StoragePoolAggregatedList>): void;
        aggregatedList(params: Params$Resource$Storagepools$Aggregatedlist, callback: BodyResponseCallback<Schema$StoragePoolAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$StoragePoolAggregatedList>): void;
        /**
         * Deletes the specified storage pool. Deleting a storagePool removes its data permanently and is irreversible. However, deleting a storagePool does not delete any snapshots previously made from the storagePool. You must separately delete snapshots.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Storagepools$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Storagepools$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Storagepools$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Storagepools$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Storagepools$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns a specified storage pool. Gets a list of available storage pools by making a list() request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Storagepools$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Storagepools$Get, options?: MethodOptions): GaxiosPromise<Schema$StoragePool>;
        get(params: Params$Resource$Storagepools$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Storagepools$Get, options: MethodOptions | BodyResponseCallback<Schema$StoragePool>, callback: BodyResponseCallback<Schema$StoragePool>): void;
        get(params: Params$Resource$Storagepools$Get, callback: BodyResponseCallback<Schema$StoragePool>): void;
        get(callback: BodyResponseCallback<Schema$StoragePool>): void;
        /**
         * Gets the access control policy for a resource. May be empty if no such policy or resource exists.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getIamPolicy(params: Params$Resource$Storagepools$Getiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getIamPolicy(params?: Params$Resource$Storagepools$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        getIamPolicy(params: Params$Resource$Storagepools$Getiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getIamPolicy(params: Params$Resource$Storagepools$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(params: Params$Resource$Storagepools$Getiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Creates a storage pool in the specified project using the data in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Storagepools$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Storagepools$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Storagepools$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Storagepools$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Storagepools$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves a list of storage pools contained within the specified zone.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Storagepools$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Storagepools$List, options?: MethodOptions): GaxiosPromise<Schema$StoragePoolList>;
        list(params: Params$Resource$Storagepools$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Storagepools$List, options: MethodOptions | BodyResponseCallback<Schema$StoragePoolList>, callback: BodyResponseCallback<Schema$StoragePoolList>): void;
        list(params: Params$Resource$Storagepools$List, callback: BodyResponseCallback<Schema$StoragePoolList>): void;
        list(callback: BodyResponseCallback<Schema$StoragePoolList>): void;
        /**
         * Lists the disks in a specified storage pool.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        listDisks(params: Params$Resource$Storagepools$Listdisks, options: StreamMethodOptions): GaxiosPromise<Readable>;
        listDisks(params?: Params$Resource$Storagepools$Listdisks, options?: MethodOptions): GaxiosPromise<Schema$StoragePoolListDisks>;
        listDisks(params: Params$Resource$Storagepools$Listdisks, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        listDisks(params: Params$Resource$Storagepools$Listdisks, options: MethodOptions | BodyResponseCallback<Schema$StoragePoolListDisks>, callback: BodyResponseCallback<Schema$StoragePoolListDisks>): void;
        listDisks(params: Params$Resource$Storagepools$Listdisks, callback: BodyResponseCallback<Schema$StoragePoolListDisks>): void;
        listDisks(callback: BodyResponseCallback<Schema$StoragePoolListDisks>): void;
        /**
         * Sets the access control policy on the specified resource. Replaces any existing policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setIamPolicy(params: Params$Resource$Storagepools$Setiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setIamPolicy(params?: Params$Resource$Storagepools$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        setIamPolicy(params: Params$Resource$Storagepools$Setiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setIamPolicy(params: Params$Resource$Storagepools$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(params: Params$Resource$Storagepools$Setiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Sets the labels on a storage pools. To learn more about labels, read the Labeling Resources documentation.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setLabels(params: Params$Resource$Storagepools$Setlabels, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setLabels(params?: Params$Resource$Storagepools$Setlabels, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setLabels(params: Params$Resource$Storagepools$Setlabels, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setLabels(params: Params$Resource$Storagepools$Setlabels, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(params: Params$Resource$Storagepools$Setlabels, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Storagepools$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Storagepools$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Storagepools$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Storagepools$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Storagepools$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        /**
         * Updates the specified storagePool with the data included in the request. The update is performed only on selected fields included as part of update-mask. Only the following fields can be modified: size_tb and provisioned_iops.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        update(params: Params$Resource$Storagepools$Update, options: StreamMethodOptions): GaxiosPromise<Readable>;
        update(params?: Params$Resource$Storagepools$Update, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        update(params: Params$Resource$Storagepools$Update, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        update(params: Params$Resource$Storagepools$Update, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        update(params: Params$Resource$Storagepools$Update, callback: BodyResponseCallback<Schema$Operation>): void;
        update(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    export interface Params$Resource$Storagepools$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Storagepools$Delete extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the storage pool to delete.
         */
        storagePool?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Storagepools$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the storage pool to return.
         */
        storagePool?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Storagepools$Getiampolicy extends StandardParameters {
        /**
         * Requested IAM Policy version.
         */
        optionsRequestedPolicyVersion?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Storagepools$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$StoragePool;
    }
    export interface Params$Resource$Storagepools$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Storagepools$Listdisks extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         * Name of the storage pool to list disks of.
         */
        storagePool?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Storagepools$Setiampolicy extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ZoneSetPolicyRequest;
    }
    export interface Params$Resource$Storagepools$Setlabels extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$ZoneSetLabelsRequest;
    }
    export interface Params$Resource$Storagepools$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export interface Params$Resource$Storagepools$Update extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * The storagePool name for this request.
         */
        storagePool?: string;
        /**
         * update_mask indicates fields to be updated as part of this request.
         */
        updateMask?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$StoragePool;
    }
    export class Resource$Storagepooltypes {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves an aggregated list of storage pool types.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Storagepooltypes$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Storagepooltypes$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$StoragePoolTypeAggregatedList>;
        aggregatedList(params: Params$Resource$Storagepooltypes$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Storagepooltypes$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$StoragePoolTypeAggregatedList>, callback: BodyResponseCallback<Schema$StoragePoolTypeAggregatedList>): void;
        aggregatedList(params: Params$Resource$Storagepooltypes$Aggregatedlist, callback: BodyResponseCallback<Schema$StoragePoolTypeAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$StoragePoolTypeAggregatedList>): void;
        /**
         * Returns the specified storage pool type.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Storagepooltypes$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Storagepooltypes$Get, options?: MethodOptions): GaxiosPromise<Schema$StoragePoolType>;
        get(params: Params$Resource$Storagepooltypes$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Storagepooltypes$Get, options: MethodOptions | BodyResponseCallback<Schema$StoragePoolType>, callback: BodyResponseCallback<Schema$StoragePoolType>): void;
        get(params: Params$Resource$Storagepooltypes$Get, callback: BodyResponseCallback<Schema$StoragePoolType>): void;
        get(callback: BodyResponseCallback<Schema$StoragePoolType>): void;
        /**
         * Retrieves a list of storage pool types available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Storagepooltypes$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Storagepooltypes$List, options?: MethodOptions): GaxiosPromise<Schema$StoragePoolTypeList>;
        list(params: Params$Resource$Storagepooltypes$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Storagepooltypes$List, options: MethodOptions | BodyResponseCallback<Schema$StoragePoolTypeList>, callback: BodyResponseCallback<Schema$StoragePoolTypeList>): void;
        list(params: Params$Resource$Storagepooltypes$List, callback: BodyResponseCallback<Schema$StoragePoolTypeList>): void;
        list(callback: BodyResponseCallback<Schema$StoragePoolTypeList>): void;
    }
    export interface Params$Resource$Storagepooltypes$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Storagepooltypes$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the storage pool type to return.
         */
        storagePoolType?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Storagepooltypes$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
    }
    export class Resource$Subnetworks {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves an aggregated list of subnetworks.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Subnetworks$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Subnetworks$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$SubnetworkAggregatedList>;
        aggregatedList(params: Params$Resource$Subnetworks$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Subnetworks$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$SubnetworkAggregatedList>, callback: BodyResponseCallback<Schema$SubnetworkAggregatedList>): void;
        aggregatedList(params: Params$Resource$Subnetworks$Aggregatedlist, callback: BodyResponseCallback<Schema$SubnetworkAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$SubnetworkAggregatedList>): void;
        /**
         * Deletes the specified subnetwork.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Subnetworks$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Subnetworks$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Subnetworks$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Subnetworks$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Subnetworks$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Expands the IP CIDR range of the subnetwork to a specified value.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        expandIpCidrRange(params: Params$Resource$Subnetworks$Expandipcidrrange, options: StreamMethodOptions): GaxiosPromise<Readable>;
        expandIpCidrRange(params?: Params$Resource$Subnetworks$Expandipcidrrange, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        expandIpCidrRange(params: Params$Resource$Subnetworks$Expandipcidrrange, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        expandIpCidrRange(params: Params$Resource$Subnetworks$Expandipcidrrange, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        expandIpCidrRange(params: Params$Resource$Subnetworks$Expandipcidrrange, callback: BodyResponseCallback<Schema$Operation>): void;
        expandIpCidrRange(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified subnetwork.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Subnetworks$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Subnetworks$Get, options?: MethodOptions): GaxiosPromise<Schema$Subnetwork>;
        get(params: Params$Resource$Subnetworks$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Subnetworks$Get, options: MethodOptions | BodyResponseCallback<Schema$Subnetwork>, callback: BodyResponseCallback<Schema$Subnetwork>): void;
        get(params: Params$Resource$Subnetworks$Get, callback: BodyResponseCallback<Schema$Subnetwork>): void;
        get(callback: BodyResponseCallback<Schema$Subnetwork>): void;
        /**
         * Gets the access control policy for a resource. May be empty if no such policy or resource exists.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getIamPolicy(params: Params$Resource$Subnetworks$Getiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getIamPolicy(params?: Params$Resource$Subnetworks$Getiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        getIamPolicy(params: Params$Resource$Subnetworks$Getiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getIamPolicy(params: Params$Resource$Subnetworks$Getiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(params: Params$Resource$Subnetworks$Getiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        getIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Creates a subnetwork in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Subnetworks$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Subnetworks$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Subnetworks$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Subnetworks$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Subnetworks$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves a list of subnetworks available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Subnetworks$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Subnetworks$List, options?: MethodOptions): GaxiosPromise<Schema$SubnetworkList>;
        list(params: Params$Resource$Subnetworks$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Subnetworks$List, options: MethodOptions | BodyResponseCallback<Schema$SubnetworkList>, callback: BodyResponseCallback<Schema$SubnetworkList>): void;
        list(params: Params$Resource$Subnetworks$List, callback: BodyResponseCallback<Schema$SubnetworkList>): void;
        list(callback: BodyResponseCallback<Schema$SubnetworkList>): void;
        /**
         * Retrieves an aggregated list of all usable subnetworks in the project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        listUsable(params: Params$Resource$Subnetworks$Listusable, options: StreamMethodOptions): GaxiosPromise<Readable>;
        listUsable(params?: Params$Resource$Subnetworks$Listusable, options?: MethodOptions): GaxiosPromise<Schema$UsableSubnetworksAggregatedList>;
        listUsable(params: Params$Resource$Subnetworks$Listusable, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        listUsable(params: Params$Resource$Subnetworks$Listusable, options: MethodOptions | BodyResponseCallback<Schema$UsableSubnetworksAggregatedList>, callback: BodyResponseCallback<Schema$UsableSubnetworksAggregatedList>): void;
        listUsable(params: Params$Resource$Subnetworks$Listusable, callback: BodyResponseCallback<Schema$UsableSubnetworksAggregatedList>): void;
        listUsable(callback: BodyResponseCallback<Schema$UsableSubnetworksAggregatedList>): void;
        /**
         * Patches the specified subnetwork with the data included in the request. Only certain fields can be updated with a patch request as indicated in the field descriptions. You must specify the current fingerprint of the subnetwork resource being patched.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Subnetworks$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Subnetworks$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Subnetworks$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Subnetworks$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Subnetworks$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the access control policy on the specified resource. Replaces any existing policy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setIamPolicy(params: Params$Resource$Subnetworks$Setiampolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setIamPolicy(params?: Params$Resource$Subnetworks$Setiampolicy, options?: MethodOptions): GaxiosPromise<Schema$Policy>;
        setIamPolicy(params: Params$Resource$Subnetworks$Setiampolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setIamPolicy(params: Params$Resource$Subnetworks$Setiampolicy, options: MethodOptions | BodyResponseCallback<Schema$Policy>, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(params: Params$Resource$Subnetworks$Setiampolicy, callback: BodyResponseCallback<Schema$Policy>): void;
        setIamPolicy(callback: BodyResponseCallback<Schema$Policy>): void;
        /**
         * Set whether VMs in this subnet can access Google services without assigning external IP addresses through Private Google Access.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setPrivateIpGoogleAccess(params: Params$Resource$Subnetworks$Setprivateipgoogleaccess, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setPrivateIpGoogleAccess(params?: Params$Resource$Subnetworks$Setprivateipgoogleaccess, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setPrivateIpGoogleAccess(params: Params$Resource$Subnetworks$Setprivateipgoogleaccess, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setPrivateIpGoogleAccess(params: Params$Resource$Subnetworks$Setprivateipgoogleaccess, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setPrivateIpGoogleAccess(params: Params$Resource$Subnetworks$Setprivateipgoogleaccess, callback: BodyResponseCallback<Schema$Operation>): void;
        setPrivateIpGoogleAccess(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Subnetworks$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Subnetworks$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Subnetworks$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Subnetworks$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Subnetworks$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Subnetworks$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Subnetworks$Delete extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the Subnetwork resource to delete.
         */
        subnetwork?: string;
    }
    export interface Params$Resource$Subnetworks$Expandipcidrrange extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the Subnetwork resource to update.
         */
        subnetwork?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SubnetworksExpandIpCidrRangeRequest;
    }
    export interface Params$Resource$Subnetworks$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Name of the Subnetwork resource to return.
         */
        subnetwork?: string;
    }
    export interface Params$Resource$Subnetworks$Getiampolicy extends StandardParameters {
        /**
         * Requested IAM Policy version.
         */
        optionsRequestedPolicyVersion?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
    }
    export interface Params$Resource$Subnetworks$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Subnetwork;
    }
    export interface Params$Resource$Subnetworks$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Subnetworks$Listusable extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         * The project id or project number in which the subnetwork is intended to be used. Only applied for Shared VPC. See [Shared VPC documentation](https://cloud.google.com/vpc/docs/shared-vpc/)
         */
        serviceProject?: string;
    }
    export interface Params$Resource$Subnetworks$Patch extends StandardParameters {
        /**
         * The drain timeout specifies the upper bound in seconds on the amount of time allowed to drain connections from the current ACTIVE subnetwork to the current BACKUP subnetwork. The drain timeout is only applicable when the following conditions are true: - the subnetwork being patched has purpose = INTERNAL_HTTPS_LOAD_BALANCER - the subnetwork being patched has role = BACKUP - the patch request is setting the role to ACTIVE. Note that after this patch operation the roles of the ACTIVE and BACKUP subnetworks will be swapped.
         */
        drainTimeoutSeconds?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the Subnetwork resource to patch.
         */
        subnetwork?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$Subnetwork;
    }
    export interface Params$Resource$Subnetworks$Setiampolicy extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionSetPolicyRequest;
    }
    export interface Params$Resource$Subnetworks$Setprivateipgoogleaccess extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the Subnetwork resource.
         */
        subnetwork?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SubnetworksSetPrivateIpGoogleAccessRequest;
    }
    export interface Params$Resource$Subnetworks$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Targetgrpcproxies {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Deletes the specified TargetGrpcProxy in the given scope
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Targetgrpcproxies$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Targetgrpcproxies$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Targetgrpcproxies$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Targetgrpcproxies$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Targetgrpcproxies$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified TargetGrpcProxy resource in the given scope.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Targetgrpcproxies$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Targetgrpcproxies$Get, options?: MethodOptions): GaxiosPromise<Schema$TargetGrpcProxy>;
        get(params: Params$Resource$Targetgrpcproxies$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Targetgrpcproxies$Get, options: MethodOptions | BodyResponseCallback<Schema$TargetGrpcProxy>, callback: BodyResponseCallback<Schema$TargetGrpcProxy>): void;
        get(params: Params$Resource$Targetgrpcproxies$Get, callback: BodyResponseCallback<Schema$TargetGrpcProxy>): void;
        get(callback: BodyResponseCallback<Schema$TargetGrpcProxy>): void;
        /**
         * Creates a TargetGrpcProxy in the specified project in the given scope using the parameters that are included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Targetgrpcproxies$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Targetgrpcproxies$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Targetgrpcproxies$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Targetgrpcproxies$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Targetgrpcproxies$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Lists the TargetGrpcProxies for a project in the given scope.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Targetgrpcproxies$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Targetgrpcproxies$List, options?: MethodOptions): GaxiosPromise<Schema$TargetGrpcProxyList>;
        list(params: Params$Resource$Targetgrpcproxies$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Targetgrpcproxies$List, options: MethodOptions | BodyResponseCallback<Schema$TargetGrpcProxyList>, callback: BodyResponseCallback<Schema$TargetGrpcProxyList>): void;
        list(params: Params$Resource$Targetgrpcproxies$List, callback: BodyResponseCallback<Schema$TargetGrpcProxyList>): void;
        list(callback: BodyResponseCallback<Schema$TargetGrpcProxyList>): void;
        /**
         * Patches the specified TargetGrpcProxy resource with the data included in the request. This method supports PATCH semantics and uses JSON merge patch format and processing rules.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Targetgrpcproxies$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Targetgrpcproxies$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Targetgrpcproxies$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Targetgrpcproxies$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Targetgrpcproxies$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Targetgrpcproxies$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Targetgrpcproxies$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Targetgrpcproxies$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Targetgrpcproxies$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Targetgrpcproxies$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Targetgrpcproxies$Delete extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetGrpcProxy resource to delete.
         */
        targetGrpcProxy?: string;
    }
    export interface Params$Resource$Targetgrpcproxies$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the TargetGrpcProxy resource to return.
         */
        targetGrpcProxy?: string;
    }
    export interface Params$Resource$Targetgrpcproxies$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetGrpcProxy;
    }
    export interface Params$Resource$Targetgrpcproxies$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Targetgrpcproxies$Patch extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetGrpcProxy resource to patch.
         */
        targetGrpcProxy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetGrpcProxy;
    }
    export interface Params$Resource$Targetgrpcproxies$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Targethttpproxies {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves the list of all TargetHttpProxy resources, regional and global, available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Targethttpproxies$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Targethttpproxies$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$TargetHttpProxyAggregatedList>;
        aggregatedList(params: Params$Resource$Targethttpproxies$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Targethttpproxies$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$TargetHttpProxyAggregatedList>, callback: BodyResponseCallback<Schema$TargetHttpProxyAggregatedList>): void;
        aggregatedList(params: Params$Resource$Targethttpproxies$Aggregatedlist, callback: BodyResponseCallback<Schema$TargetHttpProxyAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$TargetHttpProxyAggregatedList>): void;
        /**
         * Deletes the specified TargetHttpProxy resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Targethttpproxies$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Targethttpproxies$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Targethttpproxies$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Targethttpproxies$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Targethttpproxies$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified TargetHttpProxy resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Targethttpproxies$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Targethttpproxies$Get, options?: MethodOptions): GaxiosPromise<Schema$TargetHttpProxy>;
        get(params: Params$Resource$Targethttpproxies$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Targethttpproxies$Get, options: MethodOptions | BodyResponseCallback<Schema$TargetHttpProxy>, callback: BodyResponseCallback<Schema$TargetHttpProxy>): void;
        get(params: Params$Resource$Targethttpproxies$Get, callback: BodyResponseCallback<Schema$TargetHttpProxy>): void;
        get(callback: BodyResponseCallback<Schema$TargetHttpProxy>): void;
        /**
         * Creates a TargetHttpProxy resource in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Targethttpproxies$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Targethttpproxies$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Targethttpproxies$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Targethttpproxies$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Targethttpproxies$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of TargetHttpProxy resources available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Targethttpproxies$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Targethttpproxies$List, options?: MethodOptions): GaxiosPromise<Schema$TargetHttpProxyList>;
        list(params: Params$Resource$Targethttpproxies$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Targethttpproxies$List, options: MethodOptions | BodyResponseCallback<Schema$TargetHttpProxyList>, callback: BodyResponseCallback<Schema$TargetHttpProxyList>): void;
        list(params: Params$Resource$Targethttpproxies$List, callback: BodyResponseCallback<Schema$TargetHttpProxyList>): void;
        list(callback: BodyResponseCallback<Schema$TargetHttpProxyList>): void;
        /**
         * Patches the specified TargetHttpProxy resource with the data included in the request. This method supports PATCH semantics and uses JSON merge patch format and processing rules.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Targethttpproxies$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Targethttpproxies$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Targethttpproxies$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Targethttpproxies$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Targethttpproxies$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Changes the URL map for TargetHttpProxy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setUrlMap(params: Params$Resource$Targethttpproxies$Seturlmap, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setUrlMap(params?: Params$Resource$Targethttpproxies$Seturlmap, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setUrlMap(params: Params$Resource$Targethttpproxies$Seturlmap, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setUrlMap(params: Params$Resource$Targethttpproxies$Seturlmap, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setUrlMap(params: Params$Resource$Targethttpproxies$Seturlmap, callback: BodyResponseCallback<Schema$Operation>): void;
        setUrlMap(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Targethttpproxies$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Targethttpproxies$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Targethttpproxies$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Targethttpproxies$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Targethttpproxies$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Targethttpproxies$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Name of the project scoping this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Targethttpproxies$Delete extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetHttpProxy resource to delete.
         */
        targetHttpProxy?: string;
    }
    export interface Params$Resource$Targethttpproxies$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the TargetHttpProxy resource to return.
         */
        targetHttpProxy?: string;
    }
    export interface Params$Resource$Targethttpproxies$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetHttpProxy;
    }
    export interface Params$Resource$Targethttpproxies$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Targethttpproxies$Patch extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetHttpProxy resource to patch.
         */
        targetHttpProxy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetHttpProxy;
    }
    export interface Params$Resource$Targethttpproxies$Seturlmap extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetHttpProxy to set a URL map for.
         */
        targetHttpProxy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$UrlMapReference;
    }
    export interface Params$Resource$Targethttpproxies$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Targethttpsproxies {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves the list of all TargetHttpsProxy resources, regional and global, available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Targethttpsproxies$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Targethttpsproxies$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$TargetHttpsProxyAggregatedList>;
        aggregatedList(params: Params$Resource$Targethttpsproxies$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Targethttpsproxies$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$TargetHttpsProxyAggregatedList>, callback: BodyResponseCallback<Schema$TargetHttpsProxyAggregatedList>): void;
        aggregatedList(params: Params$Resource$Targethttpsproxies$Aggregatedlist, callback: BodyResponseCallback<Schema$TargetHttpsProxyAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$TargetHttpsProxyAggregatedList>): void;
        /**
         * Deletes the specified TargetHttpsProxy resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Targethttpsproxies$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Targethttpsproxies$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Targethttpsproxies$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Targethttpsproxies$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Targethttpsproxies$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified TargetHttpsProxy resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Targethttpsproxies$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Targethttpsproxies$Get, options?: MethodOptions): GaxiosPromise<Schema$TargetHttpsProxy>;
        get(params: Params$Resource$Targethttpsproxies$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Targethttpsproxies$Get, options: MethodOptions | BodyResponseCallback<Schema$TargetHttpsProxy>, callback: BodyResponseCallback<Schema$TargetHttpsProxy>): void;
        get(params: Params$Resource$Targethttpsproxies$Get, callback: BodyResponseCallback<Schema$TargetHttpsProxy>): void;
        get(callback: BodyResponseCallback<Schema$TargetHttpsProxy>): void;
        /**
         * Creates a TargetHttpsProxy resource in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Targethttpsproxies$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Targethttpsproxies$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Targethttpsproxies$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Targethttpsproxies$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Targethttpsproxies$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of TargetHttpsProxy resources available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Targethttpsproxies$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Targethttpsproxies$List, options?: MethodOptions): GaxiosPromise<Schema$TargetHttpsProxyList>;
        list(params: Params$Resource$Targethttpsproxies$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Targethttpsproxies$List, options: MethodOptions | BodyResponseCallback<Schema$TargetHttpsProxyList>, callback: BodyResponseCallback<Schema$TargetHttpsProxyList>): void;
        list(params: Params$Resource$Targethttpsproxies$List, callback: BodyResponseCallback<Schema$TargetHttpsProxyList>): void;
        list(callback: BodyResponseCallback<Schema$TargetHttpsProxyList>): void;
        /**
         * Patches the specified TargetHttpsProxy resource with the data included in the request. This method supports PATCH semantics and uses JSON merge patch format and processing rules.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Targethttpsproxies$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Targethttpsproxies$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Targethttpsproxies$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Targethttpsproxies$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Targethttpsproxies$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Changes the Certificate Map for TargetHttpsProxy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setCertificateMap(params: Params$Resource$Targethttpsproxies$Setcertificatemap, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setCertificateMap(params?: Params$Resource$Targethttpsproxies$Setcertificatemap, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setCertificateMap(params: Params$Resource$Targethttpsproxies$Setcertificatemap, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setCertificateMap(params: Params$Resource$Targethttpsproxies$Setcertificatemap, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setCertificateMap(params: Params$Resource$Targethttpsproxies$Setcertificatemap, callback: BodyResponseCallback<Schema$Operation>): void;
        setCertificateMap(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the QUIC override policy for TargetHttpsProxy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setQuicOverride(params: Params$Resource$Targethttpsproxies$Setquicoverride, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setQuicOverride(params?: Params$Resource$Targethttpsproxies$Setquicoverride, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setQuicOverride(params: Params$Resource$Targethttpsproxies$Setquicoverride, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setQuicOverride(params: Params$Resource$Targethttpsproxies$Setquicoverride, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setQuicOverride(params: Params$Resource$Targethttpsproxies$Setquicoverride, callback: BodyResponseCallback<Schema$Operation>): void;
        setQuicOverride(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Replaces SslCertificates for TargetHttpsProxy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setSslCertificates(params: Params$Resource$Targethttpsproxies$Setsslcertificates, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setSslCertificates(params?: Params$Resource$Targethttpsproxies$Setsslcertificates, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setSslCertificates(params: Params$Resource$Targethttpsproxies$Setsslcertificates, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setSslCertificates(params: Params$Resource$Targethttpsproxies$Setsslcertificates, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setSslCertificates(params: Params$Resource$Targethttpsproxies$Setsslcertificates, callback: BodyResponseCallback<Schema$Operation>): void;
        setSslCertificates(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the SSL policy for TargetHttpsProxy. The SSL policy specifies the server-side support for SSL features. This affects connections between clients and the HTTPS proxy load balancer. They do not affect the connection between the load balancer and the backends.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setSslPolicy(params: Params$Resource$Targethttpsproxies$Setsslpolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setSslPolicy(params?: Params$Resource$Targethttpsproxies$Setsslpolicy, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setSslPolicy(params: Params$Resource$Targethttpsproxies$Setsslpolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setSslPolicy(params: Params$Resource$Targethttpsproxies$Setsslpolicy, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setSslPolicy(params: Params$Resource$Targethttpsproxies$Setsslpolicy, callback: BodyResponseCallback<Schema$Operation>): void;
        setSslPolicy(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Changes the URL map for TargetHttpsProxy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setUrlMap(params: Params$Resource$Targethttpsproxies$Seturlmap, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setUrlMap(params?: Params$Resource$Targethttpsproxies$Seturlmap, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setUrlMap(params: Params$Resource$Targethttpsproxies$Seturlmap, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setUrlMap(params: Params$Resource$Targethttpsproxies$Seturlmap, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setUrlMap(params: Params$Resource$Targethttpsproxies$Seturlmap, callback: BodyResponseCallback<Schema$Operation>): void;
        setUrlMap(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Targethttpsproxies$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Targethttpsproxies$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Targethttpsproxies$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Targethttpsproxies$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Targethttpsproxies$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Targethttpsproxies$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Name of the project scoping this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Targethttpsproxies$Delete extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetHttpsProxy resource to delete.
         */
        targetHttpsProxy?: string;
    }
    export interface Params$Resource$Targethttpsproxies$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the TargetHttpsProxy resource to return.
         */
        targetHttpsProxy?: string;
    }
    export interface Params$Resource$Targethttpsproxies$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetHttpsProxy;
    }
    export interface Params$Resource$Targethttpsproxies$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Targethttpsproxies$Patch extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetHttpsProxy resource to patch.
         */
        targetHttpsProxy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetHttpsProxy;
    }
    export interface Params$Resource$Targethttpsproxies$Setcertificatemap extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetHttpsProxy resource whose CertificateMap is to be set. The name must be 1-63 characters long, and comply with RFC1035.
         */
        targetHttpsProxy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetHttpsProxiesSetCertificateMapRequest;
    }
    export interface Params$Resource$Targethttpsproxies$Setquicoverride extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetHttpsProxy resource to set the QUIC override policy for. The name should conform to RFC1035.
         */
        targetHttpsProxy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetHttpsProxiesSetQuicOverrideRequest;
    }
    export interface Params$Resource$Targethttpsproxies$Setsslcertificates extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetHttpsProxy resource to set an SslCertificates resource for.
         */
        targetHttpsProxy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetHttpsProxiesSetSslCertificatesRequest;
    }
    export interface Params$Resource$Targethttpsproxies$Setsslpolicy extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetHttpsProxy resource whose SSL policy is to be set. The name must be 1-63 characters long, and comply with RFC1035.
         */
        targetHttpsProxy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SslPolicyReference;
    }
    export interface Params$Resource$Targethttpsproxies$Seturlmap extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetHttpsProxy resource whose URL map is to be set.
         */
        targetHttpsProxy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$UrlMapReference;
    }
    export interface Params$Resource$Targethttpsproxies$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Targetinstances {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves an aggregated list of target instances.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Targetinstances$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Targetinstances$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$TargetInstanceAggregatedList>;
        aggregatedList(params: Params$Resource$Targetinstances$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Targetinstances$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$TargetInstanceAggregatedList>, callback: BodyResponseCallback<Schema$TargetInstanceAggregatedList>): void;
        aggregatedList(params: Params$Resource$Targetinstances$Aggregatedlist, callback: BodyResponseCallback<Schema$TargetInstanceAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$TargetInstanceAggregatedList>): void;
        /**
         * Deletes the specified TargetInstance resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Targetinstances$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Targetinstances$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Targetinstances$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Targetinstances$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Targetinstances$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified TargetInstance resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Targetinstances$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Targetinstances$Get, options?: MethodOptions): GaxiosPromise<Schema$TargetInstance>;
        get(params: Params$Resource$Targetinstances$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Targetinstances$Get, options: MethodOptions | BodyResponseCallback<Schema$TargetInstance>, callback: BodyResponseCallback<Schema$TargetInstance>): void;
        get(params: Params$Resource$Targetinstances$Get, callback: BodyResponseCallback<Schema$TargetInstance>): void;
        get(callback: BodyResponseCallback<Schema$TargetInstance>): void;
        /**
         * Creates a TargetInstance resource in the specified project and zone using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Targetinstances$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Targetinstances$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Targetinstances$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Targetinstances$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Targetinstances$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves a list of TargetInstance resources available to the specified project and zone.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Targetinstances$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Targetinstances$List, options?: MethodOptions): GaxiosPromise<Schema$TargetInstanceList>;
        list(params: Params$Resource$Targetinstances$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Targetinstances$List, options: MethodOptions | BodyResponseCallback<Schema$TargetInstanceList>, callback: BodyResponseCallback<Schema$TargetInstanceList>): void;
        list(params: Params$Resource$Targetinstances$List, callback: BodyResponseCallback<Schema$TargetInstanceList>): void;
        list(callback: BodyResponseCallback<Schema$TargetInstanceList>): void;
        /**
         * Sets the Google Cloud Armor security policy for the specified target instance. For more information, see Google Cloud Armor Overview
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setSecurityPolicy(params: Params$Resource$Targetinstances$Setsecuritypolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setSecurityPolicy(params?: Params$Resource$Targetinstances$Setsecuritypolicy, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setSecurityPolicy(params: Params$Resource$Targetinstances$Setsecuritypolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setSecurityPolicy(params: Params$Resource$Targetinstances$Setsecuritypolicy, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setSecurityPolicy(params: Params$Resource$Targetinstances$Setsecuritypolicy, callback: BodyResponseCallback<Schema$Operation>): void;
        setSecurityPolicy(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Targetinstances$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Targetinstances$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Targetinstances$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Targetinstances$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Targetinstances$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Targetinstances$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Targetinstances$Delete extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetInstance resource to delete.
         */
        targetInstance?: string;
        /**
         * Name of the zone scoping this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Targetinstances$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the TargetInstance resource to return.
         */
        targetInstance?: string;
        /**
         * Name of the zone scoping this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Targetinstances$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the zone scoping this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetInstance;
    }
    export interface Params$Resource$Targetinstances$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         * Name of the zone scoping this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Targetinstances$Setsecuritypolicy extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetInstance resource to which the security policy should be set. The name should conform to RFC1035.
         */
        targetInstance?: string;
        /**
         * Name of the zone scoping this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SecurityPolicyReference;
    }
    export interface Params$Resource$Targetinstances$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * The name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Targetpools {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Adds health check URLs to a target pool.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        addHealthCheck(params: Params$Resource$Targetpools$Addhealthcheck, options: StreamMethodOptions): GaxiosPromise<Readable>;
        addHealthCheck(params?: Params$Resource$Targetpools$Addhealthcheck, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        addHealthCheck(params: Params$Resource$Targetpools$Addhealthcheck, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        addHealthCheck(params: Params$Resource$Targetpools$Addhealthcheck, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        addHealthCheck(params: Params$Resource$Targetpools$Addhealthcheck, callback: BodyResponseCallback<Schema$Operation>): void;
        addHealthCheck(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Adds an instance to a target pool.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        addInstance(params: Params$Resource$Targetpools$Addinstance, options: StreamMethodOptions): GaxiosPromise<Readable>;
        addInstance(params?: Params$Resource$Targetpools$Addinstance, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        addInstance(params: Params$Resource$Targetpools$Addinstance, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        addInstance(params: Params$Resource$Targetpools$Addinstance, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        addInstance(params: Params$Resource$Targetpools$Addinstance, callback: BodyResponseCallback<Schema$Operation>): void;
        addInstance(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves an aggregated list of target pools.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Targetpools$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Targetpools$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$TargetPoolAggregatedList>;
        aggregatedList(params: Params$Resource$Targetpools$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Targetpools$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$TargetPoolAggregatedList>, callback: BodyResponseCallback<Schema$TargetPoolAggregatedList>): void;
        aggregatedList(params: Params$Resource$Targetpools$Aggregatedlist, callback: BodyResponseCallback<Schema$TargetPoolAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$TargetPoolAggregatedList>): void;
        /**
         * Deletes the specified target pool.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Targetpools$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Targetpools$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Targetpools$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Targetpools$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Targetpools$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified target pool.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Targetpools$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Targetpools$Get, options?: MethodOptions): GaxiosPromise<Schema$TargetPool>;
        get(params: Params$Resource$Targetpools$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Targetpools$Get, options: MethodOptions | BodyResponseCallback<Schema$TargetPool>, callback: BodyResponseCallback<Schema$TargetPool>): void;
        get(params: Params$Resource$Targetpools$Get, callback: BodyResponseCallback<Schema$TargetPool>): void;
        get(callback: BodyResponseCallback<Schema$TargetPool>): void;
        /**
         * Gets the most recent health check results for each IP for the instance that is referenced by the given target pool.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getHealth(params: Params$Resource$Targetpools$Gethealth, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getHealth(params?: Params$Resource$Targetpools$Gethealth, options?: MethodOptions): GaxiosPromise<Schema$TargetPoolInstanceHealth>;
        getHealth(params: Params$Resource$Targetpools$Gethealth, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getHealth(params: Params$Resource$Targetpools$Gethealth, options: MethodOptions | BodyResponseCallback<Schema$TargetPoolInstanceHealth>, callback: BodyResponseCallback<Schema$TargetPoolInstanceHealth>): void;
        getHealth(params: Params$Resource$Targetpools$Gethealth, callback: BodyResponseCallback<Schema$TargetPoolInstanceHealth>): void;
        getHealth(callback: BodyResponseCallback<Schema$TargetPoolInstanceHealth>): void;
        /**
         * Creates a target pool in the specified project and region using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Targetpools$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Targetpools$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Targetpools$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Targetpools$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Targetpools$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves a list of target pools available to the specified project and region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Targetpools$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Targetpools$List, options?: MethodOptions): GaxiosPromise<Schema$TargetPoolList>;
        list(params: Params$Resource$Targetpools$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Targetpools$List, options: MethodOptions | BodyResponseCallback<Schema$TargetPoolList>, callback: BodyResponseCallback<Schema$TargetPoolList>): void;
        list(params: Params$Resource$Targetpools$List, callback: BodyResponseCallback<Schema$TargetPoolList>): void;
        list(callback: BodyResponseCallback<Schema$TargetPoolList>): void;
        /**
         * Removes health check URL from a target pool.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        removeHealthCheck(params: Params$Resource$Targetpools$Removehealthcheck, options: StreamMethodOptions): GaxiosPromise<Readable>;
        removeHealthCheck(params?: Params$Resource$Targetpools$Removehealthcheck, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        removeHealthCheck(params: Params$Resource$Targetpools$Removehealthcheck, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        removeHealthCheck(params: Params$Resource$Targetpools$Removehealthcheck, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        removeHealthCheck(params: Params$Resource$Targetpools$Removehealthcheck, callback: BodyResponseCallback<Schema$Operation>): void;
        removeHealthCheck(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Removes instance URL from a target pool.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        removeInstance(params: Params$Resource$Targetpools$Removeinstance, options: StreamMethodOptions): GaxiosPromise<Readable>;
        removeInstance(params?: Params$Resource$Targetpools$Removeinstance, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        removeInstance(params: Params$Resource$Targetpools$Removeinstance, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        removeInstance(params: Params$Resource$Targetpools$Removeinstance, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        removeInstance(params: Params$Resource$Targetpools$Removeinstance, callback: BodyResponseCallback<Schema$Operation>): void;
        removeInstance(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Changes a backup target pool's configurations.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setBackup(params: Params$Resource$Targetpools$Setbackup, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setBackup(params?: Params$Resource$Targetpools$Setbackup, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setBackup(params: Params$Resource$Targetpools$Setbackup, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setBackup(params: Params$Resource$Targetpools$Setbackup, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setBackup(params: Params$Resource$Targetpools$Setbackup, callback: BodyResponseCallback<Schema$Operation>): void;
        setBackup(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the Google Cloud Armor security policy for the specified target pool. For more information, see Google Cloud Armor Overview
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setSecurityPolicy(params: Params$Resource$Targetpools$Setsecuritypolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setSecurityPolicy(params?: Params$Resource$Targetpools$Setsecuritypolicy, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setSecurityPolicy(params: Params$Resource$Targetpools$Setsecuritypolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setSecurityPolicy(params: Params$Resource$Targetpools$Setsecuritypolicy, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setSecurityPolicy(params: Params$Resource$Targetpools$Setsecuritypolicy, callback: BodyResponseCallback<Schema$Operation>): void;
        setSecurityPolicy(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Targetpools$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Targetpools$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Targetpools$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Targetpools$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Targetpools$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Targetpools$Addhealthcheck extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the target pool to add a health check to.
         */
        targetPool?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetPoolsAddHealthCheckRequest;
    }
    export interface Params$Resource$Targetpools$Addinstance extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetPool resource to add instances to.
         */
        targetPool?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetPoolsAddInstanceRequest;
    }
    export interface Params$Resource$Targetpools$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Targetpools$Delete extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetPool resource to delete.
         */
        targetPool?: string;
    }
    export interface Params$Resource$Targetpools$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Name of the TargetPool resource to return.
         */
        targetPool?: string;
    }
    export interface Params$Resource$Targetpools$Gethealth extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Name of the TargetPool resource to which the queried instance belongs.
         */
        targetPool?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$InstanceReference;
    }
    export interface Params$Resource$Targetpools$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetPool;
    }
    export interface Params$Resource$Targetpools$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Targetpools$Removehealthcheck extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the target pool to remove health checks from.
         */
        targetPool?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetPoolsRemoveHealthCheckRequest;
    }
    export interface Params$Resource$Targetpools$Removeinstance extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetPool resource to remove instances from.
         */
        targetPool?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetPoolsRemoveInstanceRequest;
    }
    export interface Params$Resource$Targetpools$Setbackup extends StandardParameters {
        /**
         * New failoverRatio value for the target pool.
         */
        failoverRatio?: number;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetPool resource to set a backup pool for.
         */
        targetPool?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetReference;
    }
    export interface Params$Resource$Targetpools$Setsecuritypolicy extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region scoping this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetPool resource to which the security policy should be set. The name should conform to RFC1035.
         */
        targetPool?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SecurityPolicyReference;
    }
    export interface Params$Resource$Targetpools$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Targetsslproxies {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Deletes the specified TargetSslProxy resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Targetsslproxies$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Targetsslproxies$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Targetsslproxies$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Targetsslproxies$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Targetsslproxies$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified TargetSslProxy resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Targetsslproxies$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Targetsslproxies$Get, options?: MethodOptions): GaxiosPromise<Schema$TargetSslProxy>;
        get(params: Params$Resource$Targetsslproxies$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Targetsslproxies$Get, options: MethodOptions | BodyResponseCallback<Schema$TargetSslProxy>, callback: BodyResponseCallback<Schema$TargetSslProxy>): void;
        get(params: Params$Resource$Targetsslproxies$Get, callback: BodyResponseCallback<Schema$TargetSslProxy>): void;
        get(callback: BodyResponseCallback<Schema$TargetSslProxy>): void;
        /**
         * Creates a TargetSslProxy resource in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Targetsslproxies$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Targetsslproxies$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Targetsslproxies$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Targetsslproxies$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Targetsslproxies$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of TargetSslProxy resources available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Targetsslproxies$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Targetsslproxies$List, options?: MethodOptions): GaxiosPromise<Schema$TargetSslProxyList>;
        list(params: Params$Resource$Targetsslproxies$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Targetsslproxies$List, options: MethodOptions | BodyResponseCallback<Schema$TargetSslProxyList>, callback: BodyResponseCallback<Schema$TargetSslProxyList>): void;
        list(params: Params$Resource$Targetsslproxies$List, callback: BodyResponseCallback<Schema$TargetSslProxyList>): void;
        list(callback: BodyResponseCallback<Schema$TargetSslProxyList>): void;
        /**
         * Changes the BackendService for TargetSslProxy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setBackendService(params: Params$Resource$Targetsslproxies$Setbackendservice, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setBackendService(params?: Params$Resource$Targetsslproxies$Setbackendservice, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setBackendService(params: Params$Resource$Targetsslproxies$Setbackendservice, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setBackendService(params: Params$Resource$Targetsslproxies$Setbackendservice, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setBackendService(params: Params$Resource$Targetsslproxies$Setbackendservice, callback: BodyResponseCallback<Schema$Operation>): void;
        setBackendService(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Changes the Certificate Map for TargetSslProxy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setCertificateMap(params: Params$Resource$Targetsslproxies$Setcertificatemap, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setCertificateMap(params?: Params$Resource$Targetsslproxies$Setcertificatemap, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setCertificateMap(params: Params$Resource$Targetsslproxies$Setcertificatemap, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setCertificateMap(params: Params$Resource$Targetsslproxies$Setcertificatemap, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setCertificateMap(params: Params$Resource$Targetsslproxies$Setcertificatemap, callback: BodyResponseCallback<Schema$Operation>): void;
        setCertificateMap(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Changes the ProxyHeaderType for TargetSslProxy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setProxyHeader(params: Params$Resource$Targetsslproxies$Setproxyheader, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setProxyHeader(params?: Params$Resource$Targetsslproxies$Setproxyheader, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setProxyHeader(params: Params$Resource$Targetsslproxies$Setproxyheader, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setProxyHeader(params: Params$Resource$Targetsslproxies$Setproxyheader, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setProxyHeader(params: Params$Resource$Targetsslproxies$Setproxyheader, callback: BodyResponseCallback<Schema$Operation>): void;
        setProxyHeader(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Changes SslCertificates for TargetSslProxy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setSslCertificates(params: Params$Resource$Targetsslproxies$Setsslcertificates, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setSslCertificates(params?: Params$Resource$Targetsslproxies$Setsslcertificates, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setSslCertificates(params: Params$Resource$Targetsslproxies$Setsslcertificates, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setSslCertificates(params: Params$Resource$Targetsslproxies$Setsslcertificates, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setSslCertificates(params: Params$Resource$Targetsslproxies$Setsslcertificates, callback: BodyResponseCallback<Schema$Operation>): void;
        setSslCertificates(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Sets the SSL policy for TargetSslProxy. The SSL policy specifies the server-side support for SSL features. This affects connections between clients and the SSL proxy load balancer. They do not affect the connection between the load balancer and the backends.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setSslPolicy(params: Params$Resource$Targetsslproxies$Setsslpolicy, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setSslPolicy(params?: Params$Resource$Targetsslproxies$Setsslpolicy, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setSslPolicy(params: Params$Resource$Targetsslproxies$Setsslpolicy, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setSslPolicy(params: Params$Resource$Targetsslproxies$Setsslpolicy, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setSslPolicy(params: Params$Resource$Targetsslproxies$Setsslpolicy, callback: BodyResponseCallback<Schema$Operation>): void;
        setSslPolicy(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Targetsslproxies$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Targetsslproxies$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Targetsslproxies$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Targetsslproxies$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Targetsslproxies$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Targetsslproxies$Delete extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetSslProxy resource to delete.
         */
        targetSslProxy?: string;
    }
    export interface Params$Resource$Targetsslproxies$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the TargetSslProxy resource to return.
         */
        targetSslProxy?: string;
    }
    export interface Params$Resource$Targetsslproxies$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetSslProxy;
    }
    export interface Params$Resource$Targetsslproxies$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Targetsslproxies$Setbackendservice extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetSslProxy resource whose BackendService resource is to be set.
         */
        targetSslProxy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetSslProxiesSetBackendServiceRequest;
    }
    export interface Params$Resource$Targetsslproxies$Setcertificatemap extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetSslProxy resource whose CertificateMap is to be set. The name must be 1-63 characters long, and comply with RFC1035.
         */
        targetSslProxy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetSslProxiesSetCertificateMapRequest;
    }
    export interface Params$Resource$Targetsslproxies$Setproxyheader extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetSslProxy resource whose ProxyHeader is to be set.
         */
        targetSslProxy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetSslProxiesSetProxyHeaderRequest;
    }
    export interface Params$Resource$Targetsslproxies$Setsslcertificates extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetSslProxy resource whose SslCertificate resource is to be set.
         */
        targetSslProxy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetSslProxiesSetSslCertificatesRequest;
    }
    export interface Params$Resource$Targetsslproxies$Setsslpolicy extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetSslProxy resource whose SSL policy is to be set. The name must be 1-63 characters long, and comply with RFC1035.
         */
        targetSslProxy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$SslPolicyReference;
    }
    export interface Params$Resource$Targetsslproxies$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Targettcpproxies {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves the list of all TargetTcpProxy resources, regional and global, available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Targettcpproxies$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Targettcpproxies$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$TargetTcpProxyAggregatedList>;
        aggregatedList(params: Params$Resource$Targettcpproxies$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Targettcpproxies$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$TargetTcpProxyAggregatedList>, callback: BodyResponseCallback<Schema$TargetTcpProxyAggregatedList>): void;
        aggregatedList(params: Params$Resource$Targettcpproxies$Aggregatedlist, callback: BodyResponseCallback<Schema$TargetTcpProxyAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$TargetTcpProxyAggregatedList>): void;
        /**
         * Deletes the specified TargetTcpProxy resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Targettcpproxies$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Targettcpproxies$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Targettcpproxies$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Targettcpproxies$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Targettcpproxies$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified TargetTcpProxy resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Targettcpproxies$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Targettcpproxies$Get, options?: MethodOptions): GaxiosPromise<Schema$TargetTcpProxy>;
        get(params: Params$Resource$Targettcpproxies$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Targettcpproxies$Get, options: MethodOptions | BodyResponseCallback<Schema$TargetTcpProxy>, callback: BodyResponseCallback<Schema$TargetTcpProxy>): void;
        get(params: Params$Resource$Targettcpproxies$Get, callback: BodyResponseCallback<Schema$TargetTcpProxy>): void;
        get(callback: BodyResponseCallback<Schema$TargetTcpProxy>): void;
        /**
         * Creates a TargetTcpProxy resource in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Targettcpproxies$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Targettcpproxies$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Targettcpproxies$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Targettcpproxies$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Targettcpproxies$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of TargetTcpProxy resources available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Targettcpproxies$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Targettcpproxies$List, options?: MethodOptions): GaxiosPromise<Schema$TargetTcpProxyList>;
        list(params: Params$Resource$Targettcpproxies$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Targettcpproxies$List, options: MethodOptions | BodyResponseCallback<Schema$TargetTcpProxyList>, callback: BodyResponseCallback<Schema$TargetTcpProxyList>): void;
        list(params: Params$Resource$Targettcpproxies$List, callback: BodyResponseCallback<Schema$TargetTcpProxyList>): void;
        list(callback: BodyResponseCallback<Schema$TargetTcpProxyList>): void;
        /**
         * Changes the BackendService for TargetTcpProxy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setBackendService(params: Params$Resource$Targettcpproxies$Setbackendservice, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setBackendService(params?: Params$Resource$Targettcpproxies$Setbackendservice, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setBackendService(params: Params$Resource$Targettcpproxies$Setbackendservice, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setBackendService(params: Params$Resource$Targettcpproxies$Setbackendservice, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setBackendService(params: Params$Resource$Targettcpproxies$Setbackendservice, callback: BodyResponseCallback<Schema$Operation>): void;
        setBackendService(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Changes the ProxyHeaderType for TargetTcpProxy.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setProxyHeader(params: Params$Resource$Targettcpproxies$Setproxyheader, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setProxyHeader(params?: Params$Resource$Targettcpproxies$Setproxyheader, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setProxyHeader(params: Params$Resource$Targettcpproxies$Setproxyheader, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setProxyHeader(params: Params$Resource$Targettcpproxies$Setproxyheader, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setProxyHeader(params: Params$Resource$Targettcpproxies$Setproxyheader, callback: BodyResponseCallback<Schema$Operation>): void;
        setProxyHeader(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Targettcpproxies$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Targettcpproxies$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Targettcpproxies$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Targettcpproxies$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Targettcpproxies$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Targettcpproxies$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Name of the project scoping this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Targettcpproxies$Delete extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetTcpProxy resource to delete.
         */
        targetTcpProxy?: string;
    }
    export interface Params$Resource$Targettcpproxies$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the TargetTcpProxy resource to return.
         */
        targetTcpProxy?: string;
    }
    export interface Params$Resource$Targettcpproxies$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetTcpProxy;
    }
    export interface Params$Resource$Targettcpproxies$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Targettcpproxies$Setbackendservice extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetTcpProxy resource whose BackendService resource is to be set.
         */
        targetTcpProxy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetTcpProxiesSetBackendServiceRequest;
    }
    export interface Params$Resource$Targettcpproxies$Setproxyheader extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the TargetTcpProxy resource whose ProxyHeader is to be set.
         */
        targetTcpProxy?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetTcpProxiesSetProxyHeaderRequest;
    }
    export interface Params$Resource$Targettcpproxies$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Targetvpngateways {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves an aggregated list of target VPN gateways.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Targetvpngateways$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Targetvpngateways$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$TargetVpnGatewayAggregatedList>;
        aggregatedList(params: Params$Resource$Targetvpngateways$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Targetvpngateways$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$TargetVpnGatewayAggregatedList>, callback: BodyResponseCallback<Schema$TargetVpnGatewayAggregatedList>): void;
        aggregatedList(params: Params$Resource$Targetvpngateways$Aggregatedlist, callback: BodyResponseCallback<Schema$TargetVpnGatewayAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$TargetVpnGatewayAggregatedList>): void;
        /**
         * Deletes the specified target VPN gateway.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Targetvpngateways$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Targetvpngateways$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Targetvpngateways$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Targetvpngateways$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Targetvpngateways$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified target VPN gateway.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Targetvpngateways$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Targetvpngateways$Get, options?: MethodOptions): GaxiosPromise<Schema$TargetVpnGateway>;
        get(params: Params$Resource$Targetvpngateways$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Targetvpngateways$Get, options: MethodOptions | BodyResponseCallback<Schema$TargetVpnGateway>, callback: BodyResponseCallback<Schema$TargetVpnGateway>): void;
        get(params: Params$Resource$Targetvpngateways$Get, callback: BodyResponseCallback<Schema$TargetVpnGateway>): void;
        get(callback: BodyResponseCallback<Schema$TargetVpnGateway>): void;
        /**
         * Creates a target VPN gateway in the specified project and region using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Targetvpngateways$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Targetvpngateways$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Targetvpngateways$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Targetvpngateways$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Targetvpngateways$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves a list of target VPN gateways available to the specified project and region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Targetvpngateways$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Targetvpngateways$List, options?: MethodOptions): GaxiosPromise<Schema$TargetVpnGatewayList>;
        list(params: Params$Resource$Targetvpngateways$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Targetvpngateways$List, options: MethodOptions | BodyResponseCallback<Schema$TargetVpnGatewayList>, callback: BodyResponseCallback<Schema$TargetVpnGatewayList>): void;
        list(params: Params$Resource$Targetvpngateways$List, callback: BodyResponseCallback<Schema$TargetVpnGatewayList>): void;
        list(callback: BodyResponseCallback<Schema$TargetVpnGatewayList>): void;
        /**
         * Sets the labels on a TargetVpnGateway. To learn more about labels, read the Labeling Resources documentation.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setLabels(params: Params$Resource$Targetvpngateways$Setlabels, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setLabels(params?: Params$Resource$Targetvpngateways$Setlabels, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setLabels(params: Params$Resource$Targetvpngateways$Setlabels, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setLabels(params: Params$Resource$Targetvpngateways$Setlabels, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(params: Params$Resource$Targetvpngateways$Setlabels, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Targetvpngateways$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Targetvpngateways$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Targetvpngateways$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Targetvpngateways$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Targetvpngateways$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Targetvpngateways$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Targetvpngateways$Delete extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the target VPN gateway to delete.
         */
        targetVpnGateway?: string;
    }
    export interface Params$Resource$Targetvpngateways$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * Name of the target VPN gateway to return.
         */
        targetVpnGateway?: string;
    }
    export interface Params$Resource$Targetvpngateways$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TargetVpnGateway;
    }
    export interface Params$Resource$Targetvpngateways$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Targetvpngateways$Setlabels extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionSetLabelsRequest;
    }
    export interface Params$Resource$Targetvpngateways$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Urlmaps {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves the list of all UrlMap resources, regional and global, available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Urlmaps$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Urlmaps$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$UrlMapsAggregatedList>;
        aggregatedList(params: Params$Resource$Urlmaps$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Urlmaps$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$UrlMapsAggregatedList>, callback: BodyResponseCallback<Schema$UrlMapsAggregatedList>): void;
        aggregatedList(params: Params$Resource$Urlmaps$Aggregatedlist, callback: BodyResponseCallback<Schema$UrlMapsAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$UrlMapsAggregatedList>): void;
        /**
         * Deletes the specified UrlMap resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Urlmaps$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Urlmaps$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Urlmaps$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Urlmaps$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Urlmaps$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified UrlMap resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Urlmaps$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Urlmaps$Get, options?: MethodOptions): GaxiosPromise<Schema$UrlMap>;
        get(params: Params$Resource$Urlmaps$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Urlmaps$Get, options: MethodOptions | BodyResponseCallback<Schema$UrlMap>, callback: BodyResponseCallback<Schema$UrlMap>): void;
        get(params: Params$Resource$Urlmaps$Get, callback: BodyResponseCallback<Schema$UrlMap>): void;
        get(callback: BodyResponseCallback<Schema$UrlMap>): void;
        /**
         * Creates a UrlMap resource in the specified project using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Urlmaps$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Urlmaps$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Urlmaps$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Urlmaps$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Urlmaps$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Initiates a cache invalidation operation, invalidating the specified path, scoped to the specified UrlMap. For more information, see [Invalidating cached content](/cdn/docs/invalidating-cached-content).
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        invalidateCache(params: Params$Resource$Urlmaps$Invalidatecache, options: StreamMethodOptions): GaxiosPromise<Readable>;
        invalidateCache(params?: Params$Resource$Urlmaps$Invalidatecache, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        invalidateCache(params: Params$Resource$Urlmaps$Invalidatecache, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        invalidateCache(params: Params$Resource$Urlmaps$Invalidatecache, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        invalidateCache(params: Params$Resource$Urlmaps$Invalidatecache, callback: BodyResponseCallback<Schema$Operation>): void;
        invalidateCache(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of UrlMap resources available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Urlmaps$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Urlmaps$List, options?: MethodOptions): GaxiosPromise<Schema$UrlMapList>;
        list(params: Params$Resource$Urlmaps$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Urlmaps$List, options: MethodOptions | BodyResponseCallback<Schema$UrlMapList>, callback: BodyResponseCallback<Schema$UrlMapList>): void;
        list(params: Params$Resource$Urlmaps$List, callback: BodyResponseCallback<Schema$UrlMapList>): void;
        list(callback: BodyResponseCallback<Schema$UrlMapList>): void;
        /**
         * Patches the specified UrlMap resource with the data included in the request. This method supports PATCH semantics and uses the JSON merge patch format and processing rules.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        patch(params: Params$Resource$Urlmaps$Patch, options: StreamMethodOptions): GaxiosPromise<Readable>;
        patch(params?: Params$Resource$Urlmaps$Patch, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        patch(params: Params$Resource$Urlmaps$Patch, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        patch(params: Params$Resource$Urlmaps$Patch, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(params: Params$Resource$Urlmaps$Patch, callback: BodyResponseCallback<Schema$Operation>): void;
        patch(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Urlmaps$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Urlmaps$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Urlmaps$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Urlmaps$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Urlmaps$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        /**
         * Updates the specified UrlMap resource with the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        update(params: Params$Resource$Urlmaps$Update, options: StreamMethodOptions): GaxiosPromise<Readable>;
        update(params?: Params$Resource$Urlmaps$Update, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        update(params: Params$Resource$Urlmaps$Update, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        update(params: Params$Resource$Urlmaps$Update, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        update(params: Params$Resource$Urlmaps$Update, callback: BodyResponseCallback<Schema$Operation>): void;
        update(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Runs static validation for the UrlMap. In particular, the tests of the provided UrlMap will be run. Calling this method does NOT create the UrlMap.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        validate(params: Params$Resource$Urlmaps$Validate, options: StreamMethodOptions): GaxiosPromise<Readable>;
        validate(params?: Params$Resource$Urlmaps$Validate, options?: MethodOptions): GaxiosPromise<Schema$UrlMapsValidateResponse>;
        validate(params: Params$Resource$Urlmaps$Validate, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        validate(params: Params$Resource$Urlmaps$Validate, options: MethodOptions | BodyResponseCallback<Schema$UrlMapsValidateResponse>, callback: BodyResponseCallback<Schema$UrlMapsValidateResponse>): void;
        validate(params: Params$Resource$Urlmaps$Validate, callback: BodyResponseCallback<Schema$UrlMapsValidateResponse>): void;
        validate(callback: BodyResponseCallback<Schema$UrlMapsValidateResponse>): void;
    }
    export interface Params$Resource$Urlmaps$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Name of the project scoping this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Urlmaps$Delete extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the UrlMap resource to delete.
         */
        urlMap?: string;
    }
    export interface Params$Resource$Urlmaps$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the UrlMap resource to return.
         */
        urlMap?: string;
    }
    export interface Params$Resource$Urlmaps$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$UrlMap;
    }
    export interface Params$Resource$Urlmaps$Invalidatecache extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the UrlMap scoping this request.
         */
        urlMap?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$CacheInvalidationRule;
    }
    export interface Params$Resource$Urlmaps$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Urlmaps$Patch extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the UrlMap resource to patch.
         */
        urlMap?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$UrlMap;
    }
    export interface Params$Resource$Urlmaps$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export interface Params$Resource$Urlmaps$Update extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the UrlMap resource to update.
         */
        urlMap?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$UrlMap;
    }
    export interface Params$Resource$Urlmaps$Validate extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the UrlMap resource to be validated as.
         */
        urlMap?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$UrlMapsValidateRequest;
    }
    export class Resource$Vpngateways {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves an aggregated list of VPN gateways.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Vpngateways$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Vpngateways$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$VpnGatewayAggregatedList>;
        aggregatedList(params: Params$Resource$Vpngateways$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Vpngateways$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$VpnGatewayAggregatedList>, callback: BodyResponseCallback<Schema$VpnGatewayAggregatedList>): void;
        aggregatedList(params: Params$Resource$Vpngateways$Aggregatedlist, callback: BodyResponseCallback<Schema$VpnGatewayAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$VpnGatewayAggregatedList>): void;
        /**
         * Deletes the specified VPN gateway.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Vpngateways$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Vpngateways$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Vpngateways$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Vpngateways$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Vpngateways$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified VPN gateway.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Vpngateways$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Vpngateways$Get, options?: MethodOptions): GaxiosPromise<Schema$VpnGateway>;
        get(params: Params$Resource$Vpngateways$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Vpngateways$Get, options: MethodOptions | BodyResponseCallback<Schema$VpnGateway>, callback: BodyResponseCallback<Schema$VpnGateway>): void;
        get(params: Params$Resource$Vpngateways$Get, callback: BodyResponseCallback<Schema$VpnGateway>): void;
        get(callback: BodyResponseCallback<Schema$VpnGateway>): void;
        /**
         * Returns the status for the specified VPN gateway.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        getStatus(params: Params$Resource$Vpngateways$Getstatus, options: StreamMethodOptions): GaxiosPromise<Readable>;
        getStatus(params?: Params$Resource$Vpngateways$Getstatus, options?: MethodOptions): GaxiosPromise<Schema$VpnGatewaysGetStatusResponse>;
        getStatus(params: Params$Resource$Vpngateways$Getstatus, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        getStatus(params: Params$Resource$Vpngateways$Getstatus, options: MethodOptions | BodyResponseCallback<Schema$VpnGatewaysGetStatusResponse>, callback: BodyResponseCallback<Schema$VpnGatewaysGetStatusResponse>): void;
        getStatus(params: Params$Resource$Vpngateways$Getstatus, callback: BodyResponseCallback<Schema$VpnGatewaysGetStatusResponse>): void;
        getStatus(callback: BodyResponseCallback<Schema$VpnGatewaysGetStatusResponse>): void;
        /**
         * Creates a VPN gateway in the specified project and region using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Vpngateways$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Vpngateways$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Vpngateways$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Vpngateways$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Vpngateways$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves a list of VPN gateways available to the specified project and region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Vpngateways$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Vpngateways$List, options?: MethodOptions): GaxiosPromise<Schema$VpnGatewayList>;
        list(params: Params$Resource$Vpngateways$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Vpngateways$List, options: MethodOptions | BodyResponseCallback<Schema$VpnGatewayList>, callback: BodyResponseCallback<Schema$VpnGatewayList>): void;
        list(params: Params$Resource$Vpngateways$List, callback: BodyResponseCallback<Schema$VpnGatewayList>): void;
        list(callback: BodyResponseCallback<Schema$VpnGatewayList>): void;
        /**
         * Sets the labels on a VpnGateway. To learn more about labels, read the Labeling Resources documentation.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setLabels(params: Params$Resource$Vpngateways$Setlabels, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setLabels(params?: Params$Resource$Vpngateways$Setlabels, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setLabels(params: Params$Resource$Vpngateways$Setlabels, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setLabels(params: Params$Resource$Vpngateways$Setlabels, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(params: Params$Resource$Vpngateways$Setlabels, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Vpngateways$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Vpngateways$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Vpngateways$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Vpngateways$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Vpngateways$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Vpngateways$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Vpngateways$Delete extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the VPN gateway to delete.
         */
        vpnGateway?: string;
    }
    export interface Params$Resource$Vpngateways$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * Name of the VPN gateway to return.
         */
        vpnGateway?: string;
    }
    export interface Params$Resource$Vpngateways$Getstatus extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * Name of the VPN gateway to return.
         */
        vpnGateway?: string;
    }
    export interface Params$Resource$Vpngateways$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$VpnGateway;
    }
    export interface Params$Resource$Vpngateways$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Vpngateways$Setlabels extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionSetLabelsRequest;
    }
    export interface Params$Resource$Vpngateways$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Vpntunnels {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves an aggregated list of VPN tunnels.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Vpntunnels$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Vpntunnels$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$VpnTunnelAggregatedList>;
        aggregatedList(params: Params$Resource$Vpntunnels$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Vpntunnels$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$VpnTunnelAggregatedList>, callback: BodyResponseCallback<Schema$VpnTunnelAggregatedList>): void;
        aggregatedList(params: Params$Resource$Vpntunnels$Aggregatedlist, callback: BodyResponseCallback<Schema$VpnTunnelAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$VpnTunnelAggregatedList>): void;
        /**
         * Deletes the specified VpnTunnel resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Vpntunnels$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Vpntunnels$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Vpntunnels$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Vpntunnels$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Vpntunnels$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified VpnTunnel resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Vpntunnels$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Vpntunnels$Get, options?: MethodOptions): GaxiosPromise<Schema$VpnTunnel>;
        get(params: Params$Resource$Vpntunnels$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Vpntunnels$Get, options: MethodOptions | BodyResponseCallback<Schema$VpnTunnel>, callback: BodyResponseCallback<Schema$VpnTunnel>): void;
        get(params: Params$Resource$Vpntunnels$Get, callback: BodyResponseCallback<Schema$VpnTunnel>): void;
        get(callback: BodyResponseCallback<Schema$VpnTunnel>): void;
        /**
         * Creates a VpnTunnel resource in the specified project and region using the data included in the request.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Vpntunnels$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Vpntunnels$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Vpntunnels$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Vpntunnels$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Vpntunnels$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves a list of VpnTunnel resources contained in the specified project and region.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Vpntunnels$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Vpntunnels$List, options?: MethodOptions): GaxiosPromise<Schema$VpnTunnelList>;
        list(params: Params$Resource$Vpntunnels$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Vpntunnels$List, options: MethodOptions | BodyResponseCallback<Schema$VpnTunnelList>, callback: BodyResponseCallback<Schema$VpnTunnelList>): void;
        list(params: Params$Resource$Vpntunnels$List, callback: BodyResponseCallback<Schema$VpnTunnelList>): void;
        list(callback: BodyResponseCallback<Schema$VpnTunnelList>): void;
        /**
         * Sets the labels on a VpnTunnel. To learn more about labels, read the Labeling Resources documentation.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        setLabels(params: Params$Resource$Vpntunnels$Setlabels, options: StreamMethodOptions): GaxiosPromise<Readable>;
        setLabels(params?: Params$Resource$Vpntunnels$Setlabels, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        setLabels(params: Params$Resource$Vpntunnels$Setlabels, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        setLabels(params: Params$Resource$Vpntunnels$Setlabels, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(params: Params$Resource$Vpntunnels$Setlabels, callback: BodyResponseCallback<Schema$Operation>): void;
        setLabels(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns permissions that a caller has on the specified resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        testIamPermissions(params: Params$Resource$Vpntunnels$Testiampermissions, options: StreamMethodOptions): GaxiosPromise<Readable>;
        testIamPermissions(params?: Params$Resource$Vpntunnels$Testiampermissions, options?: MethodOptions): GaxiosPromise<Schema$TestPermissionsResponse>;
        testIamPermissions(params: Params$Resource$Vpntunnels$Testiampermissions, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        testIamPermissions(params: Params$Resource$Vpntunnels$Testiampermissions, options: MethodOptions | BodyResponseCallback<Schema$TestPermissionsResponse>, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(params: Params$Resource$Vpntunnels$Testiampermissions, callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
        testIamPermissions(callback: BodyResponseCallback<Schema$TestPermissionsResponse>): void;
    }
    export interface Params$Resource$Vpntunnels$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Vpntunnels$Delete extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the VpnTunnel resource to delete.
         */
        vpnTunnel?: string;
    }
    export interface Params$Resource$Vpntunnels$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * Name of the VpnTunnel resource to return.
         */
        vpnTunnel?: string;
    }
    export interface Params$Resource$Vpntunnels$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$VpnTunnel;
    }
    export interface Params$Resource$Vpntunnels$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the region for this request.
         */
        region?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export interface Params$Resource$Vpntunnels$Setlabels extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The region for this request.
         */
        region?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$RegionSetLabelsRequest;
    }
    export interface Params$Resource$Vpntunnels$Testiampermissions extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * The name of the region for this request.
         */
        region?: string;
        /**
         * Name or id of the resource for this request.
         */
        resource?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$TestPermissionsRequest;
    }
    export class Resource$Zoneoperations {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Deletes the specified zone-specific Operations resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Zoneoperations$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Zoneoperations$Delete, options?: MethodOptions): GaxiosPromise<void>;
        delete(params: Params$Resource$Zoneoperations$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Zoneoperations$Delete, options: MethodOptions | BodyResponseCallback<void>, callback: BodyResponseCallback<void>): void;
        delete(params: Params$Resource$Zoneoperations$Delete, callback: BodyResponseCallback<void>): void;
        delete(callback: BodyResponseCallback<void>): void;
        /**
         * Retrieves the specified zone-specific Operations resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Zoneoperations$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Zoneoperations$Get, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        get(params: Params$Resource$Zoneoperations$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Zoneoperations$Get, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        get(params: Params$Resource$Zoneoperations$Get, callback: BodyResponseCallback<Schema$Operation>): void;
        get(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves a list of Operation resources contained within the specified zone.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Zoneoperations$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Zoneoperations$List, options?: MethodOptions): GaxiosPromise<Schema$OperationList>;
        list(params: Params$Resource$Zoneoperations$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Zoneoperations$List, options: MethodOptions | BodyResponseCallback<Schema$OperationList>, callback: BodyResponseCallback<Schema$OperationList>): void;
        list(params: Params$Resource$Zoneoperations$List, callback: BodyResponseCallback<Schema$OperationList>): void;
        list(callback: BodyResponseCallback<Schema$OperationList>): void;
        /**
         * Waits for the specified Operation resource to return as `DONE` or for the request to approach the 2 minute deadline, and retrieves the specified Operation resource. This method waits for no more than the 2 minutes and then returns the current state of the operation, which might be `DONE` or still in progress. This method is called on a best-effort basis. Specifically: - In uncommon cases, when the server is overloaded, the request might return before the default deadline is reached, or might return after zero seconds. - If the default deadline is reached, there is no guarantee that the operation is actually done when the method returns. Be prepared to retry if the operation is not `DONE`.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        wait(params: Params$Resource$Zoneoperations$Wait, options: StreamMethodOptions): GaxiosPromise<Readable>;
        wait(params?: Params$Resource$Zoneoperations$Wait, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        wait(params: Params$Resource$Zoneoperations$Wait, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        wait(params: Params$Resource$Zoneoperations$Wait, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        wait(params: Params$Resource$Zoneoperations$Wait, callback: BodyResponseCallback<Schema$Operation>): void;
        wait(callback: BodyResponseCallback<Schema$Operation>): void;
    }
    export interface Params$Resource$Zoneoperations$Delete extends StandardParameters {
        /**
         * Name of the Operations resource to delete.
         */
        operation?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Zoneoperations$Get extends StandardParameters {
        /**
         * Name of the Operations resource to return.
         */
        operation?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Zoneoperations$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         * Name of the zone for request.
         */
        zone?: string;
    }
    export interface Params$Resource$Zoneoperations$Wait extends StandardParameters {
        /**
         * Name of the Operations resource to return.
         */
        operation?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the zone for this request.
         */
        zone?: string;
    }
    export class Resource$Zonequeuedresources {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Retrieves an aggregated list of all of the queued resources in a project across all zones.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        aggregatedList(params: Params$Resource$Zonequeuedresources$Aggregatedlist, options: StreamMethodOptions): GaxiosPromise<Readable>;
        aggregatedList(params?: Params$Resource$Zonequeuedresources$Aggregatedlist, options?: MethodOptions): GaxiosPromise<Schema$QueuedResourcesAggregatedList>;
        aggregatedList(params: Params$Resource$Zonequeuedresources$Aggregatedlist, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        aggregatedList(params: Params$Resource$Zonequeuedresources$Aggregatedlist, options: MethodOptions | BodyResponseCallback<Schema$QueuedResourcesAggregatedList>, callback: BodyResponseCallback<Schema$QueuedResourcesAggregatedList>): void;
        aggregatedList(params: Params$Resource$Zonequeuedresources$Aggregatedlist, callback: BodyResponseCallback<Schema$QueuedResourcesAggregatedList>): void;
        aggregatedList(callback: BodyResponseCallback<Schema$QueuedResourcesAggregatedList>): void;
        /**
         * Cancels a QueuedResource. Only a resource in ACCEPTED state may be cancelled.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        cancel(params: Params$Resource$Zonequeuedresources$Cancel, options: StreamMethodOptions): GaxiosPromise<Readable>;
        cancel(params?: Params$Resource$Zonequeuedresources$Cancel, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        cancel(params: Params$Resource$Zonequeuedresources$Cancel, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        cancel(params: Params$Resource$Zonequeuedresources$Cancel, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        cancel(params: Params$Resource$Zonequeuedresources$Cancel, callback: BodyResponseCallback<Schema$Operation>): void;
        cancel(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Deletes a QueuedResource. For a QueuedResource in ACCEPTED state, call cancel on the resource before deleting, to make sure no VMs have been provisioned and may require cleaning up. For a QueuedResource in PROVISIONING state the request to delete is registered for execution following the provisioning.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        delete(params: Params$Resource$Zonequeuedresources$Delete, options: StreamMethodOptions): GaxiosPromise<Readable>;
        delete(params?: Params$Resource$Zonequeuedresources$Delete, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        delete(params: Params$Resource$Zonequeuedresources$Delete, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        delete(params: Params$Resource$Zonequeuedresources$Delete, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(params: Params$Resource$Zonequeuedresources$Delete, callback: BodyResponseCallback<Schema$Operation>): void;
        delete(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Returns the specified QueuedResource resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Zonequeuedresources$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Zonequeuedresources$Get, options?: MethodOptions): GaxiosPromise<Schema$QueuedResource>;
        get(params: Params$Resource$Zonequeuedresources$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Zonequeuedresources$Get, options: MethodOptions | BodyResponseCallback<Schema$QueuedResource>, callback: BodyResponseCallback<Schema$QueuedResource>): void;
        get(params: Params$Resource$Zonequeuedresources$Get, callback: BodyResponseCallback<Schema$QueuedResource>): void;
        get(callback: BodyResponseCallback<Schema$QueuedResource>): void;
        /**
         * Creates a QueuedResource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        insert(params: Params$Resource$Zonequeuedresources$Insert, options: StreamMethodOptions): GaxiosPromise<Readable>;
        insert(params?: Params$Resource$Zonequeuedresources$Insert, options?: MethodOptions): GaxiosPromise<Schema$Operation>;
        insert(params: Params$Resource$Zonequeuedresources$Insert, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        insert(params: Params$Resource$Zonequeuedresources$Insert, options: MethodOptions | BodyResponseCallback<Schema$Operation>, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(params: Params$Resource$Zonequeuedresources$Insert, callback: BodyResponseCallback<Schema$Operation>): void;
        insert(callback: BodyResponseCallback<Schema$Operation>): void;
        /**
         * Retrieves the list of QueuedResource resources.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Zonequeuedresources$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Zonequeuedresources$List, options?: MethodOptions): GaxiosPromise<Schema$QueuedResourceList>;
        list(params: Params$Resource$Zonequeuedresources$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Zonequeuedresources$List, options: MethodOptions | BodyResponseCallback<Schema$QueuedResourceList>, callback: BodyResponseCallback<Schema$QueuedResourceList>): void;
        list(params: Params$Resource$Zonequeuedresources$List, callback: BodyResponseCallback<Schema$QueuedResourceList>): void;
        list(callback: BodyResponseCallback<Schema$QueuedResourceList>): void;
    }
    export interface Params$Resource$Zonequeuedresources$Aggregatedlist extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.
         */
        includeAllScopes?: boolean;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         *
         */
        serviceProjectNumber?: string;
    }
    export interface Params$Resource$Zonequeuedresources$Cancel extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the QueuedResource to cancel.
         */
        queuedResource?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Zonequeuedresources$Delete extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the QueuedResource to delete.
         */
        queuedResource?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Zonequeuedresources$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the QueuedResource resource to return.
         */
        queuedResource?: string;
        /**
         * Name of the zone for this request.
         */
        zone?: string;
    }
    export interface Params$Resource$Zonequeuedresources$Insert extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
         */
        requestId?: string;
        /**
         * Name of the zone for this request.
         */
        zone?: string;
        /**
         * Request body metadata
         */
        requestBody?: Schema$QueuedResource;
    }
    export interface Params$Resource$Zonequeuedresources$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
        /**
         * Name of the zone for this request.
         */
        zone?: string;
    }
    export class Resource$Zones {
        context: APIRequestContext;
        constructor(context: APIRequestContext);
        /**
         * Returns the specified Zone resource.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        get(params: Params$Resource$Zones$Get, options: StreamMethodOptions): GaxiosPromise<Readable>;
        get(params?: Params$Resource$Zones$Get, options?: MethodOptions): GaxiosPromise<Schema$Zone>;
        get(params: Params$Resource$Zones$Get, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        get(params: Params$Resource$Zones$Get, options: MethodOptions | BodyResponseCallback<Schema$Zone>, callback: BodyResponseCallback<Schema$Zone>): void;
        get(params: Params$Resource$Zones$Get, callback: BodyResponseCallback<Schema$Zone>): void;
        get(callback: BodyResponseCallback<Schema$Zone>): void;
        /**
         * Retrieves the list of Zone resources available to the specified project.
         *
         * @param params - Parameters for request
         * @param options - Optionally override request options, such as `url`, `method`, and `encoding`.
         * @param callback - Optional callback that handles the response.
         * @returns A promise if used with async/await, or void if used with a callback.
         */
        list(params: Params$Resource$Zones$List, options: StreamMethodOptions): GaxiosPromise<Readable>;
        list(params?: Params$Resource$Zones$List, options?: MethodOptions): GaxiosPromise<Schema$ZoneList>;
        list(params: Params$Resource$Zones$List, options: StreamMethodOptions | BodyResponseCallback<Readable>, callback: BodyResponseCallback<Readable>): void;
        list(params: Params$Resource$Zones$List, options: MethodOptions | BodyResponseCallback<Schema$ZoneList>, callback: BodyResponseCallback<Schema$ZoneList>): void;
        list(params: Params$Resource$Zones$List, callback: BodyResponseCallback<Schema$ZoneList>): void;
        list(callback: BodyResponseCallback<Schema$ZoneList>): void;
    }
    export interface Params$Resource$Zones$Get extends StandardParameters {
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Name of the zone resource to return.
         */
        zone?: string;
    }
    export interface Params$Resource$Zones$List extends StandardParameters {
        /**
         * A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request. If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either `=`, `!=`, `\>`, `<`, `<=`, `\>=` or `:`. For example, if you are filtering Compute Engine instances, you can exclude instances named `example-instance` by specifying `name != example-instance`. The `:*` comparison can be used to test whether a key has been defined. For example, to find all objects with `owner` label use: ``` labels.owner:* ``` You can also filter nested fields. For example, you could specify `scheduling.automaticRestart = false` to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based on resource labels. To filter on multiple expressions, provide each separate expression within parentheses. For example: ``` (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ``` By default, each expression is an `AND` expression. However, you can include `AND` and `OR` expressions explicitly. For example: ``` (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND (scheduling.automaticRestart = true) ``` If you want to use a regular expression, use the `eq` (equal) or `ne` (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples: `fieldname eq unquoted literal` `fieldname eq 'single quoted literal'` `fieldname eq "double quoted literal"` `(fieldname1 eq literal) (fieldname2 ne "literal")` The literal value is interpreted as a regular expression using Google RE2 library syntax. The literal value must match the entire field. For example, to filter for instances that do not end with name "instance", you would use `name ne .*instance`. You cannot combine constraints on multiple fields using regular expressions.
         */
        filter?: string;
        /**
         * The maximum number of results per page that should be returned. If the number of available results is larger than `maxResults`, Compute Engine returns a `nextPageToken` that can be used to get the next page of results in subsequent list requests. Acceptable values are `0` to `500`, inclusive. (Default: `500`)
         */
        maxResults?: number;
        /**
         * Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name. You can also sort results in descending order based on the creation timestamp using `orderBy="creationTimestamp desc"`. This sorts results based on the `creationTimestamp` field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first. Currently, only sorting by `name` or `creationTimestamp desc` is supported.
         */
        orderBy?: string;
        /**
         * Specifies a page token to use. Set `pageToken` to the `nextPageToken` returned by a previous list request to get the next page of results.
         */
        pageToken?: string;
        /**
         * Project ID for this request.
         */
        project?: string;
        /**
         * Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
         */
        returnPartialSuccess?: boolean;
    }
    export {};
}
